
create table classroom
	(building		varchar(15),
	 room_number		varchar(7),
	 capacity		numeric(4,0),
	 primary key (building, room_number)
	);

create table department
	(dept_name		varchar(20),
	 building		varchar(15),
	 budget		        numeric(12,2) check (budget > 0),
	 primary key (dept_name)
	);

create table course
	(course_id		varchar(8),
	 title			varchar(50),
	 dept_name		varchar(20) NULL,
	 credits		numeric(2,0) check (credits > 0),
	 primary key (course_id),
    FOREIGN KEY (dept_name)
    REFERENCES `department` (dept_name)
    ON DELETE SET NULL
--    ON UPDATE NO ACTION
--    foreign key (dept_name) references department
-- on delete set null
   );

create table instructor
	(ID			varchar(5),
	 name			varchar(20) not null,
	 dept_name		varchar(20),
	 salary			numeric(8,2) check (salary > 29000),
	 primary key (ID),
	 foreign key (dept_name) references department (dept_name)
		on delete set null
	);

create table section
	(course_id		varchar(8),
         sec_id			varchar(8),
	 semester		varchar(6)
		check (semester in ('Fall', 'Winter', 'Spring', 'Summer')),
	 year			numeric(4,0) check (year > 1701 and year < 2100),
	 building		varchar(15),
	 room_number		varchar(7),
	 time_slot_id		varchar(4),
	 primary key (course_id, sec_id, semester, year),
	 foreign key (course_id) references course (course_id)
		on delete cascade,
	 foreign key (building, room_number) references classroom (building, room_number)
		on delete set null
	);

create table teaches
	(ID			varchar(5),
	 course_id		varchar(8),
	 sec_id			varchar(8),
	 semester		varchar(6),
	 year			numeric(4,0),
	 primary key (ID, course_id, sec_id, semester, year),
	 foreign key (course_id,sec_id, semester, year) references section (course_id, sec_id, semester, year)
		on delete cascade,
	 foreign key (ID) references instructor (ID)
		on delete cascade
	);

create table student
	(ID			varchar(5),
	 name			varchar(20) not null,
	 dept_name		varchar(20),
	 tot_cred		numeric(3,0) check (tot_cred >= 0),
	 primary key (ID),
	 foreign key (dept_name) references department (dept_name)
		on delete set null
	);

create table takes
	(ID			varchar(5),
	 course_id		varchar(8),
	 sec_id			varchar(8),
	 semester		varchar(6),
	 year			numeric(4,0),
	 grade		        varchar(2),
	 primary key (ID, course_id, sec_id, semester, year),
	 foreign key (course_id,sec_id, semester, year) references section (course_id, sec_id, semester, year)
		on delete cascade,
	 foreign key (ID) references student (ID)
		on delete cascade
	);

create table advisor
	(s_ID			varchar(5),
	 i_ID			varchar(5),
	 primary key (s_ID),
	 foreign key (i_ID) references instructor (ID)
		on delete set null,
	 foreign key (s_ID) references student (ID)
		on delete cascade
	);

create table time_slot
	(time_slot_id		varchar(4),
	 day			varchar(1),
	 start_hr		numeric(2) check (start_hr >= 0 and start_hr < 24),
	 start_min		numeric(2) check (start_min >= 0 and start_min < 60),
	 end_hr			numeric(2) check (end_hr >= 0 and end_hr < 24),
	 end_min		numeric(2) check (end_min >= 0 and end_min < 60),
	 primary key (time_slot_id, day, start_hr, start_min)
	);

create table prereq
	(course_id		varchar(8),
	 prereq_id		varchar(8),
	 primary key (course_id, prereq_id),
	 foreign key (course_id) references course (course_id)
		on delete cascade,
	 foreign key (prereq_id) references course (course_id)
	);


	delete from prereq;
	delete from time_slot;
	delete from advisor;
	delete from takes;
	delete from student;
	delete from teaches;
	delete from section;
	delete from instructor;
	delete from course;
	delete from department;
	delete from classroom;
	insert into time_slot values ( 'A', 'M', 8, 0, 8, 50);
	insert into time_slot values ( 'A', 'W', 8, 0, 8, 50);
	insert into time_slot values ( 'A', 'F', 8, 0, 8, 50);
	insert into time_slot values ( 'B', 'M', 9, 0, 9, 50);
	insert into time_slot values ( 'B', 'W', 9, 0, 9, 50);
	insert into time_slot values ( 'B', 'F', 9, 0, 9, 50);
	insert into time_slot values ( 'C', 'M', 11, 0, 11, 50);
	insert into time_slot values ( 'C', 'W', 11, 0, 11, 50);
	insert into time_slot values ( 'C', 'F', 11, 0, 11, 50);
	insert into time_slot values ( 'D', 'M', 13, 0, 13, 50);
	insert into time_slot values ( 'D', 'W', 13, 0, 13, 50);
	insert into time_slot values ( 'D', 'F', 13, 0, 13, 50);
	insert into time_slot values ( 'E', 'T', 10, 30, 11, 45);
	insert into time_slot values ( 'E', 'R', 10, 30, 11, 45);
	insert into time_slot values ( 'F', 'T', 14, 30, 15, 45);
	insert into time_slot values ( 'F', 'R', 14, 30, 15, 45);
	insert into time_slot values ( 'G', 'M', 16, 0, 16, 50);
	insert into time_slot values ( 'G', 'W', 16, 0, 16, 50);
	insert into time_slot values ( 'G', 'F', 16, 0, 16, 50);
	insert into time_slot values ( 'H', 'W', 10, 0, 12, 30);
	insert into classroom values('Lamberton', 134, 10);
	insert into classroom values('Chandler', 375, 10);
	insert into classroom values('Fairchild', 145, 27);
	insert into classroom values('Nassau', 45, 92);
	insert into classroom values('Grace', 40, 34);
	insert into classroom values('Whitman', 134, 120);
	insert into classroom values('Lamberton', 143, 10);
	insert into classroom values('Taylor', 812, 115);
	insert into classroom values('Saucon', 113, 109);
	insert into classroom values('Painter', 86, 97);
	insert into classroom values('Alumni', 547, 26);
	insert into classroom values('Alumni', 143, 47);
	insert into classroom values('Drown', 757, 18);
	insert into classroom values('Saucon', 180, 15);
	insert into classroom values('Whitman', 434, 32);
	insert into classroom values('Saucon', 844, 24);
	insert into classroom values('Bronfman', 700, 12);
	insert into classroom values('Polya', 808, 28);
	insert into classroom values('Gates', 707, 65);
	insert into classroom values('Gates', 314, 10);
	insert into classroom values('Main', 45, 30);
	insert into classroom values('Taylor', 183, 71);
	insert into classroom values('Power', 972, 10);
	insert into classroom values('Garfield', 119, 59);
	insert into classroom values('Rathbone', 261, 60);
	insert into classroom values('Stabler', 105, 113);
	insert into classroom values('Power', 717, 12);
	insert into classroom values('Main', 425, 22);
	insert into classroom values('Lambeau', 348, 51);
	insert into classroom values('Chandler', 804, 11);
	insert into department values('Civil Eng.', 'Chandler', 255041.46);
	insert into department values('Biology', 'Candlestick', 647610.55);
	insert into department values('History', 'Taylor', 699140.86);
	insert into department values('Physics', 'Wrigley', 942162.76);
	insert into department values('Marketing', 'Lambeau', 210627.58);
	insert into department values('Pol. Sci.', 'Whitman', 573745.09);
	insert into department values('English', 'Palmer', 611042.66);
	insert into department values('Accounting', 'Saucon', 441840.92);
	insert into department values('Comp. Sci.', 'Lamberton', 106378.69);
	insert into department values('Languages', 'Linderman', 601283.60);
	insert into department values('Finance', 'Candlestick', 866831.75);
	insert into department values('Geology', 'Palmer', 406557.93);
	insert into department values('Cybernetics', 'Mercer', 794541.46);
	insert into department values('Astronomy', 'Taylor', 617253.94);
	insert into department values('Athletics', 'Bronfman', 734550.70);
	insert into department values('Statistics', 'Taylor', 395051.74);
	insert into department values('Psychology', 'Thompson', 848175.04);
	insert into department values('Math', 'Brodhead', 777605.11);
	insert into department values('Elec. Eng.', 'Main', 276527.61);
	insert into department values('Mech. Eng.', 'Rauch', 520350.65);
	insert into course values('787', 'C  Programming', 'Mech. Eng.', 4);
	insert into course values('238', 'The Music of Donovan', 'Mech. Eng.', 3);
	insert into course values('608', 'Electron Microscopy', 'Mech. Eng.', 3);
	insert into course values('539', 'International Finance', 'Comp. Sci.', 3);
	insert into course values('278', 'Greek Tragedy', 'Statistics', 4);
	insert into course values('972', 'Greek Tragedy', 'Psychology', 4);
	insert into course values('391', 'Virology', 'Biology', 3);
	insert into course values('814', 'Compiler Design', 'Elec. Eng.', 3);
	insert into course values('272', 'Geology', 'Mech. Eng.', 3);
	insert into course values('612', 'Mobile Computing', 'Physics', 3);
	insert into course values('237', 'Surfing', 'Cybernetics', 3);
	insert into course values('313', 'International Trade', 'Marketing', 3);
	insert into course values('887', 'Latin', 'Mech. Eng.', 3);
	insert into course values('328', 'Composition and Literature', 'Cybernetics', 3);
	insert into course values('984', 'Music of the 50s', 'History', 3);
	insert into course values('241', 'Biostatistics', 'Geology', 3);
	insert into course values('338', 'Graph Theory', 'Psychology', 3);
	insert into course values('400', 'Visual BASIC', 'Psychology', 4);
	insert into course values('760', 'How to Groom your Cat', 'Accounting', 3);
	insert into course values('629', 'Finite Element Analysis', 'Cybernetics', 3);
	insert into course values('762', 'The Monkeys', 'History', 4);
	insert into course values('242', 'Rock and Roll', 'Marketing', 3);
	insert into course values('482', 'FOCAL Programming', 'Psychology', 4);
	insert into course values('581', 'Calculus', 'Pol. Sci.', 4);
	insert into course values('843', 'Environmental Law', 'Math', 4);
	insert into course values('679', 'The Beatles', 'Math', 3);
	insert into course values('704', 'Marine Mammals', 'Geology', 4);
	insert into course values('774', 'Game Programming', 'Cybernetics', 4);
	insert into course values('591', 'Shakespeare', 'Pol. Sci.', 4);
	insert into course values('319', 'World History', 'Finance', 4);
	insert into course values('960', 'Tort Law', 'Civil Eng.', 3);
	insert into course values('274', 'Corporate Law', 'Comp. Sci.', 4);
	insert into course values('426', 'Video Gaming', 'Finance', 3);
	insert into course values('852', 'World History', 'Athletics', 4);
	insert into course values('408', 'Bankruptcy', 'Accounting', 3);
	insert into course values('808', 'Organic Chemistry', 'English', 4);
	insert into course values('902', 'Existentialism', 'Finance', 3);
	insert into course values('730', 'Quantum Mechanics', 'Elec. Eng.', 4);
	insert into course values('362', 'Embedded Systems', 'Finance', 4);
	insert into course values('341', 'Quantum Mechanics', 'Cybernetics', 3);
	insert into course values('582', 'Marine Mammals', 'Cybernetics', 3);
	insert into course values('867', 'The IBM 360 Architecture', 'History', 3);
	insert into course values('169', 'Marine Mammals', 'Elec. Eng.', 3);
	insert into course values('680', 'Electricity and Magnetism', 'Civil Eng.', 3);
	insert into course values('227', 'Elastic Structures', 'Languages', 4);
	insert into course values('991', 'Transaction Processing', 'Psychology', 3);
	insert into course values('366', 'Computational Biology', 'English', 3);
	insert into course values('376', 'Cost Accounting', 'Physics', 4);
	insert into course values('489', 'Journalism', 'Astronomy', 4);
	insert into course values('663', 'Geology', 'Psychology', 3);
	insert into course values('461', 'Physical Chemistry', 'Math', 3);
	insert into course values('105', 'Image Processing', 'Astronomy', 3);
	insert into course values('407', 'Industrial Organization', 'Languages', 4);
	insert into course values('254', 'Security', 'Cybernetics', 3);
	insert into course values('998', 'Immunology', 'Civil Eng.', 4);
	insert into course values('457', 'Systems Software', 'History', 3);
	insert into course values('401', 'Sanitary Engineering', 'Athletics', 4);
	insert into course values('127', 'Thermodynamics', 'Geology', 3);
	insert into course values('399', 'RPG Programming', 'Pol. Sci.', 4);
	insert into course values('949', 'Japanese', 'Comp. Sci.', 3);
	insert into course values('496', 'Aquatic Chemistry', 'Cybernetics', 3);
	insert into course values('334', 'International Trade', 'Athletics', 3);
	insert into course values('544', 'Differential Geometry', 'Statistics', 3);
	insert into course values('451', 'Database System Concepts', 'Pol. Sci.', 4);
	insert into course values('190', 'Romantic Literature', 'Civil Eng.', 3);
	insert into course values('630', 'Religion', 'English', 3);
	insert into course values('761', 'Existentialism', 'Athletics', 3);
	insert into course values('804', 'Introduction to Burglary', 'Cybernetics', 4);
	insert into course values('781', 'Compiler Design', 'Finance', 4);
	insert into course values('805', 'Composition and Literature', 'Statistics', 4);
	insert into course values('318', 'Geology', 'Cybernetics', 3);
	insert into course values('353', 'Operating Systems', 'Psychology', 3);
	insert into course values('394', 'C  Programming', 'Athletics', 3);
	insert into course values('137', 'Manufacturing', 'Finance', 3);
	insert into course values('192', 'Drama', 'Languages', 4);
	insert into course values('681', 'Medieval Civilization or Lack Thereof', 'English', 3);
	insert into course values('377', 'Differential Geometry', 'Astronomy', 4);
	insert into course values('959', 'Bacteriology', 'Physics', 4);
	insert into course values('235', 'International Trade', 'Math', 3);
	insert into course values('421', 'Aquatic Chemistry', 'Athletics', 4);
	insert into course values('647', 'Service-Oriented Architectures', 'Comp. Sci.', 4);
	insert into course values('598', 'Number Theory', 'Accounting', 4);
	insert into course values('858', 'Sailing', 'Math', 4);
	insert into course values('487', 'Physical Chemistry', 'History', 3);
	insert into course values('133', 'Antidisestablishmentarianism in Modern America', 'Biology', 4);
	insert into course values('267', 'Hydraulics', 'Physics', 4);
	insert into course values('200', 'The Music of the Ramones', 'Accounting', 4);
	insert into course values('664', 'Elastic Structures', 'English', 3);
	insert into course values('599', 'Mechanics', 'Psychology', 4);
	insert into course values('456', 'Hebrew', 'Civil Eng.', 3);
	insert into course values('558', 'Environmental Law', 'Psychology', 3);
	insert into course values('919', 'Computability Theory', 'Math', 3);
	insert into course values('546', 'Creative Writing', 'Mech. Eng.', 4);
	insert into course values('969', 'The Monkeys', 'Astronomy', 4);
	insert into course values('877', 'Composition and Literature', 'Biology', 4);
	insert into course values('337', 'Differential Geometry', 'Statistics', 3);
	insert into course values('983', 'Virology', 'Languages', 4);
	insert into course values('603', 'Care and Feeding of Cats', 'Statistics', 3);
	insert into course values('747', 'International Practicum', 'Comp. Sci.', 4);
	insert into course values('659', 'Geology', 'Math', 4);
	insert into course values('559', 'Martian History', 'Biology', 3);
	insert into course values('403', 'Immunology', 'Biology', 3);
	insert into course values('436', 'Stream Processing', 'Physics', 4);
	insert into course values('656', 'Groups and Rings', 'Civil Eng.', 4);
	insert into course values('731', 'The Music of Donovan', 'Physics', 4);
	insert into course values('820', 'Assembly Language Programming', 'Cybernetics', 3);
	insert into course values('898', 'Petroleum Engineering', 'Marketing', 4);
	insert into course values('545', 'International Practicum', 'History', 3);
	insert into course values('893', 'Systems Software', 'Cybernetics', 3);
	insert into course values('818', 'Environmental Law', 'Astronomy', 4);
	insert into course values('618', 'Thermodynamics', 'English', 4);
	insert into course values('416', 'Data Mining', 'Accounting', 3);
	insert into course values('716', 'Medieval Civilization or Lack Thereof', 'Languages', 4);
	insert into course values('130', 'Differential Geometry', 'Physics', 3);
	insert into course values('476', 'International Communication', 'Astronomy', 4);
	insert into course values('101', 'Diffusion and Phase Transformation', 'Mech. Eng.', 3);
	insert into course values('123', 'Differential Equations', 'Mech. Eng.', 3);
	insert into course values('209', 'International Trade', 'Cybernetics', 4);
	insert into course values('352', 'Compiler Design', 'Psychology', 4);
	insert into course values('393', 'Aerodynamics', 'Languages', 3);
	insert into course values('795', 'Death and Taxes', 'Marketing', 3);
	insert into course values('577', 'The Music of Dave Edmunds', 'Elec. Eng.', 3);
	insert into course values('584', 'Computability Theory', 'Comp. Sci.', 3);
	insert into course values('864', 'Heat Transfer', 'Geology', 3);
	insert into course values('594', 'Cognitive Psychology', 'Finance', 3);
	insert into course values('802', 'African History', 'Cybernetics', 3);
	insert into course values('692', 'Cat Herding', 'Athletics', 3);
	insert into course values('258', 'Colloid and Surface Chemistry', 'Math', 3);
	insert into course values('748', 'Tort Law', 'Cybernetics', 4);
	insert into course values('770', 'European History', 'Pol. Sci.', 3);
	insert into course values('340', 'Corporate Law', 'History', 3);
	insert into course values('158', 'Elastic Structures', 'Cybernetics', 3);
	insert into course values('276', 'Game Design', 'Comp. Sci.', 4);
	insert into course values('626', 'Multimedia Design', 'History', 4);
	insert into course values('696', 'Heat Transfer', 'Marketing', 4);
	insert into course values('239', 'The Music of the Ramones', 'Physics', 4);
	insert into course values('962', 'Animal Behavior', 'Psychology', 3);
	insert into course values('527', 'Graphics', 'Finance', 3);
	insert into course values('275', 'Romantic Literature', 'Languages', 3);
	insert into course values('549', 'Banking and Finance', 'Astronomy', 3);
	insert into course values('974', 'Astronautics', 'Accounting', 3);
	insert into course values('897', 'How to Succeed in Business Without Really Trying', 'Languages', 4);
	insert into course values('359', 'Game Programming', 'Comp. Sci.', 4);
	insert into course values('345', 'Race Car Driving', 'Accounting', 4);
	insert into course values('371', 'Milton', 'Finance', 3);
	insert into course values('284', 'Topology', 'Comp. Sci.', 4);
	insert into course values('642', 'Video Gaming', 'Psychology', 3);
	insert into course values('769', 'Logic', 'Elec. Eng.', 4);
	insert into course values('947', 'Real-Time Database Systems', 'Accounting', 3);
	insert into course values('265', 'Thermal Physics', 'Cybernetics', 4);
	insert into course values('927', 'Differential Geometry', 'Cybernetics', 4);
	insert into course values('694', 'Optics', 'Math', 3);
	insert into course values('580', 'The Music of Dave Edmunds', 'Physics', 4);
	insert into course values('324', 'Ponzi Schemes', 'Civil Eng.', 3);
	insert into course values('349', 'Networking', 'Finance', 4);
	insert into course values('392', 'Recursive Function Theory', 'Astronomy', 4);
	insert into course values('735', 'Greek Tragedy', 'Geology', 3);
	insert into course values('702', 'Arabic', 'Biology', 3);
	insert into course values('458', 'The Renaissance', 'Civil Eng.', 4);
	insert into course values('348', 'Compiler Design', 'Elec. Eng.', 3);
	insert into course values('500', 'Networking', 'Astronomy', 3);
	insert into course values('494', 'Automobile Mechanics', 'Pol. Sci.', 4);
	insert into course values('411', 'Music of the 80s', 'Mech. Eng.', 4);
	insert into course values('493', 'Music of the 50s', 'Geology', 3);
	insert into course values('396', 'C  Programming', 'Languages', 3);
	insert into course values('810', 'Mobile Computing', 'Geology', 3);
	insert into course values('631', 'Plasma Physics', 'Elec. Eng.', 4);
	insert into course values('486', 'Accounting', 'Geology', 3);
	insert into course values('963', 'Groups and Rings', 'Languages', 4);
	insert into course values('445', 'Biostatistics', 'Finance', 3);
	insert into course values('292', 'Electron Microscopy', 'English', 4);
	insert into course values('830', 'Sensor Networks', 'Astronomy', 4);
	insert into course values('604', 'UNIX System Programmming', 'Statistics', 4);
	insert into course values('857', 'UNIX System Programmming', 'Geology', 4);
	insert into course values('304', 'Music 2 New for your Instructor', 'Finance', 4);
	insert into course values('922', 'Microeconomics', 'Finance', 4);
	insert into course values('571', 'Plastics', 'Comp. Sci.', 4);
	insert into course values('628', 'Existentialism', 'Accounting', 3);
	insert into course values('841', 'Fractal Geometry', 'Mech. Eng.', 4);
	insert into course values('586', 'Image Processing', 'Finance', 4);
	insert into course values('139', 'Number Theory', 'English', 4);
	insert into course values('666', 'Multivariable Calculus', 'Accounting', 3);
	insert into course values('443', 'Journalism', 'Physics', 4);
	insert into course values('195', 'Numerical Methods', 'Geology', 4);
	insert into course values('634', 'Astronomy', 'Cybernetics', 4);
	insert into course values('224', 'International Finance', 'Athletics', 3);
	insert into course values('791', 'Operating Systems', 'Marketing', 3);
	insert into course values('875', 'Bioinformatics', 'Cybernetics', 3);
	insert into course values('958', 'Fiction Writing', 'Mech. Eng.', 3);
	insert into course values('415', 'Numerical Methods', 'Biology', 3);
	insert into course values('442', 'Strength of Materials', 'Athletics', 3);
	insert into course values('468', 'Fractal Geometry', 'Civil Eng.', 4);
	insert into course values('270', 'Music of the 90s', 'Math', 4);
	insert into course values('966', 'Sanitary Engineering', 'History', 3);
	insert into course values('793', 'Decison Support Systems', 'Civil Eng.', 3);
	insert into course values('236', 'Design and Analysis of Algorithms', 'Mech. Eng.', 3);
	insert into course values('792', 'Image Processing', 'Accounting', 3);
	insert into course values('561', 'The Music of Donovan', 'Elec. Eng.', 4);
	insert into course values('344', 'Quantum Mechanics', 'Accounting', 4);
	insert into course values('780', 'Geology', 'Psychology', 3);
	insert into instructor values('63395', 'McKinnon', 'Cybernetics', 94333.99);
	insert into instructor values('78699', 'Pingr', 'Statistics', 59303.62);
	insert into instructor values('96895', 'Mird', 'Marketing', 119921.41);
	insert into instructor values('4233', 'Luo', 'English', 88791.45);
	insert into instructor values('4034', 'Murata', 'Athletics', 61387.56);
	insert into instructor values('50885', 'Konstantinides', 'Languages', 32570.50);
	insert into instructor values('79653', 'Levine', 'Elec. Eng.', 89805.83);
	insert into instructor values('50330', 'Shuming', 'Physics', 108011.81);
	insert into instructor values('80759', 'Queiroz', 'Biology', 45538.32);
	insert into instructor values('73623', 'Sullivan', 'Elec. Eng.', 90038.09);
	insert into instructor values('97302', 'Bertolino', 'Mech. Eng.', 51647.57);
	insert into instructor values('57180', 'Hau', 'Accounting', 43966.29);
	insert into instructor values('74420', 'Voronina', 'Physics', 121141.99);
	insert into instructor values('35579', 'Soisalon-Soininen', 'Psychology', 62579.61);
	insert into instructor values('31955', 'Moreira', 'Accounting', 71351.42);
	insert into instructor values('37687', 'Arias', 'Statistics', 104563.38);
	insert into instructor values('6569', 'Mingoz', 'Finance', 105311.38);
	insert into instructor values('16807', 'Yazdi', 'Athletics', 98333.65);
	insert into instructor values('14365', 'Lembr', 'Accounting', 32241.56);
	insert into instructor values('90643', 'Choll', 'Statistics', 57807.09);
	insert into instructor values('81991', 'Valtchev', 'Biology', 77036.18);
	insert into instructor values('95030', 'Arinb', 'Statistics', 54805.11);
	insert into instructor values('15347', 'Bawa', 'Athletics', 72140.88);
	insert into instructor values('74426', 'Kenje', 'Marketing', 106554.73);
	insert into instructor values('42782', 'Vicentino', 'Elec. Eng.', 34272.67);
	insert into instructor values('58558', 'Dusserre', 'Marketing', 66143.25);
	insert into instructor values('63287', 'Jaekel', 'Athletics', 103146.87);
	insert into instructor values('59795', 'Desyl', 'Languages', 48803.38);
	insert into instructor values('22591', 'DAgostino', 'Psychology', 59706.49);
	insert into instructor values('48570', 'Sarkar', 'Pol. Sci.', 87549.80);
	insert into instructor values('79081', 'Ullman ', 'Accounting', 47307.10);
	insert into instructor values('52647', 'Bancilhon', 'Pol. Sci.', 87958.01);
	insert into instructor values('25946', 'Liley', 'Languages', 90891.69);
	insert into instructor values('36897', 'Morris', 'Marketing', 43770.36);
	insert into instructor values('72553', 'Yin', 'English', 46397.59);
	insert into instructor values('3199', 'Gustafsson', 'Elec. Eng.', 82534.37);
	insert into instructor values('34175', 'Bondi', 'Comp. Sci.', 115469.11);
	insert into instructor values('48507', 'Lent', 'Mech. Eng.', 107978.47);
	insert into instructor values('65931', 'Pimenta', 'Cybernetics', 79866.95);
	insert into instructor values('3335', 'Bourrier', 'Comp. Sci.', 80797.83);
	insert into instructor values('64871', 'Gutierrez', 'Statistics', 45310.53);
	insert into instructor values('95709', 'Sakurai', 'English', 118143.98);
	insert into instructor values('43779', 'Romero', 'Astronomy', 79070.08);
	insert into instructor values('77346', 'Mahmoud', 'Geology', 99382.59);
	insert into instructor values('28097', 'Kean', 'English', 35023.18);
	insert into instructor values('90376', 'Bietzk', 'Cybernetics', 117836.50);
	insert into instructor values('28400', 'Atanassov', 'Statistics', 84982.92);
	insert into instructor values('41930', 'Tung', 'Athletics', 50482.03);
	insert into instructor values('19368', 'Wieland', 'Pol. Sci.', 124651.41);
	insert into instructor values('99052', 'Dale', 'Cybernetics', 93348.83);
	insert into section values('313', '1', 'Fall', 2010, 'Chandler', '804', 'N');
	insert into section values('747', '1', 'Spring', 2004, 'Gates', '314', 'K');
	insert into section values('443', '1', 'Spring', 2010, 'Whitman', '434', 'O');
	insert into section values('893', '1', 'Fall', 2007, 'Fairchild', '145', 'B');
	insert into section values('663', '1', 'Spring', 2005, 'Fairchild', '145', 'D');
	insert into section values('457', '1', 'Spring', 2001, 'Saucon', '844', 'D');
	insert into section values('445', '1', 'Spring', 2001, 'Alumni', '547', 'J');
	insert into section values('559', '1', 'Fall', 2002, 'Lamberton', '134', 'J');
	insert into section values('239', '1', 'Fall', 2006, 'Taylor', '183', 'C');
	insert into section values('802', '1', 'Spring', 2003, 'Saucon', '113', 'J');
	insert into section values('158', '1', 'Fall', 2008, 'Whitman', '434', 'F');
	insert into section values('735', '1', 'Spring', 2003, 'Drown', '757', 'D');
	insert into section values('237', '1', 'Spring', 2008, 'Power', '717', 'D');
	insert into section values('338', '1', 'Spring', 2007, 'Fairchild', '145', 'G');
	insert into section values('376', '1', 'Fall', 2006, 'Power', '717', 'K');
	insert into section values('927', '1', 'Fall', 2002, 'Saucon', '180', 'F');
	insert into section values('692', '1', 'Spring', 2010, 'Taylor', '183', 'I');
	insert into section values('867', '1', 'Fall', 2006, 'Taylor', '183', 'E');
	insert into section values('561', '1', 'Fall', 2006, 'Main', '45', 'L');
	insert into section values('604', '1', 'Spring', 2009, 'Bronfman', '700', 'N');
	insert into section values('974', '1', 'Fall', 2003, 'Polya', '808', 'H');
	insert into section values('959', '1', 'Fall', 2006, 'Saucon', '180', 'M');
	insert into section values('702', '1', 'Spring', 2001, 'Saucon', '113', 'O');
	insert into section values('631', '1', 'Spring', 2007, 'Taylor', '183', 'E');
	insert into section values('334', '1', 'Fall', 2009, 'Taylor', '812', 'O');
	insert into section values('274', '1', 'Fall', 2002, 'Main', '425', 'N');
	insert into section values('366', '1', 'Fall', 2005, 'Saucon', '844', 'O');
	insert into section values('545', '1', 'Fall', 2001, 'Saucon', '180', 'P');
	insert into section values('486', '1', 'Fall', 2009, 'Whitman', '134', 'K');
	insert into section values('426', '1', 'Spring', 2006, 'Lamberton', '134', 'G');
	insert into section values('258', '1', 'Fall', 2007, 'Main', '45', 'K');
	insert into section values('972', '1', 'Spring', 2009, 'Taylor', '183', 'J');
	insert into section values('349', '1', 'Spring', 2008, 'Saucon', '113', 'K');
	insert into section values('415', '1', 'Fall', 2010, 'Lamberton', '134', 'D');
	insert into section values('137', '1', 'Spring', 2002, 'Fairchild', '145', 'I');
	insert into section values('304', '1', 'Fall', 2009, 'Lamberton', '143', 'H');
	insert into section values('468', '1', 'Fall', 2005, 'Lambeau', '348', 'J');
	insert into section values('748', '1', 'Fall', 2003, 'Saucon', '180', 'L');
	insert into section values('694', '1', 'Fall', 2002, 'Alumni', '143', 'O');
	insert into section values('345', '1', 'Spring', 2008, 'Taylor', '183', 'A');
	insert into section values('352', '1', 'Spring', 2006, 'Lambeau', '348', 'M');
	insert into section values('581', '1', 'Spring', 2005, 'Alumni', '547', 'G');
	insert into section values('493', '1', 'Spring', 2010, 'Lamberton', '134', 'H');
	insert into section values('795', '1', 'Spring', 2004, 'Lamberton', '143', 'D');
	insert into section values('793', '1', 'Spring', 2002, 'Nassau', '45', 'F');
	insert into section values('237', '2', 'Fall', 2009, 'Fairchild', '145', 'J');
	insert into section values('362', '1', 'Fall', 2005, 'Lamberton', '143', 'I');
	insert into section values('642', '1', 'Fall', 2004, 'Saucon', '113', 'D');
	insert into section values('808', '1', 'Fall', 2003, 'Polya', '808', 'M');
	insert into section values('679', '1', 'Spring', 2010, 'Saucon', '844', 'D');
	insert into section values('629', '1', 'Spring', 2003, 'Stabler', '105', 'F');
	insert into section values('400', '1', 'Spring', 2007, 'Lambeau', '348', 'M');
	insert into section values('599', '1', 'Spring', 2003, 'Chandler', '804', 'D');
	insert into section values('760', '1', 'Spring', 2004, 'Garfield', '119', 'A');
	insert into section values('843', '1', 'Fall', 2010, 'Fairchild', '145', 'J');
	insert into section values('200', '1', 'Spring', 2007, 'Saucon', '180', 'D');
	insert into section values('443', '2', 'Spring', 2002, 'Gates', '707', 'K');
	insert into section values('612', '1', 'Fall', 2007, 'Lamberton', '143', 'G');
	insert into section values('169', '1', 'Spring', 2007, 'Gates', '314', 'A');
	insert into section values('791', '1', 'Spring', 2006, 'Polya', '808', 'H');
	insert into section values('867', '2', 'Fall', 2010, 'Lamberton', '134', 'M');
	insert into section values('489', '1', 'Fall', 2007, 'Lamberton', '143', 'D');
	insert into section values('158', '2', 'Spring', 2008, 'Taylor', '812', 'D');
	insert into section values('242', '1', 'Fall', 2009, 'Fairchild', '145', 'C');
	insert into section values('960', '1', 'Fall', 2009, 'Lamberton', '134', 'J');
	insert into section values('421', '1', 'Fall', 2004, 'Gates', '707', 'E');
	insert into section values('105', '1', 'Fall', 2009, 'Chandler', '375', 'C');
	insert into section values('591', '1', 'Spring', 2005, 'Saucon', '180', 'F');
	insert into section values('192', '1', 'Fall', 2002, 'Polya', '808', 'B');
	insert into section values('362', '2', 'Fall', 2006, 'Alumni', '547', 'A');
	insert into section values('270', '1', 'Spring', 2010, 'Power', '717', 'M');
	insert into section values('461', '1', 'Fall', 2002, 'Main', '425', 'P');
	insert into section values('704', '1', 'Spring', 2008, 'Taylor', '812', 'E');
	insert into section values('626', '1', 'Fall', 2006, 'Lamberton', '143', 'B');
	insert into section values('105', '2', 'Fall', 2002, 'Taylor', '183', 'C');
	insert into section values('696', '1', 'Spring', 2002, 'Saucon', '180', 'E');
	insert into section values('962', '1', 'Spring', 2008, 'Nassau', '45', 'L');
	insert into section values('362', '3', 'Spring', 2008, 'Bronfman', '700', 'L');
	insert into section values('852', '1', 'Spring', 2008, 'Gates', '707', 'F');
	insert into section values('949', '1', 'Fall', 2007, 'Saucon', '180', 'B');
	insert into section values('482', '1', 'Fall', 2005, 'Whitman', '434', 'H');
	insert into section values('527', '1', 'Fall', 2004, 'Saucon', '113', 'M');
	insert into section values('476', '1', 'Fall', 2010, 'Drown', '757', 'C');
	insert into section values('991', '1', 'Spring', 2008, 'Lamberton', '134', 'J');
	insert into section values('408', '1', 'Spring', 2007, 'Taylor', '812', 'C');
	insert into section values('319', '1', 'Spring', 2003, 'Rathbone', '261', 'E');
	insert into section values('400', '2', 'Fall', 2003, 'Main', '425', 'O');
	insert into section values('401', '1', 'Fall', 2003, 'Saucon', '180', 'A');
	insert into section values('960', '2', 'Fall', 2006, 'Power', '717', 'M');
	insert into section values('571', '1', 'Spring', 2004, 'Power', '972', 'I');
	insert into section values('468', '2', 'Fall', 2007, 'Power', '717', 'L');
	insert into section values('735', '2', 'Spring', 2010, 'Taylor', '183', 'D');
	insert into section values('169', '2', 'Fall', 2002, 'Drown', '757', 'L');
	insert into section values('496', '1', 'Fall', 2001, 'Taylor', '812', 'I');
	insert into section values('200', '2', 'Fall', 2002, 'Chandler', '375', 'D');
	insert into section values('875', '1', 'Spring', 2005, 'Power', '717', 'P');
	insert into section values('603', '1', 'Fall', 2003, 'Taylor', '812', 'P');
	insert into section values('408', '2', 'Spring', 2003, 'Taylor', '183', 'J');
	insert into section values('338', '2', 'Spring', 2006, 'Stabler', '105', 'J');
	insert into section values('864', '1', 'Spring', 2006, 'Power', '972', 'D');
	insert into teaches values('34175', '747', '1', 'Spring', 2004);
	insert into teaches values('3199', '169', '1', 'Spring', 2007);
	insert into teaches values('6569', '445', '1', 'Spring', 2001);
	insert into teaches values('28097', '808', '1', 'Fall', 2003);
	insert into teaches values('22591', '962', '1', 'Spring', 2008);
	insert into teaches values('90376', '158', '1', 'Fall', 2008);
	insert into teaches values('3199', '561', '1', 'Fall', 2006);
	insert into teaches values('34175', '274', '1', 'Fall', 2002);
	insert into teaches values('34175', '571', '1', 'Spring', 2004);
	insert into teaches values('79081', '345', '1', 'Spring', 2008);
	insert into teaches values('80759', '559', '1', 'Fall', 2002);
	insert into teaches values('22591', '991', '1', 'Spring', 2008);
	insert into teaches values('22591', '400', '2', 'Fall', 2003);
	insert into teaches values('74420', '376', '1', 'Fall', 2006);
	insert into teaches values('73623', '694', '1', 'Fall', 2002);
	insert into teaches values('6569', '137', '1', 'Spring', 2002);
	insert into teaches values('95709', '270', '1', 'Spring', 2010);
	insert into teaches values('36897', '795', '1', 'Spring', 2004);
	insert into teaches values('74420', '443', '2', 'Spring', 2002);
	insert into teaches values('77346', '486', '1', 'Fall', 2009);
	insert into teaches values('79081', '408', '1', 'Spring', 2007);
	insert into teaches values('6569', '362', '3', 'Spring', 2008);
	insert into teaches values('6569', '527', '1', 'Fall', 2004);
	insert into teaches values('41930', '401', '1', 'Fall', 2003);
	insert into teaches values('79081', '408', '2', 'Spring', 2003);
	insert into teaches values('77346', '493', '1', 'Spring', 2010);
	insert into teaches values('4233', '679', '1', 'Spring', 2010);
	insert into teaches values('99052', '237', '2', 'Fall', 2009);
	insert into teaches values('95709', '258', '1', 'Fall', 2007);
	insert into teaches values('63287', '334', '1', 'Fall', 2009);
	insert into teaches values('28097', '366', '1', 'Fall', 2005);
	insert into teaches values('19368', '581', '1', 'Spring', 2005);
	insert into teaches values('42782', '793', '1', 'Spring', 2002);
	insert into teaches values('74420', '959', '1', 'Fall', 2006);
	insert into teaches values('41930', '421', '1', 'Fall', 2004);
	insert into teaches values('6569', '426', '1', 'Spring', 2006);
	insert into teaches values('6569', '362', '2', 'Fall', 2006);
	insert into teaches values('77346', '864', '1', 'Spring', 2006);
	insert into teaches values('3335', '960', '1', 'Fall', 2009);
	insert into teaches values('43779', '105', '1', 'Fall', 2009);
	insert into teaches values('48507', '626', '1', 'Fall', 2006);
	insert into teaches values('99052', '893', '1', 'Fall', 2007);
	insert into teaches values('22591', '663', '1', 'Spring', 2005);
	insert into teaches values('25946', '192', '1', 'Fall', 2002);
	insert into teaches values('6569', '349', '1', 'Spring', 2008);
	insert into teaches values('99052', '237', '1', 'Spring', 2008);
	insert into teaches values('22591', '972', '1', 'Spring', 2009);
	insert into teaches values('77346', '704', '1', 'Spring', 2008);
	insert into teaches values('36897', '242', '1', 'Fall', 2009);
	insert into teaches values('99052', '158', '2', 'Spring', 2008);
	insert into teaches values('19368', '545', '1', 'Fall', 2001);
	insert into teaches values('36897', '791', '1', 'Spring', 2006);
	insert into teaches values('22591', '642', '1', 'Fall', 2004);
	insert into teaches values('95709', '468', '1', 'Fall', 2005);
	insert into teaches values('3335', '949', '1', 'Fall', 2007);
	insert into teaches values('99052', '748', '1', 'Fall', 2003);
	insert into teaches values('43779', '489', '1', 'Fall', 2007);
	insert into teaches values('28400', '603', '1', 'Fall', 2003);
	insert into teaches values('81991', '415', '1', 'Fall', 2010);
	insert into teaches values('48570', '867', '2', 'Fall', 2010);
	insert into teaches values('3199', '631', '1', 'Spring', 2007);
	insert into teaches values('74420', '443', '1', 'Spring', 2010);
	insert into teaches values('81991', '702', '1', 'Spring', 2001);
	insert into teaches values('14365', '843', '1', 'Fall', 2010);
	insert into teaches values('74420', '612', '1', 'Fall', 2007);
	insert into teaches values('99052', '629', '1', 'Spring', 2003);
	insert into teaches values('43779', '105', '2', 'Fall', 2002);
	insert into teaches values('79081', '200', '2', 'Fall', 2002);
	insert into teaches values('99052', '496', '1', 'Fall', 2001);
	insert into teaches values('50330', '468', '2', 'Fall', 2007);
	insert into teaches values('36897', '696', '1', 'Spring', 2002);
	insert into teaches values('77346', '735', '1', 'Spring', 2003);
	insert into teaches values('14365', '200', '1', 'Spring', 2007);
	insert into teaches values('90643', '461', '1', 'Fall', 2002);
	insert into teaches values('77346', '735', '2', 'Spring', 2010);
	insert into teaches values('6569', '362', '1', 'Fall', 2005);
	insert into teaches values('43779', '476', '1', 'Fall', 2010);
	insert into teaches values('74420', '239', '1', 'Fall', 2006);
	insert into teaches values('6569', '304', '1', 'Fall', 2009);
	insert into teaches values('22591', '599', '1', 'Spring', 2003);
	insert into teaches values('63287', '852', '1', 'Spring', 2008);
	insert into teaches values('79081', '760', '1', 'Spring', 2004);
	insert into teaches values('19368', '591', '1', 'Spring', 2005);
	insert into teaches values('3199', '169', '2', 'Fall', 2002);
	insert into teaches values('36897', '313', '1', 'Fall', 2010);
	insert into teaches values('41930', '692', '1', 'Spring', 2010);
	insert into teaches values('22591', '867', '1', 'Fall', 2006);
	insert into teaches values('22591', '482', '1', 'Fall', 2005);
	insert into teaches values('15347', '457', '1', 'Spring', 2001);
	insert into teaches values('99052', '802', '1', 'Spring', 2003);
	insert into teaches values('22591', '338', '1', 'Spring', 2007);
	insert into teaches values('22591', '352', '1', 'Spring', 2006);
	insert into teaches values('22591', '338', '2', 'Spring', 2006);
	insert into teaches values('95709', '960', '2', 'Fall', 2006);
	insert into teaches values('65931', '875', '1', 'Spring', 2005);
	insert into teaches values('22591', '400', '1', 'Spring', 2007);
	insert into teaches values('99052', '927', '1', 'Fall', 2002);
	insert into teaches values('79081', '974', '1', 'Fall', 2003);
	insert into teaches values('28400', '604', '1', 'Spring', 2009);
	insert into teaches values('6569', '319', '1', 'Spring', 2003);
	insert into student values('24746', 'Schrefl', 'History', 4);
	insert into student values('79352', 'Rumat', 'Finance', 100);
	insert into student values('76672', 'Miliko', 'Statistics', 116);
	insert into student values('14182', 'Moszkowski', 'Civil Eng.', 73);
	insert into student values('44985', 'Prieto', 'Biology', 91);
	insert into student values('96052', 'Marcol', 'Cybernetics', 15);
	insert into student values('35175', 'Quimby', 'History', 4);
	insert into student values('44271', 'Sowerby', 'English', 108);
	insert into student values('40897', 'Coppens', 'Math', 58);
	insert into student values('92839', 'Cirsto', 'Math', 115);
	insert into student values('79329', 'Velikovs', 'Marketing', 110);
	insert into student values('97101', 'Marek', 'Psychology', 53);
	insert into student values('24865', 'Tran-', 'Marketing', 116);
	insert into student values('36052', 'Guerra', 'Elec. Eng.', 59);
	insert into student values('98940', 'Hawthorne', 'Marketing', 78);
	insert into student values('21395', 'Leuen', 'Math', 43);
	insert into student values('55859', 'Eguchi', 'Astronomy', 14);
	insert into student values('74016', 'Moei', 'Elec. Eng.', 15);
	insert into student values('93061', 'Alfaro', 'Elec. Eng.', 69);
	insert into student values('94998', 'Krishnakumar', 'Physics', 81);
	insert into student values('30772', 'Inoue', 'Math', 18);
	insert into student values('1968', 'Sahm', 'Finance', 4);
	insert into student values('90567', 'Tomason', 'Pol. Sci.', 118);
	insert into student values('49611', 'Karande', 'Astronomy', 57);
	insert into student values('81538', 'Wunderli', 'Languages', 117);
	insert into student values('68999', 'Greve', 'Psychology', 113);
	insert into student values('74639', 'Cerime', 'Accounting', 35);
	insert into student values('66054', 'Crick', 'Comp. Sci.', 86);
	insert into student values('792', 'Hashimoto', 'Athletics', 102);
	insert into student values('60267', 'Dage', 'Physics', 7);
	insert into student values('17769', 'Pearlman', 'Biology', 45);
	insert into student values('39580', 'Macias', 'Psychology', 128);
	insert into student values('89106', 'Dawson', 'Mech. Eng.', 88);
	insert into student values('37856', 'Gay', 'Statistics', 92);
	insert into student values('58307', 'Tiamp', 'Pol. Sci.', 63);
	insert into student values('57985', 'Weller', 'Geology', 45);
	insert into student values('72014', 'Kee', 'Languages', 57);
	insert into student values('2795', 'Milner', 'Finance', 8);
	insert into student values('89000', 'Guthk', 'Finance', 80);
	insert into student values('46442', 'Kagd', 'Cybernetics', 61);
	insert into student values('60040', 'Samel', 'Math', 100);
	insert into student values('19791', 'Vanrell', 'Comp. Sci.', 61);
	insert into student values('4582', 'Zaniolo', 'Math', 0);
	insert into student values('108', 'Dhav', 'Biology', 80);
	insert into student values('1533', 'She', 'Statistics', 29);
	insert into student values('7123', 'Holn', 'Math', 27);
	insert into student values('44584', 'Agar', 'Geology', 58);
	insert into student values('32954', 'Curutchet', 'Languages', 121);
	insert into student values('98056', 'Di', 'Civil Eng.', 81);
	insert into student values('76953', 'Lemoine', 'Athletics', 60);
	insert into student values('81884', 'Kereth', 'Accounting', 96);
	insert into student values('22057', 'Cal', 'Cybernetics', 20);
	insert into student values('21126', 'McCarter', 'Cybernetics', 38);
	insert into student values('82918', 'Yemini', 'Statistics', 43);
	insert into student values('4173', 'Erol', 'Statistics', 21);
	insert into student values('83022', 'Chyr', 'Math', 10);
	insert into student values('25525', 'Moreira', 'Comp. Sci.', 107);
	insert into student values('75040', 'Kruglyak', 'Pol. Sci.', 99);
	insert into student values('31624', 'Keuk', 'Geology', 107);
	insert into student values('64893', 'Katzenb', 'Statistics', 78);
	insert into student values('59920', 'Dano', 'Civil Eng.', 16);
	insert into student values('38602', 'Torres', 'Cybernetics', 108);
	insert into student values('21401', 'Garze', 'Physics', 92);
	insert into student values('93004', 'Gibbs', 'Finance', 129);
	insert into student values('38899', 'Murphy', 'Marketing', 30);
	insert into student values('75241', 'Hughes', 'Languages', 79);
	insert into student values('98830', 'Frolova', 'Comp. Sci.', 13);
	insert into student values('37101', 'Falconer', 'Physics', 78);
	insert into student values('4508', 'Cochran', 'English', 127);
	insert into student values('32130', 'Bannac', 'Biology', 56);
	insert into student values('56755', 'Paul', 'Mech. Eng.', 62);
	insert into student values('11510', 'Rakoj', 'Mech. Eng.', 37);
	insert into student values('3335', 'Otterm', 'Finance', 73);
	insert into student values('61081', 'Bai', 'Geology', 100);
	insert into student values('33651', 'Seike', 'Geology', 2);
	insert into student values('8251', 'Kite', 'History', 47);
	insert into student values('10705', 'Terauchi', 'Physics', 48);
	insert into student values('64082', 'Boyle', 'Languages', 87);
	insert into student values('59517', 'Harrison', 'Elec. Eng.', 81);
	insert into student values('91569', 'Pavlovico', 'Marketing', 90);
	insert into student values('88085', 'Bouamama', 'Comp. Sci.', 8);
	insert into student values('96722', 'Liley', 'English', 34);
	insert into student values('36379', 'Triebel', 'Comp. Sci.', 115);
	insert into student values('69581', 'Prabhakaran', 'Statistics', 26);
	insert into student values('65329', 'Benson', 'Mech. Eng.', 63);
	insert into student values('49214', 'Vogel', 'Psychology', 46);
	insert into student values('64155', 'Midu', 'Languages', 33);
	insert into student values('58594', 'Ivanov', 'Finance', 11);
	insert into student values('71904', 'Boldin', 'Mech. Eng.', 89);
	insert into student values('69241', 'Kannan', 'Athletics', 99);
	insert into student values('58889', 'Collet', 'Geology', 76);
	insert into student values('30341', 'Anse', 'History', 58);
	insert into student values('70688', 'Ishihara', 'Elec. Eng.', 86);
	insert into student values('81258', 'Nirenbu', 'History', 102);
	insert into student values('63090', 'Hoov', 'Math', 118);
	insert into student values('70572', 'Andrews', 'Psychology', 7);
	insert into student values('58413', 'Xiong', 'Athletics', 27);
	insert into student values('93171', 'Carey', 'Marketing', 56);
	insert into student values('35138', 'Corbac', 'Mech. Eng.', 86);
	insert into student values('77289', 'Kok', 'Geology', 57);
	insert into student values('93571', 'Kato', 'Psychology', 0);
	insert into student values('14554', 'Ramadan', 'Psychology', 96);
	insert into student values('46725', 'Richi', 'Statistics', 18);
	insert into student values('99730', 'Courtney', 'English', 99);
	insert into student values('10527', 'Kieras', 'Physics', 128);
	insert into student values('898', 'Heilprin', 'Accounting', 88);
	insert into student values('64297', 'Desp', 'Athletics', 95);
	insert into student values('10204', 'Mediratta', 'Geology', 112);
	insert into student values('36926', 'Kamae', 'Civil Eng.', 87);
	insert into student values('49618', 'Stone', 'Languages', 60);
	insert into student values('34329', 'Malcher', 'English', 32);
	insert into student values('84410', 'Bae', 'Psychology', 71);
	insert into student values('29435', 'Siddiqi', 'Psychology', 86);
	insert into student values('62636', 'Soni', 'Geology', 4);
	insert into student values('8483', 'Luk', 'Elec. Eng.', 53);
	insert into student values('2177', 'Cheah', 'Astronomy', 15);
	insert into student values('43348', 'Venturini', 'Mech. Eng.', 94);
	insert into student values('37430', 'Norman', 'Languages', 35);
	insert into student values('37586', 'Valtchev', 'Biology', 19);
	insert into student values('55238', 'Thadani', 'Physics', 75);
	insert into student values('34404', 'Fries', 'History', 48);
	insert into student values('59539', 'Madden', 'Civil Eng.', 4);
	insert into student values('43123', 'Shim', 'Geology', 69);
	insert into student values('19582', 'Canas', 'Finance', 7);
	insert into student values('88553', 'Levine', 'Pol. Sci.', 51);
	insert into student values('5898', 'Dahl', 'Languages', 28);
	insert into student values('2419', 'Hirakuri', 'Mech. Eng.', 49);
	insert into student values('31516', 'Hassine', 'Elec. Eng.', 49);
	insert into student values('3487', 'Deshpande', 'Languages', 6);
	insert into student values('66269', 'Hsueh', 'Accounting', 43);
	insert into student values('54622', 'Yu', 'Statistics', 107);
	insert into student values('19638', 'Dawson', 'Cybernetics', 107);
	insert into student values('88418', 'Slaw', 'Elec. Eng.', 112);
	insert into student values('86802', 'Hameed', 'Mech. Eng.', 47);
	insert into student values('63361', 'Djurd', 'Languages', 36);
	insert into student values('6367', 'Doisy', 'Pol. Sci.', 66);
	insert into student values('84239', 'Jordan', 'Languages', 20);
	insert into student values('4940', 'Rhyne', 'Mech. Eng.', 102);
	insert into student values('90663', 'Sram', 'Comp. Sci.', 119);
	insert into student values('38476', 'Rzecz', 'Pol. Sci.', 129);
	insert into student values('96003', 'Nakajima', 'Astronomy', 95);
	insert into student values('64914', 'Lembr', 'Finance', 17);
	insert into student values('41599', 'Meneses', 'Geology', 40);
	insert into student values('22226', 'Kinney', 'Biology', 116);
	insert into student values('96153', 'Sawah', 'Pol. Sci.', 67);
	insert into student values('44998', 'Borrus', 'Civil Eng.', 79);
	insert into student values('74163', 'Chettao', 'Marketing', 115);
	insert into student values('75046', 'Hamagi', 'Marketing', 101);
	insert into student values('97679', 'Sacchi', 'Psychology', 102);
	insert into student values('94894', 'Kozlov', 'Accounting', 27);
	insert into student values('44881', 'Harshman', 'Cybernetics', 59);
	insert into student values('98619', 'Nagaraj', 'Civil Eng.', 61);
	insert into student values('86753', 'Leister', 'History', 81);
	insert into student values('87054', 'Dietzsch', 'Statistics', 91);
	insert into student values('39046', 'Narasimhamu', 'Math', 121);
	insert into student values('29031', 'Berthold', 'English', 85);
	insert into student values('97355', 'Ratcliff', 'Languages', 60);
	insert into student values('24010', 'Brookh', 'Comp. Sci.', 65);
	insert into student values('21789', 'Bates', 'History', 118);
	insert into student values('52157', 'Nagle', 'Astronomy', 52);
	insert into student values('64938', 'Kaep', 'Civil Eng.', 126);
	insert into student values('94535', 'Nishida', 'History', 127);
	insert into student values('58595', 'Cronin', 'Physics', 100);
	insert into student values('72979', 'Guix', 'Astronomy', 117);
	insert into student values('32506', 'Suzuki', 'Astronomy', 86);
	insert into student values('31690', 'Bondi', 'Comp. Sci.', 110);
	insert into student values('87044', 'McDonald', 'Accounting', 87);
	insert into student values('34236', 'Maalej', 'Math', 80);
	insert into student values('18808', 'Snif', 'Mech. Eng.', 116);
	insert into student values('91063', 'Dair', 'Civil Eng.', 105);
	insert into student values('48462', 'Wolf', 'Civil Eng.', 19);
	insert into student values('41965', 'Boden', 'Cybernetics', 87);
	insert into student values('31137', 'Porter', 'Statistics', 36);
	insert into student values('7602', 'Ingram', 'Geology', 71);
	insert into student values('84845', 'Zuo', 'Comp. Sci.', 81);
	insert into student values('28252', 'Pfister', 'Finance', 6);
	insert into student values('10736', 'Veselovsky', 'Elec. Eng.', 62);
	insert into student values('58465', 'Romeo', 'Elec. Eng.', 76);
	insert into student values('64140', 'Tiroz', 'Athletics', 118);
	insert into student values('6523', 'Karlsson', 'Civil Eng.', 1);
	insert into student values('64067', 'Mennif', 'Languages', 8);
	insert into student values('99399', 'Duan', 'Astronomy', 96);
	insert into student values('21337', 'Goualh', 'Marketing', 46);
	insert into student values('15457', 'Arinb', 'Physics', 123);
	insert into student values('26102', 'Tanaka', 'Statistics', 118);
	insert into student values('31337', 'Graziano', 'Elec. Eng.', 29);
	insert into student values('67425', 'Cooper', 'Athletics', 51);
	insert into student values('48640', 'Brown', 'History', 33);
	insert into student values('72741', 'Weiss', 'Astronomy', 22);
	insert into student values('29803', 'Beavis', 'Accounting', 76);
	insert into student values('38895', 'Beuthel', 'Biology', 70);
	insert into student values('49391', 'Rammer', 'Marketing', 15);
	insert into student values('13741', 'Grieng', 'Psychology', 122);
	insert into student values('59538', 'Kothari', 'Accounting', 125);
	insert into student values('9360', 'Mukai', 'Marketing', 36);
	insert into student values('53728', 'Eck', 'Statistics', 61);
	insert into student values('77898', 'Yap', 'Marketing', 10);
	insert into student values('32419', 'Sahani', 'Civil Eng.', 48);
	insert into student values('37521', 'Mes', 'Biology', 9);
	insert into student values('97065', 'Gandhi', 'Languages', 22);
	insert into student values('80057', 'Szczerban', 'Biology', 101);
	insert into student values('1826', 'Dhav', 'Astronomy', 8);
	insert into student values('80285', 'Karv', 'Cybernetics', 93);
	insert into student values('72959', 'Audeh', 'Elec. Eng.', 43);
	insert into student values('41751', 'Kaufman', 'Pol. Sci.', 13);
	insert into student values('11604', 'Neff', 'Pol. Sci.', 39);
	insert into student values('41827', 'Chriso', 'Languages', 89);
	insert into student values('8853', 'Warner', 'Mech. Eng.', 69);
	insert into student values('9440', 'Gierl', 'Psychology', 9);
	insert into student values('1884', 'Masini', 'Marketing', 89);
	insert into student values('41774', 'Tassel', 'Languages', 7);
	insert into student values('32385', 'Park', 'Civil Eng.', 120);
	insert into student values('336', 'Constantinescu', 'Finance', 61);
	insert into student values('82688', 'Rote', 'Cybernetics', 33);
	insert into student values('66090', 'Brochhause', 'Pol. Sci.', 53);
	insert into student values('4182', 'Powals', 'Languages', 102);
	insert into student values('20099', 'Lewis', 'Mech. Eng.', 46);
	insert into student values('81028', 'Perna', 'Pol. Sci.', 105);
	insert into student values('27556', 'Leitner', 'Astronomy', 82);
	insert into student values('65258', 'Tian', 'Comp. Sci.', 3);
	insert into student values('29239', 'Simmel', 'Astronomy', 107);
	insert into student values('54508', 'Gregga', 'Physics', 41);
	insert into student values('37449', 'Ssu', 'Pol. Sci.', 64);
	insert into student values('16753', 'Kuwadak', 'Comp. Sci.', 67);
	insert into student values('82697', 'Ye', 'Civil Eng.', 71);
	insert into student values('11422', 'Saito', 'Physics', 34);
	insert into student values('59046', 'Reichl', 'Elec. Eng.', 56);
	insert into student values('89246', 'Loyka', 'History', 46);
	insert into student values('95859', 'Huft', 'Physics', 33);
	insert into student values('94173', 'Winkler', 'Biology', 16);
	insert into student values('70021', 'Aydin', 'Cybernetics', 16);
	insert into student values('92040', 'Alexandri', 'Athletics', 66);
	insert into student values('36019', 'Quaranta', 'Astronomy', 128);
	insert into student values('40558', 'Pacie', 'Finance', 101);
	insert into student values('62549', 'Komatsu', 'Comp. Sci.', 74);
	insert into student values('92385', 'Godfrey', 'English', 34);
	insert into student values('14214', 'Yoneda', 'Cybernetics', 129);
	insert into student values('32245', 'Saariluoma', 'Statistics', 12);
	insert into student values('13506', 'Patrick', 'Physics', 85);
	insert into student values('26080', 'Simmel', 'Biology', 80);
	insert into student values('52872', 'Chaney', 'Elec. Eng.', 57);
	insert into student values('28952', 'Kennedy', 'Accounting', 30);
	insert into student values('1080', 'Xue', 'Languages', 94);
	insert into student values('11095', 'Schultz', 'Languages', 51);
	insert into student values('33460', 'Leonard', 'Psychology', 48);
	insert into student values('99226', 'Hao', 'Civil Eng.', 50);
	insert into student values('52707', 'Arena', 'History', 73);
	insert into student values('40189', 'Holt', 'Comp. Sci.', 104);
	insert into student values('35721', 'Suppan', 'Math', 85);
	insert into student values('6400', 'Kelly', 'Astronomy', 110);
	insert into student values('60688', 'Zander', 'Accounting', 69);
	insert into student values('18821', 'Linden', 'Astronomy', 98);
	insert into student values('65443', 'Yagit', 'Finance', 78);
	insert into student values('71630', 'Heath', 'Psychology', 116);
	insert into student values('46956', 'Nallape', 'Astronomy', 6);
	insert into student values('64259', 'Busch', 'Marketing', 123);
	insert into student values('77021', 'Bollen', 'Psychology', 120);
	insert into student values('41450', 'McLeod', 'Marketing', 78);
	insert into student values('13028', 'Okano', 'Geology', 89);
	insert into student values('90381', 'Chaudhuri', 'Math', 108);
	insert into student values('9460', 'Wrzesz', 'Accounting', 99);
	insert into student values('98423', 'Alfaro', 'Physics', 101);
	insert into student values('38691', 'Theodores', 'Accounting', 37);
	insert into student values('86806', 'Unger', 'Marketing', 101);
	insert into student values('18469', 'Coppens', 'Marketing', 26);
	insert into student values('11194', 'El-Helw', 'Pol. Sci.', 71);
	insert into student values('19862', 'Prasad', 'Pol. Sci.', 22);
	insert into student values('24116', 'Fauth', 'Elec. Eng.', 10);
	insert into student values('67021', 'Chenu', 'Accounting', 73);
	insert into student values('69752', 'Tan', 'English', 24);
	insert into student values('69225', 'Mejia', 'History', 22);
	insert into student values('1018', 'Colin', 'Civil Eng.', 81);
	insert into student values('7656', 'Maher', 'Pol. Sci.', 24);
	insert into student values('35220', 'Shilv', 'History', 58);
	insert into student values('79210', 'Sanchez', 'Astronomy', 14);
	insert into student values('10814', 'Waks', 'Elec. Eng.', 56);
	insert into student values('55698', 'Choung', 'Finance', 67);
	insert into student values('49684', 'Ceze', 'Civil Eng.', 50);
	insert into student values('59908', 'Cox', 'Civil Eng.', 0);
	insert into student values('64724', 'Deupree', 'Cybernetics', 36);
	insert into student values('19048', 'Leuen', 'Statistics', 122);
	insert into student values('62716', 'Bocchi', 'Math', 33);
	insert into student values('95205', 'Hammond', 'Athletics', 115);
	insert into student values('40303', 'Rudolf', 'Marketing', 25);
	insert into student values('27430', 'Gonzalez', 'Cybernetics', 75);
	insert into student values('83953', 'Jordan', 'Math', 26);
	insert into student values('4248', 'Wright', 'Finance', 63);
	insert into student values('21766', 'Cox', 'Astronomy', 74);
	insert into student values('39657', 'Ryder', 'Astronomy', 80);
	insert into student values('85366', 'Erol', 'Finance', 112);
	insert into student values('93354', 'Varghese', 'English', 88);
	insert into student values('77580', 'Frazin', 'Civil Eng.', 46);
	insert into student values('92864', 'Rogers', 'Accounting', 54);
	insert into student values('57135', 'Margetts', 'Marketing', 66);
	insert into student values('1727', 'Ratcliff', 'Mech. Eng.', 49);
	insert into student values('91788', 'Streitf', 'Cybernetics', 56);
	insert into student values('80420', 'Bansal', 'Statistics', 69);
	insert into student values('67810', 'Forestiero', 'English', 114);
	insert into student values('86404', 'Cordt', 'Marketing', 1);
	insert into student values('16907', 'Keiss', 'Accounting', 59);
	insert into student values('46928', 'Barry', 'Athletics', 108);
	insert into student values('84702', 'Lucas', 'Math', 105);
	insert into student values('91343', 'Clarkson', 'Statistics', 42);
	insert into student values('83686', 'Krasser', 'Statistics', 95);
	insert into student values('83462', 'Mehra', 'Accounting', 55);
	insert into student values('67725', 'Yamamoto', 'Pol. Sci.', 35);
	insert into student values('5393', 'Clemens', 'Mech. Eng.', 4);
	insert into student values('34422', 'Nakajima', 'Mech. Eng.', 86);
	insert into student values('17128', 'Chuon', 'Civil Eng.', 81);
	insert into student values('81883', 'Perei', 'Marketing', 124);
	insert into student values('87965', 'Reiss', 'Accounting', 17);
	insert into student values('93653', 'Mellor', 'Astronomy', 127);
	insert into student values('70522', 'Holn', 'Comp. Sci.', 29);
	insert into student values('48850', 'Wehen', 'Biology', 14);
	insert into student values('68070', 'Cameron', 'Pol. Sci.', 85);
	insert into student values('50206', 'Cesaret', 'Mech. Eng.', 102);
	insert into student values('80254', 'Mittelm', 'Languages', 122);
	insert into student values('22396', 'Wodn', 'Biology', 100);
	insert into student values('19293', 'Singhal', 'Geology', 118);
	insert into student values('67660', 'Newitt', 'Biology', 64);
	insert into student values('85910', 'Levitan', 'Finance', 73);
	insert into student values('10917', 'Morales', 'Cybernetics', 54);
	insert into student values('95574', 'Pampal', 'Comp. Sci.', 111);
	insert into student values('13081', 'Alqui', 'Languages', 112);
	insert into student values('33349', 'Peck', 'Biology', 125);
	insert into student values('19861', 'Fontana', 'Civil Eng.', 81);
	insert into student values('30723', 'Mali', 'Physics', 115);
	insert into student values('83039', 'Harmon', 'Psychology', 124);
	insert into student values('41741', 'Kato', 'Languages', 94);
	insert into student values('97400', 'Noda', 'Accounting', 62);
	insert into student values('81207', 'Masri', 'Athletics', 123);
	insert into student values('23994', 'Kalisz', 'Elec. Eng.', 75);
	insert into student values('54672', 'Thie', 'Pol. Sci.', 44);
	insert into student values('47001', 'Correia', 'Comp. Sci.', 63);
	insert into student values('26147', 'Richter', 'Comp. Sci.', 115);
	insert into student values('65987', 'Morrison', 'Athletics', 98);
	insert into student values('99250', 'Khaw', 'English', 14);
	insert into student values('13826', 'Sommerfeldt', 'Pol. Sci.', 80);
	insert into student values('3739', 'Davy', 'History', 75);
	insert into student values('10454', 'Ugarte', 'Pol. Sci.', 120);
	insert into student values('48053', 'Macias', 'Comp. Sci.', 0);
	insert into student values('66813', 'Spengler', 'Languages', 55);
	insert into student values('16593', 'Skuras', 'Psychology', 5);
	insert into student values('14668', 'Malinen', 'Athletics', 20);
	insert into student values('33338', 'Stead', 'Psychology', 65);
	insert into student values('45300', 'Kambayashi', 'Geology', 67);
	insert into student values('3127', 'Resa', 'Psychology', 73);
	insert into student values('40992', 'Xing', 'Psychology', 93);
	insert into student values('70310', 'Ding', 'Biology', 107);
	insert into student values('46451', 'Chilu', 'Pol. Sci.', 123);
	insert into student values('288', 'Canellas', 'Astronomy', 95);
	insert into student values('557', 'Bhat', 'Math', 44);
	insert into student values('22170', 'Sugavanam', 'Physics', 41);
	insert into student values('64164', 'Zander', 'Languages', 111);
	insert into student values('74911', 'Wall', 'Languages', 111);
	insert into student values('7020', 'Thoreson', 'Comp. Sci.', 61);
	insert into student values('78552', 'Douss', 'History', 90);
	insert into student values('50386', 'Bersk', 'Elec. Eng.', 125);
	insert into student values('48678', 'Tuomisto', 'Athletics', 121);
	insert into student values('24442', 'Greene', 'Physics', 11);
	insert into student values('89188', 'Anse', 'Statistics', 77);
	insert into student values('390', 'Alkio', 'Elec. Eng.', 65);
	insert into student values('10663', 'Okaf', 'Geology', 59);
	insert into student values('97551', 'Labaye', 'Civil Eng.', 128);
	insert into student values('76895', 'Olro', 'Accounting', 63);
	insert into student values('85451', 'Chapman', 'Languages', 70);
	insert into student values('43989', 'Makarychev', 'Accounting', 72);
	insert into student values('99719', 'Bennett', 'Accounting', 70);
	insert into student values('19245', 'Cai', 'Comp. Sci.', 4);
	insert into student values('36685', 'Fathi', 'Accounting', 8);
	insert into student values('57123', 'Katsik', 'Cybernetics', 46);
	insert into student values('51997', 'Nadg', 'Languages', 49);
	insert into student values('95631', 'Mauras', 'Elec. Eng.', 42);
	insert into student values('70452', 'Al-Hu', 'Astronomy', 18);
	insert into student values('37219', 'Poize', 'Comp. Sci.', 45);
	insert into student values('59530', 'Poulin', 'History', 64);
	insert into student values('61737', 'Kissel', 'Finance', 86);
	insert into student values('33645', 'Kawakami', 'Comp. Sci.', 129);
	insert into student values('3143', 'Haddad', 'Geology', 55);
	insert into student values('78792', 'Ram', 'Mech. Eng.', 102);
	insert into student values('10076', 'Duan', 'Civil Eng.', 105);
	insert into student values('59553', 'Schoenfl', 'Mech. Eng.', 110);
	insert into student values('57666', 'Fries', 'History', 96);
	insert into student values('22004', 'OBrien', 'Geology', 106);
	insert into student values('38668', 'Spector', 'Elec. Eng.', 97);
	insert into student values('43130', 'Yong', 'Comp. Sci.', 123);
	insert into student values('36263', 'Souza', 'Civil Eng.', 58);
	insert into student values('99271', 'Soricu', 'Math', 70);
	insert into student values('69850', 'Alexandri', 'Finance', 80);
	insert into student values('59397', 'Williams', 'Statistics', 126);
	insert into student values('61127', 'Tuki', 'Physics', 30);
	insert into student values('30299', 'Marsh', 'Geology', 38);
	insert into student values('57962', 'Aarde', 'Statistics', 22);
	insert into student values('88169', 'Schroeder', 'Cybernetics', 106);
	insert into student values('27094', 'Gur', 'Geology', 120);
	insert into student values('39115', 'Boulah', 'Civil Eng.', 2);
	insert into student values('84189', 'Kuwadak', 'Statistics', 119);
	insert into student values('79892', 'Chiari', 'Cybernetics', 76);
	insert into student values('95046', 'Mercank', 'Astronomy', 100);
	insert into student values('34386', 'Hagedorn', 'History', 98);
	insert into student values('82646', 'Nirenbu', 'Biology', 0);
	insert into student values('31086', 'Zulueta', 'Psychology', 125);
	insert into student values('85226', 'Vicentino', 'Psychology', 18);
	insert into student values('32490', 'McCracken', 'Comp. Sci.', 117);
	insert into student values('39704', 'Frank', 'Statistics', 31);
	insert into student values('80610', 'Nakamura', 'Physics', 79);
	insert into student values('18675', 'Araya', 'Statistics', 82);
	insert into student values('47630', 'Odell', 'Cybernetics', 77);
	insert into student values('36102', 'Szendrei', 'Cybernetics', 109);
	insert into student values('22620', 'Lykin', 'Accounting', 18);
	insert into student values('39157', 'Loull', 'Accounting', 0);
	insert into student values('86327', 'Moscarini', 'Marketing', 31);
	insert into student values('84865', 'Fernandez-Gonzalez', 'Finance', 20);
	insert into student values('83557', 'Khalil', 'Psychology', 95);
	insert into student values('7490', 'Giuffrida', 'Math', 39);
	insert into student values('94178', 'Bengtss', 'Psychology', 47);
	insert into student values('99660', 'OMalley', 'Civil Eng.', 128);
	insert into student values('57511', 'Pulido', 'English', 78);
	insert into student values('56941', 'Swain', 'Astronomy', 17);
	insert into student values('77415', 'Morales', 'Astronomy', 102);
	insert into student values('99754', 'Califieri', 'Cybernetics', 55);
	insert into student values('81550', 'Harada', 'Elec. Eng.', 98);
	insert into student values('79911', 'Corr', 'Physics', 117);
	insert into student values('82082', 'Towsey', 'Statistics', 12);
	insert into student values('58846', 'Fengl', 'Pol. Sci.', 66);
	insert into student values('11076', 'Prasad', 'Pol. Sci.', 114);
	insert into student values('7204', 'Halbert', 'Biology', 83);
	insert into student values('73165', 'Fox', 'Statistics', 19);
	insert into student values('1737', 'Shinagawa', 'Biology', 118);
	insert into student values('12979', 'Hammond', 'Elec. Eng.', 5);
	insert into student values('57334', 'Roeder', 'Math', 70);
	insert into student values('1827', 'Westbrook', 'Civil Eng.', 61);
	insert into student values('29390', 'Aufr', 'Geology', 49);
	insert into student values('31302', 'Qian', 'Geology', 110);
	insert into student values('77231', 'Roschew', 'History', 38);
	insert into student values('36126', 'Fung', 'Astronomy', 47);
	insert into student values('45200', 'Kitagawa', 'Elec. Eng.', 125);
	insert into student values('99463', 'Jacobi', 'Statistics', 19);
	insert into student values('79170', 'Lingamp', 'Cybernetics', 28);
	insert into student values('12216', 'Griffiths', 'Cybernetics', 94);
	insert into student values('64593', 'Kamez', 'Mech. Eng.', 8);
	insert into student values('30177', 'Vajapeyaz', 'Pol. Sci.', 41);
	insert into student values('15074', 'Kirtane', 'Physics', 36);
	insert into student values('5005', 'Cesaret', 'Civil Eng.', 15);
	insert into student values('99348', 'Tobin', 'Finance', 85);
	insert into student values('82591', 'Pomy', 'Mech. Eng.', 92);
	insert into student values('53089', 'Vedag', 'English', 98);
	insert into student values('24630', 'Halbert', 'Geology', 66);
	insert into student values('71387', 'Tleu', 'Civil Eng.', 69);
	insert into student values('61354', 'Barranco', 'Mech. Eng.', 129);
	insert into student values('10481', 'Grosch', 'Astronomy', 39);
	insert into student values('39310', 'Ploski', 'Comp. Sci.', 64);
	insert into student values('16297', 'Sacchi', 'Marketing', 44);
	insert into student values('72622', 'Kashima', 'Cybernetics', 54);
	insert into student values('92965', 'Mesne', 'Biology', 26);
	insert into student values('89104', 'Mitsuhashi', 'Biology', 54);
	insert into student values('13408', 'Bromley', 'Elec. Eng.', 81);
	insert into student values('66229', 'Qvi', 'Civil Eng.', 128);
	insert into student values('87280', 'Kim', 'Pol. Sci.', 67);
	insert into student values('73206', 'Maw', 'Cybernetics', 36);
	insert into student values('24387', 'Yap', 'History', 29);
	insert into student values('32744', 'Robins', 'Finance', 40);
	insert into student values('39204', 'Castle', 'Civil Eng.', 27);
	insert into student values('42298', 'Fournier', 'Biology', 61);
	insert into student values('53588', 'Schwet', 'Languages', 100);
	insert into student values('90004', 'Unay', 'Astronomy', 81);
	insert into student values('12563', 'Stone', 'Marketing', 66);
	insert into student values('55000', 'Levitan', 'Biology', 103);
	insert into student values('1110', 'Tzeng', 'Civil Eng.', 23);
	insert into student values('55170', 'Ivanov', 'History', 22);
	insert into student values('56080', 'Zamani', 'Geology', 127);
	insert into student values('61065', 'Jovicic', 'Civil Eng.', 31);
	insert into student values('107', 'Shabuno', 'Math', 19);
	insert into student values('11453', 'Yamashita', 'Astronomy', 109);
	insert into student values('53805', 'Ludwig', 'Cybernetics', 30);
	insert into student values('39241', 'Solar', 'Mech. Eng.', 64);
	insert into student values('32886', 'Damas', 'Psychology', 58);
	insert into student values('40080', 'Llam', 'Civil Eng.', 6);
	insert into student values('22142', 'Gerstend', 'History', 22);
	insert into student values('94257', 'Unger', 'Languages', 12);
	insert into student values('75513', 'Griffin', 'Statistics', 12);
	insert into student values('99268', 'Makarychev', 'Elec. Eng.', 115);
	insert into student values('20084', 'Adda', 'Accounting', 13);
	insert into student values('51868', 'Guthk', 'Pol. Sci.', 109);
	insert into student values('7287', 'Tadjo', 'Cybernetics', 116);
	insert into student values('35588', 'John', 'Civil Eng.', 31);
	insert into student values('83170', 'Ariav', 'English', 43);
	insert into student values('14596', 'Vekk', 'Biology', 105);
	insert into student values('23794', 'Sokolov', 'Pol. Sci.', 13);
	insert into student values('78332', 'Ohki', 'Pol. Sci.', 76);
	insert into student values('49339', 'Snif', 'Civil Eng.', 107);
	insert into student values('40677', 'Ponnambalam', 'Civil Eng.', 127);
	insert into student values('90220', 'Iacovoni', 'Elec. Eng.', 113);
	insert into student values('95029', 'Oliveira', 'Astronomy', 17);
	insert into student values('83728', 'Kaminsky', 'Biology', 38);
	insert into student values('67033', 'Yun', 'Marketing', 59);
	insert into student values('87785', 'Liepelt', 'Pol. Sci.', 122);
	insert into student values('4345', 'Resa', 'Languages', 125);
	insert into student values('96085', 'Wood', 'Accounting', 70);
	insert into student values('64249', 'Kalantari', 'Mech. Eng.', 102);
	insert into student values('53803', 'Okaf', 'Civil Eng.', 89);
	insert into student values('27956', 'Watzel', 'Psychology', 53);
	insert into student values('24796', 'Thimm', 'Pol. Sci.', 18);
	insert into student values('4449', 'Gilliam', 'Biology', 99);
	insert into student values('77364', 'Lacruz', 'Elec. Eng.', 59);
	insert into student values('70384', 'Shevade', 'Cybernetics', 45);
	insert into student values('18007', 'Chanon', 'Biology', 90);
	insert into student values('51723', 'Lagendijk', 'Comp. Sci.', 99);
	insert into student values('56486', 'DeMil', 'Pol. Sci.', 110);
	insert into student values('70359', 'Lorinczi', 'Cybernetics', 63);
	insert into student values('18234', 'Nirenbu', 'Pol. Sci.', 19);
	insert into student values('34322', 'Baba', 'Biology', 74);
	insert into student values('24325', 'Ãlvarez', 'Cybernetics', 50);
	insert into student values('83444', 'Vieira', 'Mech. Eng.', 115);
	insert into student values('93814', 'Smoro', 'Marketing', 19);
	insert into student values('80912', 'Homyk', 'Biology', 16);
	insert into student values('70099', 'Zhiyong', 'Languages', 86);
	insert into student values('64945', 'Gall', 'Mech. Eng.', 6);
	insert into student values('81789', 'Urwin', 'Biology', 25);
	insert into student values('38271', 'Kosken', 'Cybernetics', 100);
	insert into student values('87784', 'McCracken', 'Astronomy', 64);
	insert into student values('46436', 'Richardson', 'History', 52);
	insert into student values('20195', 'Finney', 'Mech. Eng.', 7);
	insert into student values('31080', 'Aschoff', 'Athletics', 88);
	insert into student values('85887', 'Stoltzfus', 'Mech. Eng.', 15);
	insert into student values('85234', 'Dubu', 'Finance', 69);
	insert into student values('1460', 'Martinsen', 'History', 55);
	insert into student values('30650', 'Chaudhuri', 'Languages', 101);
	insert into student values('6474', 'Rossettin', 'Civil Eng.', 85);
	insert into student values('67051', 'Labroc', 'Statistics', 70);
	insert into student values('58300', 'Lum', 'Mech. Eng.', 8);
	insert into student values('64192', 'Pradhan', 'Physics', 86);
	insert into student values('84727', 'Hennig', 'Languages', 108);
	insert into student values('39881', 'Herman', 'Athletics', 85);
	insert into student values('3163', 'Riera', 'Biology', 55);
	insert into student values('72643', 'Castle', 'Athletics', 49);
	insert into student values('66008', 'Szczerban', 'Languages', 25);
	insert into student values('76291', 'Dellwo', 'Physics', 30);
	insert into student values('92274', 'Caporali', 'Pol. Sci.', 12);
	insert into student values('16075', 'Wolter', 'Pol. Sci.', 45);
	insert into student values('30334', 'Arakawa', 'Physics', 37);
	insert into student values('75123', 'Chowdhury', 'Physics', 92);
	insert into student values('35042', 'Nives', 'Comp. Sci.', 38);
	insert into student values('99073', 'Bartels', 'Comp. Sci.', 6);
	insert into student values('68280', 'Shuming', 'Languages', 123);
	insert into student values('80976', 'Mozayani', 'Elec. Eng.', 34);
	insert into student values('68554', 'Larsson', 'English', 60);
	insert into student values('99949', 'Samo', 'Astronomy', 125);
	insert into student values('71287', 'Damas', 'Marketing', 59);
	insert into student values('73268', 'Yagit', 'Civil Eng.', 67);
	insert into student values('93708', 'Steines', 'Psychology', 99);
	insert into student values('29399', 'Sutter', 'Marketing', 38);
	insert into student values('14284', 'Takeshi', 'Athletics', 32);
	insert into student values('80247', 'Rueda', 'Mech. Eng.', 17);
	insert into student values('86344', 'Kaar', 'Accounting', 49);
	insert into student values('54728', 'Seta', 'History', 50);
	insert into student values('86375', 'Loher', 'English', 110);
	insert into student values('64401', 'Larion', 'Elec. Eng.', 42);
	insert into student values('9183', 'Sutter', 'Athletics', 44);
	insert into student values('71529', 'Fredrickso', 'Elec. Eng.', 12);
	insert into student values('65433', 'Stratulat', 'Math', 123);
	insert into student values('89051', 'Dubink', 'History', 65);
	insert into student values('90448', 'Godfrey', 'English', 120);
	insert into student values('90082', 'Esparza', 'Astronomy', 62);
	insert into student values('25362', 'Simmel', 'Psychology', 117);
	insert into student values('74509', 'Tanzi', 'Civil Eng.', 76);
	insert into student values('20445', 'Laak', 'Marketing', 4);
	insert into student values('40059', 'Montilla', 'Astronomy', 16);
	insert into student values('60867', 'Poulin', 'Finance', 5);
	insert into student values('28128', 'Crick', 'Comp. Sci.', 111);
	insert into student values('28518', 'Catani', 'Cybernetics', 20);
	insert into student values('17086', 'Hazemi', 'Math', 90);
	insert into student values('91132', 'Sud', 'History', 57);
	insert into student values('29260', 'Verhoeven', 'Physics', 25);
	insert into student values('29707', 'Gaspar', 'Statistics', 68);
	insert into student values('85746', 'Wilks', 'Pol. Sci.', 5);
	insert into student values('54605', 'Yoshioka', 'Elec. Eng.', 50);
	insert into student values('78922', 'Koltso', 'Astronomy', 20);
	insert into student values('76173', 'Jovicic', 'Elec. Eng.', 127);
	insert into student values('6304', 'Tamura', 'Cybernetics', 122);
	insert into student values('98120', 'Furukawa', 'Physics', 33);
	insert into student values('6195', 'Hartmann', 'Finance', 20);
	insert into student values('33837', 'Nicol', 'Psychology', 37);
	insert into student values('86833', 'Viani', 'Psychology', 86);
	insert into student values('28829', 'Reiss', 'Physics', 113);
	insert into student values('82974', 'Duncan', 'Cybernetics', 111);
	insert into student values('39114', 'Kerz', 'English', 18);
	insert into student values('53485', 'Rowe', 'English', 70);
	insert into student values('8603', 'Piedrah', 'Pol. Sci.', 64);
	insert into student values('7973', 'Breed', 'English', 64);
	insert into student values('34502', 'Farr', 'Pol. Sci.', 8);
	insert into student values('69853', 'Boken', 'Statistics', 55);
	insert into student values('70389', 'Paulk', 'History', 93);
	insert into student values('75423', 'Oller', 'Elec. Eng.', 79);
	insert into student values('26881', 'Markin', 'History', 110);
	insert into student values('19848', 'Tiwari', 'Comp. Sci.', 96);
	insert into student values('5017', 'Reuter', 'Statistics', 60);
	insert into student values('33094', 'Fakin', 'Accounting', 69);
	insert into student values('25468', 'Hunter', 'Comp. Sci.', 49);
	insert into student values('75928', 'Yoshimoto', 'Cybernetics', 52);
	insert into student values('94522', 'Pampal', 'Civil Eng.', 41);
	insert into student values('30289', 'Lanfr', 'History', 72);
	insert into student values('54296', 'Osinski', 'Elec. Eng.', 91);
	insert into student values('12069', 'Skeen', 'History', 10);
	insert into student values('89059', 'Juan', 'Civil Eng.', 62);
	insert into student values('38336', 'Sagawe', 'Civil Eng.', 39);
	insert into student values('98563', 'Yen', 'Languages', 74);
	insert into student values('19541', 'Drews', 'Marketing', 1);
	insert into student values('95366', 'Isogai', 'Cybernetics', 33);
	insert into student values('69758', 'Baroni', 'Pol. Sci.', 57);
	insert into student values('98690', 'Neru', 'Accounting', 41);
	insert into student values('66494', 'Shevade', 'Biology', 62);
	insert into student values('65205', 'Sauer', 'Accounting', 128);
	insert into student values('11682', 'Juol', 'Athletics', 126);
	insert into student values('36265', 'Kaupp', 'Physics', 98);
	insert into student values('14432', 'Whitley', 'Geology', 2);
	insert into student values('63860', 'Bayn', 'English', 106);
	insert into student values('50969', 'Terauchi', 'History', 119);
	insert into student values('95089', 'Zarpell', 'Mech. Eng.', 111);
	insert into student values('74840', 'Schill', 'Biology', 116);
	insert into student values('29002', 'Duxbury', 'History', 29);
	insert into student values('37809', 'Soni', 'Geology', 38);
	insert into student values('27727', 'Duong', 'Finance', 115);
	insert into student values('66469', 'Komori', 'History', 105);
	insert into student values('31486', 'Okubo', 'Elec. Eng.', 72);
	insert into student values('95099', 'Chien', 'Accounting', 81);
	insert into student values('57083', 'Gray', 'Pol. Sci.', 107);
	insert into student values('83622', 'Achilles', 'Elec. Eng.', 57);
	insert into student values('68278', 'Becker', 'Psychology', 83);
	insert into student values('87651', 'Liang', 'Math', 67);
	insert into student values('8426', 'Harass', 'Pol. Sci.', 67);
	insert into student values('88793', 'Sakhno', 'Mech. Eng.', 77);
	insert into student values('60249', 'Nishida', 'Geology', 83);
	insert into student values('65144', 'Butler', 'Marketing', 121);
	insert into student values('91091', 'Ockerb', 'English', 105);
	insert into student values('8252', 'Breuer', 'Civil Eng.', 13);
	insert into student values('82126', 'Koizumi', 'Math', 103);
	insert into student values('13290', 'Bonatto', 'Biology', 83);
	insert into student values('85356', 'Kocsis', 'Marketing', 68);
	insert into student values('5871', 'Carey', 'Athletics', 70);
	insert into student values('59290', 'Morris', 'English', 120);
	insert into student values('5414', 'Aiken', 'Pol. Sci.', 118);
	insert into student values('30124', 'Alfaro', 'Math', 126);
	insert into student values('21008', 'Pavlovico', 'Mech. Eng.', 44);
	insert into student values('69732', 'Barbosa', 'English', 76);
	insert into student values('19450', 'Asahara', 'Cybernetics', 37);
	insert into student values('55915', 'Mohamed', 'Civil Eng.', 78);
	insert into student values('14621', 'Azevedo', 'Astronomy', 17);
	insert into student values('22003', 'Ibah', 'Elec. Eng.', 48);
	insert into student values('16631', 'Stratulat', 'Biology', 20);
	insert into student values('51549', 'Rao', 'Mech. Eng.', 87);
	insert into student values('95284', 'Hands', 'Physics', 25);
	insert into student values('60366', 'Kostie', 'Statistics', 106);
	insert into student values('99369', 'Klingenb', 'Comp. Sci.', 57);
	insert into student values('50873', 'Beck', 'Marketing', 33);
	insert into student values('36244', 'Neuhold', 'Accounting', 50);
	insert into student values('58874', 'Ray', 'Physics', 109);
	insert into student values('82687', 'Cameron', 'Athletics', 77);
	insert into student values('2423', 'Giralt', 'Accounting', 114);
	insert into student values('62429', 'Dietzsch', 'Psychology', 111);
	insert into student values('93631', 'Sendlm', 'History', 71);
	insert into student values('29705', 'Stetson', 'Finance', 76);
	insert into student values('52076', 'Noda', 'Astronomy', 85);
	insert into student values('53451', 'Hasan', 'Physics', 83);
	insert into student values('69730', 'Peip', 'English', 12);
	insert into student values('56276', 'Lansi', 'History', 122);
	insert into student values('23311', 'Brunet', 'Languages', 83);
	insert into student values('21086', 'Held', 'Math', 97);
	insert into student values('61003', 'Pietkiewicz', 'Math', 88);
	insert into student values('27950', 'YÃ¼ksel', 'English', 74);
	insert into student values('50583', 'Ng', 'Finance', 113);
	insert into student values('40276', 'Konstantinides', 'Mech. Eng.', 37);
	insert into student values('15487', 'Januszewski', 'Athletics', 14);
	insert into student values('83592', 'Benkov', 'Accounting', 33);
	insert into student values('46970', 'Rafiq', 'Athletics', 31);
	insert into student values('30188', 'Ahmad', 'Marketing', 126);
	insert into student values('64934', 'Halbert', 'Psychology', 38);
	insert into student values('99694', 'Beckert', 'Statistics', 119);
	insert into student values('79534', 'Martel-', 'Statistics', 11);
	insert into student values('57156', 'Haigh', 'Math', 120);
	insert into student values('41894', 'Ortmann', 'Civil Eng.', 89);
	insert into student values('69679', 'RamÃ­rez', 'Accounting', 7);
	insert into student values('62795', 'Conradie', 'Pol. Sci.', 63);
	insert into student values('34331', 'Kacpr', 'Accounting', 59);
	insert into student values('4645', 'Ryoo', 'Finance', 65);
	insert into student values('70395', 'Ballew', 'Physics', 128);
	insert into student values('69222', 'Albuquerque', 'Math', 18);
	insert into student values('22254', 'Gordon', 'Statistics', 75);
	insert into student values('51817', 'MacIntyre', 'Physics', 51);
	insert into student values('66495', 'Michel', 'Statistics', 82);
	insert into student values('72501', 'Mulet', 'Elec. Eng.', 93);
	insert into student values('7390', 'Stone', 'Accounting', 30);
	insert into student values('28538', 'Mathur', 'Statistics', 97);
	insert into student values('68649', 'Klug', 'Pol. Sci.', 49);
	insert into student values('15249', 'Cheah', 'Accounting', 1);
	insert into student values('98984', 'Seraphin', 'Mech. Eng.', 43);
	insert into student values('35198', 'Loc', 'Civil Eng.', 87);
	insert into student values('67017', 'Westervelt', 'Physics', 102);
	insert into student values('27919', 'Hubr', 'Athletics', 124);
	insert into student values('46762', 'Bier', 'Comp. Sci.', 71);
	insert into student values('98843', 'Julier', 'Cybernetics', 85);
	insert into student values('14094', 'Miao', 'Comp. Sci.', 45);
	insert into student values('79589', 'Schopp', 'Elec. Eng.', 104);
	insert into student values('94371', 'Milner', 'Athletics', 120);
	insert into student values('25528', 'Sivew', 'Elec. Eng.', 40);
	insert into student values('7620', 'Potry', 'Mech. Eng.', 107);
	insert into student values('43658', 'Meneses', 'Astronomy', 87);
	insert into student values('65714', 'Hughes', 'English', 19);
	insert into student values('37339', 'Warren', 'Psychology', 68);
	insert into student values('38555', 'Vogt', 'Elec. Eng.', 55);
	insert into student values('73908', 'Cruz', 'Biology', 60);
	insert into student values('4438', 'Yoshioka', 'Cybernetics', 110);
	insert into student values('15883', 'Marques', 'Math', 24);
	insert into student values('41890', 'Srivastava', 'Physics', 15);
	insert into student values('75547', 'Varadaran', 'Pol. Sci.', 96);
	insert into student values('89196', 'KlÃ¶pper', 'Pol. Sci.', 37);
	insert into student values('52494', 'Sznajder', 'Statistics', 25);
	insert into student values('44551', 'Nguyen', 'Astronomy', 119);
	insert into student values('61332', 'Canon', 'Astronomy', 8);
	insert into student values('37715', 'Westbrook', 'Languages', 53);
	insert into student values('68779', 'Harmon', 'Athletics', 47);
	insert into student values('71768', 'Stephenn', 'Geology', 89);
	insert into student values('72055', 'Schinag', 'Languages', 7);
	insert into student values('29514', 'Michael', 'Biology', 124);
	insert into student values('62152', 'Oba', 'Elec. Eng.', 78);
	insert into student values('66212', 'Kurt', 'Finance', 113);
	insert into student values('53048', 'Keps', 'Cybernetics', 122);
	insert into student values('4015', 'Cole', 'Astronomy', 32);
	insert into student values('67340', 'Dubu', 'Cybernetics', 38);
	insert into student values('2970', 'Montes-y', 'History', 56);
	insert into student values('27952', 'McQuillan', 'History', 51);
	insert into student values('51008', 'Kandadai', 'History', 107);
	insert into student values('97629', 'Awano', 'Biology', 101);
	insert into student values('31079', 'Canas', 'Astronomy', 85);
	insert into student values('57941', 'Kleinberg', 'Astronomy', 24);
	insert into student values('30397', 'Dism', 'Civil Eng.', 116);
	insert into student values('45826', 'Teng', 'Mech. Eng.', 70);
	insert into student values('70299', 'Hirvas', 'Athletics', 65);
	insert into student values('9084', 'Rabu', 'Finance', 87);
	insert into student values('78116', 'Xiao', 'Civil Eng.', 65);
	insert into student values('5250', 'Ã…strÃ¶m', 'Finance', 49);
	insert into student values('93508', 'Graham', 'Physics', 14);
	insert into student values('30845', 'Fonseca', 'Math', 19);
	insert into student values('91442', 'Ohno', 'Pol. Sci.', 91);
	insert into student values('75938', 'Kotsonis', 'Marketing', 71);
	insert into student values('74672', 'Eggers', 'Athletics', 24);
	insert into student values('12078', 'Knutson', 'Languages', 97);
	insert into student values('94311', 'Napoletani', 'English', 40);
	insert into student values('94697', 'Pettersen', 'Geology', 105);
	insert into student values('50702', 'Harders', 'Math', 63);
	insert into student values('35462', 'Byrd', 'Statistics', 42);
	insert into student values('34018', 'Asahara', 'Elec. Eng.', 103);
	insert into student values('99775', 'Epley', 'Athletics', 116);
	insert into student values('88140', 'Stanko', 'Pol. Sci.', 122);
	insert into student values('46106', 'Pledg', 'Astronomy', 68);
	insert into student values('68096', 'Teo', 'Elec. Eng.', 68);
	insert into student values('84808', 'Randers', 'Psychology', 104);
	insert into student values('97658', 'Baier', 'Finance', 82);
	insert into student values('73186', 'Schweitzer', 'Psychology', 3);
	insert into student values('50944', 'Tao', 'Pol. Sci.', 66);
	insert into student values('53165', 'Dowey', 'History', 90);
	insert into student values('86981', 'Hansch', 'Cybernetics', 3);
	insert into student values('16885', 'Biehl', 'Math', 59);
	insert into student values('2561', 'Aschoff', 'Finance', 20);
	insert into student values('96178', 'Hay', 'Civil Eng.', 84);
	insert into student values('64731', 'Yuanq', 'Languages', 13);
	insert into student values('14023', 'Deshpande', 'History', 90);
	insert into student values('47265', 'Albinal', 'Comp. Sci.', 105);
	insert into student values('84704', 'Rammer', 'Physics', 55);
	insert into student values('69132', 'Sciore', 'Statistics', 25);
	insert into student values('49073', 'Bonvin', 'English', 74);
	insert into student values('44703', 'Hsieh', 'Marketing', 5);
	insert into student values('41211', 'Fok', 'Accounting', 113);
	insert into student values('61414', 'Ohyama', 'Elec. Eng.', 90);
	insert into student values('38696', 'Spadon', 'Comp. Sci.', 118);
	insert into student values('90009', 'Donofrio', 'Pol. Sci.', 13);
	insert into student values('97868', 'Schinag', 'Athletics', 104);
	insert into student values('17944', 'Hamarn', 'Mech. Eng.', 5);
	insert into student values('25380', 'Vassileva', 'English', 97);
	insert into student values('85614', 'Champes', 'English', 87);
	insert into student values('60984', 'Emms', 'Finance', 48);
	insert into student values('84495', 'Kurata', 'Psychology', 84);
	insert into student values('19321', 'Chang', 'Mech. Eng.', 124);
	insert into student values('99611', 'Schrefl', 'Pol. Sci.', 22);
	insert into student values('72485', 'Wetzel', 'Finance', 33);
	insert into student values('50267', 'Spengler', 'Finance', 52);
	insert into student values('544', 'Uchiyama', 'Biology', 81);
	insert into student values('55009', 'Pohlem', 'Pol. Sci.', 18);
	insert into student values('45083', 'Stasko', 'Marketing', 44);
	insert into student values('67018', 'Catona', 'Biology', 46);
	insert into student values('93039', 'Hau', 'English', 21);
	insert into student values('75772', 'Morton', 'Comp. Sci.', 48);
	insert into student values('60224', 'Bensaber', 'Physics', 54);
	insert into student values('41674', 'April', 'Biology', 46);
	insert into student values('97435', 'Winzer', 'Finance', 77);
	insert into student values('21101', 'Gotchev', 'Astronomy', 117);
	insert into student values('76250', 'Maw', 'History', 57);
	insert into student values('40682', 'Rowe', 'Geology', 114);
	insert into student values('39612', 'Androutsopoulos', 'Elec. Eng.', 103);
	insert into student values('14032', 'Belhadji', 'Elec. Eng.', 0);
	insert into student values('75791', 'Keuk', 'Finance', 11);
	insert into student values('5208', 'Feyr', 'Statistics', 47);
	insert into student values('43432', 'Caporali', 'Astronomy', 77);
	insert into student values('68453', 'Kjellmer', 'Elec. Eng.', 102);
	insert into student values('12711', 'Malagoli', 'Physics', 97);
	insert into student values('40932', 'Rioult', 'Comp. Sci.', 94);
	insert into student values('6710', 'Matli', 'Elec. Eng.', 102);
	insert into student values('91370', 'Frangeu', 'Mech. Eng.', 9);
	insert into student values('43912', 'Papakir', 'Finance', 34);
	insert into student values('12666', 'Power', 'Athletics', 118);
	insert into student values('74460', 'McWilliams', 'Statistics', 120);
	insert into student values('99422', 'Fickl', 'Civil Eng.', 83);
	insert into student values('95320', 'Morgan', 'Mech. Eng.', 127);
	insert into student values('56299', 'Sadry', 'Finance', 75);
	insert into student values('84432', 'Schrefl', 'Athletics', 111);
	insert into student values('75231', 'Ravindranath', 'Statistics', 127);
	insert into student values('94846', 'Hossain', 'Cybernetics', 103);
	insert into student values('4004', 'Tabor', 'Biology', 51);
	insert into student values('28361', 'Sorensen', 'Physics', 109);
	insert into student values('97228', 'Brzezinski', 'Mech. Eng.', 25);
	insert into student values('39552', 'Tsukamoto', 'Physics', 72);
	insert into student values('38676', 'Swien', 'Elec. Eng.', 48);
	insert into student values('94814', 'Kee', 'Mech. Eng.', 73);
	insert into student values('16035', 'Starker', 'English', 94);
	insert into student values('79205', 'Zander', 'Geology', 115);
	insert into student values('4682', 'Betho', 'Accounting', 59);
	insert into student values('5925', 'Maw', 'Languages', 30);
	insert into student values('25187', 'Fenwick', 'History', 103);
	insert into student values('19603', 'Colu', 'Finance', 122);
	insert into student values('41491', 'Beavis', 'Comp. Sci.', 15);
	insert into student values('99764', 'Lv', 'Marketing', 104);
	insert into student values('50537', 'Felling', 'Mech. Eng.', 20);
	insert into student values('67793', 'Pigd', 'Mech. Eng.', 45);
	insert into student values('47487', 'Villa', 'Finance', 72);
	insert into student values('19362', 'Linden', 'Finance', 123);
	insert into student values('25942', 'Leclercq', 'Mech. Eng.', 23);
	insert into student values('39238', 'Kyriakopoulos', 'Pol. Sci.', 90);
	insert into student values('65979', 'Chenu', 'Comp. Sci.', 22);
	insert into student values('22086', 'Ockerb', 'Athletics', 23);
	insert into student values('37734', 'Kamata', 'Civil Eng.', 68);
	insert into student values('17911', 'Audeh', 'Biology', 92);
	insert into student values('87831', 'Turunen', 'Psychology', 128);
	insert into student values('12214', 'Morales', 'Languages', 51);
	insert into student values('20378', 'Lomi', 'Languages', 3);
	insert into student values('11083', 'Kerridge', 'Statistics', 113);
	insert into student values('57377', 'Soricu', 'Elec. Eng.', 40);
	insert into student values('35881', 'Ã–zel', 'Cybernetics', 99);
	insert into student values('34542', 'Basile', 'Physics', 25);
	insert into student values('91978', 'Pourkas', 'Cybernetics', 128);
	insert into student values('87048', 'Gani', 'Mech. Eng.', 10);
	insert into student values('64820', 'Hendrickson', 'Geology', 79);
	insert into student values('57474', 'Coddington', 'Accounting', 110);
	insert into student values('53496', 'Cashman', 'Marketing', 27);
	insert into student values('87193', 'Pinkus', 'English', 25);
	insert into student values('847', 'Yamaguchi', 'Elec. Eng.', 105);
	insert into student values('42388', 'Nikut', 'History', 87);
	insert into student values('62749', 'Giroux', 'Math', 49);
	insert into student values('41988', 'Gall', 'Languages', 12);
	insert into student values('85680', 'Krohn', 'Mech. Eng.', 93);
	insert into student values('82083', 'Peeri', 'English', 58);
	insert into student values('65056', 'Kean', 'Astronomy', 76);
	insert into student values('3639', 'Story', 'Statistics', 73);
	insert into student values('37038', 'Grieng', 'Math', 114);
	insert into student values('9933', 'Pircher', 'Geology', 90);
	insert into student values('65190', 'Dumas', 'Accounting', 77);
	insert into student values('15328', 'Chien', 'Statistics', 129);
	insert into student values('59455', 'Lowenstein', 'English', 110);
	insert into student values('49873', 'Nikut', 'Athletics', 85);
	insert into student values('82039', 'Hendrickson', 'Astronomy', 37);
	insert into student values('20974', 'Hawkins', 'Mech. Eng.', 127);
	insert into student values('56089', 'Mezzar', 'Marketing', 109);
	insert into student values('86573', 'Schauser', 'Physics', 107);
	insert into student values('38712', 'Kreutz', 'Elec. Eng.', 29);
	insert into student values('42991', 'Kaiser', 'Languages', 126);
	insert into student values('28019', 'Cayto', 'History', 38);
	insert into student values('13023', 'Serrano', 'Marketing', 108);
	insert into student values('31761', 'Jame', 'Pol. Sci.', 57);
	insert into student values('56882', 'Browne', 'Comp. Sci.', 24);
	insert into student values('34788', 'Barkov', 'Civil Eng.', 35);
	insert into student values('17607', 'Ould', 'Athletics', 115);
	insert into student values('48776', 'Wall', 'Statistics', 58);
	insert into student values('78758', 'Chakraborty', 'Geology', 7);
	insert into student values('77218', 'Lohman', 'Finance', 51);
	insert into student values('4034', 'Xie', 'Elec. Eng.', 64);
	insert into student values('50658', 'Cayto', 'Civil Eng.', 56);
	insert into student values('76057', 'Sakanushi', 'Comp. Sci.', 2);
	insert into student values('96067', 'Sugavanam', 'Civil Eng.', 113);
	insert into student values('24784', 'Jessup', 'Comp. Sci.', 126);
	insert into student values('31560', 'Neld', 'Languages', 13);
	insert into student values('32345', 'Chormo', 'Biology', 38);
	insert into student values('76799', 'Monger', 'Statistics', 63);
	insert into student values('37454', 'Frasinc', 'Biology', 109);
	insert into student values('30943', 'Botha', 'History', 65);
	insert into student values('16405', 'Rahman', 'Languages', 5);
	insert into student values('95850', 'Schrefl', 'Comp. Sci.', 13);
	insert into student values('26619', 'Matsukawa', 'Biology', 58);
	insert into student values('17997', 'Ishikawa', 'Languages', 128);
	insert into student values('26427', 'Ende', 'Finance', 129);
	insert into student values('73213', 'Fall', 'Psychology', 64);
	insert into student values('93366', 'Gault', 'Cybernetics', 29);
	insert into student values('33882', 'Borutz', 'Civil Eng.', 3);
	insert into student values('37818', 'Jiao', 'Civil Eng.', 66);
	insert into student values('21102', 'He', 'Biology', 121);
	insert into student values('76798', 'Clifford', 'Languages', 43);
	insert into student values('31820', 'Riahi', 'Athletics', 51);
	insert into student values('63489', 'Enokib', 'Comp. Sci.', 81);
	insert into student values('51955', 'Tompa', 'Finance', 106);
	insert into student values('71631', 'Scheine', 'Astronomy', 87);
	insert into student values('48009', 'Lopes', 'Pol. Sci.', 36);
	insert into student values('51678', 'Klivansky', 'Pol. Sci.', 49);
	insert into student values('73602', 'Richardson', 'History', 119);
	insert into student values('11530', 'Ng', 'Marketing', 92);
	insert into student values('32376', 'Nakajima', 'Astronomy', 8);
	insert into student values('80799', 'Almeida', 'Finance', 106);
	insert into student values('40178', 'Greene', 'Mech. Eng.', 93);
	insert into student values('58701', 'Hampp', 'Geology', 44);
	insert into student values('46655', 'Advani', 'Athletics', 112);
	insert into student values('93043', 'McQuillan', 'Marketing', 42);
	insert into student values('1402', 'Oswald', 'Comp. Sci.', 12);
	insert into student values('29462', 'Daues', 'Pol. Sci.', 88);
	insert into student values('49701', 'Read', 'Civil Eng.', 33);
	insert into student values('96968', 'Mohamed', 'Mech. Eng.', 118);
	insert into student values('89551', 'Shapiro', 'History', 127);
	insert into student values('32483', 'Atre', 'Math', 114);
	insert into student values('39472', 'Soper', 'Elec. Eng.', 62);
	insert into student values('88045', 'Jackson', 'Languages', 126);
	insert into student values('30474', 'Paniez', 'Athletics', 55);
	insert into student values('31476', 'OConnor', 'Elec. Eng.', 7);
	insert into student values('95175', 'Guiho', 'Elec. Eng.', 42);
	insert into student values('95697', 'Gruns', 'Cybernetics', 77);
	insert into student values('37759', 'Signah', 'Cybernetics', 26);
	insert into student values('96134', 'Prince', 'Languages', 121);
	insert into student values('92464', 'Enokib', 'History', 47);
	insert into student values('78434', 'Ruhe', 'Psychology', 26);
	insert into student values('44038', 'Chandra', 'Civil Eng.', 11);
	insert into student values('43993', 'Halbert', 'Math', 113);
	insert into student values('914', 'Schill', 'Comp. Sci.', 32);
	insert into student values('19342', 'Bouzeghoub', 'Finance', 35);
	insert into student values('13749', 'Alfaro', 'Marketing', 23);
	insert into student values('33546', 'Saguez', 'Pol. Sci.', 53);
	insert into student values('40116', 'Joshi', 'Psychology', 23);
	insert into student values('46980', 'Roessler', 'Astronomy', 58);
	insert into student values('31266', 'Kacpr', 'Physics', 22);
	insert into student values('65688', 'Loudn', 'Mech. Eng.', 65);
	insert into student values('65563', 'Bawa', 'Psychology', 111);
	insert into student values('83314', 'Chow', 'Accounting', 40);
	insert into student values('39876', 'Wood', 'Accounting', 14);
	insert into student values('44706', 'Bland', 'English', 119);
	insert into student values('15086', 'Sun', 'Physics', 74);
	insert into student values('12615', 'Tewari', 'Geology', 40);
	insert into student values('63538', 'Pulido', 'History', 46);
	insert into student values('17831', 'Srivastava', 'Languages', 75);
	insert into student values('96117', 'Nisso', 'English', 128);
	insert into student values('82066', 'Varghese', 'Comp. Sci.', 11);
	insert into student values('28738', 'Birkett', 'Civil Eng.', 94);
	insert into student values('84515', 'Levie', 'Biology', 126);
	insert into student values('90132', 'Jo', 'Psychology', 11);
	insert into student values('8192', 'Verma', 'Civil Eng.', 123);
	insert into student values('25611', 'Sve', 'English', 107);
	insert into student values('50743', 'Lindner', 'Biology', 83);
	insert into student values('41683', 'Pietkiewicz', 'Biology', 20);
	insert into student values('99553', 'Strader', 'Languages', 6);
	insert into student values('22179', 'Sundho', 'Statistics', 40);
	insert into student values('65121', 'Winter', 'Comp. Sci.', 56);
	insert into student values('52057', 'Garg', 'Elec. Eng.', 101);
	insert into student values('931', 'Tsalidi', 'English', 122);
	insert into student values('23392', 'Curutchet', 'Elec. Eng.', 43);
	insert into student values('33759', 'Mowbray', 'Psychology', 44);
	insert into student values('52203', 'Suwanno', 'Pol. Sci.', 41);
	insert into student values('78581', 'Hegde', 'Finance', 41);
	insert into student values('65241', 'Riser', 'Astronomy', 96);
	insert into student values('45359', 'Zelek', 'Marketing', 79);
	insert into student values('86001', 'Meise', 'English', 27);
	insert into student values('22532', 'Silverman', 'History', 120);
	insert into student values('97573', 'Yusop', 'Physics', 60);
	insert into student values('90609', 'Mohamed', 'Finance', 95);
	insert into student values('16528', 'Angs', 'Accounting', 24);
	insert into student values('61920', 'Marcol', 'Geology', 59);
	insert into student values('282', 'Rougemont', 'Languages', 34);
	insert into student values('85602', 'Bogdanova', 'Pol. Sci.', 81);
	insert into student values('62832', 'Anderson', 'English', 19);
	insert into student values('78454', 'Michael', 'Pol. Sci.', 68);
	insert into student values('30222', 'Lepp', 'Accounting', 121);
	insert into student values('28994', 'Williamson', 'Statistics', 104);
	insert into student values('39927', 'Bartels', 'History', 62);
	insert into student values('74070', 'Sandberg', 'Mech. Eng.', 119);
	insert into student values('65208', 'Farahvash', 'Civil Eng.', 45);
	insert into student values('2286', 'Ceze', 'Elec. Eng.', 65);
	insert into student values('49450', 'Gotoh', 'Astronomy', 83);
	insert into student values('83214', 'Dasd', 'Biology', 35);
	insert into student values('6287', 'Makowski', 'Pol. Sci.', 32);
	insert into student values('86661', 'Shani', 'Elec. Eng.', 21);
	insert into student values('68242', 'Hugo', 'English', 109);
	insert into student values('42092', 'Arinb', 'Comp. Sci.', 47);
	insert into student values('9993', 'Won', 'Math', 40);
	insert into student values('89734', 'Doeschn', 'Astronomy', 66);
	insert into student values('7732', 'Osc', 'Comp. Sci.', 98);
	insert into student values('89312', 'Marques', 'Statistics', 101);
	insert into student values('35357', 'Gradino', 'English', 34);
	insert into student values('86127', 'Spikov', 'Math', 27);
	insert into student values('18775', 'Pampal', 'Comp. Sci.', 89);
	insert into student values('24374', 'Jo', 'Cybernetics', 105);
	insert into student values('2848', 'Carr', 'Civil Eng.', 121);
	insert into student values('78143', 'Erdem', 'Astronomy', 12);
	insert into student values('50977', 'Allen', 'Elec. Eng.', 93);
	insert into student values('96895', 'Stelzl', 'Statistics', 94);
	insert into student values('95626', 'Tellez', 'Math', 32);
	insert into student values('22260', 'Daat', 'Accounting', 8);
	insert into student values('23224', 'Kempn', 'Psychology', 81);
	insert into student values('27528', 'Probst', 'Biology', 95);
	insert into student values('71025', 'Cadis', 'History', 129);
	insert into student values('36845', 'Okaf', 'Math', 30);
	insert into student values('17924', 'Tavan', 'Psychology', 97);
	insert into student values('69632', 'Gibbs', 'Languages', 40);
	insert into student values('70828', 'Kaska', 'Physics', 88);
	insert into student values('27687', 'YÃ¼ksel', 'Physics', 31);
	insert into student values('28299', 'Grange', 'Languages', 120);
	insert into student values('14869', 'Palmer', 'Astronomy', 106);
	insert into student values('11152', 'Al-Tahat', 'English', 87);
	insert into student values('17507', 'Mathur', 'Mech. Eng.', 48);
	insert into student values('57107', 'Janssen', 'Astronomy', 36);
	insert into student values('47670', 'Xue', 'Pol. Sci.', 55);
	insert into student values('25718', 'Seyfert', 'Athletics', 83);
	insert into student values('67293', 'Ueno', 'History', 19);
	insert into student values('41091', 'Maillet', 'Geology', 66);
	insert into student values('86674', 'Peter', 'Biology', 105);
	insert into student values('23506', 'Ã…strÃ¶m', 'Pol. Sci.', 109);
	insert into student values('8022', 'Heng', 'Languages', 74);
	insert into student values('97953', 'Kaneko', 'Math', 110);
	insert into student values('86934', 'Berthold', 'Athletics', 35);
	insert into student values('58172', 'GeiÃŸl', 'Astronomy', 127);
	insert into student values('81610', 'Ching', 'Languages', 0);
	insert into student values('77172', 'Klepper', 'Statistics', 64);
	insert into student values('499', 'Seike', 'Elec. Eng.', 52);
	insert into student values('94730', 'Neff', 'Geology', 101);
	insert into student values('40371', 'Trimble', 'Physics', 109);
	insert into student values('3651', 'Narayanan', 'Elec. Eng.', 14);
	insert into student values('85904', 'Harass', 'Cybernetics', 120);
	insert into student values('73394', 'Blasbe', 'Geology', 96);
	insert into student values('8807', 'Zacharias', 'Finance', 33);
	insert into student values('62705', 'Hoffman', 'Marketing', 86);
	insert into student values('11578', 'Kwan', 'Languages', 37);
	insert into student values('68248', 'Tillmann', 'Athletics', 83);
	insert into student values('98315', 'Saill', 'Pol. Sci.', 65);
	insert into student values('62754', 'Durrant', 'Geology', 54);
	insert into student values('41406', 'Dahmann', 'Biology', 24);
	insert into student values('82063', 'Zeng', 'Athletics', 68);
	insert into student values('87706', 'Nakao', 'Physics', 80);
	insert into student values('20540', 'Cunha', 'History', 58);
	insert into student values('69960', 'RaÃ¯ev', 'Biology', 17);
	insert into student values('30252', 'Folkers', 'Geology', 80);
	insert into student values('70098', 'Prabhakaran', 'Biology', 61);
	insert into student values('93986', 'Zahrani', 'Physics', 73);
	insert into student values('35685', 'Usi', 'History', 31);
	insert into student values('31364', 'Rieger', 'Biology', 94);
	insert into student values('36494', 'Baccou', 'Psychology', 41);
	insert into student values('32217', 'Argar', 'Math', 14);
	insert into student values('69952', 'MuÃ±oz', 'Psychology', 115);
	insert into student values('52523', 'Hobbs', 'English', 14);
	insert into student values('7149', 'Xin', 'Pol. Sci.', 120);
	insert into student values('71878', 'Hayat', 'Finance', 27);
	insert into student values('29192', 'Gomez', 'Geology', 81);
	insert into student values('79446', 'Frost', 'Pol. Sci.', 24);
	insert into student values('77000', 'Cherchi', 'Physics', 125);
	insert into student values('1836', 'Marinov', 'Elec. Eng.', 85);
	insert into student values('84167', 'Sakanushi', 'Comp. Sci.', 20);
	insert into student values('81785', 'Crues', 'Civil Eng.', 102);
	insert into student values('1087', 'Roses', 'Accounting', 73);
	insert into student values('5617', 'Souza', 'Languages', 60);
	insert into student values('53547', 'Neubert', 'Mech. Eng.', 66);
	insert into student values('39978', 'Drig', 'English', 92);
	insert into student values('60748', 'Nagal', 'Elec. Eng.', 58);
	insert into student values('23449', 'Noda', 'Cybernetics', 94);
	insert into student values('52385', 'Higuchi', 'Astronomy', 78);
	insert into student values('2139', 'Agarwal', 'Physics', 99);
	insert into student values('12941', 'Ren', 'Marketing', 76);
	insert into student values('72521', 'Caleff', 'Mech. Eng.', 48);
	insert into student values('82580', 'Wyes', 'Mech. Eng.', 103);
	insert into student values('39394', 'Reinhardt', 'History', 84);
	insert into student values('39901', 'Dellwo', 'Biology', 82);
	insert into student values('3493', 'Riser', 'Geology', 16);
	insert into student values('90353', 'Bruderm', 'Astronomy', 46);
	insert into student values('69747', 'Beichn', 'Finance', 34);
	insert into student values('39514', 'Yean', 'Accounting', 65);
	insert into student values('36995', 'Sgot', 'Finance', 79);
	insert into student values('12971', 'Bumbau', 'Elec. Eng.', 47);
	insert into student values('76768', 'Oblak', 'Pol. Sci.', 56);
	insert into student values('79502', 'Marongiu', 'Math', 84);
	insert into student values('63390', 'Loudn', 'Cybernetics', 41);
	insert into student values('19824', 'Savelieva', 'Physics', 7);
	insert into student values('46769', 'Kivv', 'Psychology', 85);
	insert into student values('65400', 'Horecz', 'Psychology', 49);
	insert into student values('44258', 'Steinmetz', 'Accounting', 28);
	insert into student values('81896', 'Feldman', 'Finance', 46);
	insert into student values('79772', 'Witty', 'Marketing', 4);
	insert into student values('46155', 'Kruglyak', 'Astronomy', 67);
	insert into student values('18709', 'Agar', 'Math', 65);
	insert into student values('63502', 'Xie', 'Languages', 69);
	insert into student values('39521', 'Holloway', 'Accounting', 113);
	insert into student values('51203', 'Lahtinen', 'Math', 99);
	insert into student values('96741', 'Kobayashi', 'Comp. Sci.', 87);
	insert into student values('38371', 'Harada', 'Math', 50);
	insert into student values('59673', 'Mertens', 'Astronomy', 98);
	insert into student values('13365', 'Wolter', 'Mech. Eng.', 55);
	insert into student values('1000', 'Manber', 'Civil Eng.', 39);
	insert into student values('19735', 'Bishop', 'Physics', 9);
	insert into student values('34126', 'Schreitm', 'Accounting', 14);
	insert into student values('16467', 'Meyl', 'Comp. Sci.', 92);
	insert into student values('80248', 'Satoh', 'English', 74);
	insert into student values('58634', 'Choung', 'Finance', 101);
	insert into student values('51975', 'Nicol', 'Languages', 127);
	insert into student values('77548', 'Krohn', 'History', 45);
	insert into student values('74796', 'Vulp', 'History', 108);
	insert into student values('85981', 'Kahs', 'Statistics', 91);
	insert into student values('29645', 'Oller', 'History', 120);
	insert into student values('89234', 'Hird', 'Civil Eng.', 78);
	insert into student values('94142', 'Simon', 'Languages', 45);
	insert into student values('79697', 'Marquis', 'Accounting', 75);
	insert into student values('90089', 'Mohan', 'Astronomy', 28);
	insert into student values('20244', 'Abu-B', 'Marketing', 112);
	insert into student values('37350', 'Sohn', 'Physics', 49);
	insert into student values('81638', 'Chiu', 'Statistics', 30);
	insert into student values('90914', 'Grange', 'Pol. Sci.', 38);
	insert into student values('75395', 'Moscarini', 'Psychology', 19);
	insert into student values('42556', 'Tsantis', 'Languages', 43);
	insert into student values('10556', 'Reed', 'English', 79);
	insert into student values('39619', 'Dwyer', 'Mech. Eng.', 89);
	insert into student values('38288', 'Matsuda', 'Mech. Eng.', 107);
	insert into student values('20985', 'Wunderli', 'History', 66);
	insert into student values('38548', 'Scibili', 'Pol. Sci.', 88);
	insert into student values('15698', 'Dink', 'Psychology', 72);
	insert into student values('23500', 'Kinney', 'Marketing', 68);
	insert into student values('70965', 'Dooley', 'Languages', 66);
	insert into student values('76911', 'Alart', 'Finance', 66);
	insert into student values('3545', 'Peskin', 'Statistics', 119);
	insert into student values('46694', 'Masamura', 'Math', 118);
	insert into student values('99977', 'Englund', 'Psychology', 93);
	insert into student values('90124', 'Koppit', 'Physics', 104);
	insert into student values('95840', 'Jakobsen', 'History', 127);
	insert into student values('56143', 'Yusop', 'Civil Eng.', 86);
	insert into student values('79469', 'Jacobs', 'Math', 38);
	insert into student values('3693', 'Zafar', 'Athletics', 27);
	insert into student values('42096', 'Freib', 'Biology', 10);
	insert into student values('88472', 'Lynch', 'Marketing', 12);
	insert into student values('14874', 'Singhal', 'Comp. Sci.', 34);
	insert into student values('978', 'Salzman', 'Comp. Sci.', 127);
	insert into student values('33201', 'Macias', 'Civil Eng.', 61);
	insert into student values('30161', 'Grude', 'Cybernetics', 23);
	insert into student values('46441', 'Zander', 'Athletics', 18);
	insert into student values('31035', 'Arnoux', 'Civil Eng.', 92);
	insert into student values('67371', 'Garcia-Ferr', 'Geology', 70);
	insert into student values('80651', 'Holz', 'English', 108);
	insert into student values('43505', 'Yoon', 'Statistics', 118);
	insert into student values('35498', 'Lanfr', 'Accounting', 78);
	insert into student values('48423', 'Krone', 'Pol. Sci.', 80);
	insert into student values('51093', 'Syng', 'Psychology', 92);
	insert into student values('78572', 'Kurt', 'Comp. Sci.', 20);
	insert into student values('52669', 'Rayad', 'Physics', 114);
	insert into student values('87246', 'Dellwo', 'Comp. Sci.', 15);
	insert into student values('69122', 'Epstein', 'Biology', 128);
	insert into student values('52945', 'Adeni', 'Languages', 13);
	insert into student values('52471', 'Recc', 'Finance', 110);
	insert into student values('62728', 'Camme', 'Biology', 107);
	insert into student values('52929', 'Hashim', 'Math', 118);
	insert into student values('85754', 'Betho', 'Finance', 45);
	insert into student values('18583', 'Ma', 'Finance', 74);
	insert into student values('74974', 'Lao', 'Athletics', 86);
	insert into student values('48611', 'Suppan', 'Geology', 102);
	insert into student values('63582', 'Fischer', 'Pol. Sci.', 120);
	insert into student values('53118', 'Carvey', 'Comp. Sci.', 120);
	insert into student values('88887', 'Wodn', 'Languages', 122);
	insert into student values('81175', 'Zelek', 'Biology', 0);
	insert into student values('69783', 'Putru', 'Pol. Sci.', 117);
	insert into student values('14829', 'Philippe', 'Accounting', 105);
	insert into student values('53469', 'Fujii', 'Astronomy', 43);
	insert into student values('44304', 'Cox', 'English', 31);
	insert into student values('48861', 'Ende', 'Accounting', 54);
	insert into student values('73411', 'Schulz', 'Math', 78);
	insert into student values('95225', 'Moire', 'Languages', 99);
	insert into student values('53788', 'Byun', 'Astronomy', 101);
	insert into student values('68712', 'Hill', 'Civil Eng.', 30);
	insert into student values('52866', 'Loull', 'Math', 30);
	insert into student values('5298', 'Radici', 'Finance', 10);
	insert into student values('58606', 'Opitz', 'Cybernetics', 91);
	insert into student values('76049', 'Tavan', 'Cybernetics', 112);
	insert into student values('78858', 'Abdul-Rahman', 'Psychology', 49);
	insert into student values('97041', 'Rajnov', 'Psychology', 22);
	insert into student values('98388', 'Nilsson', 'Math', 33);
	insert into student values('15024', 'Kawahara', 'Civil Eng.', 10);
	insert into student values('5243', 'Bajracharya', 'Marketing', 83);
	insert into student values('80990', 'Strzem', 'Biology', 117);
	insert into student values('77664', 'Apostolov', 'Marketing', 125);
	insert into student values('49982', 'Haigh', 'Geology', 41);
	insert into student values('87222', 'Allard', 'Mech. Eng.', 114);
	insert into student values('35523', 'Yamamoto', 'Accounting', 15);
	insert into student values('14499', 'Axte', 'Biology', 115);
	insert into student values('33107', 'Liley', 'Civil Eng.', 16);
	insert into student values('18108', 'Brailsford', 'Cybernetics', 107);
	insert into student values('67655', 'Kuch', 'Math', 46);
	insert into student values('95852', 'Cabr', 'Athletics', 48);
	insert into student values('50664', 'Rajnov', 'Biology', 127);
	insert into student values('59117', 'Belmes', 'Astronomy', 109);
	insert into student values('435', 'Moskow', 'Languages', 32);
	insert into student values('75596', 'Sayre', 'Biology', 19);
	insert into student values('34197', 'Nestor', 'Languages', 106);
	insert into student values('66281', 'Schelten', 'Civil Eng.', 49);
	insert into student values('86736', 'Franchet', 'Finance', 94);
	insert into student values('14484', 'Langer', 'Astronomy', 62);
	insert into student values('88308', 'Reiss', 'English', 19);
	insert into student values('36657', 'Ching', 'English', 51);
	insert into student values('93125', 'Harders', 'Physics', 47);
	insert into student values('29140', 'Reuver', 'Elec. Eng.', 123);
	insert into student values('85211', 'Sumi', 'Athletics', 109);
	insert into student values('23525', 'DAgostino', 'Elec. Eng.', 128);
	insert into student values('3005', 'Ibrahim', 'Pol. Sci.', 73);
	insert into student values('91197', 'Manzoor', 'Geology', 110);
	insert into student values('1285', 'Szczerban', 'Pol. Sci.', 97);
	insert into student values('29863', 'Harmon', 'Athletics', 112);
	insert into student values('15070', 'Enokib', 'Math', 65);
	insert into student values('98047', 'Takahashi', 'History', 49);
	insert into student values('87624', 'Carrera', 'Civil Eng.', 81);
	insert into student values('38902', 'Xiang', 'Math', 61);
	insert into student values('15538', 'Yeung', 'Athletics', 111);
	insert into student values('83691', 'Katehakis', 'Mech. Eng.', 33);
	insert into student values('89759', 'Zettel', 'Mech. Eng.', 55);
	insert into student values('34770', 'Porter', 'Languages', 111);
	insert into student values('11202', 'Heckman', 'Math', 120);
	insert into student values('65681', 'Roses', 'English', 17);
	insert into student values('17665', 'Tewari', 'English', 62);
	insert into student values('11966', 'Kowe', 'Math', 69);
	insert into student values('21556', 'Negron', 'Marketing', 60);
	insert into student values('24002', 'Russa', 'Languages', 14);
	insert into student values('75878', 'Hahn-', 'Physics', 53);
	insert into student values('52120', 'Redw', 'Physics', 8);
	insert into student values('93491', 'Rees-', 'History', 74);
	insert into student values('78637', 'Beeu', 'Physics', 42);
	insert into student values('9256', 'Tran-', 'Pol. Sci.', 107);
	insert into student values('41345', 'Tola', 'Finance', 17);
	insert into student values('98726', 'Mathias', 'Comp. Sci.', 36);
	insert into student values('5381', 'Diana', 'Languages', 30);
	insert into student values('99647', 'Bellman', 'English', 106);
	insert into student values('50331', 'Bullinger', 'Psychology', 9);
	insert into student values('48247', 'Gustafsson', 'History', 80);
	insert into student values('65753', 'Planti', 'Geology', 12);
	insert into student values('29091', 'Ahso', 'Pol. Sci.', 22);
	insert into student values('72165', 'Otsuki', 'Psychology', 61);
	insert into student values('43981', 'Quimby', 'Pol. Sci.', 87);
	insert into student values('16057', 'Wicki', 'Mech. Eng.', 114);
	insert into student values('88525', 'Hung', 'Mech. Eng.', 92);
	insert into student values('16480', 'Noga', 'Psychology', 5);
	insert into student values('92849', 'Flossmann', 'Astronomy', 54);
	insert into student values('9495', 'Crimm', 'Comp. Sci.', 68);
	insert into student values('14581', 'Vagn', 'Biology', 129);
	insert into student values('65901', 'Shishkin', 'Accounting', 120);
	insert into student values('96203', 'Olin', 'Comp. Sci.', 87);
	insert into student values('1954', 'Frank', 'Geology', 29);
	insert into student values('66484', 'Amberg', 'Mech. Eng.', 75);
	insert into student values('15083', 'Formisano', 'Physics', 50);
	insert into student values('48901', 'Gong', 'Marketing', 57);
	insert into student values('15340', 'Silbert', 'Psychology', 39);
	insert into student values('16515', 'Suppan', 'Languages', 48);
	insert into student values('54620', 'Hancock', 'Geology', 27);
	insert into student values('15430', 'Sasso', 'Psychology', 39);
	insert into student values('27236', 'Date', 'Astronomy', 105);
	insert into student values('2201', 'Sauer', 'Biology', 99);
	insert into student values('69471', 'Aly', 'Astronomy', 41);
	insert into student values('13880', 'Lazos', 'Physics', 98);
	insert into student values('827', 'Das', 'Languages', 98);
	insert into student values('42960', 'McGinn', 'Finance', 95);
	insert into student values('48471', 'Elias', 'Languages', 90);
	insert into student values('13217', 'Liu', 'Athletics', 95);
	insert into student values('45570', 'Hoyos', 'Biology', 99);
	insert into student values('94815', 'Xiang', 'Finance', 6);
	insert into student values('1922', 'Cavalcanti', 'Athletics', 48);
	insert into student values('51084', 'Pah', 'Languages', 63);
	insert into student values('842', 'Jode', 'Languages', 81);
	insert into student values('53152', 'Sayre', 'Civil Eng.', 18);
	insert into student values('11201', 'Bianchi', 'Statistics', 0);
	insert into student values('88577', 'Smoro', 'Astronomy', 91);
	insert into student values('22050', 'Alioto', 'Physics', 108);
	insert into student values('68010', 'Blecken', 'Pol. Sci.', 43);
	insert into student values('10838', 'Marlet', 'Accounting', 91);
	insert into student values('59848', 'Barwin', 'History', 86);
	insert into student values('7035', 'Liots', 'English', 23);
	insert into student values('5463', 'Reiss', 'Finance', 95);
	insert into student values('74464', 'Sulimova', 'Athletics', 76);
	insert into student values('16969', 'Hakkinen', 'Finance', 70);
	insert into student values('62054', 'Wood', 'Mech. Eng.', 13);
	insert into student values('50719', 'Model', 'Geology', 66);
	insert into student values('41280', 'Birtz', 'Finance', 83);
	insert into student values('31341', 'Rotter', 'Marketing', 32);
	insert into student values('23475', 'Cecchi', 'Athletics', 16);
	insert into student values('55354', 'Yang', 'Comp. Sci.', 107);
	insert into student values('50966', 'Concilio', 'Finance', 95);
	insert into student values('10269', 'Hilberg', 'Psychology', 75);
	insert into student values('92659', 'Mathias', 'Biology', 98);
	insert into student values('49792', 'Petersen', 'Accounting', 38);
	insert into student values('27140', 'Fitzpatrick', 'Marketing', 98);
	insert into student values('993', 'McGarr', 'Comp. Sci.', 55);
	insert into student values('58326', 'Afim', 'Accounting', 100);
	insert into student values('70924', 'Rajnov', 'Civil Eng.', 0);
	insert into student values('71944', 'Schinag', 'Mech. Eng.', 58);
	insert into student values('95201', 'Yang', 'Psychology', 28);
	insert into student values('52876', 'Dahmann', 'Languages', 50);
	insert into student values('58355', 'Honeyman', 'Athletics', 42);
	insert into student values('90181', 'Giannoulis', 'Biology', 23);
	insert into student values('53799', 'Okabe', 'Cybernetics', 12);
	insert into student values('13511', 'Adam', 'Cybernetics', 15);
	insert into student values('69521', 'Greenbaum', 'Accounting', 124);
	insert into student values('37946', 'Vrato', 'Finance', 110);
	insert into student values('15578', 'Pacie', 'Elec. Eng.', 32);
	insert into student values('16311', 'Liao', 'Accounting', 33);
	insert into student values('56124', 'Strieg', 'Civil Eng.', 33);
	insert into student values('63560', 'Gleit', 'History', 82);
	insert into student values('75299', 'Miao', 'Marketing', 82);
	insert into student values('61356', 'Vulp', 'Cybernetics', 6);
	insert into student values('70061', 'Konno', 'Comp. Sci.', 50);
	insert into student values('61232', 'Fukui', 'Pol. Sci.', 48);
	insert into student values('16523', 'Redw', 'Math', 117);
	insert into student values('57238', 'Rehd', 'Accounting', 33);
	insert into student values('63645', 'Mandviwall', 'Marketing', 20);
	insert into student values('55857', 'Martin', 'Languages', 74);
	insert into student values('90041', 'Barberis', 'Mech. Eng.', 122);
	insert into student values('68263', 'Roessler', 'Languages', 69);
	insert into student values('48165', 'Asikainen', 'Marketing', 57);
	insert into student values('23373', 'Lang', 'Astronomy', 70);
	insert into student values('5336', 'Peltz', 'Math', 22);
	insert into student values('18286', 'Pang', 'Finance', 110);
	insert into student values('4860', 'Penneb', 'Elec. Eng.', 83);
	insert into student values('68516', 'Kouan', 'Mech. Eng.', 8);
	insert into student values('94766', 'Buril', 'History', 81);
	insert into student values('72669', 'Schmitz', 'Elec. Eng.', 126);
	insert into student values('41596', 'Abeggl', 'Finance', 51);
	insert into student values('55286', 'Kihn', 'Mech. Eng.', 73);
	insert into student values('10693', 'Zabary', 'Statistics', 111);
	insert into student values('50467', 'Kabir', 'Athletics', 71);
	insert into student values('21692', 'Nagal', 'Accounting', 83);
	insert into student values('8517', 'Tomkins', 'Pol. Sci.', 100);
	insert into student values('28133', 'Evano', 'Civil Eng.', 53);
	insert into student values('10033', 'Zelty', 'Mech. Eng.', 60);
	insert into student values('60406', 'Sofer', 'Physics', 113);
	insert into student values('50703', 'Blanchard', 'Astronomy', 44);
	insert into student values('98359', 'Patne', 'Accounting', 105);
	insert into student values('23992', 'Thornton', 'Psychology', 58);
	insert into student values('31554', 'Fuller', 'Geology', 102);
	insert into student values('70807', 'Kreitman', 'Math', 91);
	insert into student values('4355', 'Cui', 'English', 127);
	insert into student values('8457', 'Christiansen', 'Mech. Eng.', 26);
	insert into student values('10904', 'Jerns', 'History', 21);
	insert into student values('83836', 'Gifford', 'Pol. Sci.', 64);
	insert into student values('72657', 'Hird', 'Comp. Sci.', 129);
	insert into student values('46035', 'Kamez', 'Biology', 42);
	insert into student values('36881', 'Dalton', 'Biology', 32);
	insert into student values('79487', 'Androutsopoulos', 'Languages', 2);
	insert into student values('48778', 'Pup', 'Psychology', 107);
	insert into student values('64039', 'Aarde', 'Civil Eng.', 120);
	insert into student values('42565', 'Hartsk', 'Astronomy', 27);
	insert into student values('29665', 'Lykin', 'Languages', 94);
	insert into student values('83511', 'Godfrey', 'Finance', 87);
	insert into student values('45494', 'Matsush', 'Geology', 105);
	insert into student values('12173', 'Thimm', 'English', 60);
	insert into student values('16993', 'Akaiw', 'Accounting', 82);
	insert into student values('62784', 'Stylian', 'Biology', 65);
	insert into student values('23344', 'Fierro-', 'Math', 56);
	insert into student values('92417', 'Dubink', 'Comp. Sci.', 92);
	insert into student values('86529', 'Leister', 'Accounting', 22);
	insert into student values('84654', 'BraÃ±a', 'Statistics', 59);
	insert into student values('52134', 'Johnson', 'Physics', 9);
	insert into student values('90234', 'Sram', 'Biology', 31);
	insert into student values('13921', 'Berger', 'Math', 120);
	insert into student values('76169', 'Williamson', 'Astronomy', 123);
	insert into student values('41832', 'Curl', 'History', 2);
	insert into student values('68720', 'Gordon', 'Civil Eng.', 94);
	insert into student values('66753', 'Mazzat', 'Math', 17);
	insert into student values('13753', 'Hoshi', 'Civil Eng.', 68);
	insert into student values('57190', 'Theuniss', 'History', 73);
	insert into student values('27804', 'Brunt', 'English', 75);
	insert into student values('63449', 'Sellink', 'Accounting', 39);
	insert into student values('27017', 'Trur', 'Elec. Eng.', 11);
	insert into student values('52291', 'Wolff', 'Mech. Eng.', 39);
	insert into student values('80941', 'Sankappanavar', 'Math', 70);
	insert into student values('95953', 'Batano', 'Comp. Sci.', 77);
	insert into student values('72528', 'Tuki', 'Cybernetics', 76);
	insert into student values('61854', 'Roytman', 'Psychology', 128);
	insert into student values('91851', 'Tchuri', 'History', 101);
	insert into student values('38973', 'Maglioni', 'Comp. Sci.', 56);
	insert into student values('83480', 'Whitten', 'Psychology', 9);
	insert into student values('13504', 'Zander', 'Astronomy', 90);
	insert into student values('19766', 'Simon', 'Biology', 29);
	insert into student values('50365', 'Held', 'Mech. Eng.', 121);
	insert into student values('43616', 'Tam', 'Athletics', 15);
	insert into student values('19917', 'Hayrapetyan', 'Languages', 121);
	insert into student values('29849', 'Solar', 'Physics', 90);
	insert into student values('85063', 'Chaney', 'Mech. Eng.', 4);
	insert into student values('70564', 'Bouguet', 'Psychology', 13);
	insert into student values('38121', 'Zuyev', 'English', 98);
	insert into student values('14563', 'Haigh', 'Comp. Sci.', 16);
	insert into student values('6895', 'Portillo', 'Geology', 4);
	insert into student values('3039', 'Brookh', 'Languages', 47);
	insert into student values('86969', 'Wicki', 'Cybernetics', 125);
	insert into student values('11455', 'Peyse', 'Athletics', 18);
	insert into student values('24809', 'Engeldr', 'Psychology', 23);
	insert into student values('50414', 'Landau', 'Accounting', 49);
	insert into student values('57026', 'Rotom', 'Geology', 44);
	insert into student values('69081', 'Stratulat', 'Geology', 59);
	insert into student values('7498', 'Charng', 'Physics', 82);
	insert into student values('34158', 'Mantzo', 'Astronomy', 127);
	insert into student values('15144', 'Lapio', 'Statistics', 110);
	insert into student values('88287', 'Geser', 'Athletics', 61);
	insert into student values('72006', 'Jawad', 'Comp. Sci.', 114);
	insert into student values('49244', 'Chikar', 'Psychology', 49);
	insert into student values('14639', 'Sagiv', 'Mech. Eng.', 26);
	insert into student values('76604', 'Ã‡ivi', 'History', 99);
	insert into student values('80113', 'Boudjelo', 'Geology', 10);
	insert into student values('18740', 'Williamson', 'Athletics', 16);
	insert into student values('69628', 'Bouamama', 'Psychology', 124);
	insert into student values('13757', 'Bedny', 'Astronomy', 3);
	insert into student values('36513', 'Ugarte', 'Athletics', 99);
	insert into student values('97042', 'Bhargava', 'Pol. Sci.', 68);
	insert into student values('46260', 'Bloom', 'History', 55);
	insert into student values('29871', 'Iwasa', 'Math', 75);
	insert into student values('75082', 'Havill', 'Comp. Sci.', 119);
	insert into student values('65715', 'Novak', 'Mech. Eng.', 37);
	insert into student values('54875', 'Feng', 'Statistics', 83);
	insert into student values('99710', 'Savolainen', 'Languages', 126);
	insert into student values('36384', 'Sandsj', 'Finance', 62);
	insert into student values('51923', 'Peterson', 'Civil Eng.', 128);
	insert into student values('37653', 'Campbell', 'Marketing', 64);
	insert into student values('61783', 'Guyer', 'Comp. Sci.', 102);
	insert into student values('86552', 'Martin', 'Pol. Sci.', 78);
	insert into student values('11855', 'Mendelzon', 'Languages', 114);
	insert into student values('43016', 'Beekw', 'History', 77);
	insert into student values('11237', 'Rokhs', 'Physics', 5);
	insert into student values('96710', 'Katehakis', 'Languages', 51);
	insert into student values('27044', 'Kota', 'Elec. Eng.', 45);
	insert into student values('25046', 'Cotterill', 'Finance', 57);
	insert into student values('62487', 'Durrant', 'History', 68);
	insert into student values('49759', 'Androutsopoulos', 'Finance', 110);
	insert into student values('65101', 'Spengler', 'Civil Eng.', 73);
	insert into student values('64550', 'Kubo', 'Statistics', 42);
	insert into student values('25143', 'Visr', 'Accounting', 11);
	insert into student values('13495', 'Srini', 'Pol. Sci.', 34);
	insert into student values('67560', 'Sandberg', 'Geology', 63);
	insert into student values('28316', 'Rajan', 'Mech. Eng.', 61);
	insert into student values('47379', 'Wakamiya', 'Comp. Sci.', 113);
	insert into student values('56003', 'Someren', 'Geology', 39);
	insert into student values('32369', 'Kaleta', 'Psychology', 34);
	insert into student values('52187', 'Fritsch', 'Math', 98);
	insert into student values('91992', 'DAtri', 'Cybernetics', 85);
	insert into student values('71543', 'Mizuno', 'Civil Eng.', 61);
	insert into student values('1220', 'Hito', 'Geology', 42);
	insert into student values('40937', 'Petzo', 'Geology', 115);
	insert into student values('14065', 'Starker', 'History', 7);
	insert into student values('43495', 'Scher', 'Astronomy', 111);
	insert into student values('26494', 'Heers', 'Psychology', 28);
	insert into student values('12362', 'Zhanr', 'Civil Eng.', 115);
	insert into student values('41675', 'Wheeler', 'Physics', 32);
	insert into student values('78314', 'Visr', 'English', 14);
	insert into student values('51579', 'Holz', 'Biology', 89);
	insert into student values('2178', 'Mingoz', 'Elec. Eng.', 41);
	insert into student values('86707', 'Houtsm', 'Marketing', 53);
	insert into student values('56849', 'Osaka', 'Accounting', 27);
	insert into student values('6712', 'Westphal', 'Math', 60);
	insert into student values('17207', 'Holn', 'Astronomy', 57);
	insert into student values('81876', 'Arora', 'Biology', 106);
	insert into student values('66259', 'Schulman', 'Biology', 67);
	insert into student values('75794', 'Hons', 'History', 9);
	insert into student values('77003', 'Munro', 'Astronomy', 42);
	insert into student values('31101', 'Lhomme', 'Astronomy', 110);
	insert into student values('64196', 'Rioult', 'Pol. Sci.', 6);
	insert into student values('14628', 'Lehtinen', 'Psychology', 47);
	insert into student values('24197', 'Andert', 'Physics', 98);
	insert into student values('3576', 'Nakanishi', 'Physics', 97);
	insert into student values('45720', 'Yeoh', 'Physics', 118);
	insert into student values('15980', 'Ross', 'Athletics', 81);
	insert into student values('34569', 'Arndt', 'Accounting', 39);
	insert into student values('73492', 'Hwang', 'Mech. Eng.', 23);
	insert into student values('44836', 'Lanfr', 'Civil Eng.', 75);
	insert into student values('27366', 'Ssu', 'History', 83);
	insert into student values('16250', 'Uhrig', 'English', 87);
	insert into student values('10267', 'Rzecz', 'Comp. Sci.', 5);
	insert into student values('77244', 'Benitez', 'Geology', 37);
	insert into student values('7854', 'Someren', 'Pol. Sci.', 113);
	insert into student values('1726', 'Matsunami', 'Biology', 94);
	insert into student values('8347', 'Wunderli', 'Comp. Sci.', 100);
	insert into student values('83573', 'Pavlovico', 'English', 81);
	insert into student values('6209', 'Baccou', 'English', 74);
	insert into student values('85849', 'Aufr', 'Accounting', 56);
	insert into student values('76224', 'Neilson', 'Elec. Eng.', 34);
	insert into student values('7043', 'Gryts', 'History', 52);
	insert into student values('70235', 'Zle', 'Elec. Eng.', 105);
	insert into student values('47824', 'Hardt', 'Astronomy', 94);
	insert into student values('58935', 'Kimu', 'Pol. Sci.', 31);
	insert into student values('987', 'Kasani', 'Athletics', 0);
	insert into student values('46074', 'Fong', 'Finance', 56);
	insert into student values('23270', 'Bouras', 'Biology', 109);
	insert into student values('42956', 'Ram', 'Physics', 60);
	insert into student values('78481', 'Clemme', 'History', 23);
	insert into student values('888', 'Frost', 'Geology', 77);
	insert into student values('42625', 'Holland', 'Languages', 0);
	insert into student values('43211', 'Xylo', 'Astronomy', 48);
	insert into student values('43226', 'Shoji', 'Biology', 83);
	insert into student values('53172', 'Du', 'Comp. Sci.', 28);
	insert into student values('16133', 'Orlet', 'Cybernetics', 43);
	insert into student values('75522', 'Yin', 'Biology', 109);
	insert into student values('68330', 'Soisalon-Soininen', 'Pol. Sci.', 13);
	insert into student values('53225', 'Juan', 'Finance', 92);
	insert into student values('67542', 'Jones', 'Civil Eng.', 15);
	insert into student values('8860', 'Aminian', 'Finance', 13);
	insert into student values('22198', 'Read', 'Languages', 101);
	insert into student values('56212', 'Rolland', 'History', 98);
	insert into student values('67514', 'Psil', 'Comp. Sci.', 25);
	insert into student values('58919', 'Schroeder', 'Languages', 60);
	insert into student values('82707', 'Hadzilacos', 'Statistics', 0);
	insert into student values('86641', 'Dair', 'Civil Eng.', 101);
	insert into student values('94324', 'Willson', 'Geology', 120);
	insert into student values('75534', 'Simmel', 'English', 93);
	insert into student values('15283', 'Williams', 'Astronomy', 0);
	insert into student values('47677', 'Tso', 'Psychology', 108);
	insert into student values('94569', 'Yip', 'English', 122);
	insert into student values('90814', 'Finance', 'Elec. Eng.', 105);
	insert into student values('63310', 'Luan', 'History', 102);
	insert into student values('48660', 'Emam', 'Psychology', 77);
	insert into student values('35293', 'Cao', 'Languages', 89);
	insert into student values('28004', 'Savelieva', 'Finance', 17);
	insert into student values('50038', 'Urano', 'Languages', 60);
	insert into student values('25940', 'Rosenkrantz', 'Comp. Sci.', 117);
	insert into student values('11126', 'Englund', 'Pol. Sci.', 76);
	insert into student values('92332', 'Nicol', 'Languages', 34);
	insert into student values('18752', 'Schulman', 'Civil Eng.', 102);
	insert into student values('61527', 'Shwartz', 'Comp. Sci.', 10);
	insert into student values('32119', 'Nagashima', 'Elec. Eng.', 12);
	insert into student values('163', 'Bandekar', 'Finance', 49);
	insert into student values('32065', 'Tapia', 'Math', 90);
	insert into student values('45436', 'Ahmadian', 'Psychology', 101);
	insert into student values('58085', 'Bic', 'Pol. Sci.', 28);
	insert into student values('17076', 'King', 'Statistics', 42);
	insert into student values('17133', 'Kang', 'Civil Eng.', 109);
	insert into student values('36791', 'Bomme', 'Elec. Eng.', 84);
	insert into student values('25785', 'Knezo', 'Athletics', 66);
	insert into student values('11055', 'Arnoux', 'Geology', 121);
	insert into student values('96227', 'Vulp', 'Civil Eng.', 88);
	insert into student values('67024', 'Aufr', 'Elec. Eng.', 62);
	insert into student values('69307', 'Gierl', 'Mech. Eng.', 15);
	insert into student values('23439', 'Cai', 'English', 101);
	insert into student values('66969', 'Sui', 'Civil Eng.', 74);
	insert into student values('22268', 'Dang', 'Astronomy', 78);
	insert into student values('41938', 'Jordan', 'History', 93);
	insert into student values('17057', 'Swartj', 'Geology', 94);
	insert into student values('92693', 'Mattor', 'Athletics', 73);
	insert into student values('49503', 'Seaz', 'Finance', 105);
	insert into student values('77130', 'Tyler', 'Math', 1);
	insert into student values('7861', 'Bollen', 'Pol. Sci.', 122);
	insert into student values('51538', 'Ang', 'Geology', 8);
	insert into student values('57787', 'Alexandri', 'Marketing', 60);
	insert into student values('75116', 'Samar', 'Mech. Eng.', 127);
	insert into student values('81984', 'Gowi', 'Mech. Eng.', 48);
	insert into student values('68395', 'Jessup', 'History', 110);
	insert into student values('11057', 'Robinson', 'Marketing', 120);
	insert into student values('20002', 'Fournier', 'Accounting', 54);
	insert into student values('95027', 'Bauer', 'Accounting', 45);
	insert into student values('7514', 'Rical', 'History', 11);
	insert into student values('88358', 'Bongio', 'Astronomy', 29);
	insert into student values('34392', 'Lauciu', 'History', 20);
	insert into student values('57538', 'Albuquerque', 'Comp. Sci.', 100);
	insert into student values('9114', 'Swien', 'Marketing', 119);
	insert into student values('8378', 'Stenv', 'English', 47);
	insert into student values('51416', 'Shan', 'Psychology', 51);
	insert into student values('71389', 'Vegt', 'Mech. Eng.', 60);
	insert into student values('16453', 'Kanata', 'Astronomy', 78);
	insert into student values('62226', 'Brookh', 'English', 39);
	insert into student values('26028', 'Birchler', 'Statistics', 47);
	insert into student values('45817', 'Herrmann', 'Psychology', 78);
	insert into student values('48469', 'Kolodko', 'Elec. Eng.', 113);
	insert into student values('69230', 'Masum', 'Athletics', 119);
	insert into student values('99711', 'Deshpande', 'Pol. Sci.', 24);
	insert into student values('26695', 'Hac', 'Finance', 104);
	insert into student values('2501', 'Leitner', 'Astronomy', 70);
	insert into student values('8819', 'Lesaffre', 'Elec. Eng.', 1);
	insert into student values('507', 'Recc', 'History', 117);
	insert into student values('80698', 'Eynd', 'Languages', 29);
	insert into student values('73328', 'Stokic', 'History', 36);
	insert into student values('23457', 'Shakhnovich', 'Accounting', 48);
	insert into student values('17996', 'Karpist', 'Finance', 103);
	insert into student values('75173', 'Basturk', 'Elec. Eng.', 54);
	insert into student values('25552', 'Calles', 'Finance', 110);
	insert into student values('63612', 'Duxbury', 'Math', 71);
	insert into student values('27898', 'Holloway', 'English', 81);
	insert into student values('33401', 'Campbell', 'Elec. Eng.', 22);
	insert into student values('49280', 'Wilson', 'Psychology', 89);
	insert into student values('66279', 'Reynolds', 'Math', 91);
	insert into student values('12326', 'Watson', 'Finance', 50);
	insert into student values('32772', 'Leventhal', 'English', 54);
	insert into student values('25725', 'Steeh', 'Geology', 125);
	insert into student values('89571', 'Zubai', 'Comp. Sci.', 88);
	insert into student values('99780', 'Bravo', 'English', 100);
	insert into student values('91580', 'Cabr', 'Mech. Eng.', 96);
	insert into student values('27043', 'Garze', 'Athletics', 119);
	insert into student values('96615', 'Anty', 'English', 9);
	insert into student values('39892', 'Urano', 'Athletics', 92);
	insert into student values('1232', 'Marcus', 'Marketing', 110);
	insert into student values('22467', 'Dias', 'Finance', 95);
	insert into student values('88884', 'Stasko', 'Elec. Eng.', 14);
	insert into student values('96911', 'Jamro', 'English', 13);
	insert into student values('46337', 'Nagaraj', 'Cybernetics', 83);
	insert into student values('23110', 'Sahani', 'Comp. Sci.', 97);
	insert into student values('60762', 'Bernstein', 'Civil Eng.', 120);
	insert into student values('65676', 'Aufr', 'Astronomy', 93);
	insert into student values('47025', 'Jouny', 'Psychology', 72);
	insert into student values('1812', 'Chyr', 'Marketing', 47);
	insert into student values('66763', 'Wilks', 'Comp. Sci.', 95);
	insert into student values('52741', 'Bernhart', 'Astronomy', 50);
	insert into student values('78911', 'Shavel', 'Math', 86);
	insert into student values('33206', 'McCormack', 'Civil Eng.', 109);
	insert into student values('15030', 'Massour', 'Mech. Eng.', 44);
	insert into student values('11377', 'Jr', 'Accounting', 100);
	insert into student values('17676', 'Michel', 'Psychology', 43);
	insert into student values('52019', 'Engen', 'Athletics', 112);
	insert into student values('64013', 'Auriche', 'Elec. Eng.', 107);
	insert into student values('45770', 'Beekw', 'Elec. Eng.', 97);
	insert into student values('63288', 'Stilla', 'Civil Eng.', 19);
	insert into student values('92949', 'Retzel', 'Pol. Sci.', 125);
	insert into student values('83871', 'Stylian', 'Languages', 92);
	insert into student values('41671', 'Valf', 'Geology', 68);
	insert into student values('645', 'Kane', 'Elec. Eng.', 58);
	insert into student values('61444', 'Vries', 'Cybernetics', 125);
	insert into student values('85534', 'Setiawan', 'Psychology', 19);
	insert into student values('35362', 'ONi', 'Statistics', 53);
	insert into student values('22417', 'McGuinness', 'Geology', 55);
	insert into student values('5961', 'Lavina', 'Geology', 79);
	insert into student values('35257', 'Ebou', 'Comp. Sci.', 65);
	insert into student values('65299', 'Schwarze', 'Athletics', 57);
	insert into student values('18367', 'Goodwin', 'Civil Eng.', 95);
	insert into student values('68396', 'Klimasauskas', 'Biology', 72);
	insert into student values('35905', 'Lima', 'Athletics', 19);
	insert into student values('45650', 'Mateo', 'Marketing', 40);
	insert into student values('27662', 'Tabarr', 'Cybernetics', 21);
	insert into student values('25077', 'Palomo', 'Cybernetics', 82);
	insert into student values('85575', 'Lal', 'Astronomy', 15);
	insert into student values('760', 'Liedm', 'Geology', 100);
	insert into student values('67583', 'Senn', 'Comp. Sci.', 93);
	insert into student values('63886', 'Kuo', 'Biology', 12);
	insert into student values('34055', 'Orono', 'Astronomy', 115);
	insert into student values('41973', 'Werf', 'Civil Eng.', 115);
	insert into student values('30017', 'Mateo', 'History', 96);
	insert into student values('37581', 'Arndt', 'Cybernetics', 68);
	insert into student values('62373', 'Cheed', 'Accounting', 60);
	insert into student values('57160', 'Baer', 'Accounting', 81);
	insert into student values('2967', 'Stokic', 'Mech. Eng.', 16);
	insert into student values('5144', 'Abdellatif', 'Geology', 55);
	insert into student values('5703', 'Yasuda', 'Accounting', 23);
	insert into student values('58170', 'Lao', 'Statistics', 119);
	insert into student values('53424', 'Lemoine', 'Languages', 10);
	insert into student values('17397', 'Caleff', 'Languages', 31);
	insert into student values('77588', 'Aguilar', 'Psychology', 111);
	insert into student values('92442', 'Satoh', 'Statistics', 81);
	insert into student values('42114', 'Mezzar', 'Cybernetics', 98);
	insert into student values('53699', 'Cordt', 'Languages', 39);
	insert into student values('22258', 'Larion', 'Languages', 3);
	insert into student values('2133', 'Nardi', 'Accounting', 60);
	insert into student values('73606', 'Sachse', 'Cybernetics', 93);
	insert into student values('63040', 'Hochri', 'Astronomy', 63);
	insert into student values('74473', 'Ledermann', 'Statistics', 22);
	insert into student values('9659', 'Sakhno', 'Cybernetics', 67);
	insert into student values('21552', 'Bradshaw', 'Physics', 71);
	insert into student values('45002', 'Abraham', 'Psychology', 109);
	insert into student values('57213', 'Andrew', 'Math', 64);
	insert into student values('56058', 'Fettes', 'Pol. Sci.', 128);
	insert into student values('84792', 'Angelo', 'Civil Eng.', 81);
	insert into student values('57185', 'ShuQ', 'Psychology', 25);
	insert into student values('75510', 'Dumont', 'Physics', 114);
	insert into student values('42560', 'Amr', 'Pol. Sci.', 80);
	insert into student values('75252', 'Huo', 'Languages', 0);
	insert into student values('82402', 'Grant', 'Comp. Sci.', 5);
	insert into student values('17339', 'Petzo', 'English', 58);
	insert into student values('77148', 'Hinik', 'Pol. Sci.', 35);
	insert into student values('11419', 'Geronimo', 'Civil Eng.', 66);
	insert into student values('37869', 'Beeu', 'English', 109);
	insert into student values('28977', 'Chatterton', 'Psychology', 73);
	insert into student values('28989', 'Albinal', 'Astronomy', 107);
	insert into student values('92867', 'Khene', 'Languages', 69);
	insert into student values('92703', 'Makinen', 'Cybernetics', 29);
	insert into student values('17600', 'Peter', 'Languages', 47);
	insert into student values('32464', 'Kinney', 'Accounting', 5);
	insert into student values('71426', 'Flecker', 'Languages', 38);
	insert into student values('8343', 'Shoji', 'History', 108);
	insert into student values('41261', 'Hubr', 'Physics', 32);
	insert into student values('58469', 'Lutes', 'Athletics', 64);
	insert into student values('36303', 'Nair', 'Mech. Eng.', 46);
	insert into student values('30164', 'Ende', 'Athletics', 114);
	insert into student values('29920', 'Kogure', 'Psychology', 62);
	insert into student values('30858', 'Shaffer', 'Physics', 42);
	insert into student values('88801', 'Fonseca', 'Athletics', 102);
	insert into student values('57780', 'Trezz', 'Athletics', 86);
	insert into student values('21246', 'Rais', 'Civil Eng.', 52);
	insert into student values('34957', 'Kalogerou', 'Elec. Eng.', 71);
	insert into student values('61998', 'Sohn', 'Civil Eng.', 22);
	insert into student values('56598', 'Carey', 'Cybernetics', 58);
	insert into student values('463', 'Houtsm', 'Physics', 78);
	insert into student values('81245', 'Mandviwall', 'Languages', 35);
	insert into student values('21100', 'Juchn', 'Physics', 51);
	insert into student values('56', 'Kameda', 'Cybernetics', 81);
	insert into student values('64121', 'Mansint', 'Math', 115);
	insert into student values('20489', 'Shuming', 'History', 2);
	insert into student values('10834', 'More', 'Geology', 126);
	insert into student values('63289', 'So', 'Psychology', 0);
	insert into student values('9953', 'Wilks', 'Biology', 45);
	insert into student values('78782', 'Sherman', 'Math', 104);
	insert into student values('5399', 'Chun', 'Pol. Sci.', 25);
	insert into student values('1367', 'Ignj', 'Math', 69);
	insert into student values('30896', 'Rueda', 'Comp. Sci.', 61);
	insert into student values('12236', 'Bricker', 'Accounting', 116);
	insert into student values('89297', 'Cacciari', 'Astronomy', 70);
	insert into student values('52656', 'Phillips', 'Psychology', 6);
	insert into student values('18859', 'Rubio', 'English', 21);
	insert into student values('17377', 'Pisini', 'English', 67);
	insert into student values('50039', 'Kurt', 'Statistics', 126);
	insert into student values('78756', 'Dai', 'Athletics', 93);
	insert into student values('3833', 'Hayat', 'Biology', 53);
	insert into student values('47627', 'Warren', 'Statistics', 54);
	insert into student values('65438', 'Saad', 'Comp. Sci.', 13);
	insert into student values('8912', 'Brenner', 'Languages', 14);
	insert into student values('22912', 'Sendlm', 'Geology', 63);
	insert into student values('99289', 'Morales', 'Finance', 80);
	insert into student values('63039', 'Wagner', 'Athletics', 69);
	insert into student values('20180', 'Reyes', 'Languages', 44);
	insert into student values('35687', 'Letouzey', 'Accounting', 58);
	insert into student values('28409', 'Hirasawa', 'Geology', 66);
	insert into student values('56078', 'Soltys', 'Geology', 70);
	insert into student values('48589', 'Martyno', 'Mech. Eng.', 73);
	insert into student values('7956', 'Brandsd', 'Statistics', 110);
	insert into student values('16347', 'Morimoto', 'Mech. Eng.', 2);
	insert into student values('75362', 'Christodoulakis', 'Pol. Sci.', 13);
	insert into student values('57242', 'Chatfield', 'Physics', 108);
	insert into student values('71085', 'Giannoulis', 'Elec. Eng.', 10);
	insert into student values('89132', 'Janssen', 'Geology', 104);
	insert into student values('79763', 'Ikeda', 'Comp. Sci.', 123);
	insert into student values('41818', 'Wari', 'English', 9);
	insert into student values('667', 'Goldman', 'History', 19);
	insert into student values('82970', 'Peip', 'Mech. Eng.', 48);
	insert into student values('68150', 'Kim', 'Math', 3);
	insert into student values('63243', 'Dostal', 'Comp. Sci.', 68);
	insert into student values('18338', 'Kangs', 'Physics', 9);
	insert into student values('51862', 'Carrillo', 'English', 105);
	insert into student values('19203', 'Koch', 'Physics', 88);
	insert into student values('78892', 'Kei', 'English', 43);
	insert into student values('67657', 'Beeu', 'Languages', 106);
	insert into student values('71628', 'Amann', 'Psychology', 60);
	insert into student values('43854', 'Gau', 'Astronomy', 47);
	insert into student values('123', 'Wingb', 'Civil Eng.', 86);
	insert into student values('5943', 'Rubio', 'Math', 28);
	insert into student values('56139', 'Schelten', 'Elec. Eng.', 82);
	insert into student values('45680', 'Kiltz', 'Cybernetics', 88);
	insert into student values('76759', 'Masum', 'Mech. Eng.', 83);
	insert into student values('26802', 'Baber', 'Comp. Sci.', 27);
	insert into student values('83747', 'Gregory', 'Mech. Eng.', 51);
	insert into student values('35935', 'ODono', 'Languages', 3);
	insert into student values('8957', 'Walker', 'Athletics', 50);
	insert into student values('40481', 'Zettel', 'Civil Eng.', 74);
	insert into student values('44352', 'Itoh', 'Athletics', 101);
	insert into student values('73072', 'Akroy', 'Comp. Sci.', 48);
	insert into student values('96206', 'Koic', 'Math', 53);
	insert into student values('8843', 'Papakir', 'Biology', 95);
	insert into student values('41299', 'Siebers', 'Civil Eng.', 23);
	insert into student values('13403', 'Latour', 'English', 82);
	insert into student values('65703', 'Goldman', 'Comp. Sci.', 37);
	insert into student values('49205', 'Agraz', 'Pol. Sci.', 82);
	insert into student values('22345', 'Wecker', 'Pol. Sci.', 76);
	insert into student values('39254', 'Elme', 'Statistics', 103);
	insert into student values('80742', 'Lucas', 'Geology', 87);
	insert into student values('94726', 'Ailamaki', 'Accounting', 47);
	insert into student values('77361', 'Neuhold', 'Physics', 14);
	insert into student values('52856', 'Grange', 'Physics', 117);
	insert into student values('64138', 'Doran', 'Biology', 99);
	insert into student values('89414', 'Feldman', 'Marketing', 34);
	insert into student values('22618', 'Voss', 'Pol. Sci.', 101);
	insert into student values('98870', 'Kun', 'Cybernetics', 43);
	insert into student values('77234', 'Hayrapetyan', 'Geology', 93);
	insert into student values('56057', 'Hull', 'Statistics', 112);
	insert into student values('32881', 'Bagato', 'Civil Eng.', 77);
	insert into student values('92776', 'Oki', 'Psychology', 0);
	insert into student values('82301', 'Conti', 'Marketing', 129);
	insert into student values('29959', 'Narli', 'Physics', 56);
	insert into student values('30182', 'Porr', 'Cybernetics', 71);
	insert into student values('96324', 'Sudirm', 'Accounting', 84);
	insert into student values('56232', 'Perozzo', 'Geology', 48);
	insert into student values('53047', 'GeiÃŸl', 'Mech. Eng.', 46);
	insert into student values('87015', 'Pottos', 'Accounting', 90);
	insert into student values('55329', 'Vyborny', 'History', 15);
	insert into student values('21394', 'Patel', 'Finance', 115);
	insert into student values('61166', 'Kangs', 'Astronomy', 73);
	insert into student values('74530', 'Ranno', 'Physics', 103);
	insert into student values('99189', 'Shelest', 'Pol. Sci.', 35);
	insert into student values('34170', 'Chan', 'Comp. Sci.', 77);
	insert into student values('19220', 'Hayashi', 'History', 77);
	insert into student values('73542', 'Dooley', 'Geology', 8);
	insert into student values('97590', 'Rammer', 'Comp. Sci.', 17);
	insert into student values('15613', 'Umehara', 'Marketing', 41);
	insert into student values('78767', 'Marlet', 'Geology', 6);
	insert into student values('51553', 'Willis', 'Finance', 121);
	insert into student values('9947', 'Bouzeghoub', 'Biology', 38);
	insert into student values('95260', 'Yannakakis', 'Statistics', 109);
	insert into student values('87268', 'Koenig', 'Languages', 82);
	insert into student values('35', 'Glaho', 'History', 110);
	insert into student values('99451', 'Bradshaw', 'Statistics', 79);
	insert into student values('65396', 'Rossos', 'Marketing', 75);
	insert into student values('98140', 'Ratcliff', 'Statistics', 5);
	insert into student values('62520', 'Im', 'Astronomy', 105);
	insert into student values('40044', 'Jode', 'Mech. Eng.', 108);
	insert into student values('78787', 'Rissanen', 'History', 57);
	insert into student values('85308', 'Yihn', 'Accounting', 20);
	insert into student values('85809', 'Andert', 'Geology', 99);
	insert into student values('30021', 'Youseffi', 'History', 90);
	insert into student values('54153', 'Kammerer', 'Mech. Eng.', 25);
	insert into student values('73387', 'Baccou', 'Cybernetics', 70);
	insert into student values('83003', 'Nam', 'Psychology', 30);
	insert into student values('13211', 'Diab', 'Civil Eng.', 66);
	insert into student values('20803', 'Mercurio', 'History', 129);
	insert into student values('6990', 'Hoshi', 'Biology', 25);
	insert into student values('2629', 'Goldbu', 'Languages', 4);
	insert into student values('83398', 'Quinta', 'History', 58);
	insert into student values('6673', 'Bernhart', 'Math', 84);
	insert into student values('81294', 'Massey', 'Mech. Eng.', 111);
	insert into student values('81566', 'Farr', 'Geology', 68);
	insert into student values('94620', 'Sarnak', 'Accounting', 100);
	insert into student values('57456', 'Stauf', 'Statistics', 89);
	insert into student values('17424', 'Zouao', 'English', 75);
	insert into student values('34195', 'Bosnjak', 'Astronomy', 120);
	insert into student values('94836', 'Fuller', 'English', 13);
	insert into student values('16543', 'Toffoli', 'History', 83);
	insert into student values('42843', 'Lin', 'Mech. Eng.', 18);
	insert into student values('82868', 'So', 'Athletics', 105);
	insert into student values('18499', 'Peter', 'Biology', 21);
	insert into student values('50013', 'Milanic', 'Math', 76);
	insert into student values('53077', 'Brandt', 'History', 87);
	insert into student values('87439', 'Scheffer', 'Comp. Sci.', 93);
	insert into student values('40738', 'Dima', 'Finance', 88);
	insert into student values('13352', 'Gorsky', 'Athletics', 53);
	insert into student values('9605', 'Beeu', 'Pol. Sci.', 61);
	insert into student values('53490', 'Reina-', 'Languages', 31);
	insert into student values('57925', 'Doeschn', 'Languages', 58);
	insert into student values('57055', 'Piou', 'Physics', 0);
	insert into student values('21009', 'Geon', 'History', 118);
	insert into student values('8140', 'Paddock', 'Comp. Sci.', 53);
	insert into student values('37284', 'Benabd', 'Physics', 74);
	insert into student values('97023', 'Bulash', 'Psychology', 48);
	insert into student values('5920', 'Godfrey', 'Marketing', 125);
	insert into student values('91915', 'Cacciari', 'Geology', 126);
	insert into student values('25780', 'Ashmi', 'Accounting', 95);
	insert into student values('26473', 'Neru', 'Accounting', 75);
	insert into student values('43032', 'Tanaka', 'Biology', 84);
	insert into student values('30110', 'Humphrey', 'Athletics', 2);
	insert into student values('88302', 'Yarmush', 'Marketing', 64);
	insert into student values('83002', 'Ladu', 'History', 99);
	insert into student values('83136', 'Caporali', 'Comp. Sci.', 61);
	insert into student values('61364', 'Bhavs', 'History', 8);
	insert into student values('50598', 'She', 'Psychology', 52);
	insert into student values('83696', 'Denso', 'Cybernetics', 94);
	insert into student values('33791', 'Wood', 'Civil Eng.', 92);
	insert into student values('61403', 'Tanno', 'Finance', 44);
	insert into student values('66356', 'Xi', 'Elec. Eng.', 44);
	insert into student values('12683', 'Sin', 'Accounting', 115);
	insert into student values('66106', 'Malagoli', 'Finance', 18);
	insert into student values('77729', 'Lui', 'Psychology', 26);
	insert into student values('52750', 'Saito', 'Mech. Eng.', 12);
	insert into student values('25256', 'Boulah', 'Astronomy', 83);
	insert into student values('3640', 'Karniel', 'Athletics', 41);
	insert into student values('22325', 'Oevers', 'Statistics', 77);
	insert into student values('26730', 'Veselovsky', 'Psychology', 68);
	insert into student values('70918', 'Holland', 'English', 23);
	insert into student values('91616', 'Hoffman', 'Astronomy', 100);
	insert into student values('69285', 'Zaharak', 'Athletics', 36);
	insert into student values('42688', 'Palma', 'Biology', 54);
	insert into student values('24932', 'Segars', 'Civil Eng.', 78);
	insert into student values('33817', 'Vagn', 'Geology', 95);
	insert into student values('53185', 'Yuanq', 'Accounting', 25);
	insert into student values('85445', 'Bocchi', 'English', 18);
	insert into student values('58081', 'Pelletier', 'Comp. Sci.', 100);
	insert into student values('75560', 'Tabor', 'History', 129);
	insert into student values('80821', 'Morris', 'Math', 102);
	insert into student values('19536', 'Bhattacharya', 'Math', 92);
	insert into student values('27002', 'Veerar', 'Statistics', 5);
	insert into student values('39925', 'Preuss', 'Civil Eng.', 32);
	insert into student values('90194', 'Busch', 'Biology', 93);
	insert into student values('32056', 'Frost', 'Math', 75);
	insert into student values('67310', 'Lindner', 'Elec. Eng.', 21);
	insert into student values('88389', 'Henriksen', 'Marketing', 5);
	insert into student values('78469', 'Xiong', 'Accounting', 14);
	insert into student values('46450', 'Tleu', 'Comp. Sci.', 83);
	insert into student values('86651', 'Dave', 'Mech. Eng.', 94);
	insert into student values('5824', 'Ocel', 'Cybernetics', 121);
	insert into student values('11101', 'Glaho', 'Cybernetics', 119);
	insert into student values('57431', 'Holloway', 'Civil Eng.', 2);
	insert into student values('96193', 'Yasuda', 'English', 19);
	insert into student values('55531', 'Apostolov', 'Physics', 85);
	insert into student values('17192', 'Carroll', 'Pol. Sci.', 75);
	insert into student values('86075', 'Juchn', 'Biology', 101);
	insert into student values('81150', 'Atkins', 'Cybernetics', 99);
	insert into student values('44206', 'Gilmour', 'Comp. Sci.', 75);
	insert into student values('67222', 'Andrews', 'English', 91);
	insert into student values('47126', 'Bakirc', 'Comp. Sci.', 56);
	insert into student values('67407', 'Yoneda', 'Biology', 115);
	insert into student values('20814', 'Cheed', 'Marketing', 42);
	insert into student values('25331', 'Baker', 'Accounting', 68);
	insert into student values('83838', 'Durrant', 'Civil Eng.', 2);
	insert into student values('66293', 'Gibson', 'English', 98);
	insert into student values('56499', 'Zarpell', 'Geology', 82);
	insert into student values('32368', 'Ouaz', 'Languages', 64);
	insert into student values('75273', 'Jia', 'Civil Eng.', 38);
	insert into student values('67436', 'LaCo', 'Physics', 56);
	insert into student values('259', 'Bertranp', 'Accounting', 105);
	insert into student values('858', 'Kashima', 'Psychology', 1);
	insert into student values('94990', 'Lykin', 'English', 120);
	insert into student values('89140', 'Fabregas', 'Biology', 94);
	insert into student values('55940', 'Subbai', 'Pol. Sci.', 31);
	insert into student values('72768', 'Queiroz', 'Mech. Eng.', 50);
	insert into student values('96772', 'Rieger', 'Cybernetics', 126);
	insert into student values('25068', 'Dickens', 'Civil Eng.', 12);
	insert into student values('96988', 'Bussel', 'History', 124);
	insert into student values('44816', 'Burman', 'History', 67);
	insert into student values('88417', 'Mitsuhashi', 'Athletics', 1);
	insert into student values('11441', 'Betho', 'Languages', 36);
	insert into student values('4435', 'Labroc', 'Accounting', 11);
	insert into student values('70362', 'Sicard', 'English', 85);
	insert into student values('54460', 'Martini', 'Math', 100);
	insert into student values('7970', 'Bartels', 'Marketing', 56);
	insert into student values('73807', 'Gubar', 'Statistics', 95);
	insert into student values('19050', 'Erdem', 'Civil Eng.', 58);
	insert into student values('67146', 'Scherze', 'Marketing', 121);
	insert into student values('23934', 'Koizumi', 'English', 59);
	insert into student values('96246', 'Tong', 'Languages', 86);
	insert into student values('21225', 'Choll', 'Elec. Eng.', 112);
	insert into student values('18554', 'Ramaswamy', 'Psychology', 21);
	insert into student values('38013', 'Frolova', 'Marketing', 29);
	insert into student values('98019', 'Ciepl', 'Marketing', 74);
	insert into student values('40457', 'Bouras', 'History', 116);
	insert into student values('94801', 'Chakraborty', 'Civil Eng.', 26);
	insert into student values('65038', 'Papakir', 'History', 78);
	insert into student values('4383', 'Tallis', 'History', 120);
	insert into student values('36402', 'Hippu', 'Athletics', 115);
	insert into student values('9514', 'Dickson', 'Geology', 112);
	insert into student values('11195', 'Shiang', 'Cybernetics', 62);
	insert into student values('31442', 'Bessou', 'Math', 63);
	insert into student values('51698', 'Sharpe', 'History', 81);
	insert into student values('18809', 'Benson', 'Marketing', 20);
	insert into student values('85505', 'Wells', 'History', 123);
	insert into student values('64642', 'Murdock', 'Elec. Eng.', 39);
	insert into student values('54612', 'ZaratÃ©', 'Elec. Eng.', 103);
	insert into student values('5843', 'Deng', 'Athletics', 11);
	insert into student values('90779', 'Lenhart', 'Math', 24);
	insert into student values('52371', 'Boons', 'Marketing', 108);
	insert into student values('51238', 'Kran', 'Civil Eng.', 19);
	insert into student values('62124', 'Towsey', 'Physics', 105);
	insert into student values('84039', 'Sveti', 'Astronomy', 79);
	insert into student values('24201', 'Juol', 'Pol. Sci.', 17);
	insert into student values('31993', 'Ueda', 'Comp. Sci.', 6);
	insert into student values('39520', 'Lui', 'Astronomy', 43);
	insert into student values('59172', 'Badran', 'Astronomy', 19);
	insert into student values('21774', 'Moh', 'Physics', 38);
	insert into student values('30957', 'Beaudry', 'Cybernetics', 38);
	insert into student values('54610', 'Tam', 'Languages', 5);
	insert into student values('72358', 'Tomason', 'Math', 92);
	insert into student values('83204', 'Tauber', 'Accounting', 0);
	insert into student values('76246', 'Pettersen', 'Comp. Sci.', 81);
	insert into student values('80047', 'Clemme', 'Astronomy', 24);
	insert into student values('38545', 'Fok', 'English', 122);
	insert into student values('8986', 'Maesf', 'Pol. Sci.', 115);
	insert into student values('89393', 'Fischbach', 'English', 21);
	insert into student values('37103', 'Walker', 'Athletics', 19);
	insert into student values('76743', 'Rani', 'Comp. Sci.', 16);
	insert into student values('81396', 'Cordt', 'Finance', 7);
	insert into student values('46066', 'Hirasawa', 'Mech. Eng.', 92);
	insert into student values('6729', 'Heilprin', 'Marketing', 39);
	insert into student values('90372', 'Rho', 'Biology', 101);
	insert into student values('28352', 'Mai', 'Pol. Sci.', 64);
	insert into student values('9408', 'Oberholzer', 'Athletics', 84);
	insert into student values('15517', 'Anis', 'Geology', 29);
	insert into student values('61402', 'Maity', 'Mech. Eng.', 62);
	insert into student values('49813', 'Al-Hu', 'History', 93);
	insert into student values('72186', 'Pace', 'Marketing', 106);
	insert into student values('31250', 'Kawasaki', 'Athletics', 31);
	insert into student values('51768', 'Noga', 'Athletics', 78);
	insert into student values('18636', 'Mori', 'Statistics', 23);
	insert into student values('88993', 'Palaniswami', 'Math', 51);
	insert into student values('72177', 'Eller', 'Mech. Eng.', 30);
	insert into student values('99760', 'Sakamoto', 'Athletics', 75);
	insert into student values('80227', 'Tsuji', 'Civil Eng.', 47);
	insert into student values('76270', 'Qian', 'History', 128);
	insert into student values('42019', 'Koch', 'Finance', 53);
	insert into student values('15726', 'Neuhold', 'Finance', 27);
	insert into student values('97694', 'ODono', 'Biology', 15);
	insert into student values('16849', 'Kantors', 'Geology', 117);
	insert into student values('11262', 'Foels', 'Marketing', 117);
	insert into student values('64222', 'Namer', 'Pol. Sci.', 23);
	insert into student values('91799', 'Steinmetz', 'Civil Eng.', 96);
	insert into student values('10727', 'Allard', 'Physics', 27);
	insert into student values('64169', 'Lucas', 'Civil Eng.', 27);
	insert into student values('81031', 'Nanda', 'Psychology', 56);
	insert into student values('18941', 'Denecker', 'History', 46);
	insert into student values('46981', 'Yalk', 'Statistics', 117);
	insert into takes values('65901', '401', '1', 'Fall', 2003, 'C-');
	insert into takes values('24932', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('61332', '200', '1', 'Spring', 2007, 'A-');
	insert into takes values('73492', '760', '1', 'Spring', 2004, 'A ');
	insert into takes values('65715', '843', '1', 'Fall', 2010, 'B+');
	insert into takes values('58300', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('760', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('69730', '313', '1', 'Fall', 2010, 'A ');
	insert into takes values('94836', '626', '1', 'Fall', 2006, 'C+');
	insert into takes values('49391', '603', '1', 'Fall', 2003, 'B-');
	insert into takes values('48850', '457', '1', 'Spring', 2001, 'C-');
	insert into takes values('68999', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('53469', '169', '1', 'Spring', 2007, 'C ');
	insert into takes values('74016', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('49073', '496', '1', 'Fall', 2001, 'C-');
	insert into takes values('52866', '795', '1', 'Spring', 2004, 'B ');
	insert into takes values('83314', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('70359', '599', '1', 'Spring', 2003, 'A-');
	insert into takes values('88993', '313', '1', 'Fall', 2010, 'C+');
	insert into takes values('97042', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('33460', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('81207', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('68010', '972', '1', 'Spring', 2009, 'A+');
	insert into takes values('15517', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('8957', '561', '1', 'Fall', 2006, 'C ');
	insert into takes values('8986', '927', '1', 'Fall', 2002, 'A ');
	insert into takes values('7956', '692', '1', 'Spring', 2010, 'C ');
	insert into takes values('792', '972', '1', 'Spring', 2009, 'A-');
	insert into takes values('84189', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('92659', '527', '1', 'Fall', 2004, 'C ');
	insert into takes values('22198', '612', '1', 'Fall', 2007, 'A-');
	insert into takes values('8957', '696', '1', 'Spring', 2002, 'B ');
	insert into takes values('36244', '401', '1', 'Fall', 2003, 'A-');
	insert into takes values('97658', '545', '1', 'Fall', 2001, 'A ');
	insert into takes values('89104', '352', '1', 'Spring', 2006, 'A+');
	insert into takes values('5393', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('80248', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('30222', '962', '1', 'Spring', 2008, 'B-');
	insert into takes values('64155', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('99660', '242', '1', 'Fall', 2009, 'A ');
	insert into takes values('8517', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('31820', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('46769', '334', '1', 'Fall', 2009, 'C-');
	insert into takes values('43505', '867', '1', 'Fall', 2006, 'A+');
	insert into takes values('79589', '158', '2', 'Spring', 2008, 'A ');
	insert into takes values('70235', '489', '1', 'Fall', 2007, 'C ');
	insert into takes values('11126', '304', '1', 'Fall', 2009, 'B+');
	insert into takes values('27366', '443', '1', 'Spring', 2010, 'A-');
	insert into takes values('3576', '338', '1', 'Spring', 2007, 'A-');
	insert into takes values('3127', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('39619', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('33651', '200', '1', 'Spring', 2007, 'C-');
	insert into takes values('62520', '702', '1', 'Spring', 2001, 'C-');
	insert into takes values('86573', '486', '1', 'Fall', 2009, 'B ');
	insert into takes values('792', '663', '1', 'Spring', 2005, 'B-');
	insert into takes values('27528', '313', '1', 'Fall', 2010, 'B ');
	insert into takes values('52945', '626', '1', 'Fall', 2006, 'C+');
	insert into takes values('37103', '581', '1', 'Spring', 2005, 'C+');
	insert into takes values('11126', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('62152', '105', '1', 'Fall', 2009, 'C+');
	insert into takes values('3127', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('2848', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('20985', '304', '1', 'Fall', 2009, 'A+');
	insert into takes values('69628', '426', '1', 'Spring', 2006, 'B ');
	insert into takes values('78572', '457', '1', 'Spring', 2001, 'C ');
	insert into takes values('60366', '426', '1', 'Spring', 2006, 'A ');
	insert into takes values('52741', '237', '2', 'Fall', 2009, 'B+');
	insert into takes values('72501', '400', '2', 'Fall', 2003, 'B-');
	insert into takes values('5250', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('38013', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('88417', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('2286', '843', '1', 'Fall', 2010, 'A ');
	insert into takes values('15083', '237', '1', 'Spring', 2008, 'B-');
	insert into takes values('336', '426', '1', 'Spring', 2006, 'A-');
	insert into takes values('64934', '169', '2', 'Fall', 2002, 'A-');
	insert into takes values('499', '692', '1', 'Spring', 2010, 'C-');
	insert into takes values('56598', '927', '1', 'Fall', 2002, 'C-');
	insert into takes values('46074', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('47627', '258', '1', 'Fall', 2007, 'A-');
	insert into takes values('85063', '581', '1', 'Spring', 2005, 'A+');
	insert into takes values('43032', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('34055', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('16250', '200', '1', 'Spring', 2007, 'B+');
	insert into takes values('16907', '137', '1', 'Spring', 2002, 'A ');
	insert into takes values('66356', '571', '1', 'Spring', 2004, 'B+');
	insert into takes values('3335', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('72501', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('18583', '642', '1', 'Fall', 2004, 'B+');
	insert into takes values('53152', '408', '2', 'Spring', 2003, 'C-');
	insert into takes values('17924', '867', '2', 'Fall', 2010, 'A+');
	insert into takes values('77729', '972', '1', 'Spring', 2009, 'B+');
	insert into takes values('4248', '571', '1', 'Spring', 2004, 'C ');
	insert into takes values('46106', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('14621', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('14829', '376', '1', 'Fall', 2006, 'C+');
	insert into takes values('50658', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('44706', '875', '1', 'Spring', 2005, 'C-');
	insert into takes values('92949', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('66969', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('97658', '852', '1', 'Spring', 2008, 'B-');
	insert into takes values('17607', '527', '1', 'Fall', 2004, 'B+');
	insert into takes values('52876', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('56058', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('15883', '571', '1', 'Spring', 2004, 'C ');
	insert into takes values('99271', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('67560', '443', '2', 'Spring', 2002, 'B ');
	insert into takes values('85063', '482', '1', 'Fall', 2005, 'C ');
	insert into takes values('7287', '642', '1', 'Fall', 2004, 'B-');
	insert into takes values('35462', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('49450', '949', '1', 'Fall', 2007, 'A-');
	insert into takes values('78922', '489', '1', 'Fall', 2007, 'B+');
	insert into takes values('94569', '960', '1', 'Fall', 2009, 'A+');
	insert into takes values('1018', '338', '1', 'Spring', 2007, 'A ');
	insert into takes values('32245', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('51093', '415', '1', 'Fall', 2010, 'C-');
	insert into takes values('29390', '443', '1', 'Spring', 2010, 'B+');
	insert into takes values('47379', '960', '2', 'Fall', 2006, 'A ');
	insert into takes values('10204', '169', '1', 'Spring', 2007, 'A-');
	insert into takes values('90381', '158', '1', 'Fall', 2008, 'C-');
	insert into takes values('36926', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('70688', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('54728', '949', '1', 'Fall', 2007, 'C ');
	insert into takes values('15070', '304', '1', 'Fall', 2009, 'C-');
	insert into takes values('52741', '489', '1', 'Fall', 2007, 'A ');
	insert into takes values('79469', '400', '2', 'Fall', 2003, 'C+');
	insert into takes values('79446', '808', '1', 'Fall', 2003, 'A+');
	insert into takes values('44551', '476', '1', 'Fall', 2010, 'C-');
	insert into takes values('83622', '408', '1', 'Spring', 2007, 'A+');
	insert into takes values('64196', '581', '1', 'Spring', 2005, 'A ');
	insert into takes values('88140', '345', '1', 'Spring', 2008, 'C-');
	insert into takes values('28361', '338', '2', 'Spring', 2006, 'A+');
	insert into takes values('51008', '476', '1', 'Fall', 2010, 'B+');
	insert into takes values('1110', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('96134', '696', '1', 'Spring', 2002, 'C-');
	insert into takes values('98830', '408', '1', 'Spring', 2007, 'A ');
	insert into takes values('14874', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('23270', '748', '1', 'Fall', 2003, 'C-');
	insert into takes values('993', '972', '1', 'Spring', 2009, 'B-');
	insert into takes values('19791', '334', '1', 'Fall', 2009, 'A-');
	insert into takes values('57083', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('72528', '476', '1', 'Fall', 2010, 'A+');
	insert into takes values('95953', '468', '1', 'Fall', 2005, 'C+');
	insert into takes values('35357', '962', '1', 'Spring', 2008, 'B-');
	insert into takes values('62520', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('50583', '239', '1', 'Fall', 2006, 'B ');
	insert into takes values('93354', '345', '1', 'Spring', 2008, 'A ');
	insert into takes values('55857', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('53048', '169', '1', 'Spring', 2007, 'B-');
	insert into takes values('89414', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('99710', '169', '2', 'Fall', 2002, 'A+');
	insert into takes values('95852', '663', '1', 'Spring', 2005, 'C-');
	insert into takes values('84702', '949', '1', 'Fall', 2007, 'C ');
	insert into takes values('82918', '258', '1', 'Fall', 2007, 'C-');
	insert into takes values('70452', '400', '1', 'Spring', 2007, 'C ');
	insert into takes values('38271', '486', '1', 'Fall', 2009, 'C+');
	insert into takes values('67425', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('78892', '960', '2', 'Fall', 2006, 'C+');
	insert into takes values('79205', '496', '1', 'Fall', 2001, 'A-');
	insert into takes values('42298', '959', '1', 'Fall', 2006, 'A ');
	insert into takes values('83836', '527', '1', 'Fall', 2004, 'B-');
	insert into takes values('56598', '192', '1', 'Fall', 2002, 'A+');
	insert into takes values('34322', '242', '1', 'Fall', 2009, 'B+');
	insert into takes values('56755', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('68248', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('36845', '338', '1', 'Spring', 2007, 'C+');
	insert into takes values('48660', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('91799', '105', '1', 'Fall', 2009, 'C-');
	insert into takes values('89551', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('87965', '694', '1', 'Fall', 2002, 'C ');
	insert into takes values('12683', '991', '1', 'Spring', 2008, 'C-');
	insert into takes values('87439', '443', '1', 'Spring', 2010, 'A ');
	insert into takes values('16467', '352', '1', 'Spring', 2006, 'C-');
	insert into takes values('49701', '692', '1', 'Spring', 2010, 'B-');
	insert into takes values('37350', '400', '2', 'Fall', 2003, 'B+');
	insert into takes values('42843', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('94766', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('65676', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('27094', '304', '1', 'Fall', 2009, 'A+');
	insert into takes values('12214', '972', '1', 'Spring', 2009, 'C-');
	insert into takes values('81566', '169', '1', 'Spring', 2007, 'C+');
	insert into takes values('37101', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('18709', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('86934', '366', '1', 'Fall', 2005, 'C-');
	insert into takes values('99660', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('41890', '599', '1', 'Spring', 2003, 'A+');
	insert into takes values('83592', '591', '1', 'Spring', 2005, 'B+');
	insert into takes values('37219', '626', '1', 'Fall', 2006, 'B ');
	insert into takes values('88302', '400', '2', 'Fall', 2003, 'A-');
	insert into takes values('75040', '694', '1', 'Fall', 2002, 'C+');
	insert into takes values('36052', '237', '1', 'Spring', 2008, 'A-');
	insert into takes values('72186', '443', '1', 'Spring', 2010, 'A+');
	insert into takes values('76759', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('27804', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('99189', '400', '1', 'Spring', 2007, 'A ');
	insert into takes values('77898', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('47001', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('3639', '421', '1', 'Fall', 2004, 'B+');
	insert into takes values('80912', '864', '1', 'Spring', 2006, 'A ');
	insert into takes values('52371', '974', '1', 'Fall', 2003, 'C-');
	insert into takes values('99719', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('68242', '927', '1', 'Fall', 2002, 'C ');
	insert into takes values('3127', '237', '1', 'Spring', 2008, 'B+');
	insert into takes values('19536', '400', '1', 'Spring', 2007, 'A-');
	insert into takes values('97694', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('99463', '493', '1', 'Spring', 2010, 'A ');
	insert into takes values('96988', '457', '1', 'Spring', 2001, 'C-');
	insert into takes values('59290', '338', '1', 'Spring', 2007, 'B-');
	insert into takes values('60249', '258', '1', 'Fall', 2007, 'B-');
	insert into takes values('41751', '972', '1', 'Spring', 2009, 'B+');
	insert into takes values('62832', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('22198', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('35', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('4034', '612', '1', 'Fall', 2007, 'B+');
	insert into takes values('59046', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('67436', '489', '1', 'Fall', 2007, 'B+');
	insert into takes values('79772', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('60224', '626', '1', 'Fall', 2006, 'B-');
	insert into takes values('32376', '192', '1', 'Fall', 2002, 'A+');
	insert into takes values('1232', '304', '1', 'Fall', 2009, 'A+');
	insert into takes values('19203', '559', '1', 'Fall', 2002, 'B+');
	insert into takes values('51203', '274', '1', 'Fall', 2002, 'B-');
	insert into takes values('42960', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('96134', '400', '1', 'Spring', 2007, 'B ');
	insert into takes values('99073', '893', '1', 'Fall', 2007, 'B ');
	insert into takes values('66969', '349', '1', 'Spring', 2008, 'B+');
	insert into takes values('99271', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('1533', '468', '1', 'Fall', 2005, 'C+');
	insert into takes values('55940', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('43432', '137', '1', 'Spring', 2002, 'B+');
	insert into takes values('71085', '105', '2', 'Fall', 2002, 'C-');
	insert into takes values('4645', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('55915', '599', '1', 'Spring', 2003, 'C ');
	insert into takes values('34569', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('15070', '415', '1', 'Fall', 2010, 'C-');
	insert into takes values('9933', '457', '1', 'Spring', 2001, 'A+');
	insert into takes values('35362', '362', '1', 'Fall', 2005, 'C-');
	insert into takes values('22417', '426', '1', 'Spring', 2006, 'A-');
	insert into takes values('6287', '349', '1', 'Spring', 2008, 'C-');
	insert into takes values('39552', '629', '1', 'Spring', 2003, 'B ');
	insert into takes values('17997', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('22912', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('15487', '626', '1', 'Fall', 2006, 'B-');
	insert into takes values('35362', '559', '1', 'Fall', 2002, 'B+');
	insert into takes values('67810', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('29091', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('45494', '960', '2', 'Fall', 2006, 'C-');
	insert into takes values('63582', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('65688', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('10838', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('92703', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('8860', '169', '1', 'Spring', 2007, 'B-');
	insert into takes values('38271', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('54610', '663', '1', 'Spring', 2005, 'C ');
	insert into takes values('64914', '105', '2', 'Fall', 2002, 'B+');
	insert into takes values('17128', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('80420', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('32065', '313', '1', 'Fall', 2010, 'C ');
	insert into takes values('74070', '476', '1', 'Fall', 2010, 'B+');
	insert into takes values('58085', '408', '1', 'Spring', 2007, 'A+');
	insert into takes values('36513', '158', '1', 'Fall', 2008, 'C-');
	insert into takes values('11422', '468', '1', 'Fall', 2005, 'A-');
	insert into takes values('99348', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('45200', '795', '1', 'Spring', 2004, 'C+');
	insert into takes values('67793', '258', '1', 'Fall', 2007, 'A+');
	insert into takes values('5703', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('83573', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('48776', '692', '1', 'Spring', 2010, 'C-');
	insert into takes values('50039', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('44584', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('13826', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('14182', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('64642', '694', '1', 'Fall', 2002, 'A ');
	insert into takes values('71628', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('12362', '270', '1', 'Spring', 2010, 'C ');
	insert into takes values('65753', '867', '2', 'Fall', 2010, 'A-');
	insert into takes values('90663', '242', '1', 'Fall', 2009, 'C+');
	insert into takes values('13826', '663', '1', 'Spring', 2005, 'A-');
	insert into takes values('13506', '242', '1', 'Fall', 2009, 'B+');
	insert into takes values('31442', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('39157', '457', '1', 'Spring', 2001, 'B+');
	insert into takes values('82688', '200', '2', 'Fall', 2002, 'B+');
	insert into takes values('66813', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('36126', '793', '1', 'Spring', 2002, 'A ');
	insert into takes values('2967', '991', '1', 'Spring', 2008, 'B ');
	insert into takes values('91569', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('78581', '338', '1', 'Spring', 2007, 'B ');
	insert into takes values('68779', '694', '1', 'Fall', 2002, 'A ');
	insert into takes values('10904', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('60984', '626', '1', 'Fall', 2006, 'B+');
	insert into takes values('35905', '200', '1', 'Spring', 2007, 'C-');
	insert into takes values('90779', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('17507', '169', '2', 'Fall', 2002, 'B+');
	insert into takes values('46260', '105', '1', 'Fall', 2009, 'C+');
	insert into takes values('38902', '415', '1', 'Fall', 2010, 'C-');
	insert into takes values('38271', '927', '1', 'Fall', 2002, 'C-');
	insert into takes values('89059', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('33546', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('89551', '663', '1', 'Spring', 2005, 'A-');
	insert into takes values('61003', '949', '1', 'Fall', 2007, 'B ');
	insert into takes values('62373', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('94730', '571', '1', 'Spring', 2004, 'C+');
	insert into takes values('73807', '313', '1', 'Fall', 2010, 'C ');
	insert into takes values('70310', '468', '2', 'Fall', 2007, 'B ');
	insert into takes values('4438', '962', '1', 'Spring', 2008, 'C-');
	insert into takes values('16035', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('69471', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('72528', '426', '1', 'Spring', 2006, 'A-');
	insert into takes values('85234', '366', '1', 'Fall', 2005, 'A+');
	insert into takes values('16528', '105', '1', 'Fall', 2009, 'A+');
	insert into takes values('65190', '408', '1', 'Spring', 2007, 'A+');
	insert into takes values('72657', '352', '1', 'Spring', 2006, 'B ');
	insert into takes values('4015', '313', '1', 'Fall', 2010, 'C ');
	insert into takes values('44706', '702', '1', 'Spring', 2001, 'C-');
	insert into takes values('54728', '496', '1', 'Fall', 2001, 'B ');
	insert into takes values('10076', '962', '1', 'Spring', 2008, 'C+');
	insert into takes values('163', '169', '1', 'Spring', 2007, 'A ');
	insert into takes values('98870', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('83003', '561', '1', 'Fall', 2006, 'C-');
	insert into takes values('4182', '457', '1', 'Spring', 2001, 'B ');
	insert into takes values('51923', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('94836', '376', '1', 'Fall', 2006, 'C ');
	insert into takes values('76250', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('12683', '604', '1', 'Spring', 2009, 'B ');
	insert into takes values('38668', '791', '1', 'Spring', 2006, 'A ');
	insert into takes values('16133', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('13741', '843', '1', 'Fall', 2010, 'A ');
	insert into takes values('37284', '559', '1', 'Fall', 2002, 'A-');
	insert into takes values('1087', '461', '1', 'Fall', 2002, 'B ');
	insert into takes values('88389', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('13921', '158', '1', 'Fall', 2008, 'C-');
	insert into takes values('11095', '242', '1', 'Fall', 2009, 'C-');
	insert into takes values('24116', '105', '2', 'Fall', 2002, 'A ');
	insert into takes values('63560', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('69225', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('75513', '959', '1', 'Fall', 2006, 'C+');
	insert into takes values('81789', '893', '1', 'Fall', 2007, 'A ');
	insert into takes values('78454', '158', '2', 'Spring', 2008, 'C ');
	insert into takes values('48471', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('32483', '591', '1', 'Spring', 2005, 'A+');
	insert into takes values('8022', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('66969', '362', '3', 'Spring', 2008, 'C-');
	insert into takes values('14581', '808', '1', 'Fall', 2003, 'B ');
	insert into takes values('31302', '489', '1', 'Fall', 2007, 'A ');
	insert into takes values('4015', '927', '1', 'Fall', 2002, 'A-');
	insert into takes values('36926', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('70099', '603', '1', 'Fall', 2003, 'A ');
	insert into takes values('76049', '599', '1', 'Spring', 2003, 'A-');
	insert into takes values('76246', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('40738', '362', '3', 'Spring', 2008, 'C-');
	insert into takes values('50719', '158', '2', 'Spring', 2008, 'C ');
	insert into takes values('94815', '401', '1', 'Fall', 2003, 'A ');
	insert into takes values('25942', '489', '1', 'Fall', 2007, 'C+');
	insert into takes values('9947', '603', '1', 'Fall', 2003, 'A ');
	insert into takes values('39157', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('33759', '760', '1', 'Spring', 2004, 'B+');
	insert into takes values('90009', '631', '1', 'Spring', 2007, 'C-');
	insert into takes values('49503', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('73602', '461', '1', 'Fall', 2002, 'B ');
	insert into takes values('85211', '352', '1', 'Spring', 2006, 'C+');
	insert into takes values('1533', '338', '2', 'Spring', 2006, 'A+');
	insert into takes values('3651', '401', '1', 'Fall', 2003, 'C-');
	insert into takes values('20378', '415', '1', 'Fall', 2010, 'B+');
	insert into takes values('61783', '972', '1', 'Spring', 2009, 'C ');
	insert into takes values('40992', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('43432', '642', '1', 'Fall', 2004, 'B-');
	insert into takes values('58846', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('9659', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('63645', '735', '2', 'Spring', 2010, 'A ');
	insert into takes values('60267', '626', '1', 'Fall', 2006, 'B+');
	insert into takes values('46762', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('89571', '581', '1', 'Spring', 2005, 'C+');
	insert into takes values('39115', '319', '1', 'Spring', 2003, 'C-');
	insert into takes values('13290', '793', '1', 'Spring', 2002, 'B ');
	insert into takes values('38476', '274', '1', 'Fall', 2002, 'B ');
	insert into takes values('58172', '493', '1', 'Spring', 2010, 'B+');
	insert into takes values('22268', '158', '2', 'Spring', 2008, 'A ');
	insert into takes values('44352', '852', '1', 'Spring', 2008, 'C-');
	insert into takes values('69853', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('84410', '599', '1', 'Spring', 2003, 'C+');
	insert into takes values('89196', '408', '2', 'Spring', 2003, 'C-');
	insert into takes values('28316', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('29091', '486', '1', 'Fall', 2009, 'A-');
	insert into takes values('62832', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('58172', '760', '1', 'Spring', 2004, 'B-');
	insert into takes values('79534', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('63886', '974', '1', 'Fall', 2003, 'B-');
	insert into takes values('92776', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('94846', '400', '1', 'Spring', 2007, 'C ');
	insert into takes values('28994', '893', '1', 'Fall', 2007, 'C ');
	insert into takes values('18941', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('35042', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('88525', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('38902', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('26080', '959', '1', 'Fall', 2006, 'A ');
	insert into takes values('63390', '949', '1', 'Fall', 2007, 'C ');
	insert into takes values('54508', '496', '1', 'Fall', 2001, 'B-');
	insert into takes values('19293', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('41406', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('14874', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('82126', '864', '1', 'Spring', 2006, 'C-');
	insert into takes values('56078', '304', '1', 'Fall', 2009, 'C+');
	insert into takes values('39238', '158', '2', 'Spring', 2008, 'A-');
	insert into takes values('56003', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('66090', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('41965', '468', '1', 'Fall', 2005, 'B-');
	insert into takes values('93508', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('81550', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('30397', '200', '1', 'Spring', 2007, 'A ');
	insert into takes values('57780', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('36995', '242', '1', 'Fall', 2009, 'C+');
	insert into takes values('30182', '362', '2', 'Fall', 2006, 'B-');
	insert into takes values('94257', '489', '1', 'Fall', 2007, 'B+');
	insert into takes values('37339', '426', '1', 'Spring', 2006, 'B ');
	insert into takes values('21009', '200', '2', 'Fall', 2002, 'C+');
	insert into takes values('95089', '735', '1', 'Spring', 2003, 'B-');
	insert into takes values('67021', '496', '1', 'Fall', 2001, 'B-');
	insert into takes values('96615', '270', '1', 'Spring', 2010, 'B+');
	insert into takes values('5843', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('84189', '270', '1', 'Spring', 2010, 'A-');
	insert into takes values('17057', '304', '1', 'Fall', 2009, 'A ');
	insert into takes values('27919', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('2201', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('57026', '962', '1', 'Spring', 2008, 'B ');
	insert into takes values('30222', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('79763', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('24796', '457', '1', 'Spring', 2001, 'B ');
	insert into takes values('18740', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('66293', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('28538', '461', '1', 'Fall', 2002, 'C-');
	insert into takes values('53496', '274', '1', 'Fall', 2002, 'A+');
	insert into takes values('32483', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('12941', '603', '1', 'Fall', 2003, 'C-');
	insert into takes values('59517', '270', '1', 'Spring', 2010, 'C ');
	insert into takes values('68280', '169', '1', 'Spring', 2007, 'B+');
	insert into takes values('38548', '631', '1', 'Spring', 2007, 'C-');
	insert into takes values('37101', '408', '2', 'Spring', 2003, 'A ');
	insert into takes values('5250', '974', '1', 'Fall', 2003, 'C ');
	insert into takes values('64938', '338', '1', 'Spring', 2007, 'C-');
	insert into takes values('16133', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('36265', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('81883', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('46451', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('46260', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('81896', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('19541', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('10663', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('16907', '795', '1', 'Spring', 2004, 'A-');
	insert into takes values('92417', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('83592', '527', '1', 'Fall', 2004, 'A-');
	insert into takes values('67793', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('38895', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('7854', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('16631', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('54153', '239', '1', 'Fall', 2006, 'B ');
	insert into takes values('993', '401', '1', 'Fall', 2003, 'A ');
	insert into takes values('77130', '663', '1', 'Spring', 2005, 'C-');
	insert into takes values('8343', '338', '2', 'Spring', 2006, 'A+');
	insert into takes values('1285', '496', '1', 'Fall', 2001, 'A-');
	insert into takes values('46725', '843', '1', 'Fall', 2010, 'C+');
	insert into takes values('95027', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('65703', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('55286', '795', '1', 'Spring', 2004, 'B ');
	insert into takes values('95260', '408', '2', 'Spring', 2003, 'B ');
	insert into takes values('11201', '581', '1', 'Spring', 2005, 'A ');
	insert into takes values('21102', '338', '2', 'Spring', 2006, 'B ');
	insert into takes values('61166', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('26473', '795', '1', 'Spring', 2004, 'B ');
	insert into takes values('25785', '376', '1', 'Fall', 2006, 'A-');
	insert into takes values('96324', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('24630', '603', '1', 'Fall', 2003, 'A ');
	insert into takes values('95631', '362', '2', 'Fall', 2006, 'B-');
	insert into takes values('38668', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('80057', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('53490', '867', '2', 'Fall', 2010, 'B-');
	insert into takes values('24374', '692', '1', 'Spring', 2010, 'A+');
	insert into takes values('44551', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('93043', '468', '2', 'Fall', 2007, 'B ');
	insert into takes values('27956', '795', '1', 'Spring', 2004, 'B ');
	insert into takes values('79170', '408', '1', 'Spring', 2007, 'C ');
	insert into takes values('59673', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('30474', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('47025', '959', '1', 'Fall', 2006, 'A ');
	insert into takes values('31341', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('89196', '421', '1', 'Fall', 2004, 'C+');
	insert into takes values('47487', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('7123', '991', '1', 'Spring', 2008, 'A ');
	insert into takes values('14581', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('83204', '959', '1', 'Fall', 2006, 'C+');
	insert into takes values('7123', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('25187', '400', '2', 'Fall', 2003, 'A-');
	insert into takes values('5414', '962', '1', 'Spring', 2008, 'C-');
	insert into takes values('544', '468', '1', 'Fall', 2005, 'B ');
	insert into takes values('32376', '612', '1', 'Fall', 2007, 'C ');
	insert into takes values('87268', '105', '2', 'Fall', 2002, 'A-');
	insert into takes values('44998', '200', '2', 'Fall', 2002, 'B+');
	insert into takes values('96710', '338', '2', 'Spring', 2006, 'C ');
	insert into takes values('82402', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('79589', '808', '1', 'Fall', 2003, 'A+');
	insert into takes values('88887', '949', '1', 'Fall', 2007, 'C ');
	insert into takes values('90372', '692', '1', 'Spring', 2010, 'B-');
	insert into takes values('50038', '366', '1', 'Fall', 2005, 'B ');
	insert into takes values('32217', '735', '2', 'Spring', 2010, 'C ');
	insert into takes values('32368', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('52866', '493', '1', 'Spring', 2010, 'C ');
	insert into takes values('57242', '443', '2', 'Spring', 2002, 'C+');
	insert into takes values('43348', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('61920', '694', '1', 'Fall', 2002, 'C ');
	insert into takes values('31560', '679', '1', 'Spring', 2010, 'C-');
	insert into takes values('41261', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('19848', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('84189', '105', '1', 'Fall', 2009, 'C+');
	insert into takes values('10727', '338', '1', 'Spring', 2007, 'C-');
	insert into takes values('75560', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('66495', '258', '1', 'Fall', 2007, 'C ');
	insert into takes values('16453', '270', '1', 'Spring', 2010, 'A-');
	insert into takes values('65299', '991', '1', 'Spring', 2008, 'B-');
	insert into takes values('41211', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('77000', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('99250', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('75938', '604', '1', 'Spring', 2009, 'A ');
	insert into takes values('37350', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('86404', '237', '1', 'Spring', 2008, 'B-');
	insert into takes values('37734', '461', '1', 'Fall', 2002, 'C-');
	insert into takes values('61166', '400', '2', 'Fall', 2003, 'A ');
	insert into takes values('30222', '974', '1', 'Fall', 2003, 'C ');
	insert into takes values('9440', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('33401', '949', '1', 'Fall', 2007, 'B ');
	insert into takes values('760', '408', '1', 'Spring', 2007, 'C+');
	insert into takes values('24796', '735', '1', 'Spring', 2003, 'A-');
	insert into takes values('16453', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('59530', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('82974', '169', '1', 'Spring', 2007, 'C ');
	insert into takes values('41827', '599', '1', 'Spring', 2003, 'A ');
	insert into takes values('64249', '242', '1', 'Fall', 2009, 'B+');
	insert into takes values('60366', '704', '1', 'Spring', 2008, 'B ');
	insert into takes values('40738', '692', '1', 'Spring', 2010, 'C ');
	insert into takes values('13290', '875', '1', 'Spring', 2005, 'A-');
	insert into takes values('76895', '791', '1', 'Spring', 2006, 'B+');
	insert into takes values('80941', '959', '1', 'Fall', 2006, 'B+');
	insert into takes values('38902', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('78922', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('51093', '476', '1', 'Fall', 2010, 'B+');
	insert into takes values('50977', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('10033', '242', '1', 'Fall', 2009, 'B ');
	insert into takes values('18499', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('81294', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('97228', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('29705', '457', '1', 'Spring', 2001, 'A ');
	insert into takes values('19220', '962', '1', 'Spring', 2008, 'A ');
	insert into takes values('58935', '545', '1', 'Fall', 2001, 'B-');
	insert into takes values('76798', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('80420', '476', '1', 'Fall', 2010, 'B+');
	insert into takes values('47126', '443', '1', 'Spring', 2010, 'A+');
	insert into takes values('82083', '694', '1', 'Fall', 2002, 'B-');
	insert into takes values('77548', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('63243', '426', '1', 'Spring', 2006, 'C ');
	insert into takes values('94814', '334', '1', 'Fall', 2009, 'A ');
	insert into takes values('58889', '137', '1', 'Spring', 2002, 'A ');
	insert into takes values('435', '105', '2', 'Fall', 2002, 'A-');
	insert into takes values('42114', '631', '1', 'Spring', 2007, 'A-');
	insert into takes values('66753', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('77000', '795', '1', 'Spring', 2004, 'C+');
	insert into takes values('49684', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('62636', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('99553', '852', '1', 'Spring', 2008, 'C-');
	insert into takes values('52471', '893', '1', 'Fall', 2007, 'B+');
	insert into takes values('40044', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('11966', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('24197', '694', '1', 'Fall', 2002, 'B-');
	insert into takes values('61127', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('4004', '626', '1', 'Fall', 2006, 'B-');
	insert into takes values('94173', '258', '1', 'Fall', 2007, 'C ');
	insert into takes values('82063', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('15613', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('847', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('25068', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('57135', '793', '1', 'Spring', 2002, 'A ');
	insert into takes values('66753', '338', '2', 'Spring', 2006, 'B+');
	insert into takes values('65987', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('57780', '334', '1', 'Fall', 2009, 'A-');
	insert into takes values('95089', '105', '2', 'Fall', 2002, 'A+');
	insert into takes values('6523', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('89759', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('95284', '468', '1', 'Fall', 2005, 'C+');
	insert into takes values('39552', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('39978', '704', '1', 'Spring', 2008, 'C-');
	insert into takes values('62784', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('34788', '169', '2', 'Fall', 2002, 'A-');
	insert into takes values('11441', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('49214', '400', '2', 'Fall', 2003, 'B+');
	insert into takes values('3143', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('71631', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('40276', '493', '1', 'Spring', 2010, 'B ');
	insert into takes values('94257', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('75231', '972', '1', 'Spring', 2009, 'C ');
	insert into takes values('81207', '692', '1', 'Spring', 2010, 'A+');
	insert into takes values('84432', '747', '1', 'Spring', 2004, 'B+');
	insert into takes values('5144', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('557', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('78787', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('792', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('78116', '867', '2', 'Fall', 2010, 'B-');
	insert into takes values('85505', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('86806', '867', '1', 'Fall', 2006, 'B+');
	insert into takes values('30222', '258', '1', 'Fall', 2007, 'A ');
	insert into takes values('76799', '242', '1', 'Fall', 2009, 'C-');
	insert into takes values('163', '747', '1', 'Spring', 2004, 'C ');
	insert into takes values('12563', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('29871', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('67371', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('66281', '591', '1', 'Spring', 2005, 'C-');
	insert into takes values('97868', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('7973', '408', '2', 'Spring', 2003, 'C-');
	insert into takes values('77898', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('84792', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('10736', '349', '1', 'Spring', 2008, 'A-');
	insert into takes values('15538', '867', '1', 'Fall', 2006, 'A+');
	insert into takes values('5463', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('29462', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('83444', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('70021', '561', '1', 'Fall', 2006, 'A ');
	insert into takes values('7732', '559', '1', 'Fall', 2002, 'A-');
	insert into takes values('31137', '401', '1', 'Fall', 2003, 'C ');
	insert into takes values('7620', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('94142', '962', '1', 'Spring', 2008, 'B-');
	insert into takes values('15083', '489', '1', 'Fall', 2007, 'C ');
	insert into takes values('282', '362', '2', 'Fall', 2006, 'A ');
	insert into takes values('4173', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('78767', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('16515', '408', '2', 'Spring', 2003, 'B ');
	insert into takes values('75252', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('26102', '443', '1', 'Spring', 2010, 'B+');
	insert into takes values('39310', '949', '1', 'Fall', 2007, 'C-');
	insert into takes values('68248', '545', '1', 'Fall', 2001, 'A ');
	insert into takes values('22325', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('70688', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('57456', '704', '1', 'Spring', 2008, 'C ');
	insert into takes values('75299', '313', '1', 'Fall', 2010, 'B+');
	insert into takes values('25046', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('90353', '489', '1', 'Fall', 2007, 'A ');
	insert into takes values('43616', '408', '1', 'Spring', 2007, 'A+');
	insert into takes values('81884', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('83170', '457', '1', 'Spring', 2001, 'B+');
	insert into takes values('78434', '200', '1', 'Spring', 2007, 'A+');
	insert into takes values('43032', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('15883', '496', '1', 'Fall', 2001, 'C ');
	insert into takes values('91091', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('36303', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('39876', '362', '1', 'Fall', 2005, 'C-');
	insert into takes values('30017', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('4438', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('29399', '972', '1', 'Spring', 2009, 'B-');
	insert into takes values('6710', '313', '1', 'Fall', 2010, 'A+');
	insert into takes values('88418', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('8912', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('78332', '760', '1', 'Spring', 2004, 'C ');
	insert into takes values('77580', '559', '1', 'Fall', 2002, 'B+');
	insert into takes values('10693', '793', '1', 'Spring', 2002, 'B+');
	insert into takes values('76953', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('37818', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('80420', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('97400', '702', '1', 'Spring', 2001, 'C+');
	insert into takes values('52929', '352', '1', 'Spring', 2006, 'C+');
	insert into takes values('85366', '338', '2', 'Spring', 2006, 'B+');
	insert into takes values('69783', '642', '1', 'Fall', 2004, 'C+');
	insert into takes values('39238', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('80057', '270', '1', 'Spring', 2010, 'C+');
	insert into takes values('47824', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('23392', '468', '2', 'Fall', 2007, 'A-');
	insert into takes values('75534', '561', '1', 'Fall', 2006, 'C+');
	insert into takes values('99399', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('98047', '137', '1', 'Spring', 2002, 'C-');
	insert into takes values('21101', '991', '1', 'Spring', 2008, 'C-');
	insert into takes values('89759', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('95840', '482', '1', 'Fall', 2005, 'B-');
	insert into takes values('54153', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('72501', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('40457', '795', '1', 'Spring', 2004, 'A-');
	insert into takes values('87015', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('41774', '603', '1', 'Fall', 2003, 'B-');
	insert into takes values('11194', '242', '1', 'Fall', 2009, 'B+');
	insert into takes values('29399', '864', '1', 'Spring', 2006, 'A+');
	insert into takes values('51538', '875', '1', 'Spring', 2005, 'C ');
	insert into takes values('72485', '591', '1', 'Spring', 2005, 'B+');
	insert into takes values('29849', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('3493', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('5414', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('21126', '338', '2', 'Spring', 2006, 'B+');
	insert into takes values('66813', '338', '2', 'Spring', 2006, 'B ');
	insert into takes values('93708', '338', '1', 'Spring', 2007, 'A+');
	insert into takes values('73411', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('16593', '349', '1', 'Spring', 2008, 'A ');
	insert into takes values('64945', '192', '1', 'Fall', 2002, 'C-');
	insert into takes values('45300', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('12078', '559', '1', 'Fall', 2002, 'A-');
	insert into takes values('76250', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('87048', '421', '1', 'Fall', 2004, 'C-');
	insert into takes values('94990', '400', '1', 'Spring', 2007, 'B+');
	insert into takes values('99660', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('1367', '158', '2', 'Spring', 2008, 'A-');
	insert into takes values('64945', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('98359', '457', '1', 'Spring', 2001, 'C+');
	insert into takes values('19342', '169', '1', 'Spring', 2007, 'B ');
	insert into takes values('52291', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('15613', '679', '1', 'Spring', 2010, 'A+');
	insert into takes values('27950', '747', '1', 'Spring', 2004, 'A ');
	insert into takes values('7970', '169', '2', 'Fall', 2002, 'A+');
	insert into takes values('28952', '457', '1', 'Spring', 2001, 'A-');
	insert into takes values('32130', '408', '1', 'Spring', 2007, 'C+');
	insert into takes values('40044', '258', '1', 'Fall', 2007, 'C-');
	insert into takes values('69960', '362', '3', 'Spring', 2008, 'A+');
	insert into takes values('58081', '949', '1', 'Fall', 2007, 'C ');
	insert into takes values('53225', '334', '1', 'Fall', 2009, 'B+');
	insert into takes values('47379', '960', '1', 'Fall', 2009, 'A-');
	insert into takes values('78332', '604', '1', 'Spring', 2009, 'A-');
	insert into takes values('29645', '591', '1', 'Spring', 2005, 'A-');
	insert into takes values('56078', '443', '2', 'Spring', 2002, 'B ');
	insert into takes values('99553', '482', '1', 'Fall', 2005, 'A-');
	insert into takes values('10693', '362', '1', 'Fall', 2005, 'C-');
	insert into takes values('43032', '421', '1', 'Fall', 2004, 'B+');
	insert into takes values('78314', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('34126', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('98388', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('92659', '400', '2', 'Fall', 2003, 'A-');
	insert into takes values('6367', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('30124', '795', '1', 'Spring', 2004, 'B+');
	insert into takes values('64140', '692', '1', 'Spring', 2010, 'C ');
	insert into takes values('78454', '421', '1', 'Fall', 2004, 'A ');
	insert into takes values('32506', '137', '1', 'Spring', 2002, 'B ');
	insert into takes values('5843', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('21774', '679', '1', 'Spring', 2010, 'B ');
	insert into takes values('69632', '352', '1', 'Spring', 2006, 'B+');
	insert into takes values('99348', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('11194', '795', '1', 'Spring', 2004, 'A-');
	insert into takes values('59455', '421', '1', 'Fall', 2004, 'C+');
	insert into takes values('97101', '591', '1', 'Spring', 2005, 'B+');
	insert into takes values('70299', '867', '1', 'Fall', 2006, 'B+');
	insert into takes values('3693', '791', '1', 'Spring', 2006, 'A ');
	insert into takes values('28829', '692', '1', 'Spring', 2010, 'C+');
	insert into takes values('37103', '972', '1', 'Spring', 2009, 'A+');
	insert into takes values('84808', '349', '1', 'Spring', 2008, 'B+');
	insert into takes values('3127', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('19862', '642', '1', 'Fall', 2004, 'B-');
	insert into takes values('71529', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('6990', '486', '1', 'Fall', 2009, 'A ');
	insert into takes values('34126', '735', '1', 'Spring', 2003, 'B-');
	insert into takes values('78911', '105', '2', 'Fall', 2002, 'A-');
	insert into takes values('67560', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('81245', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('74796', '486', '1', 'Fall', 2009, 'A ');
	insert into takes values('18636', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('58081', '864', '1', 'Spring', 2006, 'C-');
	insert into takes values('34197', '237', '2', 'Fall', 2009, 'C+');
	insert into takes values('64155', '137', '1', 'Spring', 2002, 'B+');
	insert into takes values('76057', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('41450', '493', '1', 'Spring', 2010, 'A ');
	insert into takes values('75123', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('29399', '603', '1', 'Fall', 2003, 'A ');
	insert into takes values('97041', '960', '2', 'Fall', 2006, 'A-');
	insert into takes values('80227', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('36126', '443', '2', 'Spring', 2002, 'B-');
	insert into takes values('44881', '362', '3', 'Spring', 2008, 'B ');
	insert into takes values('79763', '702', '1', 'Spring', 2001, 'A-');
	insert into takes values('63560', '476', '1', 'Fall', 2010, 'C-');
	insert into takes values('35175', '599', '1', 'Spring', 2003, 'A ');
	insert into takes values('32056', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('65241', '352', '1', 'Spring', 2006, 'B+');
	insert into takes values('14869', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('89234', '604', '1', 'Spring', 2009, 'B ');
	insert into takes values('22198', '445', '1', 'Spring', 2001, 'B+');
	insert into takes values('7854', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('987', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('81396', '571', '1', 'Spring', 2004, 'C+');
	insert into takes values('28738', '313', '1', 'Fall', 2010, 'A+');
	insert into takes values('12078', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('50743', '571', '1', 'Spring', 2004, 'C ');
	insert into takes values('16133', '239', '1', 'Fall', 2006, 'B-');
	insert into takes values('46155', '401', '1', 'Fall', 2003, 'A+');
	insert into takes values('38013', '258', '1', 'Fall', 2007, 'C+');
	insert into takes values('78314', '158', '2', 'Spring', 2008, 'C+');
	insert into takes values('41406', '735', '2', 'Spring', 2010, 'B-');
	insert into takes values('71085', '313', '1', 'Fall', 2010, 'A-');
	insert into takes values('87193', '334', '1', 'Fall', 2009, 'B+');
	insert into takes values('47627', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('5243', '599', '1', 'Spring', 2003, 'C+');
	insert into takes values('78787', '927', '1', 'Fall', 2002, 'A-');
	insert into takes values('3039', '604', '1', 'Spring', 2009, 'C ');
	insert into takes values('667', '242', '1', 'Fall', 2009, 'C+');
	insert into takes values('71628', '158', '2', 'Spring', 2008, 'B-');
	insert into takes values('39876', '376', '1', 'Fall', 2006, 'B-');
	insert into takes values('31086', '237', '2', 'Fall', 2009, 'B+');
	insert into takes values('49280', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('45826', '735', '2', 'Spring', 2010, 'B ');
	insert into takes values('83170', '864', '1', 'Spring', 2006, 'A ');
	insert into takes values('82707', '313', '1', 'Fall', 2010, 'C-');
	insert into takes values('19638', '692', '1', 'Spring', 2010, 'C+');
	insert into takes values('22618', '702', '1', 'Spring', 2001, 'C+');
	insert into takes values('97023', '663', '1', 'Spring', 2005, 'A ');
	insert into takes values('50664', '242', '1', 'Fall', 2009, 'A-');
	insert into takes values('65101', '962', '1', 'Spring', 2008, 'B-');
	insert into takes values('58170', '338', '1', 'Spring', 2007, 'C-');
	insert into takes values('7204', '105', '2', 'Fall', 2002, 'B+');
	insert into takes values('85680', '362', '3', 'Spring', 2008, 'B ');
	insert into takes values('18367', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('99073', '864', '1', 'Spring', 2006, 'C-');
	insert into takes values('70807', '663', '1', 'Spring', 2005, 'A ');
	insert into takes values('13408', '443', '2', 'Spring', 2002, 'B+');
	insert into takes values('96227', '735', '1', 'Spring', 2003, 'C+');
	insert into takes values('5250', '748', '1', 'Fall', 2003, 'C-');
	insert into takes values('4355', '808', '1', 'Fall', 2003, 'A-');
	insert into takes values('64169', '200', '2', 'Fall', 2002, 'B+');
	insert into takes values('53048', '376', '1', 'Fall', 2006, 'B+');
	insert into takes values('55286', '313', '1', 'Fall', 2010, 'C-');
	insert into takes values('43032', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('25046', '258', '1', 'Fall', 2007, 'C+');
	insert into takes values('64550', '960', '1', 'Fall', 2009, 'B-');
	insert into takes values('61414', '692', '1', 'Spring', 2010, 'A+');
	insert into takes values('5824', '581', '1', 'Spring', 2005, 'C-');
	insert into takes values('55170', '631', '1', 'Spring', 2007, 'B ');
	insert into takes values('61444', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('18740', '338', '2', 'Spring', 2006, 'B ');
	insert into takes values('14581', '237', '1', 'Spring', 2008, 'A-');
	insert into takes values('52371', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('39892', '482', '1', 'Fall', 2005, 'B-');
	insert into takes values('41938', '702', '1', 'Spring', 2001, 'C-');
	insert into takes values('14065', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('60249', '791', '1', 'Spring', 2006, 'A-');
	insert into takes values('108', '493', '1', 'Spring', 2010, 'A-');
	insert into takes values('42560', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('66356', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('65703', '461', '1', 'Fall', 2002, 'C-');
	insert into takes values('18752', '581', '1', 'Spring', 2005, 'A ');
	insert into takes values('33201', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('5920', '400', '2', 'Fall', 2003, 'C+');
	insert into takes values('63645', '696', '1', 'Spring', 2002, 'B+');
	insert into takes values('76270', '760', '1', 'Spring', 2004, 'A-');
	insert into takes values('92274', '362', '3', 'Spring', 2008, 'C+');
	insert into takes values('15030', '612', '1', 'Fall', 2007, 'B ');
	insert into takes values('45817', '545', '1', 'Fall', 2001, 'A ');
	insert into takes values('282', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('50944', '345', '1', 'Spring', 2008, 'A ');
	insert into takes values('10904', '237', '2', 'Fall', 2009, 'A ');
	insert into takes values('97551', '642', '1', 'Fall', 2004, 'B-');
	insert into takes values('15980', '893', '1', 'Fall', 2007, 'A+');
	insert into takes values('70099', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('76604', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('99611', '962', '1', 'Spring', 2008, 'A ');
	insert into takes values('1367', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('89734', '338', '1', 'Spring', 2007, 'A-');
	insert into takes values('63886', '642', '1', 'Fall', 2004, 'B-');
	insert into takes values('76270', '972', '1', 'Spring', 2009, 'A+');
	insert into takes values('91616', '105', '1', 'Fall', 2009, 'C ');
	insert into takes values('30164', '493', '1', 'Spring', 2010, 'B ');
	insert into takes values('95029', '443', '1', 'Spring', 2010, 'C+');
	insert into takes values('76799', '200', '1', 'Spring', 2007, 'C-');
	insert into takes values('37715', '192', '1', 'Fall', 2002, 'C-');
	insert into takes values('12615', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('80247', '802', '1', 'Spring', 2003, 'C+');
	insert into takes values('38676', '561', '1', 'Fall', 2006, 'B-');
	insert into takes values('18007', '747', '1', 'Spring', 2004, 'B-');
	insert into takes values('91580', '482', '1', 'Fall', 2005, 'B ');
	insert into takes values('65241', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('43912', '352', '1', 'Spring', 2006, 'B ');
	insert into takes values('38476', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('7656', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('2501', '702', '1', 'Spring', 2001, 'C ');
	insert into takes values('14554', '748', '1', 'Fall', 2003, 'C-');
	insert into takes values('30110', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('39310', '893', '1', 'Fall', 2007, 'C ');
	insert into takes values('69471', '237', '2', 'Fall', 2009, 'C ');
	insert into takes values('66469', '105', '1', 'Fall', 2009, 'C+');
	insert into takes values('14829', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('914', '415', '1', 'Fall', 2010, 'A+');
	insert into takes values('98843', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('86833', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('65329', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('52385', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('92965', '748', '1', 'Fall', 2003, 'A-');
	insert into takes values('74016', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('93061', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('95366', '376', '1', 'Fall', 2006, 'A-');
	insert into takes values('4449', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('50537', '304', '1', 'Fall', 2009, 'C+');
	insert into takes values('62728', '527', '1', 'Fall', 2004, 'A-');
	insert into takes values('65144', '696', '1', 'Spring', 2002, 'C ');
	insert into takes values('15340', '445', '1', 'Spring', 2001, 'B+');
	insert into takes values('84808', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('56089', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('7490', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('25068', '408', '2', 'Spring', 2003, 'B-');
	insert into takes values('95697', '852', '1', 'Spring', 2008, 'A-');
	insert into takes values('75878', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('52120', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('69122', '443', '2', 'Spring', 2002, 'A-');
	insert into takes values('83204', '362', '3', 'Spring', 2008, 'B ');
	insert into takes values('45770', '457', '1', 'Spring', 2001, 'C ');
	insert into takes values('4508', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('62784', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('70299', '603', '1', 'Fall', 2003, 'A+');
	insert into takes values('51549', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('54612', '158', '1', 'Fall', 2008, 'A-');
	insert into takes values('32119', '972', '1', 'Spring', 2009, 'B ');
	insert into takes values('36303', '893', '1', 'Fall', 2007, 'B+');
	insert into takes values('17607', '795', '1', 'Spring', 2004, 'B-');
	insert into takes values('11262', '631', '1', 'Spring', 2007, 'C+');
	insert into takes values('40677', '704', '1', 'Spring', 2008, 'A+');
	insert into takes values('15070', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('7973', '443', '1', 'Spring', 2010, 'A-');
	insert into takes values('14065', '421', '1', 'Fall', 2004, 'C ');
	insert into takes values('18583', '735', '1', 'Spring', 2003, 'A ');
	insert into takes values('48660', '694', '1', 'Fall', 2002, 'B-');
	insert into takes values('95046', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('4645', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('12069', '496', '1', 'Fall', 2001, 'A-');
	insert into takes values('23311', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('5843', '345', '1', 'Spring', 2008, 'B-');
	insert into takes values('49982', '482', '1', 'Fall', 2005, 'A-');
	insert into takes values('68516', '867', '1', 'Fall', 2006, 'C+');
	insert into takes values('59920', '242', '1', 'Fall', 2009, 'C+');
	insert into takes values('68453', '158', '2', 'Spring', 2008, 'B-');
	insert into takes values('17397', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('49611', '679', '1', 'Spring', 2010, 'B+');
	insert into takes values('163', '561', '1', 'Fall', 2006, 'A+');
	insert into takes values('65056', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('42556', '239', '1', 'Fall', 2006, 'C-');
	insert into takes values('90353', '486', '1', 'Fall', 2009, 'C ');
	insert into takes values('44206', '735', '1', 'Spring', 2003, 'C ');
	insert into takes values('96085', '642', '1', 'Fall', 2004, 'B-');
	insert into takes values('58594', '338', '1', 'Spring', 2007, 'A+');
	insert into takes values('96085', '599', '1', 'Spring', 2003, 'C+');
	insert into takes values('78792', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('91978', '345', '1', 'Spring', 2008, 'B ');
	insert into takes values('90004', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('88801', '496', '1', 'Fall', 2001, 'B+');
	insert into takes values('57925', '461', '1', 'Fall', 2002, 'A-');
	insert into takes values('19245', '400', '1', 'Spring', 2007, 'C+');
	insert into takes values('39394', '400', '2', 'Fall', 2003, 'B-');
	insert into takes values('52019', '242', '1', 'Fall', 2009, 'B+');
	insert into takes values('29239', '334', '1', 'Fall', 2009, 'C ');
	insert into takes values('85887', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('28352', '864', '1', 'Spring', 2006, 'A ');
	insert into takes values('17086', '400', '1', 'Spring', 2007, 'A-');
	insert into takes values('36263', '270', '1', 'Spring', 2010, 'C ');
	insert into takes values('29849', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('73186', '629', '1', 'Spring', 2003, 'A ');
	insert into takes values('63361', '362', '3', 'Spring', 2008, 'C+');
	insert into takes values('69581', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('56', '345', '1', 'Spring', 2008, 'A+');
	insert into takes values('56089', '105', '2', 'Fall', 2002, 'C-');
	insert into takes values('70688', '338', '1', 'Spring', 2007, 'B-');
	insert into takes values('13081', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('42843', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('29645', '704', '1', 'Spring', 2008, 'A+');
	insert into takes values('18469', '843', '1', 'Fall', 2010, 'C-');
	insert into takes values('30772', '270', '1', 'Spring', 2010, 'B+');
	insert into takes values('47677', '362', '3', 'Spring', 2008, 'C+');
	insert into takes values('6195', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('72669', '443', '1', 'Spring', 2010, 'C+');
	insert into takes values('92839', '415', '1', 'Fall', 2010, 'B-');
	insert into takes values('42388', '631', '1', 'Spring', 2007, 'A ');
	insert into takes values('31560', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('86753', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('34195', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('67021', '962', '1', 'Spring', 2008, 'C+');
	insert into takes values('21102', '612', '1', 'Fall', 2007, 'A+');
	insert into takes values('39310', '927', '1', 'Fall', 2002, 'A+');
	insert into takes values('15249', '679', '1', 'Spring', 2010, 'B ');
	insert into takes values('99730', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('32464', '760', '1', 'Spring', 2004, 'B-');
	insert into takes values('96741', '137', '1', 'Spring', 2002, 'B+');
	insert into takes values('61783', '735', '2', 'Spring', 2010, 'C ');
	insert into takes values('62784', '735', '2', 'Spring', 2010, 'B ');
	insert into takes values('51416', '493', '1', 'Spring', 2010, 'C ');
	insert into takes values('25143', '338', '2', 'Spring', 2006, 'A-');
	insert into takes values('1232', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('67340', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('37038', '486', '1', 'Fall', 2009, 'B ');
	insert into takes values('63860', '421', '1', 'Fall', 2004, 'C-');
	insert into takes values('29031', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('57135', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('59848', '599', '1', 'Spring', 2003, 'A+');
	insert into takes values('94178', '258', '1', 'Fall', 2007, 'C ');
	insert into takes values('69241', '158', '2', 'Spring', 2008, 'B+');
	insert into takes values('43130', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('65715', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('40276', '400', '1', 'Spring', 2007, 'A ');
	insert into takes values('1533', '696', '1', 'Spring', 2002, 'C+');
	insert into takes values('30957', '493', '1', 'Spring', 2010, 'B+');
	insert into takes values('16543', '443', '1', 'Spring', 2010, 'C+');
	insert into takes values('85809', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('84654', '545', '1', 'Fall', 2001, 'B-');
	insert into takes values('4034', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('66008', '376', '1', 'Fall', 2006, 'B+');
	insert into takes values('55286', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('69747', '875', '1', 'Spring', 2005, 'B-');
	insert into takes values('81566', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('3640', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('99189', '258', '1', 'Fall', 2007, 'B+');
	insert into takes values('30161', '338', '2', 'Spring', 2006, 'A-');
	insert into takes values('37339', '237', '1', 'Spring', 2008, 'B ');
	insert into takes values('39978', '338', '1', 'Spring', 2007, 'A-');
	insert into takes values('93004', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('1087', '400', '2', 'Fall', 2003, 'C+');
	insert into takes values('61332', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('16523', '561', '1', 'Fall', 2006, 'A-');
	insert into takes values('97101', '493', '1', 'Spring', 2010, 'A ');
	insert into takes values('43211', '696', '1', 'Spring', 2002, 'B-');
	insert into takes values('11262', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('5243', '304', '1', 'Fall', 2009, 'A ');
	insert into takes values('92867', '760', '1', 'Spring', 2004, 'B ');
	insert into takes values('63310', '158', '2', 'Spring', 2008, 'A ');
	insert into takes values('83204', '591', '1', 'Spring', 2005, 'B-');
	insert into takes values('99369', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('4438', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('67407', '366', '1', 'Fall', 2005, 'C-');
	insert into takes values('78892', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('95697', '599', '1', 'Spring', 2003, 'B+');
	insert into takes values('32056', '489', '1', 'Fall', 2007, 'B-');
	insert into takes values('12563', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('69628', '486', '1', 'Fall', 2009, 'B-');
	insert into takes values('28316', '599', '1', 'Spring', 2003, 'A-');
	insert into takes values('24374', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('58595', '105', '2', 'Fall', 2002, 'C-');
	insert into takes values('75510', '476', '1', 'Fall', 2010, 'A+');
	insert into takes values('30845', '663', '1', 'Spring', 2005, 'A ');
	insert into takes values('18469', '591', '1', 'Spring', 2005, 'B+');
	insert into takes values('76224', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('58846', '415', '1', 'Fall', 2010, 'A-');
	insert into takes values('31137', '304', '1', 'Fall', 2009, 'A ');
	insert into takes values('1110', '338', '2', 'Spring', 2006, 'C ');
	insert into takes values('88993', '612', '1', 'Fall', 2007, 'B+');
	insert into takes values('914', '457', '1', 'Spring', 2001, 'C+');
	insert into takes values('97868', '200', '2', 'Fall', 2002, 'A ');
	insert into takes values('57962', '362', '2', 'Fall', 2006, 'B-');
	insert into takes values('65563', '443', '1', 'Spring', 2010, 'A+');
	insert into takes values('90124', '105', '1', 'Fall', 2009, 'B+');
	insert into takes values('29002', '270', '1', 'Spring', 2010, 'C+');
	insert into takes values('38545', '927', '1', 'Fall', 2002, 'A ');
	insert into takes values('33759', '612', '1', 'Fall', 2007, 'C ');
	insert into takes values('52866', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('43123', '949', '1', 'Fall', 2007, 'B ');
	insert into takes values('37449', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('31442', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('14668', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('87965', '362', '1', 'Fall', 2005, 'C+');
	insert into takes values('29462', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('9440', '561', '1', 'Fall', 2006, 'C-');
	insert into takes values('390', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('48423', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('94620', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('82063', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('37869', '400', '2', 'Fall', 2003, 'C+');
	insert into takes values('83838', '545', '1', 'Fall', 2001, 'C ');
	insert into takes values('30222', '489', '1', 'Fall', 2007, 'B-');
	insert into takes values('46441', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('31364', '735', '1', 'Spring', 2003, 'A+');
	insert into takes values('18859', '158', '1', 'Fall', 2008, 'C ');
	insert into takes values('76672', '875', '1', 'Spring', 2005, 'B+');
	insert into takes values('85445', '867', '1', 'Fall', 2006, 'A ');
	insert into takes values('24442', '974', '1', 'Fall', 2003, 'A+');
	insert into takes values('80698', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('61364', '376', '1', 'Fall', 2006, 'B-');
	insert into takes values('83838', '461', '1', 'Fall', 2002, 'B+');
	insert into takes values('38121', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('1000', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('22345', '270', '1', 'Spring', 2010, 'A-');
	insert into takes values('11055', '468', '2', 'Fall', 2007, 'A+');
	insert into takes values('86404', '242', '1', 'Fall', 2009, 'C ');
	insert into takes values('21552', '702', '1', 'Spring', 2001, 'C+');
	insert into takes values('59397', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('15328', '400', '2', 'Fall', 2003, 'B+');
	insert into takes values('26473', '496', '1', 'Fall', 2001, 'C ');
	insert into takes values('41599', '864', '1', 'Spring', 2006, 'C-');
	insert into takes values('25785', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('83480', '692', '1', 'Spring', 2010, 'C-');
	insert into takes values('11152', '694', '1', 'Fall', 2002, 'A+');
	insert into takes values('89414', '476', '1', 'Fall', 2010, 'B ');
	insert into takes values('18583', '400', '1', 'Spring', 2007, 'A+');
	insert into takes values('1884', '200', '1', 'Spring', 2007, 'A-');
	insert into takes values('6712', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('99760', '852', '1', 'Spring', 2008, 'C ');
	insert into takes values('13511', '852', '1', 'Spring', 2008, 'B ');
	insert into takes values('67017', '496', '1', 'Fall', 2001, 'A-');
	insert into takes values('92839', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('40371', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('66229', '169', '2', 'Fall', 2002, 'A+');
	insert into takes values('96227', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('30896', '313', '1', 'Fall', 2010, 'C-');
	insert into takes values('96615', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('85308', '791', '1', 'Spring', 2006, 'C+');
	insert into takes values('22345', '105', '2', 'Fall', 2002, 'C+');
	insert into takes values('73602', '599', '1', 'Spring', 2003, 'B-');
	insert into takes values('46762', '158', '1', 'Fall', 2008, 'C-');
	insert into takes values('89106', '702', '1', 'Spring', 2001, 'B ');
	insert into takes values('19824', '694', '1', 'Fall', 2002, 'C ');
	insert into takes values('30021', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('9408', '793', '1', 'Spring', 2002, 'A-');
	insert into takes values('29260', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('86736', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('12078', '603', '1', 'Fall', 2003, 'C-');
	insert into takes values('58300', '200', '1', 'Spring', 2007, 'A ');
	insert into takes values('93571', '527', '1', 'Fall', 2004, 'C-');
	insert into takes values('85505', '527', '1', 'Fall', 2004, 'A ');
	insert into takes values('69521', '486', '1', 'Fall', 2009, 'B-');
	insert into takes values('1884', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('78469', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('507', '443', '2', 'Spring', 2002, 'A ');
	insert into takes values('31993', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('17924', '158', '2', 'Spring', 2008, 'C ');
	insert into takes values('69679', '169', '1', 'Spring', 2007, 'A ');
	insert into takes values('2967', '426', '1', 'Spring', 2006, 'A-');
	insert into takes values('15074', '443', '1', 'Spring', 2010, 'C+');
	insert into takes values('20244', '376', '1', 'Fall', 2006, 'A ');
	insert into takes values('5617', '489', '1', 'Fall', 2007, 'B+');
	insert into takes values('32483', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('31761', '486', '1', 'Fall', 2009, 'A ');
	insert into takes values('66281', '338', '1', 'Spring', 2007, 'C-');
	insert into takes values('56058', '313', '1', 'Fall', 2010, 'C ');
	insert into takes values('36926', '631', '1', 'Spring', 2007, 'C-');
	insert into takes values('16467', '158', '1', 'Fall', 2008, 'A ');
	insert into takes values('49611', '604', '1', 'Spring', 2009, 'B-');
	insert into takes values('13921', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('13408', '169', '2', 'Fall', 2002, 'A+');
	insert into takes values('76169', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('17944', '599', '1', 'Spring', 2003, 'B+');
	insert into takes values('98984', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('89106', '629', '1', 'Spring', 2003, 'A ');
	insert into takes values('64039', '974', '1', 'Fall', 2003, 'C ');
	insert into takes values('24865', '158', '2', 'Spring', 2008, 'B-');
	insert into takes values('97400', '692', '1', 'Spring', 2010, 'C-');
	insert into takes values('93653', '468', '1', 'Fall', 2005, 'B-');
	insert into takes values('50598', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('73542', '747', '1', 'Spring', 2004, 'A ');
	insert into takes values('8912', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('17996', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('71944', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('57123', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('1884', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('96741', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('75395', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('18752', '629', '1', 'Spring', 2003, 'B-');
	insert into takes values('14214', '237', '2', 'Fall', 2009, 'B+');
	insert into takes values('19541', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('80113', '893', '1', 'Fall', 2007, 'B ');
	insert into takes values('78911', '400', '2', 'Fall', 2003, 'C+');
	insert into takes values('65329', '319', '1', 'Spring', 2003, 'B-');
	insert into takes values('21086', '239', '1', 'Fall', 2006, 'C+');
	insert into takes values('259', '875', '1', 'Spring', 2005, 'A-');
	insert into takes values('64731', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('13403', '486', '1', 'Fall', 2009, 'B-');
	insert into takes values('72055', '237', '1', 'Spring', 2008, 'A-');
	insert into takes values('76224', '468', '1', 'Fall', 2005, 'A+');
	insert into takes values('25331', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('259', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('40059', '893', '1', 'Fall', 2007, 'C ');
	insert into takes values('66753', '679', '1', 'Spring', 2010, 'A ');
	insert into takes values('73268', '864', '1', 'Spring', 2006, 'C+');
	insert into takes values('76057', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('13290', '270', '1', 'Spring', 2010, 'C+');
	insert into takes values('53699', '242', '1', 'Fall', 2009, 'C-');
	insert into takes values('71387', '362', '3', 'Spring', 2008, 'C-');
	insert into takes values('33107', '694', '1', 'Fall', 2002, 'C+');
	insert into takes values('71085', '852', '1', 'Spring', 2008, 'C-');
	insert into takes values('70359', '604', '1', 'Spring', 2009, 'C ');
	insert into takes values('827', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('15024', '270', '1', 'Spring', 2010, 'C+');
	insert into takes values('68278', '735', '2', 'Spring', 2010, 'C ');
	insert into takes values('65329', '408', '1', 'Spring', 2007, 'C+');
	insert into takes values('87048', '200', '2', 'Fall', 2002, 'B+');
	insert into takes values('67017', '974', '1', 'Fall', 2003, 'C-');
	insert into takes values('85534', '571', '1', 'Spring', 2004, 'A+');
	insert into takes values('898', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('85211', '960', '1', 'Fall', 2009, 'B-');
	insert into takes values('41406', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('46762', '867', '1', 'Fall', 2006, 'A+');
	insert into takes values('97694', '603', '1', 'Fall', 2003, 'C-');
	insert into takes values('33759', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('36791', '571', '1', 'Spring', 2004, 'A-');
	insert into takes values('898', '960', '2', 'Fall', 2006, 'B+');
	insert into takes values('25940', '345', '1', 'Spring', 2008, 'B-');
	insert into takes values('46337', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('85614', '496', '1', 'Fall', 2001, 'B ');
	insert into takes values('44881', '959', '1', 'Fall', 2006, 'B ');
	insert into takes values('4034', '137', '1', 'Spring', 2002, 'B ');
	insert into takes values('69230', '843', '1', 'Fall', 2010, 'C-');
	insert into takes values('25380', '612', '1', 'Fall', 2007, 'B-');
	insert into takes values('67018', '400', '2', 'Fall', 2003, 'B+');
	insert into takes values('98619', '443', '1', 'Spring', 2010, 'A+');
	insert into takes values('28989', '461', '1', 'Fall', 2002, 'B+');
	insert into takes values('54296', '629', '1', 'Spring', 2003, 'B ');
	insert into takes values('59539', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('84495', '461', '1', 'Fall', 2002, 'B-');
	insert into takes values('75794', '366', '1', 'Fall', 2005, 'C-');
	insert into takes values('10693', '612', '1', 'Fall', 2007, 'B+');
	insert into takes values('73328', '927', '1', 'Fall', 2002, 'A+');
	insert into takes values('26695', '599', '1', 'Spring', 2003, 'A-');
	insert into takes values('31476', '559', '1', 'Fall', 2002, 'B+');
	insert into takes values('99422', '362', '1', 'Fall', 2005, 'C-');
	insert into takes values('87246', '400', '1', 'Spring', 2007, 'B+');
	insert into takes values('30124', '319', '1', 'Spring', 2003, 'C+');
	insert into takes values('51579', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('66229', '158', '1', 'Fall', 2008, 'A+');
	insert into takes values('13290', '105', '2', 'Fall', 2002, 'A-');
	insert into takes values('80420', '974', '1', 'Fall', 2003, 'A+');
	insert into takes values('53788', '735', '1', 'Spring', 2003, 'A-');
	insert into takes values('39978', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('107', '105', '2', 'Fall', 2002, 'A-');
	insert into takes values('32772', '258', '1', 'Fall', 2007, 'B-');
	insert into takes values('14023', '852', '1', 'Spring', 2008, 'A ');
	insert into takes values('82066', '457', '1', 'Spring', 2001, 'B-');
	insert into takes values('8378', '137', '1', 'Spring', 2002, 'B ');
	insert into takes values('64164', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('75273', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('67017', '893', '1', 'Fall', 2007, 'C ');
	insert into takes values('12683', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('51093', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('78922', '443', '1', 'Spring', 2010, 'C ');
	insert into takes values('17507', '631', '1', 'Spring', 2007, 'B ');
	insert into takes values('38121', '875', '1', 'Spring', 2005, 'C-');
	insert into takes values('9953', '400', '2', 'Fall', 2003, 'A+');
	insert into takes values('34329', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('17607', '105', '1', 'Fall', 2009, 'C+');
	insert into takes values('85849', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('83170', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('67293', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('46066', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('1000', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('16543', '696', '1', 'Spring', 2002, 'A+');
	insert into takes values('43495', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('31690', '696', '1', 'Spring', 2002, 'B-');
	insert into takes values('33107', '793', '1', 'Spring', 2002, 'B ');
	insert into takes values('79170', '421', '1', 'Fall', 2004, 'B-');
	insert into takes values('47126', '559', '1', 'Fall', 2002, 'B+');
	insert into takes values('50039', '362', '1', 'Fall', 2005, 'B ');
	insert into takes values('19342', '242', '1', 'Fall', 2009, 'A+');
	insert into takes values('46035', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('58081', '760', '1', 'Spring', 2004, 'B-');
	insert into takes values('74530', '169', '1', 'Spring', 2007, 'A ');
	insert into takes values('288', '735', '1', 'Spring', 2003, 'A-');
	insert into takes values('41671', '408', '1', 'Spring', 2007, 'C-');
	insert into takes values('27950', '735', '1', 'Spring', 2003, 'C+');
	insert into takes values('75046', '468', '2', 'Fall', 2007, 'B ');
	insert into takes values('17600', '631', '1', 'Spring', 2007, 'A+');
	insert into takes values('77580', '747', '1', 'Spring', 2004, 'C ');
	insert into takes values('94730', '893', '1', 'Fall', 2007, 'C+');
	insert into takes values('94801', '960', '1', 'Fall', 2009, 'B+');
	insert into takes values('78143', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('35935', '366', '1', 'Fall', 2005, 'B ');
	insert into takes values('62152', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('9460', '345', '1', 'Spring', 2008, 'C-');
	insert into takes values('32376', '974', '1', 'Fall', 2003, 'A-');
	insert into takes values('79502', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('83592', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('79697', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('11855', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('87280', '704', '1', 'Spring', 2008, 'A+');
	insert into takes values('55238', '461', '1', 'Fall', 2002, 'C+');
	insert into takes values('27044', '612', '1', 'Fall', 2007, 'C ');
	insert into takes values('82301', '258', '1', 'Fall', 2007, 'A+');
	insert into takes values('19766', '258', '1', 'Fall', 2007, 'B+');
	insert into takes values('69752', '496', '1', 'Fall', 2001, 'B ');
	insert into takes values('39521', '334', '1', 'Fall', 2009, 'C-');
	insert into takes values('77415', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('32506', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('61402', '313', '1', 'Fall', 2010, 'A ');
	insert into takes values('49813', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('89132', '959', '1', 'Fall', 2006, 'A-');
	insert into takes values('47487', '169', '1', 'Spring', 2007, 'B-');
	insert into takes values('95574', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('50414', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('39901', '313', '1', 'Fall', 2010, 'A ');
	insert into takes values('91978', '366', '1', 'Fall', 2005, 'C-');
	insert into takes values('14628', '468', '1', 'Fall', 2005, 'B-');
	insert into takes values('53165', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('11453', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('3576', '760', '1', 'Spring', 2004, 'C ');
	insert into takes values('11057', '843', '1', 'Fall', 2010, 'C ');
	insert into takes values('6990', '489', '1', 'Fall', 2007, 'C+');
	insert into takes values('79210', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('4004', '760', '1', 'Spring', 2004, 'C ');
	insert into takes values('24387', '352', '1', 'Spring', 2006, 'A-');
	insert into takes values('38696', '591', '1', 'Spring', 2005, 'B ');
	insert into takes values('23475', '443', '2', 'Spring', 2002, 'B+');
	insert into takes values('21337', '239', '1', 'Fall', 2006, 'A-');
	insert into takes values('25331', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('55698', '603', '1', 'Fall', 2003, 'B-');
	insert into takes values('70564', '457', '1', 'Spring', 2001, 'C-');
	insert into takes values('62705', '793', '1', 'Spring', 2002, 'B ');
	insert into takes values('40897', '461', '1', 'Fall', 2002, 'B ');
	insert into takes values('64067', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('85366', '696', '1', 'Spring', 2002, 'C+');
	insert into takes values('435', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('5017', '421', '1', 'Fall', 2004, 'A ');
	insert into takes values('89140', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('57431', '400', '1', 'Spring', 2007, 'C+');
	insert into takes values('2967', '493', '1', 'Spring', 2010, 'A+');
	insert into takes values('31101', '571', '1', 'Spring', 2004, 'B+');
	insert into takes values('89132', '400', '2', 'Fall', 2003, 'A+');
	insert into takes values('53424', '679', '1', 'Spring', 2010, 'B-');
	insert into takes values('87268', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('82970', '426', '1', 'Spring', 2006, 'A ');
	insert into takes values('36244', '867', '2', 'Fall', 2010, 'C ');
	insert into takes values('60366', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('75273', '400', '1', 'Spring', 2007, 'C ');
	insert into takes values('99422', '631', '1', 'Spring', 2007, 'A ');
	insert into takes values('61783', '362', '2', 'Fall', 2006, 'C-');
	insert into takes values('92040', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('68330', '795', '1', 'Spring', 2004, 'C+');
	insert into takes values('47630', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('90234', '663', '1', 'Spring', 2005, 'C ');
	insert into takes values('21766', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('435', '445', '1', 'Spring', 2001, 'B+');
	insert into takes values('11152', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('24197', '237', '1', 'Spring', 2008, 'B-');
	insert into takes values('57666', '960', '1', 'Fall', 2009, 'C-');
	insert into takes values('30252', '527', '1', 'Fall', 2004, 'C ');
	insert into takes values('7498', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('23934', '545', '1', 'Fall', 2001, 'A-');
	insert into takes values('24325', '169', '1', 'Spring', 2007, 'C+');
	insert into takes values('31137', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('52494', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('12069', '694', '1', 'Fall', 2002, 'A ');
	insert into takes values('39204', '604', '1', 'Spring', 2009, 'A ');
	insert into takes values('64642', '571', '1', 'Spring', 2004, 'A-');
	insert into takes values('49792', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('87706', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('27662', '702', '1', 'Spring', 2001, 'C-');
	insert into takes values('90009', '400', '2', 'Fall', 2003, 'B+');
	insert into takes values('10556', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('5298', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('842', '401', '1', 'Fall', 2003, 'C-');
	insert into takes values('70828', '867', '1', 'Fall', 2006, 'A-');
	insert into takes values('86552', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('44985', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('95626', '401', '1', 'Fall', 2003, 'C ');
	insert into takes values('11237', '200', '2', 'Fall', 2002, 'C+');
	insert into takes values('58889', '702', '1', 'Spring', 2001, 'A-');
	insert into takes values('29140', '631', '1', 'Spring', 2007, 'A ');
	insert into takes values('17207', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('29435', '105', '1', 'Fall', 2009, 'B+');
	insert into takes values('21395', '239', '1', 'Fall', 2006, 'B-');
	insert into takes values('93508', '679', '1', 'Spring', 2010, 'C+');
	insert into takes values('282', '400', '1', 'Spring', 2007, 'A-');
	insert into takes values('52385', '237', '2', 'Fall', 2009, 'C+');
	insert into takes values('52371', '482', '1', 'Fall', 2005, 'A-');
	insert into takes values('25077', '408', '2', 'Spring', 2003, 'C-');
	insert into takes values('7514', '791', '1', 'Spring', 2006, 'A ');
	insert into takes values('50702', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('13028', '468', '1', 'Fall', 2005, 'A ');
	insert into takes values('29707', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('92949', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('20489', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('24796', '626', '1', 'Fall', 2006, 'B+');
	insert into takes values('27140', '735', '2', 'Spring', 2010, 'C ');
	insert into takes values('57083', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('68330', '468', '2', 'Fall', 2007, 'B ');
	insert into takes values('65714', '867', '2', 'Fall', 2010, 'A+');
	insert into takes values('77415', '338', '1', 'Spring', 2007, 'B-');
	insert into takes values('3640', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('69222', '795', '1', 'Spring', 2004, 'B-');
	insert into takes values('98423', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('33401', '338', '1', 'Spring', 2007, 'A ');
	insert into takes values('96324', '408', '2', 'Spring', 2003, 'A ');
	insert into takes values('32217', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('86552', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('52876', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('44038', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('94726', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('36494', '760', '1', 'Spring', 2004, 'C+');
	insert into takes values('43505', '561', '1', 'Fall', 2006, 'B+');
	insert into takes values('34329', '843', '1', 'Fall', 2010, 'C+');
	insert into takes values('89414', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('7602', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('16528', '338', '1', 'Spring', 2007, 'A+');
	insert into takes values('68150', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('25718', '352', '1', 'Spring', 2006, 'A-');
	insert into takes values('82707', '599', '1', 'Spring', 2003, 'B ');
	insert into takes values('28133', '401', '1', 'Fall', 2003, 'C+');
	insert into takes values('80742', '735', '1', 'Spring', 2003, 'C-');
	insert into takes values('69222', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('34158', '334', '1', 'Fall', 2009, 'A-');
	insert into takes values('69471', '400', '2', 'Fall', 2003, 'A ');
	insert into takes values('50598', '875', '1', 'Spring', 2005, 'B+');
	insert into takes values('50598', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('82063', '629', '1', 'Spring', 2003, 'A ');
	insert into takes values('30845', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('76250', '457', '1', 'Spring', 2001, 'A+');
	insert into takes values('5920', '401', '1', 'Fall', 2003, 'C ');
	insert into takes values('80698', '843', '1', 'Fall', 2010, 'C-');
	insert into takes values('37946', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('16849', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('56058', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('68263', '237', '1', 'Spring', 2008, 'B ');
	insert into takes values('67146', '426', '1', 'Spring', 2006, 'A ');
	insert into takes values('10705', '604', '1', 'Spring', 2009, 'B+');
	insert into takes values('66259', '158', '2', 'Spring', 2008, 'C+');
	insert into takes values('54672', '760', '1', 'Spring', 2004, 'B+');
	insert into takes values('61527', '704', '1', 'Spring', 2008, 'B ');
	insert into takes values('94894', '334', '1', 'Fall', 2009, 'A-');
	insert into takes values('18007', '443', '1', 'Spring', 2010, 'B-');
	insert into takes values('53788', '612', '1', 'Fall', 2007, 'B+');
	insert into takes values('9514', '629', '1', 'Spring', 2003, 'A+');
	insert into takes values('57107', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('28518', '747', '1', 'Spring', 2004, 'A ');
	insert into takes values('59117', '496', '1', 'Fall', 2001, 'A-');
	insert into takes values('67425', '366', '1', 'Fall', 2005, 'A+');
	insert into takes values('35935', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('1726', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('22912', '362', '3', 'Spring', 2008, 'C+');
	insert into takes values('34788', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('96153', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('73602', '626', '1', 'Fall', 2006, 'C+');
	insert into takes values('68242', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('77231', '137', '1', 'Spring', 2002, 'B+');
	insert into takes values('36379', '545', '1', 'Fall', 2001, 'B ');
	insert into takes values('61737', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('50703', '349', '1', 'Spring', 2008, 'C-');
	insert into takes values('4940', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('46451', '559', '1', 'Fall', 2002, 'C-');
	insert into takes values('27044', '760', '1', 'Spring', 2004, 'B ');
	insert into takes values('50977', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('93039', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('78792', '571', '1', 'Spring', 2004, 'C ');
	insert into takes values('79772', '867', '1', 'Fall', 2006, 'C+');
	insert into takes values('45570', '864', '1', 'Spring', 2006, 'A ');
	insert into takes values('20378', '702', '1', 'Spring', 2001, 'B ');
	insert into takes values('69230', '105', '2', 'Fall', 2002, 'C-');
	insert into takes values('3487', '949', '1', 'Fall', 2007, 'A-');
	insert into takes values('30177', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('64297', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('25380', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('63886', '545', '1', 'Fall', 2001, 'B-');
	insert into takes values('14094', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('72657', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('25143', '489', '1', 'Fall', 2007, 'C+');
	insert into takes values('19861', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('65056', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('77218', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('67542', '338', '1', 'Spring', 2007, 'A ');
	insert into takes values('48469', '345', '1', 'Spring', 2008, 'A ');
	insert into takes values('95574', '362', '1', 'Fall', 2005, 'C-');
	insert into takes values('65563', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('63090', '527', '1', 'Fall', 2004, 'C ');
	insert into takes values('44551', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('79763', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('9084', '893', '1', 'Fall', 2007, 'C+');
	insert into takes values('35', '400', '2', 'Fall', 2003, 'C-');
	insert into takes values('8986', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('22258', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('84515', '362', '2', 'Fall', 2006, 'A-');
	insert into takes values('62754', '338', '1', 'Spring', 2007, 'A-');
	insert into takes values('1737', '867', '2', 'Fall', 2010, 'C ');
	insert into takes values('57213', '793', '1', 'Spring', 2002, 'B ');
	insert into takes values('34329', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('67018', '270', '1', 'Spring', 2010, 'C ');
	insert into takes values('60249', '696', '1', 'Spring', 2002, 'A ');
	insert into takes values('79329', '461', '1', 'Fall', 2002, 'B-');
	insert into takes values('60984', '169', '2', 'Fall', 2002, 'B ');
	insert into takes values('93653', '867', '1', 'Fall', 2006, 'A+');
	insert into takes values('70452', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('82591', '486', '1', 'Fall', 2009, 'C ');
	insert into takes values('24809', '105', '2', 'Fall', 2002, 'C-');
	insert into takes values('69230', '468', '1', 'Fall', 2005, 'B ');
	insert into takes values('61854', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('38555', '852', '1', 'Spring', 2008, 'A ');
	insert into takes values('20002', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('28133', '400', '2', 'Fall', 2003, 'B+');
	insert into takes values('26494', '338', '2', 'Spring', 2006, 'A ');
	insert into takes values('66753', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('19342', '200', '2', 'Fall', 2002, 'A+');
	insert into takes values('87785', '486', '1', 'Fall', 2009, 'A-');
	insert into takes values('43981', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('82646', '349', '1', 'Spring', 2008, 'A-');
	insert into takes values('82646', '581', '1', 'Spring', 2005, 'A-');
	insert into takes values('90448', '642', '1', 'Fall', 2004, 'B-');
	insert into takes values('83480', '313', '1', 'Fall', 2010, 'A-');
	insert into takes values('29399', '843', '1', 'Fall', 2010, 'C ');
	insert into takes values('96153', '793', '1', 'Spring', 2002, 'A ');
	insert into takes values('67425', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('55009', '415', '1', 'Fall', 2010, 'C ');
	insert into takes values('30474', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('78792', '893', '1', 'Fall', 2007, 'B+');
	insert into takes values('46106', '352', '1', 'Spring', 2006, 'B ');
	insert into takes values('29871', '642', '1', 'Fall', 2004, 'A-');
	insert into takes values('40457', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('57431', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('85575', '242', '1', 'Fall', 2009, 'A+');
	insert into takes values('75252', '443', '1', 'Spring', 2010, 'A ');
	insert into takes values('19848', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('36995', '496', '1', 'Fall', 2001, 'B+');
	insert into takes values('85849', '747', '1', 'Spring', 2004, 'A ');
	insert into takes values('16885', '401', '1', 'Fall', 2003, 'A+');
	insert into takes values('58594', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('86573', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('11262', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('89734', '629', '1', 'Spring', 2003, 'B-');
	insert into takes values('21100', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('44304', '791', '1', 'Spring', 2006, 'A ');
	insert into takes values('73165', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('73186', '864', '1', 'Spring', 2006, 'A+');
	insert into takes values('72622', '959', '1', 'Fall', 2006, 'B ');
	insert into takes values('15030', '169', '2', 'Fall', 2002, 'A+');
	insert into takes values('87624', '603', '1', 'Fall', 2003, 'A+');
	insert into takes values('83170', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('80113', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('46694', '496', '1', 'Fall', 2001, 'A-');
	insert into takes values('14094', '679', '1', 'Spring', 2010, 'C-');
	insert into takes values('99463', '959', '1', 'Fall', 2006, 'B+');
	insert into takes values('23525', '581', '1', 'Spring', 2005, 'C ');
	insert into takes values('64082', '852', '1', 'Spring', 2008, 'A ');
	insert into takes values('22226', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('77588', '415', '1', 'Fall', 2010, 'B-');
	insert into takes values('33338', '338', '1', 'Spring', 2007, 'A ');
	insert into takes values('18007', '604', '1', 'Spring', 2009, 'B ');
	insert into takes values('16523', '893', '1', 'Fall', 2007, 'B+');
	insert into takes values('108', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('18859', '795', '1', 'Spring', 2004, 'B ');
	insert into takes values('39927', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('66753', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('72643', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('61356', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('44206', '603', '1', 'Fall', 2003, 'A ');
	insert into takes values('11083', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('60406', '612', '1', 'Fall', 2007, 'B+');
	insert into takes values('11237', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('64249', '237', '2', 'Fall', 2009, 'C+');
	insert into takes values('41675', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('10917', '974', '1', 'Fall', 2003, 'C-');
	insert into takes values('92864', '258', '1', 'Fall', 2007, 'A-');
	insert into takes values('3143', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('2419', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('17339', '304', '1', 'Fall', 2009, 'B+');
	insert into takes values('14869', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('72643', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('52203', '486', '1', 'Fall', 2009, 'A ');
	insert into takes values('2139', '748', '1', 'Fall', 2003, 'C ');
	insert into takes values('66969', '169', '1', 'Spring', 2007, 'B ');
	insert into takes values('37818', '604', '1', 'Spring', 2009, 'B-');
	insert into takes values('65038', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('64140', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('37759', '400', '2', 'Fall', 2003, 'C+');
	insert into takes values('33338', '747', '1', 'Spring', 2004, 'A ');
	insert into takes values('3163', '581', '1', 'Spring', 2005, 'A-');
	insert into takes values('34957', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('35293', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('94815', '258', '1', 'Fall', 2007, 'B+');
	insert into takes values('30845', '962', '1', 'Spring', 2008, 'B ');
	insert into takes values('31476', '169', '1', 'Spring', 2007, 'C+');
	insert into takes values('75794', '527', '1', 'Fall', 2004, 'A ');
	insert into takes values('65258', '169', '1', 'Spring', 2007, 'C ');
	insert into takes values('7656', '748', '1', 'Fall', 2003, 'B ');
	insert into takes values('51549', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('847', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('29399', '376', '1', 'Fall', 2006, 'C+');
	insert into takes values('64140', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('87965', '401', '1', 'Fall', 2003, 'A+');
	insert into takes values('38696', '527', '1', 'Fall', 2004, 'B-');
	insert into takes values('85445', '362', '1', 'Fall', 2005, 'C-');
	insert into takes values('25046', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('33645', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('28994', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('20002', '242', '1', 'Fall', 2009, 'B ');
	insert into takes values('53699', '408', '2', 'Spring', 2003, 'A+');
	insert into takes values('39157', '338', '2', 'Spring', 2006, 'A-');
	insert into takes values('41674', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('45570', '408', '2', 'Spring', 2003, 'A ');
	insert into takes values('53788', '581', '1', 'Spring', 2005, 'C-');
	insert into takes values('11530', '591', '1', 'Spring', 2005, 'A-');
	insert into takes values('90663', '604', '1', 'Spring', 2009, 'B ');
	insert into takes values('89196', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('91616', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('23992', '735', '2', 'Spring', 2010, 'B ');
	insert into takes values('32772', '642', '1', 'Fall', 2004, 'B-');
	insert into takes values('80057', '972', '1', 'Spring', 2009, 'B ');
	insert into takes values('16347', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('58413', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('56058', '489', '1', 'Fall', 2007, 'B ');
	insert into takes values('64155', '486', '1', 'Fall', 2009, 'B-');
	insert into takes values('93708', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('96710', '362', '1', 'Fall', 2005, 'C+');
	insert into takes values('12326', '242', '1', 'Fall', 2009, 'C ');
	insert into takes values('29091', '426', '1', 'Spring', 2006, 'A-');
	insert into takes values('23794', '864', '1', 'Spring', 2006, 'C-');
	insert into takes values('89297', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('96227', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('21246', '489', '1', 'Fall', 2007, 'B+');
	insert into takes values('49280', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('85754', '239', '1', 'Fall', 2006, 'B ');
	insert into takes values('23311', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('29192', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('65396', '421', '1', 'Fall', 2004, 'C+');
	insert into takes values('81245', '704', '1', 'Spring', 2008, 'C-');
	insert into takes values('37430', '960', '1', 'Fall', 2009, 'A-');
	insert into takes values('6367', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('49391', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('65443', '200', '1', 'Spring', 2007, 'A ');
	insert into takes values('64934', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('96968', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('82082', '158', '1', 'Fall', 2008, 'C ');
	insert into takes values('76911', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('44038', '867', '2', 'Fall', 2010, 'A-');
	insert into takes values('81245', '482', '1', 'Fall', 2005, 'B ');
	insert into takes values('83039', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('5336', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('8819', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('10033', '629', '1', 'Spring', 2003, 'B-');
	insert into takes values('53805', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('7149', '345', '1', 'Spring', 2008, 'B-');
	insert into takes values('63040', '747', '1', 'Spring', 2004, 'C-');
	insert into takes values('81876', '591', '1', 'Spring', 2005, 'B ');
	insert into takes values('35498', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('70061', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('60748', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('22260', '482', '1', 'Fall', 2005, 'B-');
	insert into takes values('13749', '239', '1', 'Fall', 2006, 'B-');
	insert into takes values('65438', '237', '2', 'Fall', 2009, 'A-');
	insert into takes values('6209', '270', '1', 'Spring', 2010, 'A+');
	insert into takes values('60249', '974', '1', 'Fall', 2003, 'A-');
	insert into takes values('827', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('62832', '334', '1', 'Fall', 2009, 'B ');
	insert into takes values('65438', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('56276', '408', '1', 'Spring', 2007, 'B ');
	insert into takes values('89551', '352', '1', 'Spring', 2006, 'A+');
	insert into takes values('52872', '476', '1', 'Fall', 2010, 'A+');
	insert into takes values('40738', '808', '1', 'Fall', 2003, 'C ');
	insert into takes values('38973', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('12362', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('63560', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('1812', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('57334', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('65987', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('69285', '482', '1', 'Fall', 2005, 'A+');
	insert into takes values('63040', '362', '1', 'Fall', 2005, 'C ');
	insert into takes values('43616', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('66229', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('71529', '457', '1', 'Spring', 2001, 'C+');
	insert into takes values('94173', '974', '1', 'Fall', 2003, 'C ');
	insert into takes values('83462', '443', '1', 'Spring', 2010, 'A+');
	insert into takes values('47126', '960', '2', 'Fall', 2006, 'C-');
	insert into takes values('46436', '105', '2', 'Fall', 2002, 'A ');
	insert into takes values('46769', '237', '2', 'Fall', 2009, 'B+');
	insert into takes values('31080', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('59908', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('39876', '352', '1', 'Spring', 2006, 'B ');
	insert into takes values('19220', '496', '1', 'Fall', 2001, 'C ');
	insert into takes values('87193', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('82063', '158', '2', 'Spring', 2008, 'C-');
	insert into takes values('98690', '192', '1', 'Fall', 2002, 'C-');
	insert into takes values('57787', '603', '1', 'Fall', 2003, 'B ');
	insert into takes values('71287', '345', '1', 'Spring', 2008, 'C-');
	insert into takes values('8819', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('50537', '457', '1', 'Spring', 2001, 'C-');
	insert into takes values('66269', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('24746', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('59538', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('24630', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('90609', '482', '1', 'Fall', 2005, 'C ');
	insert into takes values('95626', '612', '1', 'Fall', 2007, 'B+');
	insert into takes values('87222', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('25256', '415', '1', 'Fall', 2010, 'C+');
	insert into takes values('66259', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('14554', '559', '1', 'Fall', 2002, 'C+');
	insert into takes values('86674', '696', '1', 'Spring', 2002, 'C-');
	insert into takes values('71628', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('39978', '313', '1', 'Fall', 2010, 'B-');
	insert into takes values('95284', '545', '1', 'Fall', 2001, 'C ');
	insert into takes values('28352', '612', '1', 'Fall', 2007, 'B ');
	insert into takes values('85809', '258', '1', 'Fall', 2007, 'A+');
	insert into takes values('53152', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('91851', '694', '1', 'Fall', 2002, 'A+');
	insert into takes values('63886', '599', '1', 'Spring', 2003, 'A-');
	insert into takes values('52019', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('95840', '612', '1', 'Fall', 2007, 'B+');
	insert into takes values('29863', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('4173', '468', '1', 'Fall', 2005, 'C ');
	insert into takes values('75116', '843', '1', 'Fall', 2010, 'C ');
	insert into takes values('38895', '482', '1', 'Fall', 2005, 'A ');
	insert into takes values('38336', '545', '1', 'Fall', 2001, 'A+');
	insert into takes values('43495', '362', '2', 'Fall', 2006, 'A ');
	insert into takes values('94569', '927', '1', 'Fall', 2002, 'C+');
	insert into takes values('13741', '242', '1', 'Fall', 2009, 'C ');
	insert into takes values('29514', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('27043', '239', '1', 'Fall', 2006, 'C+');
	insert into takes values('14214', '893', '1', 'Fall', 2007, 'A+');
	insert into takes values('99463', '258', '1', 'Fall', 2007, 'B+');
	insert into takes values('67810', '960', '1', 'Fall', 2009, 'C-');
	insert into takes values('51997', '105', '2', 'Fall', 2002, 'B+');
	insert into takes values('17676', '496', '1', 'Fall', 2001, 'B+');
	insert into takes values('18554', '612', '1', 'Fall', 2007, 'A-');
	insert into takes values('56', '581', '1', 'Spring', 2005, 'A-');
	insert into takes values('98359', '493', '1', 'Spring', 2010, 'B+');
	insert into takes values('10481', '461', '1', 'Fall', 2002, 'A-');
	insert into takes values('72979', '571', '1', 'Spring', 2004, 'C-');
	insert into takes values('91343', '735', '1', 'Spring', 2003, 'A ');
	insert into takes values('54620', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('41280', '545', '1', 'Fall', 2001, 'B ');
	insert into takes values('91063', '875', '1', 'Spring', 2005, 'A+');
	insert into takes values('68263', '599', '1', 'Spring', 2003, 'C+');
	insert into takes values('27727', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('2848', '867', '2', 'Fall', 2010, 'C-');
	insert into takes values('1367', '482', '1', 'Fall', 2005, 'B-');
	insert into takes values('57123', '366', '1', 'Fall', 2005, 'A ');
	insert into takes values('88287', '338', '1', 'Spring', 2007, 'C ');
	insert into takes values('4645', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('80698', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('15074', '735', '2', 'Spring', 2010, 'A-');
	insert into takes values('27140', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('1727', '334', '1', 'Fall', 2009, 'A ');
	insert into takes values('79446', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('64593', '599', '1', 'Spring', 2003, 'A-');
	insert into takes values('83686', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('99073', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('8912', '443', '1', 'Spring', 2010, 'B-');
	insert into takes values('92864', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('86641', '313', '1', 'Fall', 2010, 'A ');
	insert into takes values('85754', '679', '1', 'Spring', 2010, 'B ');
	insert into takes values('17377', '793', '1', 'Spring', 2002, 'C ');
	insert into takes values('69783', '486', '1', 'Fall', 2009, 'C+');
	insert into takes values('28409', '875', '1', 'Spring', 2005, 'B+');
	insert into takes values('17397', '457', '1', 'Spring', 2001, 'A-');
	insert into takes values('65121', '137', '1', 'Spring', 2002, 'A-');
	insert into takes values('57160', '270', '1', 'Spring', 2010, 'C+');
	insert into takes values('8986', '237', '1', 'Spring', 2008, 'B-');
	insert into takes values('58085', '527', '1', 'Fall', 2004, 'C-');
	insert into takes values('3335', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('31080', '468', '1', 'Fall', 2005, 'B-');
	insert into takes values('80248', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('76173', '486', '1', 'Fall', 2009, 'A ');
	insert into takes values('34386', '696', '1', 'Spring', 2002, 'C-');
	insert into takes values('35257', '192', '1', 'Fall', 2002, 'A+');
	insert into takes values('63582', '376', '1', 'Fall', 2006, 'B-');
	insert into takes values('57474', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('54610', '843', '1', 'Fall', 2010, 'C-');
	insert into takes values('67660', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('10838', '604', '1', 'Spring', 2009, 'B-');
	insert into takes values('23311', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('99553', '313', '1', 'Fall', 2010, 'B+');
	insert into takes values('15613', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('78454', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('93986', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('60867', '338', '1', 'Spring', 2007, 'A-');
	insert into takes values('42843', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('19582', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('92703', '486', '1', 'Fall', 2009, 'C ');
	insert into takes values('57538', '158', '1', 'Fall', 2008, 'A ');
	insert into takes values('15883', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('78892', '489', '1', 'Fall', 2007, 'B ');
	insert into takes values('65101', '239', '1', 'Fall', 2006, 'C-');
	insert into takes values('30161', '200', '1', 'Spring', 2007, 'C-');
	insert into takes values('36263', '338', '2', 'Spring', 2006, 'C+');
	insert into takes values('16969', '626', '1', 'Fall', 2006, 'C ');
	insert into takes values('39241', '258', '1', 'Fall', 2007, 'A-');
	insert into takes values('29192', '169', '2', 'Fall', 2002, 'A ');
	insert into takes values('12069', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('3493', '735', '1', 'Spring', 2003, 'A ');
	insert into takes values('35687', '974', '1', 'Fall', 2003, 'B-');
	insert into takes values('11510', '875', '1', 'Spring', 2005, 'B-');
	insert into takes values('50013', '169', '1', 'Spring', 2007, 'A ');
	insert into takes values('123', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('64196', '468', '1', 'Fall', 2005, 'A+');
	insert into takes values('1018', '972', '1', 'Spring', 2009, 'C-');
	insert into takes values('89734', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('13290', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('86661', '867', '1', 'Fall', 2006, 'B+');
	insert into takes values('91343', '748', '1', 'Fall', 2003, 'C-');
	insert into takes values('20814', '237', '1', 'Spring', 2008, 'A-');
	insert into takes values('41491', '408', '2', 'Spring', 2003, 'B ');
	insert into takes values('95205', '345', '1', 'Spring', 2008, 'B ');
	insert into takes values('6474', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('63612', '158', '1', 'Fall', 2008, 'C ');
	insert into takes values('57135', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('16297', '415', '1', 'Fall', 2010, 'A+');
	insert into takes values('21100', '852', '1', 'Spring', 2008, 'A ');
	insert into takes values('96052', '445', '1', 'Spring', 2001, 'B-');
	insert into takes values('43658', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('29192', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('25380', '270', '1', 'Spring', 2010, 'B-');
	insert into takes values('40481', '642', '1', 'Fall', 2004, 'A+');
	insert into takes values('77580', '843', '1', 'Fall', 2010, 'A-');
	insert into takes values('75596', '545', '1', 'Fall', 2001, 'B-');
	insert into takes values('89393', '702', '1', 'Spring', 2001, 'A-');
	insert into takes values('8140', '949', '1', 'Fall', 2007, 'A-');
	insert into takes values('17207', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('95631', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('47487', '105', '1', 'Fall', 2009, 'C ');
	insert into takes values('93125', '959', '1', 'Fall', 2006, 'B+');
	insert into takes values('98843', '795', '1', 'Spring', 2004, 'C+');
	insert into takes values('37715', '591', '1', 'Spring', 2005, 'B+');
	insert into takes values('62124', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('64642', '242', '1', 'Fall', 2009, 'C+');
	insert into takes values('47487', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('16075', '443', '1', 'Spring', 2010, 'B+');
	insert into takes values('60688', '545', '1', 'Fall', 2001, 'A-');
	insert into takes values('28133', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('15024', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('66753', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('72165', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('82688', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('27804', '169', '2', 'Fall', 2002, 'A+');
	insert into takes values('87268', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('85534', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('57456', '972', '1', 'Spring', 2009, 'A ');
	insert into takes values('13741', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('25942', '443', '1', 'Spring', 2010, 'C+');
	insert into takes values('43495', '445', '1', 'Spring', 2001, 'A-');
	insert into takes values('53118', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('25380', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('53165', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('17831', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('74473', '352', '1', 'Spring', 2006, 'A+');
	insert into takes values('27528', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('32506', '482', '1', 'Fall', 2005, 'A-');
	insert into takes values('43211', '545', '1', 'Fall', 2001, 'B-');
	insert into takes values('90381', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('65438', '401', '1', 'Fall', 2003, 'B+');
	insert into takes values('4345', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('8986', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('33546', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('41299', '461', '1', 'Fall', 2002, 'C-');
	insert into takes values('96193', '468', '2', 'Fall', 2007, 'B ');
	insert into takes values('3005', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('91788', '270', '1', 'Spring', 2010, 'A-');
	insert into takes values('14499', '237', '1', 'Spring', 2008, 'B-');
	insert into takes values('72177', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('57431', '852', '1', 'Spring', 2008, 'B ');
	insert into takes values('64121', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('37869', '959', '1', 'Fall', 2006, 'A+');
	insert into takes values('89140', '426', '1', 'Spring', 2006, 'A+');
	insert into takes values('5463', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('70061', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('45720', '629', '1', 'Spring', 2003, 'B-');
	insert into takes values('8192', '974', '1', 'Fall', 2003, 'B-');
	insert into takes values('74464', '158', '1', 'Fall', 2008, 'C-');
	insert into takes values('85809', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('57538', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('54508', '366', '1', 'Fall', 2005, 'C-');
	insert into takes values('90779', '200', '1', 'Spring', 2007, 'C-');
	insert into takes values('15430', '476', '1', 'Fall', 2010, 'C ');
	insert into takes values('4173', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('86802', '443', '2', 'Spring', 2002, 'C-');
	insert into takes values('81884', '304', '1', 'Fall', 2009, 'A ');
	insert into takes values('96067', '362', '1', 'Fall', 2005, 'C ');
	insert into takes values('45083', '949', '1', 'Fall', 2007, 'B ');
	insert into takes values('33349', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('2133', '603', '1', 'Fall', 2003, 'B+');
	insert into takes values('22620', '527', '1', 'Fall', 2004, 'A-');
	insert into takes values('88577', '461', '1', 'Fall', 2002, 'C+');
	insert into takes values('19342', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('34018', '702', '1', 'Spring', 2001, 'C+');
	insert into takes values('12615', '949', '1', 'Fall', 2007, 'A-');
	insert into takes values('10663', '735', '1', 'Spring', 2003, 'B-');
	insert into takes values('57985', '237', '1', 'Spring', 2008, 'A+');
	insert into takes values('53803', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('18809', '960', '1', 'Fall', 2009, 'A+');
	insert into takes values('61166', '694', '1', 'Fall', 2002, 'B ');
	insert into takes values('46450', '694', '1', 'Fall', 2002, 'A ');
	insert into takes values('95366', '496', '1', 'Fall', 2001, 'B ');
	insert into takes values('2423', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('68779', '457', '1', 'Spring', 2001, 'C ');
	insert into takes values('18234', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('70098', '349', '1', 'Spring', 2008, 'C-');
	insert into takes values('98870', '843', '1', 'Fall', 2010, 'B+');
	insert into takes values('18775', '959', '1', 'Fall', 2006, 'A-');
	insert into takes values('39472', '692', '1', 'Spring', 2010, 'B-');
	insert into takes values('89551', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('81638', '334', '1', 'Fall', 2009, 'B+');
	insert into takes values('88801', '802', '1', 'Spring', 2003, 'B+');
	insert into takes values('27002', '581', '1', 'Spring', 2005, 'C ');
	insert into takes values('70924', '258', '1', 'Fall', 2007, 'C+');
	insert into takes values('16297', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('9360', '991', '1', 'Spring', 2008, 'A ');
	insert into takes values('13880', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('94801', '200', '1', 'Spring', 2007, 'B+');
	insert into takes values('63645', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('75423', '875', '1', 'Spring', 2005, 'C-');
	insert into takes values('75928', '893', '1', 'Fall', 2007, 'A-');
	insert into takes values('57474', '949', '1', 'Fall', 2007, 'C+');
	insert into takes values('53077', '527', '1', 'Fall', 2004, 'C-');
	insert into takes values('83686', '376', '1', 'Fall', 2006, 'B+');
	insert into takes values('58081', '408', '2', 'Spring', 2003, 'B-');
	insert into takes values('82301', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('90181', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('78116', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('60984', '304', '1', 'Fall', 2009, 'A+');
	insert into takes values('40080', '443', '2', 'Spring', 2002, 'C+');
	insert into takes values('98315', '702', '1', 'Spring', 2001, 'B-');
	insert into takes values('46066', '408', '2', 'Spring', 2003, 'B-');
	insert into takes values('69747', '793', '1', 'Spring', 2002, 'B+');
	insert into takes values('9933', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('97868', '468', '1', 'Fall', 2005, 'C ');
	insert into takes values('66106', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('50583', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('70061', '927', '1', 'Fall', 2002, 'A ');
	insert into takes values('79446', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('15980', '239', '1', 'Fall', 2006, 'B ');
	insert into takes values('68649', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('90448', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('87015', '489', '1', 'Fall', 2007, 'C ');
	insert into takes values('79589', '493', '1', 'Spring', 2010, 'C-');
	insert into takes values('21766', '960', '1', 'Fall', 2009, 'B+');
	insert into takes values('89414', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('33094', '158', '1', 'Fall', 2008, 'A ');
	insert into takes values('93171', '137', '1', 'Spring', 2002, 'A-');
	insert into takes values('27556', '169', '2', 'Fall', 2002, 'C ');
	insert into takes values('13741', '445', '1', 'Spring', 2001, 'C ');
	insert into takes values('37339', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('37103', '496', '1', 'Fall', 2001, 'A+');
	insert into takes values('39520', '482', '1', 'Fall', 2005, 'A ');
	insert into takes values('21401', '991', '1', 'Spring', 2008, 'B-');
	insert into takes values('29192', '237', '2', 'Fall', 2009, 'B+');
	insert into takes values('71025', '415', '1', 'Fall', 2010, 'B ');
	insert into takes values('18554', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('1460', '338', '1', 'Spring', 2007, 'A+');
	insert into takes values('57156', '457', '1', 'Spring', 2001, 'C+');
	insert into takes values('6209', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('56124', '927', '1', 'Fall', 2002, 'C ');
	insert into takes values('91851', '663', '1', 'Spring', 2005, 'A-');
	insert into takes values('82066', '599', '1', 'Spring', 2003, 'C+');
	insert into takes values('5005', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('91197', '258', '1', 'Fall', 2007, 'C+');
	insert into takes values('83444', '704', '1', 'Spring', 2008, 'B ');
	insert into takes values('87222', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('83511', '345', '1', 'Spring', 2008, 'C-');
	insert into takes values('86075', '867', '2', 'Fall', 2010, 'C ');
	insert into takes values('3576', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('15538', '696', '1', 'Spring', 2002, 'C ');
	insert into takes values('85746', '345', '1', 'Spring', 2008, 'C+');
	insert into takes values('81028', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('57107', '274', '1', 'Fall', 2002, 'B-');
	insert into takes values('1460', '893', '1', 'Fall', 2007, 'B-');
	insert into takes values('51868', '239', '1', 'Fall', 2006, 'B-');
	insert into takes values('53588', '974', '1', 'Fall', 2003, 'A+');
	insert into takes values('48462', '561', '1', 'Fall', 2006, 'A+');
	insert into takes values('88417', '415', '1', 'Fall', 2010, 'B ');
	insert into takes values('22179', '476', '1', 'Fall', 2010, 'A ');
	insert into takes values('61003', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('32881', '843', '1', 'Fall', 2010, 'C-');
	insert into takes values('53805', '599', '1', 'Spring', 2003, 'A-');
	insert into takes values('87048', '561', '1', 'Fall', 2006, 'C ');
	insert into takes values('46762', '200', '2', 'Fall', 2002, 'C-');
	insert into takes values('50206', '200', '1', 'Spring', 2007, 'B+');
	insert into takes values('25380', '493', '1', 'Spring', 2010, 'B+');
	insert into takes values('87784', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('95029', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('44985', '376', '1', 'Fall', 2006, 'C+');
	insert into takes values('30222', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('46981', '158', '1', 'Fall', 2008, 'B+');
	insert into takes values('8819', '496', '1', 'Fall', 2001, 'B+');
	insert into takes values('48053', '631', '1', 'Spring', 2007, 'B ');
	insert into takes values('70099', '319', '1', 'Spring', 2003, 'C-');
	insert into takes values('41450', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('29705', '468', '1', 'Fall', 2005, 'A ');
	insert into takes values('94142', '408', '1', 'Spring', 2007, 'B ');
	insert into takes values('36019', '875', '1', 'Spring', 2005, 'C ');
	insert into takes values('68395', '400', '1', 'Spring', 2007, 'C-');
	insert into takes values('1110', '443', '1', 'Spring', 2010, 'A-');
	insert into takes values('21337', '702', '1', 'Spring', 2001, 'B ');
	insert into takes values('46725', '702', '1', 'Spring', 2001, 'B-');
	insert into takes values('62832', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('28019', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('24387', '258', '1', 'Fall', 2007, 'C-');
	insert into takes values('67725', '581', '1', 'Spring', 2005, 'A+');
	insert into takes values('97868', '527', '1', 'Fall', 2004, 'C ');
	insert into takes values('67017', '612', '1', 'Fall', 2007, 'C ');
	insert into takes values('28518', '793', '1', 'Spring', 2002, 'C-');
	insert into takes values('25380', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('67371', '867', '1', 'Fall', 2006, 'B ');
	insert into takes values('12615', '362', '1', 'Fall', 2005, 'C+');
	insert into takes values('6400', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('2795', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('37038', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('18286', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('15613', '864', '1', 'Spring', 2006, 'C-');
	insert into takes values('49873', '960', '2', 'Fall', 2006, 'B-');
	insert into takes values('57474', '362', '1', 'Fall', 2005, 'C-');
	insert into takes values('12078', '200', '1', 'Spring', 2007, 'B-');
	insert into takes values('67514', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('84239', '400', '1', 'Spring', 2007, 'A+');
	insert into takes values('18469', '313', '1', 'Fall', 2010, 'A+');
	insert into takes values('2501', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('48247', '702', '1', 'Spring', 2001, 'B-');
	insert into takes values('98423', '237', '2', 'Fall', 2009, 'A-');
	insert into takes values('86753', '445', '1', 'Spring', 2001, 'A-');
	insert into takes values('38545', '875', '1', 'Spring', 2005, 'A+');
	insert into takes values('10527', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('32744', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('50977', '802', '1', 'Spring', 2003, 'C+');
	insert into takes values('49813', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('9114', '493', '1', 'Spring', 2010, 'C+');
	insert into takes values('35293', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('99710', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('88887', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('74163', '408', '1', 'Spring', 2007, 'A-');
	insert into takes values('53805', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('38013', '169', '2', 'Fall', 2002, 'A-');
	insert into takes values('81610', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('34195', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('75046', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('15144', '581', '1', 'Spring', 2005, 'C ');
	insert into takes values('76911', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('28128', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('93171', '629', '1', 'Spring', 2003, 'A+');
	insert into takes values('82646', '408', '1', 'Spring', 2007, 'C-');
	insert into takes values('93508', '704', '1', 'Spring', 2008, 'C ');
	insert into takes values('86661', '561', '1', 'Fall', 2006, 'B-');
	insert into takes values('24442', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('91799', '545', '1', 'Fall', 2001, 'C ');
	insert into takes values('56941', '663', '1', 'Spring', 2005, 'A-');
	insert into takes values('99189', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('43993', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('96324', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('55531', '629', '1', 'Spring', 2003, 'A ');
	insert into takes values('55170', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('75362', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('47379', '974', '1', 'Fall', 2003, 'B-');
	insert into takes values('42019', '242', '1', 'Fall', 2009, 'A-');
	insert into takes values('53788', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('74016', '400', '1', 'Spring', 2007, 'A ');
	insert into takes values('11194', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('11377', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('30252', '591', '1', 'Spring', 2005, 'B-');
	insert into takes values('23992', '489', '1', 'Fall', 2007, 'B-');
	insert into takes values('70564', '408', '2', 'Spring', 2003, 'B-');
	insert into takes values('75040', '875', '1', 'Spring', 2005, 'C-');
	insert into takes values('20814', '960', '2', 'Fall', 2006, 'B+');
	insert into takes values('47487', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('13211', '793', '1', 'Spring', 2002, 'C ');
	insert into takes values('63288', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('51579', '972', '1', 'Spring', 2009, 'A ');
	insert into takes values('27952', '304', '1', 'Fall', 2009, 'C+');
	insert into takes values('47630', '581', '1', 'Spring', 2005, 'C-');
	insert into takes values('34422', '158', '1', 'Fall', 2008, 'C ');
	insert into takes values('44352', '482', '1', 'Fall', 2005, 'C ');
	insert into takes values('57107', '808', '1', 'Fall', 2003, 'A+');
	insert into takes values('11076', '362', '3', 'Spring', 2008, 'A+');
	insert into takes values('74672', '974', '1', 'Fall', 2003, 'C ');
	insert into takes values('22170', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('31624', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('63860', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('44271', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('36494', '415', '1', 'Fall', 2010, 'C ');
	insert into takes values('56089', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('91343', '349', '1', 'Spring', 2008, 'B+');
	insert into takes values('62226', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('69730', '626', '1', 'Fall', 2006, 'C+');
	insert into takes values('54622', '401', '1', 'Fall', 2003, 'A ');
	insert into takes values('76798', '559', '1', 'Fall', 2002, 'B+');
	insert into takes values('80285', '468', '1', 'Fall', 2005, 'A+');
	insert into takes values('65329', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('32881', '482', '1', 'Fall', 2005, 'A+');
	insert into takes values('23525', '867', '2', 'Fall', 2010, 'A-');
	insert into takes values('93814', '400', '1', 'Spring', 2007, 'B+');
	insert into takes values('9183', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('42956', '362', '2', 'Fall', 2006, 'B-');
	insert into takes values('92385', '527', '1', 'Fall', 2004, 'B-');
	insert into takes values('28977', '200', '1', 'Spring', 2007, 'B-');
	insert into takes values('74016', '603', '1', 'Fall', 2003, 'A+');
	insert into takes values('46725', '545', '1', 'Fall', 2001, 'B-');
	insert into takes values('12214', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('19541', '631', '1', 'Spring', 2007, 'B ');
	insert into takes values('40189', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('85746', '200', '1', 'Spring', 2007, 'A-');
	insert into takes values('37586', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('10267', '748', '1', 'Fall', 2003, 'A-');
	insert into takes values('70098', '959', '1', 'Fall', 2006, 'A ');
	insert into takes values('1968', '735', '2', 'Spring', 2010, 'A-');
	insert into takes values('87784', '696', '1', 'Spring', 2002, 'A+');
	insert into takes values('73165', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('57238', '334', '1', 'Fall', 2009, 'A-');
	insert into takes values('86327', '376', '1', 'Fall', 2006, 'C ');
	insert into takes values('85211', '200', '1', 'Spring', 2007, 'C-');
	insert into takes values('90220', '696', '1', 'Spring', 2002, 'C ');
	insert into takes values('29705', '791', '1', 'Spring', 2006, 'C+');
	insert into takes values('98047', '443', '2', 'Spring', 2002, 'B-');
	insert into takes values('99422', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('43211', '962', '1', 'Spring', 2008, 'B ');
	insert into takes values('11441', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('24630', '760', '1', 'Spring', 2004, 'B ');
	insert into takes values('66269', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('3005', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('10904', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('72669', '158', '2', 'Spring', 2008, 'C ');
	insert into takes values('10527', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('79469', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('82707', '561', '1', 'Fall', 2006, 'B-');
	insert into takes values('13826', '169', '1', 'Spring', 2007, 'B ');
	insert into takes values('69747', '376', '1', 'Fall', 2006, 'B-');
	insert into takes values('57787', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('95089', '334', '1', 'Fall', 2009, 'B-');
	insert into takes values('39046', '599', '1', 'Spring', 2003, 'C+');
	insert into takes values('97041', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('28829', '527', '1', 'Fall', 2004, 'C ');
	insert into takes values('75395', '443', '2', 'Spring', 2002, 'B ');
	insert into takes values('77415', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('80285', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('32483', '867', '2', 'Fall', 2010, 'A+');
	insert into takes values('67371', '631', '1', 'Spring', 2007, 'A-');
	insert into takes values('69752', '345', '1', 'Spring', 2008, 'A+');
	insert into takes values('39204', '679', '1', 'Spring', 2010, 'A ');
	insert into takes values('15283', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('13403', '349', '1', 'Spring', 2008, 'B+');
	insert into takes values('5925', '694', '1', 'Fall', 2002, 'A ');
	insert into takes values('33837', '476', '1', 'Fall', 2010, 'A+');
	insert into takes values('46981', '200', '2', 'Fall', 2002, 'A-');
	insert into takes values('57787', '561', '1', 'Fall', 2006, 'B-');
	insert into takes values('74473', '735', '2', 'Spring', 2010, 'B ');
	insert into takes values('85746', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('6895', '599', '1', 'Spring', 2003, 'B-');
	insert into takes values('53588', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('68070', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('78922', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('15487', '400', '1', 'Spring', 2007, 'C+');
	insert into takes values('69747', '415', '1', 'Fall', 2010, 'B-');
	insert into takes values('4355', '603', '1', 'Fall', 2003, 'B+');
	insert into takes values('4940', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('86552', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('64297', '313', '1', 'Fall', 2010, 'A+');
	insert into takes values('82868', '408', '1', 'Spring', 2007, 'B ');
	insert into takes values('98870', '200', '1', 'Spring', 2007, 'B+');
	insert into takes values('61783', '352', '1', 'Spring', 2006, 'C+');
	insert into takes values('27919', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('43495', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('78787', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('71389', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('38696', '927', '1', 'Fall', 2002, 'C-');
	insert into takes values('41345', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('85575', '137', '1', 'Spring', 2002, 'B ');
	insert into takes values('27950', '239', '1', 'Fall', 2006, 'A-');
	insert into takes values('83039', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('45770', '545', '1', 'Fall', 2001, 'A+');
	insert into takes values('92274', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('60406', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('13921', '457', '1', 'Spring', 2001, 'A ');
	insert into takes values('89759', '612', '1', 'Fall', 2007, 'B-');
	insert into takes values('91442', '527', '1', 'Fall', 2004, 'B+');
	insert into takes values('17997', '760', '1', 'Spring', 2004, 'A ');
	insert into takes values('80113', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('58846', '158', '2', 'Spring', 2008, 'A ');
	insert into takes values('95260', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('31761', '362', '3', 'Spring', 2008, 'B ');
	insert into takes values('75510', '274', '1', 'Fall', 2002, 'A+');
	insert into takes values('53496', '694', '1', 'Fall', 2002, 'A ');
	insert into takes values('48861', '893', '1', 'Fall', 2007, 'A-');
	insert into takes values('27140', '362', '3', 'Spring', 2008, 'C-');
	insert into takes values('49205', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('49391', '843', '1', 'Fall', 2010, 'C+');
	insert into takes values('86651', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('96134', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('83592', '631', '1', 'Spring', 2007, 'C-');
	insert into takes values('29665', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('40116', '408', '1', 'Spring', 2007, 'A+');
	insert into takes values('37339', '415', '1', 'Fall', 2010, 'C ');
	insert into takes values('88085', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('67655', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('84654', '338', '1', 'Spring', 2007, 'B ');
	insert into takes values('93653', '694', '1', 'Fall', 2002, 'B ');
	insert into takes values('28409', '345', '1', 'Spring', 2008, 'A-');
	insert into takes values('89000', '408', '1', 'Spring', 2007, 'A ');
	insert into takes values('91851', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('72165', '571', '1', 'Spring', 2004, 'C+');
	insert into takes values('858', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('38712', '704', '1', 'Spring', 2008, 'C ');
	insert into takes values('18583', '559', '1', 'Fall', 2002, 'B+');
	insert into takes values('93125', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('36402', '105', '1', 'Fall', 2009, 'C-');
	insert into takes values('41345', '105', '2', 'Fall', 2002, 'B+');
	insert into takes values('36244', '867', '1', 'Fall', 2006, 'A-');
	insert into takes values('59290', '237', '1', 'Spring', 2008, 'B-');
	insert into takes values('83728', '599', '1', 'Spring', 2003, 'B+');
	insert into takes values('38899', '400', '2', 'Fall', 2003, 'A-');
	insert into takes values('1826', '270', '1', 'Spring', 2010, 'C ');
	insert into takes values('24201', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('94766', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('69081', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('89312', '313', '1', 'Fall', 2010, 'B+');
	insert into takes values('59538', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('81028', '105', '2', 'Fall', 2002, 'C-');
	insert into takes values('50206', '415', '1', 'Fall', 2010, 'C ');
	insert into takes values('16753', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('63560', '626', '1', 'Fall', 2006, 'C ');
	insert into takes values('16311', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('76224', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('16057', '105', '1', 'Fall', 2009, 'B+');
	insert into takes values('9460', '591', '1', 'Spring', 2005, 'A ');
	insert into takes values('85904', '960', '2', 'Fall', 2006, 'A ');
	insert into takes values('23457', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('93491', '599', '1', 'Spring', 2003, 'C+');
	insert into takes values('31250', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('11377', '795', '1', 'Spring', 2004, 'B+');
	insert into takes values('48678', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('88287', '486', '1', 'Fall', 2009, 'B-');
	insert into takes values('80698', '493', '1', 'Spring', 2010, 'B ');
	insert into takes values('92693', '258', '1', 'Fall', 2007, 'A-');
	insert into takes values('29031', '748', '1', 'Fall', 2003, 'C-');
	insert into takes values('259', '545', '1', 'Fall', 2001, 'C ');
	insert into takes values('81610', '603', '1', 'Fall', 2003, 'C-');
	insert into takes values('65329', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('52872', '270', '1', 'Spring', 2010, 'A-');
	insert into takes values('76911', '748', '1', 'Fall', 2003, 'A-');
	insert into takes values('66469', '192', '1', 'Fall', 2002, 'A+');
	insert into takes values('9605', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('29462', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('23449', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('55531', '603', '1', 'Fall', 2003, 'C-');
	insert into takes values('57242', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('75046', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('62716', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('28252', '591', '1', 'Spring', 2005, 'B+');
	insert into takes values('75116', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('86736', '486', '1', 'Fall', 2009, 'A-');
	insert into takes values('65121', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('18108', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('96911', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('32368', '400', '1', 'Spring', 2007, 'B ');
	insert into takes values('69241', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('52656', '527', '1', 'Fall', 2004, 'B-');
	insert into takes values('71768', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('83398', '461', '1', 'Fall', 2002, 'C+');
	insert into takes values('84727', '304', '1', 'Fall', 2009, 'B+');
	insert into takes values('94178', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('67018', '704', '1', 'Spring', 2008, 'B ');
	insert into takes values('68096', '352', '1', 'Spring', 2006, 'A+');
	insert into takes values('39892', '808', '1', 'Fall', 2003, 'B-');
	insert into takes values('26473', '242', '1', 'Fall', 2009, 'B+');
	insert into takes values('53805', '489', '1', 'Fall', 2007, 'C+');
	insert into takes values('19603', '864', '1', 'Spring', 2006, 'C-');
	insert into takes values('51975', '591', '1', 'Spring', 2005, 'C-');
	insert into takes values('94766', '604', '1', 'Spring', 2009, 'A-');
	insert into takes values('88553', '237', '2', 'Fall', 2009, 'B+');
	insert into takes values('72358', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('48660', '443', '1', 'Spring', 2010, 'C ');
	insert into takes values('80254', '571', '1', 'Spring', 2004, 'C+');
	insert into takes values('11195', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('59920', '795', '1', 'Spring', 2004, 'B ');
	insert into takes values('54620', '960', '1', 'Fall', 2009, 'A-');
	insert into takes values('16631', '629', '1', 'Spring', 2003, 'B ');
	insert into takes values('91616', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('107', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('22057', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('97629', '158', '2', 'Spring', 2008, 'B+');
	insert into takes values('53185', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('99719', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('69225', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('76798', '242', '1', 'Fall', 2009, 'C-');
	insert into takes values('99764', '400', '2', 'Fall', 2003, 'B-');
	insert into takes values('25942', '949', '1', 'Fall', 2007, 'C-');
	insert into takes values('86075', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('63243', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('11152', '338', '1', 'Spring', 2007, 'A-');
	insert into takes values('10834', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('68150', '401', '1', 'Fall', 2003, 'C-');
	insert into takes values('35220', '843', '1', 'Fall', 2010, 'A-');
	insert into takes values('88140', '105', '2', 'Fall', 2002, 'C+');
	insert into takes values('77021', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('987', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('22198', '802', '1', 'Spring', 2003, 'C+');
	insert into takes values('85356', '338', '1', 'Spring', 2007, 'A-');
	insert into takes values('88045', '489', '1', 'Fall', 2007, 'B ');
	insert into takes values('60224', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('66090', '612', '1', 'Fall', 2007, 'A ');
	insert into takes values('49684', '445', '1', 'Spring', 2001, 'C+');
	insert into takes values('94726', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('47630', '366', '1', 'Fall', 2005, 'C ');
	insert into takes values('42556', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('3651', '338', '1', 'Spring', 2007, 'A ');
	insert into takes values('5414', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('64082', '802', '1', 'Spring', 2003, 'A+');
	insert into takes values('12326', '137', '1', 'Spring', 2002, 'C-');
	insert into takes values('19321', '603', '1', 'Fall', 2003, 'C-');
	insert into takes values('50386', '694', '1', 'Fall', 2002, 'B ');
	insert into takes values('72186', '401', '1', 'Fall', 2003, 'A+');
	insert into takes values('847', '239', '1', 'Fall', 2006, 'B ');
	insert into takes values('40937', '696', '1', 'Spring', 2002, 'C ');
	insert into takes values('96003', '962', '1', 'Spring', 2008, 'C-');
	insert into takes values('45436', '270', '1', 'Spring', 2010, 'C+');
	insert into takes values('59908', '875', '1', 'Spring', 2005, 'A ');
	insert into takes values('62124', '493', '1', 'Spring', 2010, 'C-');
	insert into takes values('80254', '158', '2', 'Spring', 2008, 'B+');
	insert into takes values('15726', '486', '1', 'Fall', 2009, 'A-');
	insert into takes values('46981', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('64082', '105', '1', 'Fall', 2009, 'B ');
	insert into takes values('57107', '270', '1', 'Spring', 2010, 'A+');
	insert into takes values('12362', '571', '1', 'Spring', 2004, 'B+');
	insert into takes values('51698', '972', '1', 'Spring', 2009, 'A ');
	insert into takes values('34018', '893', '1', 'Fall', 2007, 'B-');
	insert into takes values('43432', '362', '1', 'Fall', 2005, 'C ');
	insert into takes values('41890', '105', '2', 'Fall', 2002, 'A+');
	insert into takes values('82688', '679', '1', 'Spring', 2010, 'C-');
	insert into takes values('68649', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('96193', '274', '1', 'Fall', 2002, 'C+');
	insert into takes values('21008', '559', '1', 'Fall', 2002, 'C+');
	insert into takes values('34322', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('43981', '960', '1', 'Fall', 2009, 'A+');
	insert into takes values('57026', '200', '1', 'Spring', 2007, 'B-');
	insert into takes values('85614', '793', '1', 'Spring', 2002, 'B+');
	insert into takes values('19582', '415', '1', 'Fall', 2010, 'C+');
	insert into takes values('80057', '496', '1', 'Fall', 2001, 'A-');
	insert into takes values('83747', '735', '1', 'Spring', 2003, 'C+');
	insert into takes values('40457', '735', '2', 'Spring', 2010, 'A+');
	insert into takes values('76224', '352', '1', 'Spring', 2006, 'C-');
	insert into takes values('544', '457', '1', 'Spring', 2001, 'C ');
	insert into takes values('51203', '735', '1', 'Spring', 2003, 'B-');
	insert into takes values('88389', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('19861', '366', '1', 'Fall', 2005, 'A+');
	insert into takes values('53799', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('49244', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('22345', '408', '2', 'Spring', 2003, 'B-');
	insert into takes values('56124', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('15144', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('11057', '237', '1', 'Spring', 2008, 'B-');
	insert into takes values('88793', '169', '1', 'Spring', 2007, 'B+');
	insert into takes values('56139', '704', '1', 'Spring', 2008, 'C ');
	insert into takes values('34386', '137', '1', 'Spring', 2002, 'A ');
	insert into takes values('51416', '421', '1', 'Fall', 2004, 'A-');
	insert into takes values('74974', '242', '1', 'Fall', 2009, 'C ');
	insert into takes values('64820', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('60249', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('28952', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('2848', '561', '1', 'Fall', 2006, 'C ');
	insert into takes values('27366', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('15074', '192', '1', 'Fall', 2002, 'A+');
	insert into takes values('93571', '237', '2', 'Fall', 2009, 'C+');
	insert into takes values('1922', '200', '2', 'Fall', 2002, 'A+');
	insert into takes values('66763', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('53225', '200', '1', 'Spring', 2007, 'C-');
	insert into takes values('47265', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('888', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('81984', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('58085', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('92040', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('108', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('88553', '893', '1', 'Fall', 2007, 'B+');
	insert into takes values('95366', '852', '1', 'Spring', 2008, 'A-');
	insert into takes values('26028', '581', '1', 'Spring', 2005, 'A+');
	insert into takes values('85754', '962', '1', 'Spring', 2008, 'C-');
	insert into takes values('16849', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('62152', '694', '1', 'Fall', 2002, 'B-');
	insert into takes values('70098', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('50013', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('43211', '313', '1', 'Fall', 2010, 'B-');
	insert into takes values('19536', '352', '1', 'Spring', 2006, 'B ');
	insert into takes values('23344', '158', '1', 'Fall', 2008, 'B-');
	insert into takes values('11095', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('67560', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('37454', '476', '1', 'Fall', 2010, 'B ');
	insert into takes values('5017', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('77548', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('80651', '962', '1', 'Spring', 2008, 'B ');
	insert into takes values('19603', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('43211', '631', '1', 'Spring', 2007, 'A-');
	insert into takes values('82697', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('86661', '663', '1', 'Spring', 2005, 'B-');
	insert into takes values('79469', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('37586', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('88993', '893', '1', 'Fall', 2007, 'A-');
	insert into takes values('84189', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('82697', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('74509', '493', '1', 'Spring', 2010, 'A ');
	insert into takes values('99710', '334', '1', 'Fall', 2009, 'C-');
	insert into takes values('15487', '692', '1', 'Spring', 2010, 'C ');
	insert into takes values('93366', '400', '1', 'Spring', 2007, 'B+');
	insert into takes values('50039', '696', '1', 'Spring', 2002, 'C ');
	insert into takes values('50039', '972', '1', 'Spring', 2009, 'B-');
	insert into takes values('34197', '702', '1', 'Spring', 2001, 'B-');
	insert into takes values('64196', '704', '1', 'Spring', 2008, 'A+');
	insert into takes values('83573', '663', '1', 'Spring', 2005, 'B ');
	insert into takes values('22004', '105', '2', 'Fall', 2002, 'B-');
	insert into takes values('82918', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('55698', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('51723', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('85366', '338', '1', 'Spring', 2007, 'C ');
	insert into takes values('8252', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('91442', '493', '1', 'Spring', 2010, 'C-');
	insert into takes values('69960', '496', '1', 'Fall', 2001, 'B-');
	insert into takes values('74530', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('49244', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('99348', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('3576', '105', '1', 'Fall', 2009, 'C+');
	insert into takes values('75794', '962', '1', 'Spring', 2008, 'B-');
	insert into takes values('97679', '239', '1', 'Fall', 2006, 'C-');
	insert into takes values('59455', '376', '1', 'Fall', 2006, 'A-');
	insert into takes values('39472', '571', '1', 'Spring', 2004, 'A-');
	insert into takes values('58634', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('27430', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('66469', '949', '1', 'Fall', 2007, 'B ');
	insert into takes values('96067', '401', '1', 'Fall', 2003, 'C-');
	insert into takes values('25785', '867', '1', 'Fall', 2006, 'C+');
	insert into takes values('37284', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('9084', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('7854', '338', '1', 'Spring', 2007, 'C+');
	insert into takes values('63361', '631', '1', 'Spring', 2007, 'A ');
	insert into takes values('14596', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('95175', '696', '1', 'Spring', 2002, 'B-');
	insert into takes values('62784', '105', '2', 'Fall', 2002, 'B+');
	insert into takes values('53588', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('3005', '461', '1', 'Fall', 2002, 'C-');
	insert into takes values('51203', '304', '1', 'Fall', 2009, 'C-');
	insert into takes values('81876', '793', '1', 'Spring', 2002, 'A+');
	insert into takes values('80248', '443', '2', 'Spring', 2002, 'B-');
	insert into takes values('55170', '692', '1', 'Spring', 2010, 'A+');
	insert into takes values('19861', '991', '1', 'Spring', 2008, 'B-');
	insert into takes values('52876', '852', '1', 'Spring', 2008, 'C ');
	insert into takes values('62754', '808', '1', 'Fall', 2003, 'A-');
	insert into takes values('83022', '137', '1', 'Spring', 2002, 'B+');
	insert into takes values('57055', '313', '1', 'Fall', 2010, 'B ');
	insert into takes values('90353', '362', '1', 'Fall', 2005, 'C-');
	insert into takes values('52057', '748', '1', 'Fall', 2003, 'A-');
	insert into takes values('79697', '105', '2', 'Fall', 2002, 'A ');
	insert into takes values('62636', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('66229', '962', '1', 'Spring', 2008, 'A+');
	insert into takes values('41406', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('63612', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('92442', '791', '1', 'Spring', 2006, 'A-');
	insert into takes values('75299', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('30252', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('99660', '468', '1', 'Fall', 2005, 'A ');
	insert into takes values('24784', '400', '1', 'Spring', 2007, 'A ');
	insert into takes values('5898', '591', '1', 'Spring', 2005, 'C-');
	insert into takes values('31690', '972', '1', 'Spring', 2009, 'B-');
	insert into takes values('36126', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('8457', '748', '1', 'Fall', 2003, 'B ');
	insert into takes values('18675', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('95205', '694', '1', 'Fall', 2002, 'C+');
	insert into takes values('53803', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('27950', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('56089', '400', '1', 'Spring', 2007, 'B ');
	insert into takes values('79487', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('99764', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('71631', '843', '1', 'Fall', 2010, 'A ');
	insert into takes values('32385', '702', '1', 'Spring', 2001, 'C ');
	insert into takes values('85887', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('50598', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('6523', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('90004', '626', '1', 'Fall', 2006, 'C+');
	insert into takes values('3487', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('59455', '334', '1', 'Fall', 2009, 'B-');
	insert into takes values('78332', '493', '1', 'Spring', 2010, 'C-');
	insert into takes values('56212', '493', '1', 'Spring', 2010, 'A-');
	insert into takes values('48589', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('85849', '802', '1', 'Spring', 2003, 'C+');
	insert into takes values('56057', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('34422', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('52057', '242', '1', 'Fall', 2009, 'A-');
	insert into takes values('123', '486', '1', 'Fall', 2009, 'C ');
	insert into takes values('4173', '559', '1', 'Fall', 2002, 'A ');
	insert into takes values('62832', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('48462', '304', '1', 'Fall', 2009, 'C-');
	insert into takes values('21401', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('27044', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('69230', '489', '1', 'Fall', 2007, 'A ');
	insert into takes values('19536', '581', '1', 'Spring', 2005, 'C+');
	insert into takes values('79210', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('95027', '319', '1', 'Spring', 2003, 'C+');
	insert into takes values('96772', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('36019', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('9947', '949', '1', 'Fall', 2007, 'C+');
	insert into takes values('69471', '642', '1', 'Fall', 2004, 'B+');
	insert into takes values('67657', '105', '2', 'Fall', 2002, 'B-');
	insert into takes values('49214', '867', '2', 'Fall', 2010, 'C ');
	insert into takes values('98690', '137', '1', 'Spring', 2002, 'A ');
	insert into takes values('78858', '694', '1', 'Fall', 2002, 'B-');
	insert into takes values('23934', '561', '1', 'Fall', 2006, 'B-');
	insert into takes values('31624', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('36402', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('70299', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('96203', '338', '1', 'Spring', 2007, 'A ');
	insert into takes values('72006', '496', '1', 'Fall', 2001, 'C-');
	insert into takes values('69853', '319', '1', 'Spring', 2003, 'B ');
	insert into takes values('88045', '400', '1', 'Spring', 2007, 'A+');
	insert into takes values('4940', '237', '2', 'Fall', 2009, 'C+');
	insert into takes values('95953', '443', '1', 'Spring', 2010, 'C ');
	insert into takes values('55915', '158', '1', 'Fall', 2008, 'A ');
	insert into takes values('36244', '158', '1', 'Fall', 2008, 'A-');
	insert into takes values('99226', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('62520', '426', '1', 'Spring', 2006, 'A+');
	insert into takes values('64196', '893', '1', 'Fall', 2007, 'B ');
	insert into takes values('75241', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('96988', '603', '1', 'Fall', 2003, 'B-');
	insert into takes values('33546', '270', '1', 'Spring', 2010, 'A-');
	insert into takes values('50039', '443', '1', 'Spring', 2010, 'B-');
	insert into takes values('9183', '304', '1', 'Fall', 2009, 'A+');
	insert into takes values('69632', '408', '1', 'Spring', 2007, 'A ');
	insert into takes values('62832', '461', '1', 'Fall', 2002, 'B+');
	insert into takes values('83686', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('56124', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('66753', '461', '1', 'Fall', 2002, 'B-');
	insert into takes values('70362', '559', '1', 'Fall', 2002, 'A ');
	insert into takes values('75423', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('57985', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('58355', '482', '1', 'Fall', 2005, 'C ');
	insert into takes values('65400', '875', '1', 'Spring', 2005, 'A ');
	insert into takes values('48640', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('95852', '808', '1', 'Fall', 2003, 'A+');
	insert into takes values('7854', '421', '1', 'Fall', 2004, 'C+');
	insert into takes values('91343', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('32376', '376', '1', 'Fall', 2006, 'B+');
	insert into takes values('58874', '468', '1', 'Fall', 2005, 'B-');
	insert into takes values('44258', '200', '2', 'Fall', 2002, 'A ');
	insert into takes values('22170', '258', '1', 'Fall', 2007, 'A-');
	insert into takes values('9460', '408', '2', 'Spring', 2003, 'C ');
	insert into takes values('51538', '258', '1', 'Fall', 2007, 'B+');
	insert into takes values('42991', '974', '1', 'Fall', 2003, 'C-');
	insert into takes values('8843', '274', '1', 'Fall', 2002, 'B-');
	insert into takes values('83039', '362', '2', 'Fall', 2006, 'A-');
	insert into takes values('14065', '747', '1', 'Spring', 2004, 'B-');
	insert into takes values('51008', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('54605', '169', '1', 'Spring', 2007, 'A-');
	insert into takes values('7602', '158', '2', 'Spring', 2008, 'A ');
	insert into takes values('39241', '791', '1', 'Spring', 2006, 'A ');
	insert into takes values('38895', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('96134', '561', '1', 'Fall', 2006, 'C-');
	insert into takes values('36102', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('26102', '591', '1', 'Spring', 2005, 'C-');
	insert into takes values('35293', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('27366', '362', '3', 'Spring', 2008, 'A+');
	insert into takes values('65258', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('99189', '696', '1', 'Spring', 2002, 'B+');
	insert into takes values('32886', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('34197', '663', '1', 'Spring', 2005, 'B-');
	insert into takes values('16631', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('1220', '864', '1', 'Spring', 2006, 'C-');
	insert into takes values('83728', '242', '1', 'Fall', 2009, 'C ');
	insert into takes values('67024', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('28316', '808', '1', 'Fall', 2003, 'A-');
	insert into takes values('61783', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('52471', '493', '1', 'Spring', 2010, 'A+');
	insert into takes values('2501', '169', '1', 'Spring', 2007, 'C ');
	insert into takes values('60366', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('73908', '631', '1', 'Spring', 2007, 'A-');
	insert into takes values('29863', '692', '1', 'Spring', 2010, 'A+');
	insert into takes values('52669', '158', '2', 'Spring', 2008, 'A-');
	insert into takes values('61065', '338', '1', 'Spring', 2007, 'A-');
	insert into takes values('36995', '747', '1', 'Spring', 2004, 'B+');
	insert into takes values('10834', '893', '1', 'Fall', 2007, 'A-');
	insert into takes values('30957', '239', '1', 'Fall', 2006, 'A-');
	insert into takes values('37521', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('49391', '362', '2', 'Fall', 2006, 'A ');
	insert into takes values('4860', '400', '1', 'Spring', 2007, 'B+');
	insert into takes values('58594', '443', '2', 'Spring', 2002, 'A-');
	insert into takes values('53152', '489', '1', 'Fall', 2007, 'A ');
	insert into takes values('53485', '200', '1', 'Spring', 2007, 'B-');
	insert into takes values('47126', '808', '1', 'Fall', 2003, 'B ');
	insert into takes values('84039', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('8251', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('90353', '974', '1', 'Fall', 2003, 'A-');
	insert into takes values('67293', '704', '1', 'Spring', 2008, 'B ');
	insert into takes values('74530', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('48678', '545', '1', 'Fall', 2001, 'B-');
	insert into takes values('98423', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('94730', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('77361', '561', '1', 'Fall', 2006, 'A ');
	insert into takes values('8853', '400', '1', 'Spring', 2007, 'B+');
	insert into takes values('76291', '237', '2', 'Fall', 2009, 'A ');
	insert into takes values('52385', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('1884', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('55857', '457', '1', 'Spring', 2001, 'A+');
	insert into takes values('11530', '457', '1', 'Spring', 2001, 'B+');
	insert into takes values('52187', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('12078', '319', '1', 'Spring', 2003, 'C-');
	insert into takes values('56755', '242', '1', 'Fall', 2009, 'A+');
	insert into takes values('58307', '400', '1', 'Spring', 2007, 'C+');
	insert into takes values('83398', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('35498', '239', '1', 'Fall', 2006, 'C-');
	insert into takes values('31337', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('94142', '421', '1', 'Fall', 2004, 'C ');
	insert into takes values('55170', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('84039', '352', '1', 'Spring', 2006, 'A-');
	insert into takes values('21100', '663', '1', 'Spring', 2005, 'A-');
	insert into takes values('76291', '158', '1', 'Fall', 2008, 'C ');
	insert into takes values('49873', '352', '1', 'Spring', 2006, 'A+');
	insert into takes values('70099', '401', '1', 'Fall', 2003, 'C-');
	insert into takes values('17944', '663', '1', 'Spring', 2005, 'A-');
	insert into takes values('41450', '274', '1', 'Fall', 2002, 'C+');
	insert into takes values('499', '735', '1', 'Spring', 2003, 'C-');
	insert into takes values('90372', '962', '1', 'Spring', 2008, 'B-');
	insert into takes values('80698', '400', '2', 'Fall', 2003, 'B-');
	insert into takes values('89297', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('52471', '482', '1', 'Fall', 2005, 'B-');
	insert into takes values('28977', '334', '1', 'Fall', 2009, 'A ');
	insert into takes values('12362', '158', '2', 'Spring', 2008, 'B-');
	insert into takes values('19824', '591', '1', 'Spring', 2005, 'C-');
	insert into takes values('64724', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('25725', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('73492', '338', '1', 'Spring', 2007, 'A ');
	insert into takes values('53089', '349', '1', 'Spring', 2008, 'C-');
	insert into takes values('57431', '270', '1', 'Spring', 2010, 'A-');
	insert into takes values('95840', '696', '1', 'Spring', 2002, 'A+');
	insert into takes values('59553', '401', '1', 'Fall', 2003, 'A-');
	insert into takes values('76953', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('11095', '200', '1', 'Spring', 2007, 'B-');
	insert into takes values('33817', '692', '1', 'Spring', 2010, 'A-');
	insert into takes values('46956', '408', '1', 'Spring', 2007, 'A+');
	insert into takes values('48471', '991', '1', 'Spring', 2008, 'A ');
	insert into takes values('52707', '319', '1', 'Spring', 2003, 'B ');
	insert into takes values('7732', '237', '2', 'Fall', 2009, 'C ');
	insert into takes values('90181', '443', '1', 'Spring', 2010, 'B+');
	insert into takes values('82039', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('50598', '461', '1', 'Fall', 2002, 'C+');
	insert into takes values('68453', '169', '2', 'Fall', 2002, 'C ');
	insert into takes values('57925', '408', '2', 'Spring', 2003, 'C ');
	insert into takes values('499', '200', '1', 'Spring', 2007, 'B+');
	insert into takes values('43854', '843', '1', 'Fall', 2010, 'C ');
	insert into takes values('96117', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('12615', '599', '1', 'Spring', 2003, 'A-');
	insert into takes values('21789', '376', '1', 'Fall', 2006, 'C ');
	insert into takes values('93631', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('96153', '527', '1', 'Fall', 2004, 'C ');
	insert into takes values('85211', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('67371', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('59455', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('51093', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('58172', '748', '1', 'Fall', 2003, 'B-');
	insert into takes values('67146', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('87222', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('83691', '200', '2', 'Fall', 2002, 'C+');
	insert into takes values('64192', '200', '1', 'Spring', 2007, 'B-');
	insert into takes values('31086', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('82688', '105', '1', 'Fall', 2009, 'C ');
	insert into takes values('39157', '527', '1', 'Fall', 2004, 'B-');
	insert into takes values('65715', '408', '1', 'Spring', 2007, 'C ');
	insert into takes values('27043', '591', '1', 'Spring', 2005, 'B-');
	insert into takes values('978', '169', '2', 'Fall', 2002, 'A-');
	insert into takes values('57985', '545', '1', 'Fall', 2001, 'A-');
	insert into takes values('53699', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('30341', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('29031', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('10917', '468', '2', 'Fall', 2007, 'C-');
	insert into takes values('94522', '258', '1', 'Fall', 2007, 'A+');
	insert into takes values('55857', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('94535', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('59046', '748', '1', 'Fall', 2003, 'C ');
	insert into takes values('32490', '867', '2', 'Fall', 2010, 'A-');
	insert into takes values('35588', '461', '1', 'Fall', 2002, 'B+');
	insert into takes values('61356', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('52057', '735', '1', 'Spring', 2003, 'C ');
	insert into takes values('62636', '401', '1', 'Fall', 2003, 'B+');
	insert into takes values('23373', '457', '1', 'Spring', 2001, 'B-');
	insert into takes values('15538', '791', '1', 'Spring', 2006, 'A-');
	insert into takes values('37734', '362', '2', 'Fall', 2006, 'A ');
	insert into takes values('41671', '527', '1', 'Fall', 2004, 'C ');
	insert into takes values('96085', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('10838', '702', '1', 'Spring', 2001, 'B ');
	insert into takes values('14284', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('16405', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('29849', '545', '1', 'Fall', 2001, 'A ');
	insert into takes values('16907', '581', '1', 'Spring', 2005, 'A+');
	insert into takes values('86127', '604', '1', 'Spring', 2009, 'B+');
	insert into takes values('87784', '692', '1', 'Spring', 2010, 'A ');
	insert into takes values('79170', '642', '1', 'Fall', 2004, 'A+');
	insert into takes values('89571', '362', '3', 'Spring', 2008, 'C+');
	insert into takes values('26427', '735', '1', 'Spring', 2003, 'A+');
	insert into takes values('37103', '927', '1', 'Fall', 2002, 'C ');
	insert into takes values('37284', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('78572', '631', '1', 'Spring', 2007, 'A+');
	insert into takes values('93708', '105', '2', 'Fall', 2002, 'C-');
	insert into takes values('83204', '843', '1', 'Fall', 2010, 'C ');
	insert into takes values('30957', '457', '1', 'Spring', 2001, 'B-');
	insert into takes values('17997', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('8140', '105', '1', 'Fall', 2009, 'A+');
	insert into takes values('40481', '760', '1', 'Spring', 2004, 'C-');
	insert into takes values('18338', '468', '1', 'Fall', 2005, 'B+');
	insert into takes values('86552', '401', '1', 'Fall', 2003, 'C-');
	insert into takes values('42560', '972', '1', 'Spring', 2009, 'C-');
	insert into takes values('1884', '626', '1', 'Fall', 2006, 'C ');
	insert into takes values('52876', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('50969', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('44998', '237', '2', 'Fall', 2009, 'B+');
	insert into takes values('10204', '200', '2', 'Fall', 2002, 'B-');
	insert into takes values('95697', '345', '1', 'Spring', 2008, 'C-');
	insert into takes values('97041', '696', '1', 'Spring', 2002, 'C ');
	insert into takes values('67660', '679', '1', 'Spring', 2010, 'A+');
	insert into takes values('49073', '443', '1', 'Spring', 2010, 'C+');
	insert into takes values('45359', '612', '1', 'Fall', 2007, 'B-');
	insert into takes values('36102', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('84704', '795', '1', 'Spring', 2004, 'B ');
	insert into takes values('29091', '793', '1', 'Spring', 2002, 'B ');
	insert into takes values('5824', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('68242', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('78314', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('16133', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('79534', '604', '1', 'Spring', 2009, 'B+');
	insert into takes values('78922', '496', '1', 'Fall', 2001, 'C-');
	insert into takes values('32464', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('34422', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('8343', '482', '1', 'Fall', 2005, 'A ');
	insert into takes values('24932', '559', '1', 'Fall', 2002, 'B+');
	insert into takes values('32881', '852', '1', 'Spring', 2008, 'C+');
	insert into takes values('53172', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('31079', '345', '1', 'Spring', 2008, 'C+');
	insert into takes values('48660', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('92703', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('57511', '629', '1', 'Spring', 2003, 'A+');
	insert into takes values('85534', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('36052', '692', '1', 'Spring', 2010, 'B-');
	insert into takes values('78143', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('89106', '319', '1', 'Spring', 2003, 'B ');
	insert into takes values('75522', '864', '1', 'Spring', 2006, 'B ');
	insert into takes values('4645', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('3576', '960', '2', 'Fall', 2006, 'A-');
	insert into takes values('57107', '400', '2', 'Fall', 2003, 'C-');
	insert into takes values('81258', '237', '1', 'Spring', 2008, 'B ');
	insert into takes values('63645', '599', '1', 'Spring', 2003, 'A-');
	insert into takes values('2139', '692', '1', 'Spring', 2010, 'B-');
	insert into takes values('99611', '629', '1', 'Spring', 2003, 'B-');
	insert into takes values('50386', '200', '1', 'Spring', 2007, 'A-');
	insert into takes values('33107', '791', '1', 'Spring', 2006, 'C-');
	insert into takes values('17924', '338', '2', 'Spring', 2006, 'C ');
	insert into takes values('78637', '760', '1', 'Spring', 2004, 'B-');
	insert into takes values('76798', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('11855', '852', '1', 'Spring', 2008, 'C-');
	insert into takes values('390', '864', '1', 'Spring', 2006, 'B ');
	insert into takes values('40044', '949', '1', 'Fall', 2007, 'C-');
	insert into takes values('94730', '679', '1', 'Spring', 2010, 'C-');
	insert into takes values('24197', '974', '1', 'Fall', 2003, 'B-');
	insert into takes values('91799', '852', '1', 'Spring', 2008, 'C-');
	insert into takes values('10736', '559', '1', 'Fall', 2002, 'C-');
	insert into takes values('68516', '927', '1', 'Fall', 2002, 'C-');
	insert into takes values('62795', '400', '2', 'Fall', 2003, 'B-');
	insert into takes values('27956', '489', '1', 'Fall', 2007, 'C ');
	insert into takes values('28977', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('63612', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('16969', '443', '2', 'Spring', 2002, 'A ');
	insert into takes values('24932', '482', '1', 'Fall', 2005, 'A+');
	insert into takes values('24442', '105', '1', 'Fall', 2009, 'B ');
	insert into takes values('15024', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('81638', '694', '1', 'Fall', 2002, 'A+');
	insert into takes values('96052', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('842', '443', '1', 'Spring', 2010, 'C ');
	insert into takes values('32056', '445', '1', 'Spring', 2001, 'B-');
	insert into takes values('34770', '345', '1', 'Spring', 2008, 'B ');
	insert into takes values('914', '400', '2', 'Fall', 2003, 'C-');
	insert into takes values('96117', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('72055', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('39978', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('39580', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('40116', '867', '1', 'Fall', 2006, 'A+');
	insert into takes values('68720', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('57377', '527', '1', 'Fall', 2004, 'C ');
	insert into takes values('5824', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('75560', '445', '1', 'Spring', 2001, 'C+');
	insert into takes values('7043', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('70021', '747', '1', 'Spring', 2004, 'A ');
	insert into takes values('39927', '748', '1', 'Fall', 2003, 'B-');
	insert into takes values('914', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('44271', '158', '1', 'Fall', 2008, 'A+');
	insert into takes values('19362', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('5943', '169', '1', 'Spring', 2007, 'A ');
	insert into takes values('92864', '793', '1', 'Spring', 2002, 'C+');
	insert into takes values('75123', '105', '2', 'Fall', 2002, 'B-');
	insert into takes values('18636', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('1812', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('90609', '408', '2', 'Spring', 2003, 'A+');
	insert into takes values('19536', '496', '1', 'Fall', 2001, 'B+');
	insert into takes values('19917', '338', '1', 'Spring', 2007, 'B-');
	insert into takes values('3651', '345', '1', 'Spring', 2008, 'B-');
	insert into takes values('39580', '239', '1', 'Fall', 2006, 'B-');
	insert into takes values('37586', '581', '1', 'Spring', 2005, 'A ');
	insert into takes values('31080', '791', '1', 'Spring', 2006, 'A ');
	insert into takes values('18583', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('11194', '642', '1', 'Fall', 2004, 'C+');
	insert into takes values('847', '169', '1', 'Spring', 2007, 'C+');
	insert into takes values('55940', '559', '1', 'Fall', 2002, 'B+');
	insert into takes values('29031', '581', '1', 'Spring', 2005, 'C-');
	insert into takes values('20445', '867', '1', 'Fall', 2006, 'A+');
	insert into takes values('13217', '489', '1', 'Fall', 2007, 'A-');
	insert into takes values('16480', '959', '1', 'Fall', 2006, 'B+');
	insert into takes values('89312', '974', '1', 'Fall', 2003, 'C-');
	insert into takes values('95225', '949', '1', 'Fall', 2007, 'A-');
	insert into takes values('9514', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('36019', '748', '1', 'Fall', 2003, 'C ');
	insert into takes values('10267', '345', '1', 'Spring', 2008, 'C-');
	insert into takes values('31079', '791', '1', 'Spring', 2006, 'B+');
	insert into takes values('3576', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('73268', '486', '1', 'Fall', 2009, 'C+');
	insert into takes values('82039', '974', '1', 'Fall', 2003, 'C ');
	insert into takes values('68395', '604', '1', 'Spring', 2009, 'A-');
	insert into takes values('37734', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('95626', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('33759', '476', '1', 'Fall', 2010, 'B+');
	insert into takes values('50969', '702', '1', 'Spring', 2001, 'B ');
	insert into takes values('31337', '242', '1', 'Fall', 2009, 'A+');
	insert into takes values('82974', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('37715', '545', '1', 'Fall', 2001, 'B-');
	insert into takes values('5298', '476', '1', 'Fall', 2010, 'B+');
	insert into takes values('67542', '631', '1', 'Spring', 2007, 'C-');
	insert into takes values('22142', '626', '1', 'Fall', 2006, 'A-');
	insert into takes values('94311', '694', '1', 'Fall', 2002, 'A ');
	insert into takes values('90220', '258', '1', 'Fall', 2007, 'B-');
	insert into takes values('8343', '313', '1', 'Fall', 2010, 'A+');
	insert into takes values('37653', '105', '2', 'Fall', 2002, 'A-');
	insert into takes values('51955', '334', '1', 'Fall', 2009, 'C-');
	insert into takes values('978', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('57538', '468', '2', 'Fall', 2007, 'A-');
	insert into takes values('53089', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('85505', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('65056', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('9408', '972', '1', 'Spring', 2009, 'C ');
	insert into takes values('83170', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('18469', '735', '2', 'Spring', 2010, 'A-');
	insert into takes values('30858', '626', '1', 'Fall', 2006, 'C+');
	insert into takes values('14554', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('5208', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('72622', '376', '1', 'Fall', 2006, 'B ');
	insert into takes values('16515', '443', '2', 'Spring', 2002, 'B ');
	insert into takes values('78756', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('38691', '237', '1', 'Spring', 2008, 'B ');
	insert into takes values('52371', '867', '1', 'Fall', 2006, 'C+');
	insert into takes values('94814', '274', '1', 'Fall', 2002, 'C+');
	insert into takes values('36845', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('24387', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('59848', '893', '1', 'Fall', 2007, 'C+');
	insert into takes values('3576', '242', '1', 'Fall', 2009, 'B ');
	insert into takes values('94801', '679', '1', 'Spring', 2010, 'B+');
	insert into takes values('49701', '200', '2', 'Fall', 2002, 'A-');
	insert into takes values('9933', '702', '1', 'Spring', 2001, 'C-');
	insert into takes values('29390', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('10663', '443', '1', 'Spring', 2010, 'B+');
	insert into takes values('16453', '345', '1', 'Spring', 2008, 'C+');
	insert into takes values('6195', '867', '2', 'Fall', 2010, 'C-');
	insert into takes values('76250', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('15144', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('39204', '489', '1', 'Fall', 2007, 'C+');
	insert into takes values('66293', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('39115', '345', '1', 'Spring', 2008, 'A ');
	insert into takes values('67655', '949', '1', 'Fall', 2007, 'C ');
	insert into takes values('30650', '169', '2', 'Fall', 2002, 'B ');
	insert into takes values('65144', '334', '1', 'Fall', 2009, 'A ');
	insert into takes values('57123', '581', '1', 'Spring', 2005, 'C ');
	insert into takes values('1232', '476', '1', 'Fall', 2010, 'C-');
	insert into takes values('44836', '443', '1', 'Spring', 2010, 'A ');
	insert into takes values('63645', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('59538', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('69471', '158', '2', 'Spring', 2008, 'A-');
	insert into takes values('70688', '591', '1', 'Spring', 2005, 'B ');
	insert into takes values('65329', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('53728', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('7970', '679', '1', 'Spring', 2010, 'A+');
	insert into takes values('67660', '169', '2', 'Fall', 2002, 'B-');
	insert into takes values('82646', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('12563', '338', '2', 'Spring', 2006, 'A ');
	insert into takes values('40682', '349', '1', 'Spring', 2008, 'B+');
	insert into takes values('23934', '468', '2', 'Fall', 2007, 'B ');
	insert into takes values('85451', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('97400', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('19766', '376', '1', 'Fall', 2006, 'C ');
	insert into takes values('27898', '239', '1', 'Fall', 2006, 'C-');
	insert into takes values('84410', '496', '1', 'Fall', 2001, 'B-');
	insert into takes values('96206', '760', '1', 'Spring', 2004, 'B+');
	insert into takes values('52669', '443', '2', 'Spring', 2002, 'B-');
	insert into takes values('42114', '599', '1', 'Spring', 2003, 'C ');
	insert into takes values('28299', '927', '1', 'Fall', 2002, 'C-');
	insert into takes values('38288', '626', '1', 'Fall', 2006, 'A ');
	insert into takes values('22912', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('69783', '274', '1', 'Fall', 2002, 'B-');
	insert into takes values('89551', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('58326', '400', '2', 'Fall', 2003, 'B-');
	insert into takes values('2419', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('95366', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('62749', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('69758', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('80941', '415', '1', 'Fall', 2010, 'A-');
	insert into takes values('69628', '599', '1', 'Spring', 2003, 'A+');
	insert into takes values('99694', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('39115', '270', '1', 'Spring', 2010, 'C ');
	insert into takes values('37946', '457', '1', 'Spring', 2001, 'C+');
	insert into takes values('14182', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('8457', '599', '1', 'Spring', 2003, 'C ');
	insert into takes values('30017', '192', '1', 'Fall', 2002, 'C-');
	insert into takes values('8603', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('28989', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('43348', '349', '1', 'Spring', 2008, 'A-');
	insert into takes values('51768', '696', '1', 'Spring', 2002, 'C-');
	insert into takes values('14563', '376', '1', 'Fall', 2006, 'A ');
	insert into takes values('94894', '362', '1', 'Fall', 2005, 'C-');
	insert into takes values('792', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('39514', '795', '1', 'Spring', 2004, 'C+');
	insert into takes values('77729', '603', '1', 'Fall', 2003, 'B-');
	insert into takes values('40044', '581', '1', 'Spring', 2005, 'B+');
	insert into takes values('40371', '692', '1', 'Spring', 2010, 'A ');
	insert into takes values('4248', '604', '1', 'Spring', 2009, 'C ');
	insert into takes values('19048', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('28738', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('46074', '169', '2', 'Fall', 2002, 'A ');
	insert into takes values('544', '571', '1', 'Spring', 2004, 'A+');
	insert into takes values('24374', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('1018', '304', '1', 'Fall', 2009, 'B ');
	insert into takes values('38895', '802', '1', 'Spring', 2003, 'B+');
	insert into takes values('20084', '852', '1', 'Spring', 2008, 'C ');
	insert into takes values('12979', '692', '1', 'Spring', 2010, 'A+');
	insert into takes values('50944', '696', '1', 'Spring', 2002, 'C+');
	insert into takes values('56212', '349', '1', 'Spring', 2008, 'A-');
	insert into takes values('52707', '443', '2', 'Spring', 2002, 'A ');
	insert into takes values('48678', '612', '1', 'Fall', 2007, 'B ');
	insert into takes values('37715', '694', '1', 'Fall', 2002, 'C ');
	insert into takes values('84039', '443', '2', 'Spring', 2002, 'A+');
	insert into takes values('51008', '468', '2', 'Fall', 2007, 'C+');
	insert into takes values('24784', '338', '1', 'Spring', 2007, 'A-');
	insert into takes values('67793', '338', '1', 'Spring', 2007, 'B-');
	insert into takes values('13741', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('74840', '604', '1', 'Spring', 2009, 'B-');
	insert into takes values('2139', '927', '1', 'Fall', 2002, 'B-');
	insert into takes values('33401', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('40897', '457', '1', 'Spring', 2001, 'A ');
	insert into takes values('71529', '362', '3', 'Spring', 2008, 'C+');
	insert into takes values('22620', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('72643', '200', '2', 'Fall', 2002, 'C+');
	insert into takes values('69679', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('25785', '927', '1', 'Fall', 2002, 'C+');
	insert into takes values('6474', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('96134', '338', '2', 'Spring', 2006, 'A-');
	insert into takes values('30845', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('95574', '843', '1', 'Fall', 2010, 'B+');
	insert into takes values('91063', '692', '1', 'Spring', 2010, 'C ');
	insert into takes values('16467', '476', '1', 'Fall', 2010, 'B ');
	insert into takes values('8457', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('19450', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('41261', '362', '1', 'Fall', 2005, 'C ');
	insert into takes values('23224', '527', '1', 'Fall', 2004, 'C+');
	insert into takes values('95099', '808', '1', 'Fall', 2003, 'B ');
	insert into takes values('51698', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('15698', '802', '1', 'Spring', 2003, 'C+');
	insert into takes values('40932', '137', '1', 'Spring', 2002, 'B ');
	insert into takes values('52291', '468', '1', 'Fall', 2005, 'C+');
	insert into takes values('70564', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('37734', '493', '1', 'Spring', 2010, 'A-');
	insert into takes values('35257', '200', '2', 'Fall', 2002, 'C+');
	insert into takes values('42625', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('34126', '927', '1', 'Fall', 2002, 'C ');
	insert into takes values('1018', '362', '3', 'Spring', 2008, 'B ');
	insert into takes values('46066', '237', '2', 'Fall', 2009, 'C-');
	insert into takes values('47126', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('56078', '875', '1', 'Spring', 2005, 'C ');
	insert into takes values('38696', '875', '1', 'Spring', 2005, 'A-');
	insert into takes values('69471', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('69960', '843', '1', 'Fall', 2010, 'B+');
	insert into takes values('1836', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('53172', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('16453', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('1110', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('56143', '313', '1', 'Fall', 2010, 'B ');
	insert into takes values('914', '802', '1', 'Spring', 2003, 'C-');
	insert into takes values('29803', '735', '2', 'Spring', 2010, 'B-');
	insert into takes values('54875', '960', '2', 'Fall', 2006, 'C-');
	insert into takes values('89059', '338', '1', 'Spring', 2007, 'B-');
	insert into takes values('41280', '200', '2', 'Fall', 2002, 'C-');
	insert into takes values('12563', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('21789', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('11201', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('30124', '313', '1', 'Fall', 2010, 'B ');
	insert into takes values('99730', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('92849', '345', '1', 'Spring', 2008, 'C+');
	insert into takes values('28361', '852', '1', 'Spring', 2008, 'B-');
	insert into takes values('87651', '972', '1', 'Spring', 2009, 'C ');
	insert into takes values('68070', '274', '1', 'Fall', 2002, 'A+');
	insert into takes values('60267', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('64945', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('52707', '631', '1', 'Spring', 2007, 'A+');
	insert into takes values('83622', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('9514', '415', '1', 'Fall', 2010, 'B+');
	insert into takes values('66969', '482', '1', 'Fall', 2005, 'A-');
	insert into takes values('78434', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('1232', '408', '2', 'Spring', 2003, 'B-');
	insert into takes values('97551', '338', '1', 'Spring', 2007, 'C ');
	insert into takes values('24809', '461', '1', 'Fall', 2002, 'B-');
	insert into takes values('65400', '345', '1', 'Spring', 2008, 'A ');
	insert into takes values('26730', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('78787', '338', '2', 'Spring', 2006, 'C ');
	insert into takes values('97355', '694', '1', 'Fall', 2002, 'B ');
	insert into takes values('73908', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('64121', '415', '1', 'Fall', 2010, 'A+');
	insert into takes values('39115', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('19824', '960', '1', 'Fall', 2009, 'B-');
	insert into takes values('1110', '258', '1', 'Fall', 2007, 'C-');
	insert into takes values('22142', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('21789', '274', '1', 'Fall', 2002, 'C+');
	insert into takes values('20099', '137', '1', 'Spring', 2002, 'B ');
	insert into takes values('98690', '158', '1', 'Fall', 2008, 'C ');
	insert into takes values('19362', '612', '1', 'Fall', 2007, 'A ');
	insert into takes values('34126', '338', '1', 'Spring', 2007, 'C-');
	insert into takes values('16405', '747', '1', 'Spring', 2004, 'C ');
	insert into takes values('82066', '345', '1', 'Spring', 2008, 'B-');
	insert into takes values('93171', '581', '1', 'Spring', 2005, 'A+');
	insert into takes values('99369', '443', '2', 'Spring', 2002, 'B+');
	insert into takes values('24746', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('74974', '338', '1', 'Spring', 2007, 'C-');
	insert into takes values('96324', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('52707', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('67293', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('10527', '571', '1', 'Spring', 2004, 'B+');
	insert into takes values('12326', '408', '2', 'Spring', 2003, 'B ');
	insert into takes values('72501', '105', '1', 'Fall', 2009, 'B ');
	insert into takes values('75040', '443', '1', 'Spring', 2010, 'C ');
	insert into takes values('6673', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('21101', '158', '1', 'Fall', 2008, 'A-');
	insert into takes values('30177', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('76895', '200', '2', 'Fall', 2002, 'C-');
	insert into takes values('97590', '493', '1', 'Spring', 2010, 'B+');
	insert into takes values('62754', '443', '2', 'Spring', 2002, 'C+');
	insert into takes values('89051', '200', '2', 'Fall', 2002, 'B+');
	insert into takes values('57238', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('89246', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('32217', '192', '1', 'Fall', 2002, 'C-');
	insert into takes values('65038', '748', '1', 'Fall', 2003, 'C-');
	insert into takes values('75252', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('7620', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('63090', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('16057', '852', '1', 'Spring', 2008, 'B-');
	insert into takes values('33206', '692', '1', 'Spring', 2010, 'B-');
	insert into takes values('37339', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('42625', '270', '1', 'Spring', 2010, 'B-');
	insert into takes values('74016', '366', '1', 'Fall', 2005, 'A ');
	insert into takes values('58172', '192', '1', 'Fall', 2002, 'A+');
	insert into takes values('78116', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('39901', '629', '1', 'Spring', 2003, 'A ');
	insert into takes values('97573', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('40044', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('10904', '612', '1', 'Fall', 2007, 'B-');
	insert into takes values('30650', '760', '1', 'Spring', 2004, 'A ');
	insert into takes values('82591', '692', '1', 'Spring', 2010, 'B-');
	insert into takes values('71631', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('7490', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('65121', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('37339', '735', '1', 'Spring', 2003, 'A-');
	insert into takes values('15086', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('77000', '867', '1', 'Fall', 2006, 'C+');
	insert into takes values('5144', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('75794', '631', '1', 'Spring', 2007, 'A-');
	insert into takes values('29645', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('27687', '457', '1', 'Spring', 2001, 'A ');
	insert into takes values('89132', '679', '1', 'Spring', 2010, 'B-');
	insert into takes values('80248', '349', '1', 'Spring', 2008, 'A-');
	insert into takes values('80047', '571', '1', 'Spring', 2004, 'C+');
	insert into takes values('26881', '334', '1', 'Fall', 2009, 'B-');
	insert into takes values('81294', '237', '1', 'Spring', 2008, 'B ');
	insert into takes values('4182', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('46155', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('34422', '400', '2', 'Fall', 2003, 'A+');
	insert into takes values('45650', '864', '1', 'Spring', 2006, 'B ');
	insert into takes values('57925', '376', '1', 'Fall', 2006, 'B ');
	insert into takes values('89393', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('94173', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('83170', '972', '1', 'Spring', 2009, 'B ');
	insert into takes values('1018', '274', '1', 'Fall', 2002, 'A+');
	insert into takes values('78782', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('55170', '200', '2', 'Fall', 2002, 'B-');
	insert into takes values('10076', '692', '1', 'Spring', 2010, 'A-');
	insert into takes values('97355', '105', '1', 'Fall', 2009, 'C ');
	insert into takes values('8378', '468', '2', 'Fall', 2007, 'B ');
	insert into takes values('38895', '867', '1', 'Fall', 2006, 'A-');
	insert into takes values('16543', '400', '1', 'Spring', 2007, 'B+');
	insert into takes values('69581', '457', '1', 'Spring', 2001, 'C+');
	insert into takes values('67425', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('33201', '345', '1', 'Spring', 2008, 'C+');
	insert into takes values('92417', '927', '1', 'Fall', 2002, 'C ');
	insert into takes values('57334', '960', '1', 'Fall', 2009, 'A+');
	insert into takes values('81884', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('71628', '362', '3', 'Spring', 2008, 'B ');
	insert into takes values('13352', '158', '1', 'Fall', 2008, 'A-');
	insert into takes values('760', '376', '1', 'Fall', 2006, 'C ');
	insert into takes values('3335', '696', '1', 'Spring', 2002, 'C ');
	insert into takes values('44703', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('27140', '545', '1', 'Fall', 2001, 'B ');
	insert into takes values('2848', '793', '1', 'Spring', 2002, 'C ');
	insert into takes values('32954', '200', '1', 'Spring', 2007, 'C ');
	insert into takes values('29399', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('32881', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('22170', '735', '2', 'Spring', 2010, 'A ');
	insert into takes values('26473', '561', '1', 'Fall', 2006, 'A-');
	insert into takes values('83003', '338', '2', 'Spring', 2006, 'B ');
	insert into takes values('21774', '270', '1', 'Spring', 2010, 'A+');
	insert into takes values('81984', '991', '1', 'Spring', 2008, 'B-');
	insert into takes values('499', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('57334', '679', '1', 'Spring', 2010, 'A+');
	insert into takes values('36926', '949', '1', 'Fall', 2007, 'C+');
	insert into takes values('78858', '748', '1', 'Fall', 2003, 'B-');
	insert into takes values('15578', '239', '1', 'Fall', 2006, 'B-');
	insert into takes values('51923', '415', '1', 'Fall', 2010, 'C-');
	insert into takes values('16631', '959', '1', 'Fall', 2006, 'C+');
	insert into takes values('13741', '972', '1', 'Spring', 2009, 'B+');
	insert into takes values('22003', '352', '1', 'Spring', 2006, 'B ');
	insert into takes values('23525', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('4508', '599', '1', 'Spring', 2003, 'A-');
	insert into takes values('69758', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('98830', '927', '1', 'Fall', 2002, 'A ');
	insert into takes values('5843', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('19245', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('499', '338', '1', 'Spring', 2007, 'B-');
	insert into takes values('9514', '960', '1', 'Fall', 2009, 'B-');
	insert into takes values('76250', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('9084', '400', '1', 'Spring', 2007, 'A ');
	insert into takes values('31690', '158', '2', 'Spring', 2008, 'A ');
	insert into takes values('75522', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('76743', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('83170', '493', '1', 'Spring', 2010, 'C+');
	insert into takes values('10527', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('53547', '747', '1', 'Spring', 2004, 'C ');
	insert into takes values('77415', '345', '1', 'Spring', 2008, 'A-');
	insert into takes values('24374', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('64724', '304', '1', 'Fall', 2009, 'B+');
	insert into takes values('37454', '974', '1', 'Fall', 2003, 'C ');
	insert into takes values('13741', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('30017', '559', '1', 'Fall', 2002, 'C-');
	insert into takes values('58594', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('70061', '400', '2', 'Fall', 2003, 'B-');
	insert into takes values('70395', '313', '1', 'Fall', 2010, 'A-');
	insert into takes values('58606', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('51238', '599', '1', 'Spring', 2003, 'A+');
	insert into takes values('77548', '642', '1', 'Fall', 2004, 'B+');
	insert into takes values('88884', '927', '1', 'Fall', 2002, 'C ');
	insert into takes values('71529', '468', '1', 'Fall', 2005, 'B-');
	insert into takes values('97023', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('33349', '242', '1', 'Fall', 2009, 'B ');
	insert into takes values('89734', '258', '1', 'Fall', 2007, 'A ');
	insert into takes values('69521', '400', '1', 'Spring', 2007, 'B ');
	insert into takes values('75173', '401', '1', 'Fall', 2003, 'C+');
	insert into takes values('26102', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('2970', '571', '1', 'Spring', 2004, 'A-');
	insert into takes values('34569', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('25468', '137', '1', 'Spring', 2002, 'A-');
	insert into takes values('49073', '760', '1', 'Spring', 2004, 'A ');
	insert into takes values('28019', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('93366', '408', '1', 'Spring', 2007, 'C-');
	insert into takes values('98563', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('7656', '927', '1', 'Fall', 2002, 'C-');
	insert into takes values('2286', '200', '1', 'Spring', 2007, 'B-');
	insert into takes values('39115', '960', '2', 'Fall', 2006, 'C ');
	insert into takes values('36244', '760', '1', 'Spring', 2004, 'A ');
	insert into takes values('19735', '875', '1', 'Spring', 2005, 'A ');
	insert into takes values('70924', '702', '1', 'Spring', 2001, 'B-');
	insert into takes values('75040', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('9183', '864', '1', 'Spring', 2006, 'A ');
	insert into takes values('42556', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('40937', '927', '1', 'Fall', 2002, 'C-');
	insert into takes values('88553', '345', '1', 'Spring', 2008, 'B ');
	insert into takes values('93814', '457', '1', 'Spring', 2001, 'C-');
	insert into takes values('31442', '629', '1', 'Spring', 2003, 'B ');
	insert into takes values('1727', '735', '1', 'Spring', 2003, 'A+');
	insert into takes values('2139', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('32490', '443', '2', 'Spring', 2002, 'C+');
	insert into takes values('69122', '867', '1', 'Fall', 2006, 'B+');
	insert into takes values('64731', '158', '2', 'Spring', 2008, 'B+');
	insert into takes values('12666', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('17397', '319', '1', 'Spring', 2003, 'C+');
	insert into takes values('99399', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('89312', '421', '1', 'Fall', 2004, 'A ');
	insert into takes values('74016', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('68280', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('69225', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('12683', '496', '1', 'Fall', 2001, 'B+');
	insert into takes values('70522', '808', '1', 'Fall', 2003, 'A-');
	insert into takes values('90194', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('28361', '748', '1', 'Fall', 2003, 'C ');
	insert into takes values('46337', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('23994', '338', '1', 'Spring', 2007, 'C+');
	insert into takes values('34331', '237', '2', 'Fall', 2009, 'C ');
	insert into takes values('37809', '843', '1', 'Fall', 2010, 'B+');
	insert into takes values('52203', '702', '1', 'Spring', 2001, 'A-');
	insert into takes values('68070', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('60040', '408', '1', 'Spring', 2007, 'C ');
	insert into takes values('55859', '581', '1', 'Spring', 2005, 'A+');
	insert into takes values('33759', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('54460', '445', '1', 'Spring', 2001, 'C ');
	insert into takes values('18709', '408', '1', 'Spring', 2007, 'A+');
	insert into takes values('49701', '852', '1', 'Spring', 2008, 'C-');
	insert into takes values('18469', '400', '2', 'Fall', 2003, 'A-');
	insert into takes values('37219', '461', '1', 'Fall', 2002, 'B+');
	insert into takes values('88525', '793', '1', 'Spring', 2002, 'A+');
	insert into takes values('38121', '376', '1', 'Fall', 2006, 'C+');
	insert into takes values('85226', '376', '1', 'Fall', 2006, 'C+');
	insert into takes values('51416', '237', '2', 'Fall', 2009, 'C ');
	insert into takes values('69679', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('88887', '489', '1', 'Fall', 2007, 'A ');
	insert into takes values('92385', '158', '1', 'Fall', 2008, 'B+');
	insert into takes values('96615', '468', '1', 'Fall', 2005, 'A+');
	insert into takes values('52945', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('88140', '991', '1', 'Spring', 2008, 'C-');
	insert into takes values('24809', '338', '1', 'Spring', 2007, 'C ');
	insert into takes values('50267', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('46066', '760', '1', 'Spring', 2004, 'C-');
	insert into takes values('83686', '702', '1', 'Spring', 2001, 'C+');
	insert into takes values('30772', '468', '1', 'Fall', 2005, 'B-');
	insert into takes values('4015', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('93491', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('32886', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('63560', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('79589', '445', '1', 'Spring', 2001, 'B+');
	insert into takes values('42625', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('80610', '527', '1', 'Fall', 2004, 'C-');
	insert into takes values('86127', '200', '2', 'Fall', 2002, 'A ');
	insert into takes values('33349', '793', '1', 'Spring', 2002, 'C ');
	insert into takes values('99754', '443', '2', 'Spring', 2002, 'B+');
	insert into takes values('74672', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('91132', '867', '1', 'Fall', 2006, 'C+');
	insert into takes values('68999', '468', '2', 'Fall', 2007, 'A+');
	insert into takes values('10904', '581', '1', 'Spring', 2005, 'B+');
	insert into takes values('31442', '239', '1', 'Fall', 2006, 'B-');
	insert into takes values('35721', '158', '2', 'Spring', 2008, 'C+');
	insert into takes values('92274', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('5208', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('16907', '105', '2', 'Fall', 2002, 'A ');
	insert into takes values('25143', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('86969', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('73213', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('83022', '599', '1', 'Spring', 2003, 'A-');
	insert into takes values('89234', '694', '1', 'Fall', 2002, 'C ');
	insert into takes values('37869', '400', '1', 'Spring', 2007, 'C ');
	insert into takes values('40080', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('22345', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('24325', '748', '1', 'Fall', 2003, 'C-');
	insert into takes values('23500', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('24809', '105', '1', 'Fall', 2009, 'C ');
	insert into takes values('54728', '599', '1', 'Spring', 2003, 'C ');
	insert into takes values('66281', '349', '1', 'Spring', 2008, 'C-');
	insert into takes values('68779', '747', '1', 'Spring', 2004, 'B+');
	insert into takes values('96178', '242', '1', 'Fall', 2009, 'A-');
	insert into takes values('69471', '376', '1', 'Fall', 2006, 'B-');
	insert into takes values('51975', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('71543', '443', '2', 'Spring', 2002, 'C ');
	insert into takes values('58081', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('72622', '843', '1', 'Fall', 2010, 'B+');
	insert into takes values('20489', '468', '1', 'Fall', 2005, 'C+');
	insert into takes values('64259', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('43912', '867', '1', 'Fall', 2006, 'B ');
	insert into takes values('24809', '401', '1', 'Fall', 2003, 'A ');
	insert into takes values('22050', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('30334', '443', '1', 'Spring', 2010, 'B+');
	insert into takes values('60406', '561', '1', 'Fall', 2006, 'B+');
	insert into takes values('73072', '692', '1', 'Spring', 2010, 'C-');
	insert into takes values('28518', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('57985', '696', '1', 'Spring', 2002, 'A ');
	insert into takes values('89059', '748', '1', 'Fall', 2003, 'B-');
	insert into takes values('94569', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('31302', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('78767', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('31086', '489', '1', 'Fall', 2007, 'B ');
	insert into takes values('42388', '599', '1', 'Spring', 2003, 'A-');
	insert into takes values('24630', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('60040', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('43993', '867', '2', 'Fall', 2010, 'B-');
	insert into takes values('89234', '927', '1', 'Fall', 2002, 'A ');
	insert into takes values('17769', '843', '1', 'Fall', 2010, 'C+');
	insert into takes values('97101', '960', '2', 'Fall', 2006, 'A-');
	insert into takes values('9408', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('35042', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('28738', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('90234', '334', '1', 'Fall', 2009, 'B ');
	insert into takes values('99189', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('81884', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('36263', '642', '1', 'Fall', 2004, 'A-');
	insert into takes values('48589', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('70061', '443', '1', 'Spring', 2010, 'B ');
	insert into takes values('1533', '949', '1', 'Fall', 2007, 'B ');
	insert into takes values('12216', '401', '1', 'Fall', 2003, 'C-');
	insert into takes values('64249', '486', '1', 'Fall', 2009, 'A ');
	insert into takes values('75547', '270', '1', 'Spring', 2010, 'C+');
	insert into takes values('14032', '694', '1', 'Fall', 2002, 'B ');
	insert into takes values('27898', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('44703', '200', '2', 'Fall', 2002, 'B-');
	insert into takes values('51579', '408', '1', 'Spring', 2007, 'A-');
	insert into takes values('85746', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('85809', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('81028', '352', '1', 'Spring', 2006, 'C+');
	insert into takes values('27094', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('42019', '334', '1', 'Fall', 2009, 'A-');
	insert into takes values('56089', '864', '1', 'Spring', 2006, 'C+');
	insert into takes values('7204', '631', '1', 'Spring', 2007, 'A-');
	insert into takes values('88417', '319', '1', 'Spring', 2003, 'B ');
	insert into takes values('2286', '237', '2', 'Fall', 2009, 'A ');
	insert into takes values('18338', '663', '1', 'Spring', 2005, 'B-');
	insert into takes values('68453', '747', '1', 'Spring', 2004, 'C ');
	insert into takes values('15726', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('43505', '843', '1', 'Fall', 2010, 'C+');
	insert into takes values('52929', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('9084', '612', '1', 'Fall', 2007, 'A ');
	insert into takes values('97573', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('827', '486', '1', 'Fall', 2009, 'B ');
	insert into takes values('37734', '704', '1', 'Spring', 2008, 'A+');
	insert into takes values('48462', '319', '1', 'Spring', 2003, 'B-');
	insert into takes values('13217', '604', '1', 'Spring', 2009, 'B-');
	insert into takes values('39704', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('94815', '237', '2', 'Fall', 2009, 'C-');
	insert into takes values('78782', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('77415', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('41450', '843', '1', 'Fall', 2010, 'A ');
	insert into takes values('70362', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('41683', '972', '1', 'Spring', 2009, 'A+');
	insert into takes values('22086', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('50966', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('63502', '960', '1', 'Fall', 2009, 'B-');
	insert into takes values('8140', '893', '1', 'Fall', 2007, 'C ');
	insert into takes values('73186', '169', '1', 'Spring', 2007, 'C ');
	insert into takes values('27898', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('93061', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('83170', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('85614', '362', '3', 'Spring', 2008, 'C+');
	insert into takes values('26147', '927', '1', 'Fall', 2002, 'C+');
	insert into takes values('74070', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('96710', '489', '1', 'Fall', 2007, 'C ');
	insert into takes values('17769', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('30397', '760', '1', 'Spring', 2004, 'B+');
	insert into takes values('34404', '603', '1', 'Fall', 2003, 'A+');
	insert into takes values('95697', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('83398', '864', '1', 'Spring', 2006, 'C+');
	insert into takes values('11202', '426', '1', 'Spring', 2006, 'A ');
	insert into takes values('43032', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('99719', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('53547', '445', '1', 'Spring', 2001, 'B+');
	insert into takes values('13741', '696', '1', 'Spring', 2002, 'B+');
	insert into takes values('76291', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('42560', '169', '2', 'Fall', 2002, 'C ');
	insert into takes values('57377', '169', '2', 'Fall', 2002, 'B ');
	insert into takes values('29192', '313', '1', 'Fall', 2010, 'A+');
	insert into takes values('59538', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('32345', '338', '2', 'Spring', 2006, 'C+');
	insert into takes values('84654', '559', '1', 'Fall', 2002, 'B ');
	insert into takes values('60688', '239', '1', 'Fall', 2006, 'B-');
	insert into takes values('62549', '408', '1', 'Spring', 2007, 'A ');
	insert into takes values('81785', '960', '2', 'Fall', 2006, 'A ');
	insert into takes values('65121', '158', '1', 'Fall', 2008, 'C ');
	insert into takes values('71628', '735', '1', 'Spring', 2003, 'C-');
	insert into takes values('94535', '461', '1', 'Fall', 2002, 'C-');
	insert into takes values('97551', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('25718', '200', '1', 'Spring', 2007, 'A ');
	insert into takes values('68516', '893', '1', 'Fall', 2007, 'C ');
	insert into takes values('11377', '631', '1', 'Spring', 2007, 'B+');
	insert into takes values('75231', '735', '2', 'Spring', 2010, 'A-');
	insert into takes values('68330', '571', '1', 'Spring', 2004, 'B+');
	insert into takes values('88308', '604', '1', 'Spring', 2009, 'B ');
	insert into takes values('53172', '274', '1', 'Fall', 2002, 'C+');
	insert into takes values('91851', '137', '1', 'Spring', 2002, 'B ');
	insert into takes values('66484', '626', '1', 'Fall', 2006, 'B ');
	insert into takes values('36657', '237', '2', 'Fall', 2009, 'B+');
	insert into takes values('33201', '443', '1', 'Spring', 2010, 'A+');
	insert into takes values('8819', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('76250', '559', '1', 'Fall', 2002, 'B ');
	insert into takes values('38271', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('37809', '760', '1', 'Spring', 2004, 'C ');
	insert into takes values('98726', '408', '2', 'Spring', 2003, 'C-');
	insert into takes values('89188', '415', '1', 'Fall', 2010, 'C-');
	insert into takes values('56', '105', '1', 'Fall', 2009, 'A+');
	insert into takes values('56057', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('54875', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('56139', '366', '1', 'Fall', 2005, 'C ');
	insert into takes values('85575', '338', '2', 'Spring', 2006, 'B ');
	insert into takes values('10481', '581', '1', 'Spring', 2005, 'A+');
	insert into takes values('52187', '376', '1', 'Fall', 2006, 'A-');
	insert into takes values('53185', '692', '1', 'Spring', 2010, 'A-');
	insert into takes values('89196', '457', '1', 'Spring', 2001, 'C+');
	insert into takes values('23794', '468', '1', 'Fall', 2005, 'A-');
	insert into takes values('993', '457', '1', 'Spring', 2001, 'A+');
	insert into takes values('4015', '158', '2', 'Spring', 2008, 'B-');
	insert into takes values('52876', '274', '1', 'Fall', 2002, 'A+');
	insert into takes values('77130', '875', '1', 'Spring', 2005, 'C ');
	insert into takes values('10917', '239', '1', 'Fall', 2006, 'C+');
	insert into takes values('46441', '760', '1', 'Spring', 2004, 'C+');
	insert into takes values('85904', '793', '1', 'Spring', 2002, 'C+');
	insert into takes values('68248', '443', '2', 'Spring', 2002, 'C-');
	insert into takes values('46442', '401', '1', 'Fall', 2003, 'C+');
	insert into takes values('37715', '612', '1', 'Fall', 2007, 'B+');
	insert into takes values('73072', '443', '2', 'Spring', 2002, 'C ');
	insert into takes values('34392', '105', '2', 'Fall', 2002, 'B+');
	insert into takes values('31442', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('45680', '808', '1', 'Fall', 2003, 'A+');
	insert into takes values('19735', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('53185', '400', '1', 'Spring', 2007, 'A-');
	insert into takes values('15328', '158', '2', 'Spring', 2008, 'C-');
	insert into takes values('98047', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('12941', '974', '1', 'Fall', 2003, 'B-');
	insert into takes values('56941', '482', '1', 'Fall', 2005, 'A+');
	insert into takes values('70572', '457', '1', 'Spring', 2001, 'A-');
	insert into takes values('74473', '581', '1', 'Spring', 2005, 'B+');
	insert into takes values('93814', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('95201', '334', '1', 'Fall', 2009, 'B+');
	insert into takes values('25780', '338', '1', 'Spring', 2007, 'A ');
	insert into takes values('8343', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('7514', '237', '2', 'Fall', 2009, 'A-');
	insert into takes values('69732', '270', '1', 'Spring', 2010, 'C-');
	insert into takes values('33759', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('3127', '334', '1', 'Fall', 2009, 'B-');
	insert into takes values('70310', '960', '2', 'Fall', 2006, 'A-');
	insert into takes values('36019', '561', '1', 'Fall', 2006, 'A+');
	insert into takes values('83444', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('86404', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('48861', '461', '1', 'Fall', 2002, 'B ');
	insert into takes values('30161', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('17600', '694', '1', 'Fall', 2002, 'A ');
	insert into takes values('20540', '795', '1', 'Spring', 2004, 'B-');
	insert into takes values('48469', '599', '1', 'Spring', 2003, 'C+');
	insert into takes values('70384', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('49073', '545', '1', 'Fall', 2001, 'A ');
	insert into takes values('76799', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('16993', '612', '1', 'Fall', 2007, 'C ');
	insert into takes values('80227', '338', '1', 'Spring', 2007, 'C ');
	insert into takes values('28004', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('26619', '696', '1', 'Spring', 2002, 'C+');
	insert into takes values('1826', '626', '1', 'Fall', 2006, 'B+');
	insert into takes values('56299', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('3039', '362', '1', 'Fall', 2005, 'B ');
	insert into takes values('3639', '461', '1', 'Fall', 2002, 'B-');
	insert into takes values('3639', '748', '1', 'Fall', 2003, 'C ');
	insert into takes values('85849', '349', '1', 'Spring', 2008, 'A ');
	insert into takes values('20489', '443', '2', 'Spring', 2002, 'C+');
	insert into takes values('53077', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('94726', '802', '1', 'Spring', 2003, 'B+');
	insert into takes values('99660', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('3693', '476', '1', 'Fall', 2010, 'C-');
	insert into takes values('70918', '426', '1', 'Spring', 2006, 'A-');
	insert into takes values('76743', '991', '1', 'Spring', 2008, 'C-');
	insert into takes values('28994', '852', '1', 'Spring', 2008, 'C+');
	insert into takes values('91197', '893', '1', 'Fall', 2007, 'B-');
	insert into takes values('40738', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('18234', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('22003', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('61356', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('99764', '760', '1', 'Spring', 2004, 'A-');
	insert into takes values('70389', '599', '1', 'Spring', 2003, 'C+');
	insert into takes values('14214', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('11377', '468', '2', 'Fall', 2007, 'C+');
	insert into takes values('12214', '362', '1', 'Fall', 2005, 'B ');
	insert into takes values('15538', '457', '1', 'Spring', 2001, 'A-');
	insert into takes values('97868', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('98388', '313', '1', 'Fall', 2010, 'A-');
	insert into takes values('65901', '927', '1', 'Fall', 2002, 'B-');
	insert into takes values('86661', '960', '2', 'Fall', 2006, 'C ');
	insert into takes values('95631', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('82591', '875', '1', 'Spring', 2005, 'A ');
	insert into takes values('56089', '559', '1', 'Fall', 2002, 'C+');
	insert into takes values('73411', '735', '2', 'Spring', 2010, 'C ');
	insert into takes values('57135', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('667', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('76604', '808', '1', 'Fall', 2003, 'B ');
	insert into takes values('66293', '867', '1', 'Fall', 2006, 'B+');
	insert into takes values('11578', '927', '1', 'Fall', 2002, 'A+');
	insert into takes values('50206', '626', '1', 'Fall', 2006, 'A-');
	insert into takes values('41450', '496', '1', 'Fall', 2001, 'A-');
	insert into takes values('5871', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('98843', '735', '1', 'Spring', 2003, 'C-');
	insert into takes values('8853', '352', '1', 'Spring', 2006, 'C ');
	insert into takes values('51723', '362', '2', 'Fall', 2006, 'B-');
	insert into takes values('78581', '875', '1', 'Spring', 2005, 'C ');
	insert into takes values('80976', '334', '1', 'Fall', 2009, 'A ');
	insert into takes values('10904', '493', '1', 'Spring', 2010, 'C-');
	insert into takes values('61737', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('96722', '875', '1', 'Spring', 2005, 'A-');
	insert into takes values('67810', '376', '1', 'Fall', 2006, 'B ');
	insert into takes values('46441', '468', '1', 'Fall', 2005, 'B-');
	insert into takes values('74911', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('1922', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('57160', '421', '1', 'Fall', 2004, 'C-');
	insert into takes values('7514', '338', '2', 'Spring', 2006, 'B ');
	insert into takes values('26028', '443', '2', 'Spring', 2002, 'C+');
	insert into takes values('32419', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('57377', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('71529', '679', '1', 'Spring', 2010, 'B ');
	insert into takes values('32369', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('3693', '338', '1', 'Spring', 2007, 'A ');
	insert into takes values('47265', '893', '1', 'Fall', 2007, 'C ');
	insert into takes values('31516', '443', '2', 'Spring', 2002, 'C ');
	insert into takes values('69632', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('34158', '927', '1', 'Fall', 2002, 'B-');
	insert into takes values('34957', '349', '1', 'Spring', 2008, 'A ');
	insert into takes values('18583', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('17086', '468', '1', 'Fall', 2005, 'B+');
	insert into takes values('45720', '313', '1', 'Fall', 2010, 'A+');
	insert into takes values('39394', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('31080', '493', '1', 'Spring', 2010, 'A ');
	insert into takes values('78116', '747', '1', 'Spring', 2004, 'A ');
	insert into takes values('72055', '604', '1', 'Spring', 2009, 'A-');
	insert into takes values('68242', '972', '1', 'Spring', 2009, 'A+');
	insert into takes values('79329', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('90914', '949', '1', 'Fall', 2007, 'C ');
	insert into takes values('93004', '642', '1', 'Fall', 2004, 'C+');
	insert into takes values('23110', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('14628', '603', '1', 'Fall', 2003, 'B-');
	insert into takes values('21009', '239', '1', 'Fall', 2006, 'C+');
	insert into takes values('10269', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('88525', '169', '2', 'Fall', 2002, 'A-');
	insert into takes values('83314', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('66469', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('11057', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('82970', '461', '1', 'Fall', 2002, 'B ');
	insert into takes values('54153', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('31820', '702', '1', 'Spring', 2001, 'B-');
	insert into takes values('34957', '867', '1', 'Fall', 2006, 'B ');
	insert into takes values('123', '603', '1', 'Fall', 2003, 'A ');
	insert into takes values('50598', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('16075', '313', '1', 'Fall', 2010, 'A-');
	insert into takes values('99073', '581', '1', 'Spring', 2005, 'B+');
	insert into takes values('67407', '626', '1', 'Fall', 2006, 'A-');
	insert into takes values('11202', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('28829', '959', '1', 'Fall', 2006, 'A ');
	insert into takes values('29260', '496', '1', 'Fall', 2001, 'B+');
	insert into takes values('78787', '415', '1', 'Fall', 2010, 'B-');
	insert into takes values('24374', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('59117', '345', '1', 'Spring', 2008, 'A-');
	insert into takes values('93061', '629', '1', 'Spring', 2003, 'A ');
	insert into takes values('64593', '631', '1', 'Spring', 2007, 'B+');
	insert into takes values('84189', '105', '2', 'Fall', 2002, 'B+');
	insert into takes values('55000', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('37454', '313', '1', 'Fall', 2010, 'C ');
	insert into takes values('35293', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('20540', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('48861', '795', '1', 'Spring', 2004, 'B+');
	insert into takes values('68649', '561', '1', 'Fall', 2006, 'B+');
	insert into takes values('57962', '694', '1', 'Fall', 2002, 'B-');
	insert into takes values('31266', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('12711', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('48247', '760', '1', 'Spring', 2004, 'C ');
	insert into takes values('17831', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('53799', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('81876', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('73908', '421', '1', 'Fall', 2004, 'C+');
	insert into takes values('9460', '443', '2', 'Spring', 2002, 'C-');
	insert into takes values('6729', '702', '1', 'Spring', 2001, 'B-');
	insert into takes values('37586', '704', '1', 'Spring', 2008, 'C ');
	insert into takes values('53225', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('26881', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('79487', '893', '1', 'Fall', 2007, 'B-');
	insert into takes values('69581', '362', '3', 'Spring', 2008, 'C-');
	insert into takes values('86802', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('11262', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('16849', '581', '1', 'Spring', 2005, 'B+');
	insert into takes values('17665', '561', '1', 'Fall', 2006, 'B+');
	insert into takes values('41345', '362', '1', 'Fall', 2005, 'C ');
	insert into takes values('97868', '843', '1', 'Fall', 2010, 'B-');
	insert into takes values('49792', '457', '1', 'Spring', 2001, 'C+');
	insert into takes values('63860', '376', '1', 'Fall', 2006, 'A ');
	insert into takes values('56143', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('39394', '313', '1', 'Fall', 2010, 'B ');
	insert into takes values('9495', '158', '2', 'Spring', 2008, 'A ');
	insert into takes values('23344', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('18338', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('30252', '338', '1', 'Spring', 2007, 'A ');
	insert into takes values('38895', '313', '1', 'Fall', 2010, 'B-');
	insert into takes values('73213', '426', '1', 'Spring', 2006, 'B ');
	insert into takes values('96193', '169', '2', 'Fall', 2002, 'A ');
	insert into takes values('27556', '362', '3', 'Spring', 2008, 'C+');
	insert into takes values('21552', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('84495', '692', '1', 'Spring', 2010, 'C ');
	insert into takes values('16593', '867', '1', 'Fall', 2006, 'A ');
	insert into takes values('27727', '468', '2', 'Fall', 2007, 'B ');
	insert into takes values('69730', '867', '1', 'Fall', 2006, 'C+');
	insert into takes values('19862', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('96153', '591', '1', 'Spring', 2005, 'B-');
	insert into takes values('39114', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('14581', '376', '1', 'Fall', 2006, 'C+');
	insert into takes values('31486', '242', '1', 'Fall', 2009, 'A+');
	insert into takes values('74016', '421', '1', 'Fall', 2004, 'B-');
	insert into takes values('66106', '692', '1', 'Spring', 2010, 'C+');
	insert into takes values('4355', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('97590', '400', '1', 'Spring', 2007, 'C-');
	insert into takes values('63645', '612', '1', 'Fall', 2007, 'A ');
	insert into takes values('89140', '704', '1', 'Spring', 2008, 'C ');
	insert into takes values('90004', '748', '1', 'Fall', 2003, 'B-');
	insert into takes values('95046', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('35293', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('13757', '679', '1', 'Spring', 2010, 'A ');
	insert into takes values('78469', '169', '2', 'Fall', 2002, 'A+');
	insert into takes values('82301', '927', '1', 'Fall', 2002, 'A ');
	insert into takes values('59290', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('2286', '408', '2', 'Spring', 2003, 'B ');
	insert into takes values('38668', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('12941', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('22179', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('3005', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('19824', '679', '1', 'Spring', 2010, 'C+');
	insert into takes values('49873', '702', '1', 'Spring', 2001, 'A-');
	insert into takes values('59397', '867', '2', 'Fall', 2010, 'A+');
	insert into takes values('57941', '421', '1', 'Fall', 2004, 'B-');
	insert into takes values('72177', '304', '1', 'Fall', 2009, 'A+');
	insert into takes values('22086', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('84495', '237', '2', 'Fall', 2009, 'A ');
	insert into takes values('21225', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('70389', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('25525', '791', '1', 'Spring', 2006, 'C+');
	insert into takes values('41280', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('95366', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('21009', '631', '1', 'Spring', 2007, 'B ');
	insert into takes values('69952', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('38895', '270', '1', 'Spring', 2010, 'C-');
	insert into takes values('16593', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('7204', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('13365', '137', '1', 'Spring', 2002, 'B+');
	insert into takes values('6287', '482', '1', 'Fall', 2005, 'B-');
	insert into takes values('43912', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('74639', '237', '1', 'Spring', 2008, 'A-');
	insert into takes values('81028', '274', '1', 'Fall', 2002, 'B ');
	insert into takes values('46260', '663', '1', 'Spring', 2005, 'A-');
	insert into takes values('34126', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('55170', '591', '1', 'Spring', 2005, 'B-');
	insert into takes values('35935', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('66484', '258', '1', 'Fall', 2007, 'A-');
	insert into takes values('88553', '864', '1', 'Spring', 2006, 'A ');
	insert into takes values('95284', '972', '1', 'Spring', 2009, 'A-');
	insert into takes values('62795', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('33759', '704', '1', 'Spring', 2008, 'A+');
	insert into takes values('45817', '559', '1', 'Fall', 2002, 'A ');
	insert into takes values('46981', '760', '1', 'Spring', 2004, 'C+');
	insert into takes values('99611', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('77021', '962', '1', 'Spring', 2008, 'A+');
	insert into takes values('96968', '802', '1', 'Spring', 2003, 'A+');
	insert into takes values('18740', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('30299', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('8252', '496', '1', 'Fall', 2001, 'C ');
	insert into takes values('32772', '401', '1', 'Fall', 2003, 'A ');
	insert into takes values('98870', '426', '1', 'Spring', 2006, 'A-');
	insert into takes values('50331', '270', '1', 'Spring', 2010, 'C+');
	insert into takes values('74672', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('39925', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('92442', '362', '3', 'Spring', 2008, 'C+');
	insert into takes values('38696', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('8843', '571', '1', 'Spring', 2004, 'C+');
	insert into takes values('9460', '486', '1', 'Fall', 2009, 'A ');
	insert into takes values('22532', '696', '1', 'Spring', 2002, 'C ');
	insert into takes values('40178', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('78572', '735', '2', 'Spring', 2010, 'B-');
	insert into takes values('27094', '486', '1', 'Fall', 2009, 'A-');
	insert into takes values('41827', '735', '2', 'Spring', 2010, 'A ');
	insert into takes values('58307', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('41491', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('78756', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('39925', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('27043', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('10033', '445', '1', 'Spring', 2001, 'C ');
	insert into takes values('53799', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('91197', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('48462', '349', '1', 'Spring', 2008, 'A ');
	insert into takes values('62754', '663', '1', 'Spring', 2005, 'B ');
	insert into takes values('13504', '468', '1', 'Fall', 2005, 'A-');
	insert into takes values('64914', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('18709', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('77000', '468', '2', 'Fall', 2007, 'B ');
	insert into takes values('61003', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('14214', '334', '1', 'Fall', 2009, 'C ');
	insert into takes values('12216', '421', '1', 'Fall', 2004, 'B-');
	insert into takes values('52523', '401', '1', 'Fall', 2003, 'A-');
	insert into takes values('55009', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('18499', '461', '1', 'Fall', 2002, 'B+');
	insert into takes values('90372', '735', '1', 'Spring', 2003, 'A+');
	insert into takes values('14284', '486', '1', 'Fall', 2009, 'B-');
	insert into takes values('53805', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('38902', '875', '1', 'Spring', 2005, 'B-');
	insert into takes values('32065', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('94142', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('60267', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('53424', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('41890', '237', '1', 'Spring', 2008, 'B ');
	insert into takes values('91197', '304', '1', 'Fall', 2009, 'A ');
	insert into takes values('8251', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('34055', '476', '1', 'Fall', 2010, 'C ');
	insert into takes values('29140', '415', '1', 'Fall', 2010, 'B ');
	insert into takes values('67810', '591', '1', 'Spring', 2005, 'B-');
	insert into takes values('4015', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('62749', '959', '1', 'Fall', 2006, 'A+');
	insert into takes values('57055', '760', '1', 'Spring', 2004, 'B+');
	insert into takes values('4345', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('76895', '496', '1', 'Fall', 2001, 'B ');
	insert into takes values('72177', '626', '1', 'Fall', 2006, 'C+');
	insert into takes values('58170', '362', '3', 'Spring', 2008, 'B ');
	insert into takes values('65144', '626', '1', 'Fall', 2006, 'C+');
	insert into takes values('45494', '237', '1', 'Spring', 2008, 'C+');
	insert into takes values('28994', '747', '1', 'Spring', 2004, 'C-');
	insert into takes values('68010', '482', '1', 'Fall', 2005, 'B ');
	insert into takes values('61354', '747', '1', 'Spring', 2004, 'C-');
	insert into takes values('81638', '400', '2', 'Fall', 2003, 'C+');
	insert into takes values('52076', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('41674', '561', '1', 'Fall', 2006, 'B-');
	insert into takes values('67560', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('1402', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('30177', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('59117', '338', '2', 'Spring', 2006, 'A-');
	insert into takes values('69241', '893', '1', 'Fall', 2007, 'C+');
	insert into takes values('74974', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('66763', '443', '2', 'Spring', 2002, 'B-');
	insert into takes values('89551', '852', '1', 'Spring', 2008, 'C ');
	insert into takes values('98019', '808', '1', 'Fall', 2003, 'A-');
	insert into takes values('7602', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('7035', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('49701', '345', '1', 'Spring', 2008, 'A ');
	insert into takes values('36052', '158', '1', 'Fall', 2008, 'B-');
	insert into takes values('35175', '239', '1', 'Fall', 2006, 'B ');
	insert into takes values('59673', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('32056', '400', '1', 'Spring', 2007, 'C ');
	insert into takes values('16993', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('39521', '457', '1', 'Spring', 2001, 'C+');
	insert into takes values('41741', '489', '1', 'Fall', 2007, 'A-');
	insert into takes values('90181', '748', '1', 'Fall', 2003, 'C-');
	insert into takes values('35138', '694', '1', 'Fall', 2002, 'A ');
	insert into takes values('32886', '192', '1', 'Fall', 2002, 'A+');
	insert into takes values('71543', '867', '1', 'Fall', 2006, 'C+');
	insert into takes values('22532', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('56', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('64067', '426', '1', 'Spring', 2006, 'A+');
	insert into takes values('91580', '242', '1', 'Fall', 2009, 'A+');
	insert into takes values('81610', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('52157', '105', '1', 'Fall', 2009, 'C ');
	insert into takes values('978', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('31516', '468', '1', 'Fall', 2005, 'C ');
	insert into takes values('79763', '802', '1', 'Spring', 2003, 'B+');
	insert into takes values('53469', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('2286', '401', '1', 'Fall', 2003, 'A-');
	insert into takes values('78581', '960', '1', 'Fall', 2009, 'B ');
	insert into takes values('65703', '137', '1', 'Spring', 2002, 'B+');
	insert into takes values('81610', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('94535', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('52471', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('56', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('8843', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('36384', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('9659', '571', '1', 'Spring', 2004, 'C-');
	insert into takes values('99719', '242', '1', 'Fall', 2009, 'A-');
	insert into takes values('48678', '760', '1', 'Spring', 2004, 'A ');
	insert into takes values('68554', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('52750', '313', '1', 'Fall', 2010, 'C-');
	insert into takes values('69241', '696', '1', 'Spring', 2002, 'C+');
	insert into takes values('90814', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('65241', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('98690', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('79487', '760', '1', 'Spring', 2004, 'B+');
	insert into takes values('51238', '864', '1', 'Spring', 2006, 'B ');
	insert into takes values('99977', '599', '1', 'Spring', 2003, 'A-');
	insert into takes values('14023', '408', '1', 'Spring', 2007, 'C-');
	insert into takes values('33837', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('49244', '169', '1', 'Spring', 2007, 'B ');
	insert into takes values('38476', '760', '1', 'Spring', 2004, 'B ');
	insert into takes values('3335', '137', '1', 'Spring', 2002, 'A-');
	insert into takes values('14432', '200', '1', 'Spring', 2007, 'B-');
	insert into takes values('61065', '137', '1', 'Spring', 2002, 'A ');
	insert into takes values('63390', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('4355', '631', '1', 'Spring', 2007, 'C+');
	insert into takes values('59172', '599', '1', 'Spring', 2003, 'B ');
	insert into takes values('96772', '545', '1', 'Fall', 2001, 'A-');
	insert into takes values('82580', '748', '1', 'Fall', 2003, 'C-');
	insert into takes values('35462', '366', '1', 'Fall', 2005, 'B ');
	insert into takes values('898', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('53152', '237', '2', 'Fall', 2009, 'C-');
	insert into takes values('31820', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('19848', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('11055', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('888', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('48462', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('6729', '366', '1', 'Fall', 2005, 'A ');
	insert into takes values('81638', '527', '1', 'Fall', 2004, 'A-');
	insert into takes values('53799', '545', '1', 'Fall', 2001, 'A-');
	insert into takes values('65438', '486', '1', 'Fall', 2009, 'A ');
	insert into takes values('6304', '599', '1', 'Spring', 2003, 'C+');
	insert into takes values('73606', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('35042', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('44206', '571', '1', 'Spring', 2004, 'A+');
	insert into takes values('56143', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('17769', '747', '1', 'Spring', 2004, 'B-');
	insert into takes values('47001', '169', '1', 'Spring', 2007, 'A-');
	insert into takes values('49073', '443', '2', 'Spring', 2002, 'C+');
	insert into takes values('40178', '169', '2', 'Fall', 2002, 'B+');
	insert into takes values('74070', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('44706', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('88577', '408', '2', 'Spring', 2003, 'B ');
	insert into takes values('86641', '692', '1', 'Spring', 2010, 'A-');
	insert into takes values('2970', '468', '2', 'Fall', 2007, 'B ');
	insert into takes values('69679', '468', '1', 'Fall', 2005, 'B-');
	insert into takes values('86327', '426', '1', 'Spring', 2006, 'B ');
	insert into takes values('21766', '591', '1', 'Spring', 2005, 'C-');
	insert into takes values('43989', '559', '1', 'Fall', 2002, 'A ');
	insert into takes values('72979', '304', '1', 'Fall', 2009, 'B+');
	insert into takes values('14668', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('48850', '599', '1', 'Spring', 2003, 'A-');
	insert into takes values('90567', '489', '1', 'Fall', 2007, 'C ');
	insert into takes values('30252', '239', '1', 'Fall', 2006, 'C+');
	insert into takes values('77580', '704', '1', 'Spring', 2008, 'B ');
	insert into takes values('71630', '482', '1', 'Fall', 2005, 'B ');
	insert into takes values('43505', '496', '1', 'Fall', 2001, 'C ');
	insert into takes values('66494', '843', '1', 'Fall', 2010, 'A+');
	insert into takes values('84515', '408', '1', 'Spring', 2007, 'A ');
	insert into takes values('80248', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('79329', '200', '2', 'Fall', 2002, 'A-');
	insert into takes values('44258', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('21556', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('5824', '415', '1', 'Fall', 2010, 'A+');
	insert into takes values('34422', '274', '1', 'Fall', 2002, 'A+');
	insert into takes values('93043', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('5617', '735', '1', 'Spring', 2003, 'A+');
	insert into takes values('16753', '401', '1', 'Fall', 2003, 'A-');
	insert into takes values('42956', '599', '1', 'Spring', 2003, 'B-');
	insert into takes values('49450', '748', '1', 'Fall', 2003, 'B-');
	insert into takes values('53225', '748', '1', 'Fall', 2003, 'C ');
	insert into takes values('78787', '527', '1', 'Fall', 2004, 'A-');
	insert into takes values('11152', '561', '1', 'Fall', 2006, 'A+');
	insert into takes values('7149', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('81550', '679', '1', 'Spring', 2010, 'C+');
	insert into takes values('57431', '443', '1', 'Spring', 2010, 'B-');
	insert into takes values('75938', '421', '1', 'Fall', 2004, 'C ');
	insert into takes values('68395', '972', '1', 'Spring', 2009, 'B+');
	insert into takes values('40932', '376', '1', 'Fall', 2006, 'B ');
	insert into takes values('79352', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('85754', '843', '1', 'Fall', 2010, 'A-');
	insert into takes values('38476', '559', '1', 'Fall', 2002, 'B+');
	insert into takes values('86802', '334', '1', 'Fall', 2009, 'B-');
	insert into takes values('51997', '445', '1', 'Spring', 2001, 'B-');
	insert into takes values('58701', '486', '1', 'Fall', 2009, 'B ');
	insert into takes values('83686', '158', '1', 'Fall', 2008, 'A+');
	insert into takes values('49280', '852', '1', 'Spring', 2008, 'A-');
	insert into takes values('827', '692', '1', 'Spring', 2010, 'A ');
	insert into takes values('56499', '972', '1', 'Spring', 2009, 'A+');
	insert into takes values('20099', '802', '1', 'Spring', 2003, 'C-');
	insert into takes values('97042', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('39472', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('80742', '527', '1', 'Fall', 2004, 'B-');
	insert into takes values('99268', '408', '2', 'Spring', 2003, 'B-');
	insert into takes values('57474', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('80248', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('25611', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('22003', '626', '1', 'Fall', 2006, 'B ');
	insert into takes values('21789', '237', '1', 'Spring', 2008, 'B-');
	insert into takes values('43495', '400', '1', 'Spring', 2007, 'C-');
	insert into takes values('13290', '352', '1', 'Spring', 2006, 'C+');
	insert into takes values('87439', '401', '1', 'Fall', 2003, 'C-');
	insert into takes values('68248', '795', '1', 'Spring', 2004, 'C+');
	insert into takes values('1402', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('84189', '400', '1', 'Spring', 2007, 'C-');
	insert into takes values('62716', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('18675', '200', '1', 'Spring', 2007, 'B+');
	insert into takes values('99369', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('81396', '258', '1', 'Fall', 2007, 'B+');
	insert into takes values('93171', '949', '1', 'Fall', 2007, 'A-');
	insert into takes values('56078', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('37350', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('81789', '158', '2', 'Spring', 2008, 'B+');
	insert into takes values('58413', '400', '1', 'Spring', 2007, 'B ');
	insert into takes values('61127', '559', '1', 'Fall', 2002, 'C+');
	insert into takes values('50743', '599', '1', 'Spring', 2003, 'A ');
	insert into takes values('82591', '362', '1', 'Fall', 2005, 'C-');
	insert into takes values('6710', '304', '1', 'Fall', 2009, 'B ');
	insert into takes values('57925', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('57985', '893', '1', 'Fall', 2007, 'B+');
	insert into takes values('41261', '599', '1', 'Spring', 2003, 'A ');
	insert into takes values('97101', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('79911', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('21395', '696', '1', 'Spring', 2002, 'B ');
	insert into takes values('16523', '663', '1', 'Spring', 2005, 'B-');
	insert into takes values('42019', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('52157', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('15698', '366', '1', 'Fall', 2005, 'B ');
	insert into takes values('42560', '875', '1', 'Spring', 2005, 'C-');
	insert into takes values('51955', '158', '1', 'Fall', 2008, 'C ');
	insert into takes values('21225', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('69307', '631', '1', 'Spring', 2007, 'B ');
	insert into takes values('8860', '366', '1', 'Fall', 2005, 'C-');
	insert into takes values('15144', '864', '1', 'Spring', 2006, 'A+');
	insert into takes values('64934', '571', '1', 'Spring', 2004, 'C+');
	insert into takes values('27002', '401', '1', 'Fall', 2003, 'A ');
	insert into takes values('91992', '561', '1', 'Fall', 2006, 'B+');
	insert into takes values('59530', '631', '1', 'Spring', 2007, 'C-');
	insert into takes values('38902', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('77289', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('29871', '258', '1', 'Fall', 2007, 'C+');
	insert into takes values('61403', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('96324', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('53048', '169', '2', 'Fall', 2002, 'B+');
	insert into takes values('86375', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('99399', '960', '1', 'Fall', 2009, 'C-');
	insert into takes values('86806', '445', '1', 'Spring', 2001, 'A-');
	insert into takes values('23110', '760', '1', 'Spring', 2004, 'B ');
	insert into takes values('82687', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('95574', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('5961', '362', '2', 'Fall', 2006, 'B-');
	insert into takes values('72669', '735', '1', 'Spring', 2003, 'C+');
	insert into takes values('50944', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('8819', '692', '1', 'Spring', 2010, 'A+');
	insert into takes values('99226', '401', '1', 'Fall', 2003, 'A+');
	insert into takes values('544', '604', '1', 'Spring', 2009, 'B+');
	insert into takes values('11455', '493', '1', 'Spring', 2010, 'A ');
	insert into takes values('35220', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('96968', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('89312', '571', '1', 'Spring', 2004, 'C-');
	insert into takes values('35462', '376', '1', 'Fall', 2006, 'B-');
	insert into takes values('96710', '421', '1', 'Fall', 2004, 'B+');
	insert into takes values('95859', '237', '2', 'Fall', 2009, 'C-');
	insert into takes values('18234', '445', '1', 'Spring', 2001, 'B-');
	insert into takes values('62754', '270', '1', 'Spring', 2010, 'C ');
	insert into takes values('33349', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('40044', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('54605', '338', '2', 'Spring', 2006, 'C ');
	insert into takes values('69783', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('65901', '362', '3', 'Spring', 2008, 'C-');
	insert into takes values('87706', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('65715', '415', '1', 'Fall', 2010, 'B-');
	insert into takes values('75040', '591', '1', 'Spring', 2005, 'A ');
	insert into takes values('71529', '468', '2', 'Fall', 2007, 'C-');
	insert into takes values('14581', '561', '1', 'Fall', 2006, 'C ');
	insert into takes values('60249', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('63040', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('5463', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('39876', '612', '1', 'Fall', 2007, 'A ');
	insert into takes values('3127', '345', '1', 'Spring', 2008, 'C-');
	insert into takes values('51868', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('31250', '200', '2', 'Fall', 2002, 'A-');
	insert into takes values('36513', '960', '1', 'Fall', 2009, 'B ');
	insert into takes values('72521', '338', '1', 'Spring', 2007, 'B ');
	insert into takes values('15328', '793', '1', 'Spring', 2002, 'A ');
	insert into takes values('51723', '843', '1', 'Fall', 2010, 'A ');
	insert into takes values('3576', '169', '1', 'Spring', 2007, 'A ');
	insert into takes values('24442', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('87222', '415', '1', 'Fall', 2010, 'B-');
	insert into takes values('34195', '242', '1', 'Fall', 2009, 'C+');
	insert into takes values('18675', '443', '1', 'Spring', 2010, 'A ');
	insert into takes values('85981', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('96178', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('81150', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('50969', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('80976', '319', '1', 'Spring', 2003, 'C-');
	insert into takes values('57238', '468', '2', 'Fall', 2007, 'C-');
	insert into takes values('10904', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('14284', '105', '2', 'Fall', 2002, 'B+');
	insert into takes values('76057', '169', '1', 'Spring', 2007, 'B+');
	insert into takes values('1826', '629', '1', 'Spring', 2003, 'B+');
	insert into takes values('23500', '962', '1', 'Spring', 2008, 'A ');
	insert into takes values('80799', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('10076', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('16453', '457', '1', 'Spring', 2001, 'C-');
	insert into takes values('69732', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('26028', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('70965', '237', '2', 'Fall', 2009, 'C+');
	insert into takes values('60406', '468', '2', 'Fall', 2007, 'C+');
	insert into takes values('23110', '867', '2', 'Fall', 2010, 'C-');
	insert into takes values('52741', '445', '1', 'Spring', 2001, 'B+');
	insert into takes values('98843', '692', '1', 'Spring', 2010, 'B-');
	insert into takes values('39157', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('16969', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('18007', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('20084', '603', '1', 'Fall', 2003, 'B-');
	insert into takes values('14874', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('22417', '561', '1', 'Fall', 2006, 'A ');
	insert into takes values('59920', '748', '1', 'Fall', 2003, 'A-');
	insert into takes values('81883', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('25468', '345', '1', 'Spring', 2008, 'B-');
	insert into takes values('5336', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('1080', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('29239', '631', '1', 'Spring', 2007, 'A ');
	insert into takes values('33791', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('58595', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('91992', '105', '1', 'Fall', 2009, 'C ');
	insert into takes values('40738', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('1726', '362', '3', 'Spring', 2008, 'C-');
	insert into takes values('21552', '345', '1', 'Spring', 2008, 'C+');
	insert into takes values('40481', '408', '2', 'Spring', 2003, 'A ');
	insert into takes values('22532', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('4248', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('59553', '692', '1', 'Spring', 2010, 'A+');
	insert into takes values('57083', '962', '1', 'Spring', 2008, 'A+');
	insert into takes values('94836', '426', '1', 'Spring', 2006, 'A+');
	insert into takes values('16907', '242', '1', 'Fall', 2009, 'C ');
	insert into takes values('41675', '991', '1', 'Spring', 2008, 'C-');
	insert into takes values('45770', '401', '1', 'Fall', 2003, 'C-');
	insert into takes values('91851', '496', '1', 'Fall', 2001, 'B+');
	insert into takes values('40044', '991', '1', 'Spring', 2008, 'B-');
	insert into takes values('69285', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('12236', '169', '2', 'Fall', 2002, 'B-');
	insert into takes values('78892', '338', '1', 'Spring', 2007, 'B-');
	insert into takes values('87439', '468', '2', 'Fall', 2007, 'B ');
	insert into takes values('90914', '867', '1', 'Fall', 2006, 'B+');
	insert into takes values('81896', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('14639', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('14499', '421', '1', 'Fall', 2004, 'C ');
	insert into takes values('90089', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('76604', '274', '1', 'Fall', 2002, 'C+');
	insert into takes values('45817', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('24197', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('31079', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('61364', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('63886', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('49450', '631', '1', 'Spring', 2007, 'B+');
	insert into takes values('50658', '443', '2', 'Spring', 2002, 'A+');
	insert into takes values('22325', '747', '1', 'Spring', 2004, 'C ');
	insert into takes values('63489', '591', '1', 'Spring', 2005, 'A+');
	insert into takes values('48850', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('41988', '408', '2', 'Spring', 2003, 'C ');
	insert into takes values('38545', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('91978', '237', '1', 'Spring', 2008, 'C-');
	insert into takes values('84239', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('37284', '258', '1', 'Fall', 2007, 'C ');
	insert into takes values('68649', '445', '1', 'Spring', 2001, 'B+');
	insert into takes values('42388', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('30858', '591', '1', 'Spring', 2005, 'A ');
	insert into takes values('4355', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('40897', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('86404', '893', '1', 'Fall', 2007, 'B-');
	insert into takes values('56849', '694', '1', 'Fall', 2002, 'A ');
	insert into takes values('85234', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('259', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('62429', '571', '1', 'Spring', 2004, 'A+');
	insert into takes values('41818', '258', '1', 'Fall', 2007, 'C ');
	insert into takes values('14023', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('42019', '237', '1', 'Spring', 2008, 'B ');
	insert into takes values('33107', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('41741', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('59848', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('8483', '366', '1', 'Fall', 2005, 'A ');
	insert into takes values('17997', '962', '1', 'Spring', 2008, 'A+');
	insert into takes values('94814', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('86651', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('70061', '559', '1', 'Fall', 2002, 'C+');
	insert into takes values('22050', '561', '1', 'Fall', 2006, 'A+');
	insert into takes values('42625', '581', '1', 'Spring', 2005, 'C+');
	insert into takes values('65901', '105', '1', 'Fall', 2009, 'B+');
	insert into takes values('86344', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('15070', '258', '1', 'Fall', 2007, 'C+');
	insert into takes values('3639', '468', '1', 'Fall', 2005, 'B+');
	insert into takes values('11194', '893', '1', 'Fall', 2007, 'A-');
	insert into takes values('336', '843', '1', 'Fall', 2010, 'B+');
	insert into takes values('18469', '400', '1', 'Spring', 2007, 'C+');
	insert into takes values('42560', '527', '1', 'Fall', 2004, 'C+');
	insert into takes values('57431', '793', '1', 'Spring', 2002, 'B ');
	insert into takes values('48165', '338', '1', 'Spring', 2007, 'A ');
	insert into takes values('60748', '972', '1', 'Spring', 2009, 'A-');
	insert into takes values('39892', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('25362', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('63886', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('97694', '258', '1', 'Fall', 2007, 'C ');
	insert into takes values('16347', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('27236', '345', '1', 'Spring', 2008, 'B-');
	insert into takes values('77000', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('98984', '493', '1', 'Spring', 2010, 'B+');
	insert into takes values('50467', '591', '1', 'Spring', 2005, 'B+');
	insert into takes values('95320', '401', '1', 'Fall', 2003, 'A-');
	insert into takes values('64196', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('1000', '571', '1', 'Spring', 2004, 'C+');
	insert into takes values('4004', '468', '2', 'Fall', 2007, 'B ');
	insert into takes values('84845', '319', '1', 'Spring', 2003, 'C+');
	insert into takes values('74911', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('59920', '338', '1', 'Spring', 2007, 'B ');
	insert into takes values('25187', '974', '1', 'Fall', 2003, 'C ');
	insert into takes values('20985', '482', '1', 'Fall', 2005, 'B-');
	insert into takes values('71389', '242', '1', 'Fall', 2009, 'B ');
	insert into takes values('14094', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('75878', '468', '2', 'Fall', 2007, 'A+');
	insert into takes values('37869', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('56499', '105', '1', 'Fall', 2009, 'A+');
	insert into takes values('59397', '604', '1', 'Spring', 2009, 'B-');
	insert into takes values('43123', '893', '1', 'Fall', 2007, 'A-');
	insert into takes values('29707', '626', '1', 'Fall', 2006, 'A ');
	insert into takes values('37653', '338', '1', 'Spring', 2007, 'B-');
	insert into takes values('52187', '349', '1', 'Spring', 2008, 'B+');
	insert into takes values('56143', '468', '2', 'Fall', 2007, 'C-');
	insert into takes values('52371', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('35935', '237', '1', 'Spring', 2008, 'B-');
	insert into takes values('10693', '376', '1', 'Fall', 2006, 'C ');
	insert into takes values('23270', '527', '1', 'Fall', 2004, 'C ');
	insert into takes values('24746', '352', '1', 'Spring', 2006, 'B+');
	insert into takes values('18469', '426', '1', 'Spring', 2006, 'A+');
	insert into takes values('16297', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('80651', '629', '1', 'Spring', 2003, 'B-');
	insert into takes values('38691', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('10454', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('69581', '949', '1', 'Fall', 2007, 'A-');
	insert into takes values('30723', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('7035', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('23110', '496', '1', 'Fall', 2001, 'A-');
	insert into takes values('77588', '461', '1', 'Fall', 2002, 'C+');
	insert into takes values('75772', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('97435', '486', '1', 'Fall', 2009, 'A-');
	insert into takes values('33349', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('83444', '694', '1', 'Fall', 2002, 'B-');
	insert into takes values('11510', '237', '1', 'Spring', 2008, 'B-');
	insert into takes values('89051', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('55170', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('19321', '960', '1', 'Fall', 2009, 'B ');
	insert into takes values('13511', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('36845', '612', '1', 'Fall', 2007, 'A-');
	insert into takes values('10814', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('96227', '631', '1', 'Spring', 2007, 'B+');
	insert into takes values('5336', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('29192', '352', '1', 'Spring', 2006, 'B+');
	insert into takes values('22325', '349', '1', 'Spring', 2008, 'B+');
	insert into takes values('38476', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('65563', '200', '1', 'Spring', 2007, 'B-');
	insert into takes values('20180', '972', '1', 'Spring', 2009, 'B-');
	insert into takes values('15283', '258', '1', 'Fall', 2007, 'C+');
	insert into takes values('11455', '642', '1', 'Fall', 2004, 'C+');
	insert into takes values('14628', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('67542', '242', '1', 'Fall', 2009, 'A+');
	insert into takes values('83022', '158', '2', 'Spring', 2008, 'C-');
	insert into takes values('11578', '747', '1', 'Spring', 2004, 'C-');
	insert into takes values('1954', '735', '1', 'Spring', 2003, 'C ');
	insert into takes values('90779', '867', '2', 'Fall', 2010, 'A+');
	insert into takes values('92442', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('57377', '376', '1', 'Fall', 2006, 'C ');
	insert into takes values('18007', '421', '1', 'Fall', 2004, 'A-');
	insert into takes values('46450', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('5898', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('74911', '591', '1', 'Spring', 2005, 'C-');
	insert into takes values('55286', '489', '1', 'Fall', 2007, 'B-');
	insert into takes values('99463', '461', '1', 'Fall', 2002, 'C+');
	insert into takes values('14829', '612', '1', 'Fall', 2007, 'B+');
	insert into takes values('63645', '679', '1', 'Spring', 2010, 'A+');
	insert into takes values('59530', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('72006', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('72177', '457', '1', 'Spring', 2001, 'B+');
	insert into takes values('78572', '362', '1', 'Fall', 2005, 'C ');
	insert into takes values('30896', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('40992', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('74840', '362', '1', 'Fall', 2005, 'B ');
	insert into takes values('79697', '258', '1', 'Fall', 2007, 'C+');
	insert into takes values('30164', '489', '1', 'Fall', 2007, 'B-');
	insert into takes values('61402', '694', '1', 'Fall', 2002, 'C+');
	insert into takes values('31690', '496', '1', 'Fall', 2001, 'B+');
	insert into takes values('29871', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('41683', '421', '1', 'Fall', 2004, 'B+');
	insert into takes values('87268', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('54612', '545', '1', 'Fall', 2001, 'A-');
	insert into takes values('37430', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('56499', '445', '1', 'Spring', 2001, 'B-');
	insert into takes values('24325', '258', '1', 'Fall', 2007, 'B+');
	insert into takes values('88045', '334', '1', 'Fall', 2009, 'B+');
	insert into takes values('29140', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('88085', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('54672', '476', '1', 'Fall', 2010, 'B ');
	insert into takes values('42956', '561', '1', 'Fall', 2006, 'C-');
	insert into takes values('79763', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('8347', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('30177', '960', '1', 'Fall', 2009, 'C-');
	insert into takes values('13365', '679', '1', 'Spring', 2010, 'B-');
	insert into takes values('65563', '864', '1', 'Spring', 2006, 'C+');
	insert into takes values('65400', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('75423', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('83696', '791', '1', 'Spring', 2006, 'A ');
	insert into takes values('36384', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('46066', '457', '1', 'Spring', 2001, 'A+');
	insert into takes values('1968', '239', '1', 'Fall', 2006, 'A-');
	insert into takes values('46260', '571', '1', 'Spring', 2004, 'B+');
	insert into takes values('22417', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('82301', '362', '2', 'Fall', 2006, 'A ');
	insert into takes values('60267', '313', '1', 'Fall', 2010, 'B-');
	insert into takes values('51553', '663', '1', 'Spring', 2005, 'A-');
	insert into takes values('1367', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('95175', '603', '1', 'Fall', 2003, 'B-');
	insert into takes values('61081', '561', '1', 'Fall', 2006, 'B+');
	insert into takes values('43032', '489', '1', 'Fall', 2007, 'A ');
	insert into takes values('15249', '345', '1', 'Spring', 2008, 'A+');
	insert into takes values('31337', '599', '1', 'Spring', 2003, 'B ');
	insert into takes values('57135', '158', '2', 'Spring', 2008, 'C ');
	insert into takes values('78792', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('51579', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('77548', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('94766', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('73072', '242', '1', 'Fall', 2009, 'B ');
	insert into takes values('98690', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('57083', '527', '1', 'Fall', 2004, 'C ');
	insert into takes values('67407', '401', '1', 'Fall', 2003, 'C-');
	insert into takes values('74016', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('71426', '486', '1', 'Fall', 2009, 'C+');
	insert into takes values('18234', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('38676', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('39310', '457', '1', 'Spring', 2001, 'C-');
	insert into takes values('41261', '270', '1', 'Spring', 2010, 'A+');
	insert into takes values('71628', '334', '1', 'Fall', 2009, 'B+');
	insert into takes values('32772', '200', '2', 'Fall', 2002, 'B+');
	insert into takes values('11966', '493', '1', 'Spring', 2010, 'B ');
	insert into takes values('93039', '158', '2', 'Spring', 2008, 'A ');
	insert into takes values('26102', '696', '1', 'Spring', 2002, 'B ');
	insert into takes values('78454', '468', '1', 'Fall', 2005, 'B ');
	insert into takes values('64121', '960', '1', 'Fall', 2009, 'A-');
	insert into takes values('45200', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('70235', '748', '1', 'Fall', 2003, 'B ');
	insert into takes values('38476', '604', '1', 'Spring', 2009, 'C ');
	insert into takes values('2178', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('50702', '352', '1', 'Spring', 2006, 'C+');
	insert into takes values('38548', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('89132', '867', '2', 'Fall', 2010, 'C ');
	insert into takes values('95029', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('77021', '169', '1', 'Spring', 2007, 'B+');
	insert into takes values('9360', '867', '1', 'Fall', 2006, 'A ');
	insert into takes values('26473', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('95027', '334', '1', 'Fall', 2009, 'A ');
	insert into takes values('792', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('32130', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('22618', '802', '1', 'Spring', 2003, 'C+');
	insert into takes values('60406', '843', '1', 'Fall', 2010, 'C+');
	insert into takes values('52872', '362', '3', 'Spring', 2008, 'B ');
	insert into takes values('92332', '694', '1', 'Fall', 2002, 'C ');
	insert into takes values('88472', '105', '2', 'Fall', 2002, 'A-');
	insert into takes values('67660', '352', '1', 'Spring', 2006, 'A+');
	insert into takes values('91992', '270', '1', 'Spring', 2010, 'C+');
	insert into takes values('24932', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('59290', '366', '1', 'Fall', 2005, 'B ');
	insert into takes values('90009', '747', '1', 'Spring', 2004, 'B+');
	insert into takes values('1968', '401', '1', 'Fall', 2003, 'B+');
	insert into takes values('65688', '345', '1', 'Spring', 2008, 'C-');
	insert into takes values('74163', '476', '1', 'Fall', 2010, 'A ');
	insert into takes values('27804', '408', '1', 'Spring', 2007, 'A+');
	insert into takes values('5943', '426', '1', 'Spring', 2006, 'A ');
	insert into takes values('92949', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('94324', '338', '1', 'Spring', 2007, 'B-');
	insert into takes values('50873', '561', '1', 'Fall', 2006, 'C-');
	insert into takes values('48471', '527', '1', 'Fall', 2004, 'C+');
	insert into takes values('98315', '843', '1', 'Fall', 2010, 'A ');
	insert into takes values('78787', '200', '1', 'Spring', 2007, 'B+');
	insert into takes values('85575', '581', '1', 'Spring', 2005, 'B+');
	insert into takes values('15726', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('69850', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('92776', '679', '1', 'Spring', 2010, 'B ');
	insert into takes values('46106', '960', '2', 'Fall', 2006, 'B-');
	insert into takes values('41674', '352', '1', 'Spring', 2006, 'B+');
	insert into takes values('19824', '376', '1', 'Fall', 2006, 'B+');
	insert into takes values('20540', '158', '1', 'Fall', 2008, 'A-');
	insert into takes values('71631', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('4383', '735', '2', 'Spring', 2010, 'B-');
	insert into takes values('7970', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('47265', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('25611', '443', '1', 'Spring', 2010, 'B ');
	insert into takes values('98315', '169', '2', 'Fall', 2002, 'A+');
	insert into takes values('43211', '599', '1', 'Spring', 2003, 'C+');
	insert into takes values('40937', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('97228', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('31476', '626', '1', 'Fall', 2006, 'B-');
	insert into takes values('14032', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('16057', '791', '1', 'Spring', 2006, 'C+');
	insert into takes values('67024', '237', '1', 'Spring', 2008, 'A-');
	insert into takes values('49982', '408', '1', 'Spring', 2007, 'A-');
	insert into takes values('94815', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('23457', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('70807', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('99760', '527', '1', 'Fall', 2004, 'A ');
	insert into takes values('65714', '748', '1', 'Fall', 2003, 'B-');
	insert into takes values('90663', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('13753', '629', '1', 'Spring', 2003, 'A+');
	insert into takes values('26730', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('39046', '200', '1', 'Spring', 2007, 'C ');
	insert into takes values('86802', '274', '1', 'Fall', 2002, 'B-');
	insert into takes values('41818', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('8347', '319', '1', 'Spring', 2003, 'A-');
	insert into takes values('80821', '415', '1', 'Fall', 2010, 'C+');
	insert into takes values('94766', '960', '2', 'Fall', 2006, 'A ');
	insert into takes values('19582', '426', '1', 'Spring', 2006, 'C ');
	insert into takes values('4034', '345', '1', 'Spring', 2008, 'B-');
	insert into takes values('38902', '793', '1', 'Spring', 2002, 'C-');
	insert into takes values('9514', '642', '1', 'Fall', 2004, 'A-');
	insert into takes values('71387', '793', '1', 'Spring', 2002, 'A-');
	insert into takes values('53424', '105', '2', 'Fall', 2002, 'C+');
	insert into takes values('36494', '237', '2', 'Fall', 2009, 'A-');
	insert into takes values('64196', '258', '1', 'Fall', 2007, 'B+');
	insert into takes values('4004', '962', '1', 'Spring', 2008, 'B-');
	insert into takes values('43130', '852', '1', 'Spring', 2008, 'B-');
	insert into takes values('26494', '864', '1', 'Spring', 2006, 'B ');
	insert into takes values('16753', '843', '1', 'Fall', 2010, 'C-');
	insert into takes values('26473', '105', '1', 'Fall', 2009, 'B ');
	insert into takes values('47001', '400', '1', 'Spring', 2007, 'B+');
	insert into takes values('18234', '793', '1', 'Spring', 2002, 'B ');
	insert into takes values('7123', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('7020', '949', '1', 'Fall', 2007, 'C+');
	insert into takes values('29645', '400', '2', 'Fall', 2003, 'A ');
	insert into takes values('19536', '604', '1', 'Spring', 2009, 'A ');
	insert into takes values('74070', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('13211', '735', '1', 'Spring', 2003, 'A-');
	insert into takes values('30341', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('95859', '200', '2', 'Fall', 2002, 'A ');
	insert into takes values('62832', '612', '1', 'Fall', 2007, 'B+');
	insert into takes values('72768', '604', '1', 'Spring', 2009, 'A-');
	insert into takes values('3493', '631', '1', 'Spring', 2007, 'A ');
	insert into takes values('11441', '735', '1', 'Spring', 2003, 'A-');
	insert into takes values('45680', '747', '1', 'Spring', 2004, 'A ');
	insert into takes values('85680', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('50658', '304', '1', 'Fall', 2009, 'B ');
	insert into takes values('8483', '457', '1', 'Spring', 2001, 'B-');
	insert into takes values('71944', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('93004', '338', '2', 'Spring', 2006, 'A ');
	insert into takes values('15430', '843', '1', 'Fall', 2010, 'C ');
	insert into takes values('16467', '362', '2', 'Fall', 2006, 'B-');
	insert into takes values('81566', '748', '1', 'Fall', 2003, 'C-');
	insert into takes values('15083', '527', '1', 'Fall', 2004, 'C ');
	insert into takes values('35257', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('37818', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('37038', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('21774', '735', '2', 'Spring', 2010, 'A-');
	insert into takes values('40558', '974', '1', 'Fall', 2003, 'C-');
	insert into takes values('66281', '338', '2', 'Spring', 2006, 'C ');
	insert into takes values('69628', '748', '1', 'Fall', 2003, 'B-');
	insert into takes values('27956', '599', '1', 'Spring', 2003, 'A-');
	insert into takes values('14484', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('90448', '237', '1', 'Spring', 2008, 'C-');
	insert into takes values('37101', '991', '1', 'Spring', 2008, 'C-');
	insert into takes values('45817', '105', '2', 'Fall', 2002, 'A-');
	insert into takes values('91616', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('35', '702', '1', 'Spring', 2001, 'A-');
	insert into takes values('83871', '808', '1', 'Fall', 2003, 'C ');
	insert into takes values('81884', '400', '2', 'Fall', 2003, 'A ');
	insert into takes values('97590', '461', '1', 'Fall', 2002, 'C+');
	insert into takes values('6673', '960', '1', 'Fall', 2009, 'A+');
	insert into takes values('3493', '493', '1', 'Spring', 2010, 'B+');
	insert into takes values('64731', '843', '1', 'Fall', 2010, 'C+');
	insert into takes values('75231', '270', '1', 'Spring', 2010, 'A-');
	insert into takes values('48861', '974', '1', 'Fall', 2003, 'B-');
	insert into takes values('45494', '338', '2', 'Spring', 2006, 'C ');
	insert into takes values('85809', '338', '1', 'Spring', 2007, 'C+');
	insert into takes values('75928', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('65208', '581', '1', 'Spring', 2005, 'A+');
	insert into takes values('77234', '795', '1', 'Spring', 2004, 'B+');
	insert into takes values('53424', '696', '1', 'Spring', 2002, 'C-');
	insert into takes values('72501', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('76743', '704', '1', 'Spring', 2008, 'C ');
	insert into takes values('67024', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('1367', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('61127', '974', '1', 'Fall', 2003, 'B-');
	insert into takes values('85754', '105', '1', 'Fall', 2009, 'B+');
	insert into takes values('98388', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('14628', '200', '1', 'Spring', 2007, 'B+');
	insert into takes values('27044', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('6990', '704', '1', 'Spring', 2008, 'B ');
	insert into takes values('95852', '893', '1', 'Fall', 2007, 'A-');
	insert into takes values('50658', '692', '1', 'Spring', 2010, 'C ');
	insert into takes values('78572', '237', '1', 'Spring', 2008, 'C+');
	insert into takes values('60249', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('87048', '486', '1', 'Fall', 2009, 'B ');
	insert into takes values('74974', '875', '1', 'Spring', 2005, 'A+');
	insert into takes values('16907', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('32369', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('23992', '561', '1', 'Fall', 2006, 'C+');
	insert into takes values('39241', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('37818', '962', '1', 'Spring', 2008, 'A ');
	insert into takes values('58300', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('54875', '482', '1', 'Fall', 2005, 'B-');
	insert into takes values('18752', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('61402', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('48778', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('65438', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('52187', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('49759', '760', '1', 'Spring', 2004, 'C-');
	insert into takes values('85234', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('61920', '760', '1', 'Spring', 2004, 'B+');
	insert into takes values('53185', '496', '1', 'Fall', 2001, 'B ');
	insert into takes values('94990', '571', '1', 'Spring', 2004, 'A+');
	insert into takes values('25256', '704', '1', 'Spring', 2008, 'A+');
	insert into takes values('4860', '612', '1', 'Fall', 2007, 'B+');
	insert into takes values('93986', '581', '1', 'Spring', 2005, 'C+');
	insert into takes values('87785', '496', '1', 'Fall', 2001, 'B ');
	insert into takes values('85356', '274', '1', 'Fall', 2002, 'A+');
	insert into takes values('64039', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('66469', '105', '2', 'Fall', 2002, 'A+');
	insert into takes values('96772', '864', '1', 'Spring', 2006, 'C-');
	insert into takes values('27002', '426', '1', 'Spring', 2006, 'A-');
	insert into takes values('93125', '527', '1', 'Fall', 2004, 'C ');
	insert into takes values('70918', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('98388', '493', '1', 'Spring', 2010, 'C+');
	insert into takes values('71904', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('37759', '270', '1', 'Spring', 2010, 'B-');
	insert into takes values('544', '421', '1', 'Fall', 2004, 'B+');
	insert into takes values('88358', '972', '1', 'Spring', 2009, 'A+');
	insert into takes values('96741', '496', '1', 'Fall', 2001, 'C-');
	insert into takes values('66763', '408', '1', 'Spring', 2007, 'A ');
	insert into takes values('39892', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('49982', '158', '1', 'Fall', 2008, 'C ');
	insert into takes values('58465', '468', '2', 'Fall', 2007, 'A+');
	insert into takes values('23439', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('59290', '626', '1', 'Fall', 2006, 'C ');
	insert into takes values('65703', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('16523', '927', '1', 'Fall', 2002, 'C-');
	insert into takes values('43348', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('66212', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('96193', '791', '1', 'Spring', 2006, 'B+');
	insert into takes values('15074', '304', '1', 'Fall', 2009, 'C-');
	insert into takes values('62429', '735', '1', 'Spring', 2003, 'B-');
	insert into takes values('31266', '338', '2', 'Spring', 2006, 'A ');
	insert into takes values('17944', '489', '1', 'Fall', 2007, 'C+');
	insert into takes values('78552', '169', '1', 'Spring', 2007, 'B-');
	insert into takes values('49873', '960', '1', 'Fall', 2009, 'A+');
	insert into takes values('97573', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('5243', '334', '1', 'Fall', 2009, 'A-');
	insert into takes values('39520', '239', '1', 'Fall', 2006, 'B ');
	insert into takes values('99719', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('89571', '415', '1', 'Fall', 2010, 'A-');
	insert into takes values('62749', '486', '1', 'Fall', 2009, 'A ');
	insert into takes values('18234', '795', '1', 'Spring', 2004, 'B-');
	insert into takes values('39876', '345', '1', 'Spring', 2008, 'C+');
	insert into takes values('35588', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('19582', '696', '1', 'Spring', 2002, 'C-');
	insert into takes values('46066', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('83003', '468', '2', 'Fall', 2007, 'C-');
	insert into takes values('75299', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('87784', '408', '2', 'Spring', 2003, 'C ');
	insert into takes values('91788', '603', '1', 'Fall', 2003, 'A+');
	insert into takes values('81876', '239', '1', 'Fall', 2006, 'C+');
	insert into takes values('56057', '679', '1', 'Spring', 2010, 'A+');
	insert into takes values('2133', '694', '1', 'Fall', 2002, 'A ');
	insert into takes values('163', '581', '1', 'Spring', 2005, 'A+');
	insert into takes values('41091', '169', '1', 'Spring', 2007, 'A-');
	insert into takes values('64593', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('37038', '242', '1', 'Fall', 2009, 'B+');
	insert into takes values('64067', '169', '2', 'Fall', 2002, 'A+');
	insert into takes values('41988', '482', '1', 'Fall', 2005, 'A+');
	insert into takes values('16849', '972', '1', 'Spring', 2009, 'C ');
	insert into takes values('84865', '603', '1', 'Fall', 2003, 'B-');
	insert into takes values('81884', '631', '1', 'Spring', 2007, 'A+');
	insert into takes values('82591', '445', '1', 'Spring', 2001, 'B-');
	insert into takes values('74016', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('288', '105', '1', 'Fall', 2009, 'A+');
	insert into takes values('5005', '258', '1', 'Fall', 2007, 'A+');
	insert into takes values('86075', '482', '1', 'Fall', 2005, 'B ');
	insert into takes values('29665', '493', '1', 'Spring', 2010, 'C-');
	insert into takes values('96206', '808', '1', 'Fall', 2003, 'A+');
	insert into takes values('78116', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('35905', '242', '1', 'Fall', 2009, 'B+');
	insert into takes values('81028', '591', '1', 'Spring', 2005, 'A+');
	insert into takes values('67024', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('6712', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('63090', '334', '1', 'Fall', 2009, 'B-');
	insert into takes values('81538', '105', '1', 'Fall', 2009, 'A+');
	insert into takes values('17911', '349', '1', 'Spring', 2008, 'A-');
	insert into takes values('51549', '599', '1', 'Spring', 2003, 'C ');
	insert into takes values('76246', '443', '1', 'Spring', 2010, 'A ');
	insert into takes values('41675', '242', '1', 'Fall', 2009, 'C+');
	insert into takes values('46725', '258', '1', 'Fall', 2007, 'B+');
	insert into takes values('77729', '468', '2', 'Fall', 2007, 'A+');
	insert into takes values('29959', '893', '1', 'Fall', 2007, 'A-');
	insert into takes values('38288', '200', '1', 'Spring', 2007, 'A ');
	insert into takes values('88577', '457', '1', 'Spring', 2001, 'B-');
	insert into takes values('98690', '704', '1', 'Spring', 2008, 'A+');
	insert into takes values('8986', '258', '1', 'Fall', 2007, 'A-');
	insert into takes values('41596', '258', '1', 'Fall', 2007, 'A ');
	insert into takes values('20814', '457', '1', 'Spring', 2001, 'B+');
	insert into takes values('64140', '704', '1', 'Spring', 2008, 'C-');
	insert into takes values('24932', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('76911', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('14554', '158', '1', 'Fall', 2008, 'C ');
	insert into takes values('83511', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('28409', '679', '1', 'Spring', 2010, 'A+');
	insert into takes values('52471', '561', '1', 'Fall', 2006, 'A+');
	insert into takes values('63449', '694', '1', 'Fall', 2002, 'C+');
	insert into takes values('88553', '105', '2', 'Fall', 2002, 'C-');
	insert into takes values('544', '345', '1', 'Spring', 2008, 'A ');
	insert into takes values('32954', '105', '2', 'Fall', 2002, 'B+');
	insert into takes values('57190', '445', '1', 'Spring', 2001, 'B-');
	insert into takes values('11201', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('18675', '974', '1', 'Fall', 2003, 'A+');
	insert into takes values('15024', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('45083', '443', '2', 'Spring', 2002, 'C-');
	insert into takes values('16523', '366', '1', 'Fall', 2005, 'A ');
	insert into takes values('69758', '629', '1', 'Spring', 2003, 'B+');
	insert into takes values('99710', '352', '1', 'Spring', 2006, 'C-');
	insert into takes values('38545', '696', '1', 'Spring', 2002, 'C-');
	insert into takes values('87784', '105', '2', 'Fall', 2002, 'B+');
	insert into takes values('49684', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('22050', '696', '1', 'Spring', 2002, 'C+');
	insert into takes values('31137', '468', '1', 'Fall', 2005, 'B ');
	insert into takes values('30397', '702', '1', 'Spring', 2001, 'A-');
	insert into takes values('69783', '338', '1', 'Spring', 2007, 'B ');
	insert into takes values('8347', '237', '2', 'Fall', 2009, 'C+');
	insert into takes values('53728', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('7287', '692', '1', 'Spring', 2010, 'C+');
	insert into takes values('34404', '795', '1', 'Spring', 2004, 'C+');
	insert into takes values('60688', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('72528', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('78469', '334', '1', 'Fall', 2009, 'B-');
	insert into takes values('37809', '559', '1', 'Fall', 2002, 'C-');
	insert into takes values('41774', '974', '1', 'Fall', 2003, 'A-');
	insert into takes values('49982', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('84239', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('66229', '545', '1', 'Fall', 2001, 'A-');
	insert into takes values('99754', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('51817', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('50873', '962', '1', 'Spring', 2008, 'C+');
	insert into takes values('65400', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('60267', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('98120', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('12236', '561', '1', 'Fall', 2006, 'C+');
	insert into takes values('82646', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('92693', '415', '1', 'Fall', 2010, 'C-');
	insert into takes values('97355', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('31341', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('10267', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('5703', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('33206', '974', '1', 'Fall', 2003, 'A+');
	insert into takes values('35685', '626', '1', 'Fall', 2006, 'C ');
	insert into takes values('21552', '158', '2', 'Spring', 2008, 'C ');
	insert into takes values('41938', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('94178', '852', '1', 'Spring', 2008, 'C-');
	insert into takes values('46725', '974', '1', 'Fall', 2003, 'B-');
	insert into takes values('70389', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('97658', '629', '1', 'Spring', 2003, 'A+');
	insert into takes values('10527', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('88045', '445', '1', 'Spring', 2001, 'C+');
	insert into takes values('10727', '468', '1', 'Fall', 2005, 'A-');
	insert into takes values('22467', '545', '1', 'Fall', 2001, 'C ');
	insert into takes values('68070', '169', '1', 'Spring', 2007, 'B ');
	insert into takes values('25187', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('67660', '443', '1', 'Spring', 2010, 'A+');
	insert into takes values('49618', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('13028', '169', '2', 'Fall', 2002, 'C ');
	insert into takes values('69952', '527', '1', 'Fall', 2004, 'A ');
	insert into takes values('11055', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('81258', '400', '2', 'Fall', 2003, 'A ');
	insert into takes values('83573', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('99250', '692', '1', 'Spring', 2010, 'B-');
	insert into takes values('84727', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('87624', '493', '1', 'Spring', 2010, 'A-');
	insert into takes values('55170', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('85211', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('8912', '258', '1', 'Fall', 2007, 'B+');
	insert into takes values('82688', '631', '1', 'Spring', 2007, 'A+');
	insert into takes values('71628', '949', '1', 'Fall', 2007, 'B ');
	insert into takes values('41261', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('46981', '642', '1', 'Fall', 2004, 'A+');
	insert into takes values('41450', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('5250', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('57511', '747', '1', 'Spring', 2004, 'C ');
	insert into takes values('18367', '991', '1', 'Spring', 2008, 'B ');
	insert into takes values('98726', '629', '1', 'Spring', 2003, 'A+');
	insert into takes values('28252', '415', '1', 'Fall', 2010, 'B ');
	insert into takes values('15487', '169', '1', 'Spring', 2007, 'B ');
	insert into takes values('36303', '242', '1', 'Fall', 2009, 'A ');
	insert into takes values('46928', '581', '1', 'Spring', 2005, 'A+');
	insert into takes values('78892', '313', '1', 'Fall', 2010, 'B-');
	insert into takes values('93039', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('15487', '352', '1', 'Spring', 2006, 'C+');
	insert into takes values('75596', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('74639', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('52057', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('74840', '200', '1', 'Spring', 2007, 'C ');
	insert into takes values('62784', '461', '1', 'Fall', 2002, 'C+');
	insert into takes values('53047', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('58465', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('40371', '545', '1', 'Fall', 2001, 'A+');
	insert into takes values('97629', '960', '2', 'Fall', 2006, 'B+');
	insert into takes values('73268', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('92040', '376', '1', 'Fall', 2006, 'B ');
	insert into takes values('16297', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('56058', '591', '1', 'Spring', 2005, 'B ');
	insert into takes values('30943', '334', '1', 'Fall', 2009, 'B ');
	insert into takes values('25468', '527', '1', 'Fall', 2004, 'C+');
	insert into takes values('20378', '696', '1', 'Spring', 2002, 'B-');
	insert into takes values('73492', '443', '2', 'Spring', 2002, 'B-');
	insert into takes values('55915', '748', '1', 'Fall', 2003, 'C-');
	insert into takes values('42991', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('17133', '875', '1', 'Spring', 2005, 'C-');
	insert into takes values('19582', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('3833', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('1087', '893', '1', 'Fall', 2007, 'B ');
	insert into takes values('88358', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('33817', '591', '1', 'Spring', 2005, 'A ');
	insert into takes values('59553', '704', '1', 'Spring', 2008, 'A+');
	insert into takes values('32369', '642', '1', 'Fall', 2004, 'B-');
	insert into takes values('48861', '527', '1', 'Fall', 2004, 'A-');
	insert into takes values('5463', '493', '1', 'Spring', 2010, 'C+');
	insert into takes values('15030', '443', '2', 'Spring', 2002, 'A ');
	insert into takes values('29192', '864', '1', 'Spring', 2006, 'B+');
	insert into takes values('82591', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('71631', '338', '1', 'Spring', 2007, 'A-');
	insert into takes values('50977', '461', '1', 'Fall', 2002, 'B ');
	insert into takes values('64820', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('99451', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('52656', '239', '1', 'Fall', 2006, 'B-');
	insert into takes values('12666', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('97868', '604', '1', 'Spring', 2009, 'A-');
	insert into takes values('107', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('4435', '692', '1', 'Spring', 2010, 'A-');
	insert into takes values('86753', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('21009', '457', '1', 'Spring', 2001, 'B-');
	insert into takes values('31993', '482', '1', 'Fall', 2005, 'A+');
	insert into takes values('16849', '258', '1', 'Fall', 2007, 'B+');
	insert into takes values('82970', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('90353', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('85746', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('94324', '338', '2', 'Spring', 2006, 'C ');
	insert into takes values('65901', '960', '2', 'Fall', 2006, 'C+');
	insert into takes values('41818', '735', '1', 'Spring', 2003, 'A-');
	insert into takes values('61364', '274', '1', 'Fall', 2002, 'B ');
	insert into takes values('61444', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('89188', '852', '1', 'Spring', 2008, 'A-');
	insert into takes values('50977', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('39394', '496', '1', 'Fall', 2001, 'A-');
	insert into takes values('30341', '468', '2', 'Fall', 2007, 'C+');
	insert into takes values('77000', '561', '1', 'Fall', 2006, 'A+');
	insert into takes values('41832', '959', '1', 'Fall', 2006, 'B+');
	insert into takes values('33837', '105', '1', 'Fall', 2009, 'A+');
	insert into takes values('99289', '443', '2', 'Spring', 2002, 'A-');
	insert into takes values('97679', '376', '1', 'Fall', 2006, 'A ');
	insert into takes values('75596', '527', '1', 'Fall', 2004, 'B+');
	insert into takes values('67051', '875', '1', 'Spring', 2005, 'A-');
	insert into takes values('58634', '457', '1', 'Spring', 2001, 'C-');
	insert into takes values('36791', '334', '1', 'Fall', 2009, 'A-');
	insert into takes values('92693', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('62795', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('64013', '545', '1', 'Fall', 2001, 'B ');
	insert into takes values('81245', '169', '1', 'Spring', 2007, 'B+');
	insert into takes values('336', '864', '1', 'Spring', 2006, 'B+');
	insert into takes values('41299', '304', '1', 'Fall', 2009, 'B ');
	insert into takes values('74473', '629', '1', 'Spring', 2003, 'B+');
	insert into takes values('43032', '468', '1', 'Fall', 2005, 'A ');
	insert into takes values('35293', '802', '1', 'Spring', 2003, 'A+');
	insert into takes values('24746', '960', '2', 'Fall', 2006, 'A-');
	insert into takes values('81396', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('78481', '864', '1', 'Spring', 2006, 'C+');
	insert into takes values('96911', '493', '1', 'Spring', 2010, 'B ');
	insert into takes values('77218', '496', '1', 'Fall', 2001, 'A-');
	insert into takes values('30177', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('19638', '972', '1', 'Spring', 2009, 'C ');
	insert into takes values('64067', '748', '1', 'Fall', 2003, 'B-');
	insert into takes values('78922', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('99660', '626', '1', 'Fall', 2006, 'A-');
	insert into takes values('36494', '843', '1', 'Fall', 2010, 'C ');
	insert into takes values('81396', '581', '1', 'Spring', 2005, 'C ');
	insert into takes values('17665', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('42843', '867', '2', 'Fall', 2010, 'A+');
	insert into takes values('68010', '400', '2', 'Fall', 2003, 'C-');
	insert into takes values('13495', '702', '1', 'Spring', 2001, 'C-');
	insert into takes values('23525', '443', '1', 'Spring', 2010, 'B+');
	insert into takes values('18859', '338', '2', 'Spring', 2006, 'A-');
	insert into takes values('98359', '319', '1', 'Spring', 2003, 'B-');
	insert into takes values('80799', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('85614', '795', '1', 'Spring', 2004, 'B-');
	insert into takes values('2423', '443', '2', 'Spring', 2002, 'B-');
	insert into takes values('69952', '304', '1', 'Fall', 2009, 'A ');
	insert into takes values('65433', '443', '2', 'Spring', 2002, 'A ');
	insert into takes values('26730', '237', '1', 'Spring', 2008, 'C+');
	insert into takes values('68278', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('30397', '468', '2', 'Fall', 2007, 'A+');
	insert into takes values('57780', '476', '1', 'Fall', 2010, 'B+');
	insert into takes values('1836', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('96203', '400', '1', 'Spring', 2007, 'C ');
	insert into takes values('95046', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('15613', '631', '1', 'Spring', 2007, 'C-');
	insert into takes values('79469', '237', '1', 'Spring', 2008, 'B ');
	insert into takes values('34404', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('987', '867', '1', 'Fall', 2006, 'A-');
	insert into takes values('17192', '735', '2', 'Spring', 2010, 'A-');
	insert into takes values('57238', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('65676', '747', '1', 'Spring', 2004, 'C-');
	insert into takes values('10663', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('32464', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('75252', '313', '1', 'Fall', 2010, 'B-');
	insert into takes values('35905', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('6729', '376', '1', 'Fall', 2006, 'B+');
	insert into takes values('15074', '258', '1', 'Fall', 2007, 'C-');
	insert into takes values('51817', '169', '1', 'Spring', 2007, 'A-');
	insert into takes values('43912', '349', '1', 'Spring', 2008, 'B+');
	insert into takes values('95205', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('90779', '893', '1', 'Fall', 2007, 'A-');
	insert into takes values('31560', '401', '1', 'Fall', 2003, 'A+');
	insert into takes values('64164', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('96772', '461', '1', 'Fall', 2002, 'A-');
	insert into takes values('5961', '527', '1', 'Fall', 2004, 'B-');
	insert into takes values('78469', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('56078', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('85887', '362', '1', 'Fall', 2005, 'C-');
	insert into takes values('86934', '242', '1', 'Fall', 2009, 'B+');
	insert into takes values('76250', '867', '2', 'Fall', 2010, 'C ');
	insert into takes values('74473', '702', '1', 'Spring', 2001, 'B-');
	insert into takes values('30896', '875', '1', 'Spring', 2005, 'B+');
	insert into takes values('25046', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('90089', '200', '2', 'Fall', 2002, 'C+');
	insert into takes values('36791', '400', '1', 'Spring', 2007, 'C ');
	insert into takes values('21395', '400', '1', 'Spring', 2007, 'C ');
	insert into takes values('52669', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('98830', '376', '1', 'Fall', 2006, 'A ');
	insert into takes values('52120', '959', '1', 'Fall', 2006, 'A ');
	insert into takes values('24002', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('13023', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('11453', '696', '1', 'Spring', 2002, 'B ');
	insert into takes values('64820', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('65056', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('90914', '875', '1', 'Spring', 2005, 'C ');
	insert into takes values('42688', '629', '1', 'Spring', 2003, 'B+');
	insert into takes values('7123', '559', '1', 'Fall', 2002, 'A-');
	insert into takes values('71426', '105', '2', 'Fall', 2002, 'A-');
	insert into takes values('64164', '457', '1', 'Spring', 2001, 'C-');
	insert into takes values('73268', '875', '1', 'Spring', 2005, 'A+');
	insert into takes values('78767', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('29399', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('20244', '962', '1', 'Spring', 2008, 'C-');
	insert into takes values('99647', '468', '1', 'Fall', 2005, 'A ');
	insert into takes values('11855', '258', '1', 'Fall', 2007, 'A+');
	insert into takes values('10454', '864', '1', 'Spring', 2006, 'B ');
	insert into takes values('8251', '599', '1', 'Spring', 2003, 'C+');
	insert into takes values('65443', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('21774', '802', '1', 'Spring', 2003, 'A+');
	insert into takes values('76291', '468', '1', 'Fall', 2005, 'C+');
	insert into takes values('23373', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('15883', '239', '1', 'Fall', 2006, 'A-');
	insert into takes values('94257', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('7123', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('81028', '443', '2', 'Spring', 2002, 'A+');
	insert into takes values('23392', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('84189', '808', '1', 'Fall', 2003, 'B-');
	insert into takes values('13365', '476', '1', 'Fall', 2010, 'A ');
	insert into takes values('8912', '334', '1', 'Fall', 2009, 'A ');
	insert into takes values('45300', '468', '2', 'Fall', 2007, 'C-');
	insert into takes values('72643', '158', '2', 'Spring', 2008, 'C ');
	insert into takes values('5703', '334', '1', 'Fall', 2009, 'A-');
	insert into takes values('18775', '642', '1', 'Fall', 2004, 'B+');
	insert into takes values('2423', '867', '1', 'Fall', 2006, 'A-');
	insert into takes values('90663', '400', '1', 'Spring', 2007, 'A+');
	insert into takes values('97400', '468', '1', 'Fall', 2005, 'A ');
	insert into takes values('87048', '875', '1', 'Spring', 2005, 'A+');
	insert into takes values('15086', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('75878', '843', '1', 'Fall', 2010, 'C-');
	insert into takes values('33759', '694', '1', 'Fall', 2002, 'B ');
	insert into takes values('30650', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('17600', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('45650', '415', '1', 'Fall', 2010, 'A-');
	insert into takes values('34502', '105', '1', 'Fall', 2009, 'C-');
	insert into takes values('91799', '401', '1', 'Fall', 2003, 'A ');
	insert into takes values('22254', '629', '1', 'Spring', 2003, 'B+');
	insert into takes values('5298', '400', '1', 'Spring', 2007, 'C-');
	insert into takes values('16993', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('46981', '629', '1', 'Spring', 2003, 'A+');
	insert into takes values('5617', '137', '1', 'Spring', 2002, 'A ');
	insert into takes values('95284', '476', '1', 'Fall', 2010, 'C-');
	insert into takes values('90004', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('66008', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('10705', '949', '1', 'Fall', 2007, 'A-');
	insert into takes values('27956', '137', '1', 'Spring', 2002, 'A ');
	insert into takes values('74163', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('91343', '696', '1', 'Spring', 2002, 'A+');
	insert into takes values('59455', '972', '1', 'Spring', 2009, 'A+');
	insert into takes values('14432', '702', '1', 'Spring', 2001, 'A-');
	insert into takes values('42096', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('47677', '258', '1', 'Fall', 2007, 'C+');
	insert into takes values('16528', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('5005', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('91197', '352', '1', 'Spring', 2006, 'C ');
	insert into takes values('23224', '927', '1', 'Fall', 2002, 'C+');
	insert into takes values('96710', '401', '1', 'Fall', 2003, 'A+');
	insert into takes values('62728', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('62124', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('58413', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('31516', '893', '1', 'Fall', 2007, 'C+');
	insert into takes values('36384', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('94142', '692', '1', 'Spring', 2010, 'A ');
	insert into takes values('52203', '457', '1', 'Spring', 2001, 'A-');
	insert into takes values('82301', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('73411', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('93508', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('26881', '949', '1', 'Fall', 2007, 'C ');
	insert into takes values('38545', '376', '1', 'Fall', 2006, 'C+');
	insert into takes values('44551', '408', '1', 'Spring', 2007, 'C-');
	insert into takes values('85234', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('65208', '421', '1', 'Fall', 2004, 'A ');
	insert into takes values('65241', '200', '2', 'Fall', 2002, 'A ');
	insert into takes values('14432', '972', '1', 'Spring', 2009, 'A-');
	insert into takes values('76798', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('69241', '735', '2', 'Spring', 2010, 'A-');
	insert into takes values('18338', '852', '1', 'Spring', 2008, 'B+');
	insert into takes values('57083', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('56080', '702', '1', 'Spring', 2001, 'C ');
	insert into takes values('37653', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('77148', '137', '1', 'Spring', 2002, 'B ');
	insert into takes values('90089', '663', '1', 'Spring', 2005, 'A-');
	insert into takes values('4449', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('28361', '864', '1', 'Spring', 2006, 'A+');
	insert into takes values('14182', '158', '1', 'Fall', 2008, 'C-');
	insert into takes values('53048', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('81984', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('39978', '735', '1', 'Spring', 2003, 'A ');
	insert into takes values('94726', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('24784', '169', '2', 'Fall', 2002, 'A ');
	insert into takes values('98019', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('46442', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('57135', '974', '1', 'Fall', 2003, 'B-');
	insert into takes values('90609', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('97355', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('81207', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('92385', '105', '2', 'Fall', 2002, 'A+');
	insert into takes values('32744', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('94894', '867', '1', 'Fall', 2006, 'B+');
	insert into takes values('12216', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('50658', '545', '1', 'Fall', 2001, 'B-');
	insert into takes values('84704', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('88577', '376', '1', 'Fall', 2006, 'C+');
	insert into takes values('48640', '237', '1', 'Spring', 2008, 'C+');
	insert into takes values('82974', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('90132', '362', '1', 'Fall', 2005, 'B ');
	insert into takes values('4435', '959', '1', 'Fall', 2006, 'B ');
	insert into takes values('53490', '561', '1', 'Fall', 2006, 'C+');
	insert into takes values('87651', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('88308', '242', '1', 'Fall', 2009, 'C ');
	insert into takes values('81294', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('64945', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('89106', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('42688', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('23475', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('78792', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('80420', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('69758', '105', '2', 'Fall', 2002, 'C+');
	insert into takes values('9953', '345', '1', 'Spring', 2008, 'C ');
	insert into takes values('29239', '408', '1', 'Spring', 2007, 'C+');
	insert into takes values('11202', '443', '2', 'Spring', 2002, 'B ');
	insert into takes values('98830', '468', '1', 'Fall', 2005, 'B-');
	insert into takes values('21789', '137', '1', 'Spring', 2002, 'B ');
	insert into takes values('83039', '400', '2', 'Fall', 2003, 'B+');
	insert into takes values('75252', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('74460', '875', '1', 'Spring', 2005, 'A-');
	insert into takes values('59538', '692', '1', 'Spring', 2010, 'A+');
	insert into takes values('43432', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('89393', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('61920', '561', '1', 'Fall', 2006, 'A+');
	insert into takes values('24932', '169', '2', 'Fall', 2002, 'A-');
	insert into takes values('96134', '443', '1', 'Spring', 2010, 'C ');
	insert into takes values('65299', '893', '1', 'Fall', 2007, 'A+');
	insert into takes values('35685', '400', '1', 'Spring', 2007, 'B ');
	insert into takes values('67021', '334', '1', 'Fall', 2009, 'C-');
	insert into takes values('27804', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('56080', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('33882', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('59455', '468', '1', 'Fall', 2005, 'B+');
	insert into takes values('50743', '468', '1', 'Fall', 2005, 'C ');
	insert into takes values('26881', '679', '1', 'Spring', 2010, 'B+');
	insert into takes values('43616', '852', '1', 'Spring', 2008, 'C-');
	insert into takes values('68242', '313', '1', 'Fall', 2010, 'C ');
	insert into takes values('70522', '696', '1', 'Spring', 2002, 'C+');
	insert into takes values('77218', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('63390', '612', '1', 'Fall', 2007, 'C ');
	insert into takes values('89000', '274', '1', 'Fall', 2002, 'C+');
	insert into takes values('75423', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('45083', '443', '1', 'Spring', 2010, 'A+');
	insert into takes values('80799', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('13826', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('84704', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('77364', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('58919', '468', '2', 'Fall', 2007, 'C+');
	insert into takes values('38668', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('59920', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('30161', '270', '1', 'Spring', 2010, 'C-');
	insert into takes values('50206', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('30124', '105', '1', 'Fall', 2009, 'B+');
	insert into takes values('2629', '960', '2', 'Fall', 2006, 'A ');
	insert into takes values('82083', '960', '2', 'Fall', 2006, 'C+');
	insert into takes values('65190', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('87651', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('97953', '457', '1', 'Spring', 2001, 'C-');
	insert into takes values('15083', '349', '1', 'Spring', 2008, 'A-');
	insert into takes values('39978', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('31560', '486', '1', 'Fall', 2009, 'B ');
	insert into takes values('31035', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('78787', '362', '3', 'Spring', 2008, 'C+');
	insert into takes values('91132', '642', '1', 'Fall', 2004, 'B+');
	insert into takes values('40558', '362', '2', 'Fall', 2006, 'A-');
	insert into takes values('32065', '875', '1', 'Spring', 2005, 'A-');
	insert into takes values('544', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('40044', '468', '1', 'Fall', 2005, 'B-');
	insert into takes values('24784', '158', '1', 'Fall', 2008, 'B+');
	insert into takes values('30341', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('84189', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('15487', '591', '1', 'Spring', 2005, 'B+');
	insert into takes values('94620', '692', '1', 'Spring', 2010, 'C ');
	insert into takes values('94697', '642', '1', 'Fall', 2004, 'B-');
	insert into takes values('34331', '960', '2', 'Fall', 2006, 'A ');
	insert into takes values('84792', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('49073', '692', '1', 'Spring', 2010, 'A ');
	insert into takes values('40059', '927', '1', 'Fall', 2002, 'B-');
	insert into takes values('77021', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('67051', '334', '1', 'Fall', 2009, 'B+');
	insert into takes values('29665', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('71628', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('54610', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('39978', '735', '2', 'Spring', 2010, 'C ');
	insert into takes values('98140', '338', '1', 'Spring', 2007, 'B ');
	insert into takes values('46155', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('39876', '864', '1', 'Spring', 2006, 'C-');
	insert into takes values('68396', '852', '1', 'Spring', 2008, 'B+');
	insert into takes values('33401', '735', '2', 'Spring', 2010, 'C ');
	insert into takes values('42114', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('85451', '443', '1', 'Spring', 2010, 'C+');
	insert into takes values('6710', '468', '1', 'Fall', 2005, 'C+');
	insert into takes values('81789', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('57156', '105', '2', 'Fall', 2002, 'B-');
	insert into takes values('29849', '169', '2', 'Fall', 2002, 'A-');
	insert into takes values('47487', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('86981', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('67436', '349', '1', 'Spring', 2008, 'C-');
	insert into takes values('89000', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('50873', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('1727', '631', '1', 'Spring', 2007, 'B+');
	insert into takes values('40457', '408', '1', 'Spring', 2007, 'C+');
	insert into takes values('35293', '408', '1', 'Spring', 2007, 'B ');
	insert into takes values('1110', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('80742', '242', '1', 'Fall', 2009, 'C+');
	insert into takes values('70918', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('10834', '468', '1', 'Fall', 2005, 'B-');
	insert into takes values('95850', '747', '1', 'Spring', 2004, 'C-');
	insert into takes values('27528', '626', '1', 'Fall', 2006, 'A ');
	insert into takes values('53185', '443', '1', 'Spring', 2010, 'C ');
	insert into takes values('56486', '875', '1', 'Spring', 2005, 'C-');
	insert into takes values('53185', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('84495', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('70389', '468', '2', 'Fall', 2007, 'A-');
	insert into takes values('99949', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('72521', '169', '2', 'Fall', 2002, 'B+');
	insert into takes values('99694', '468', '1', 'Fall', 2005, 'A+');
	insert into takes values('85445', '875', '1', 'Spring', 2005, 'A ');
	insert into takes values('82688', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('69222', '408', '1', 'Spring', 2007, 'B ');
	insert into takes values('95852', '338', '1', 'Spring', 2007, 'C ');
	insert into takes values('41973', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('92332', '169', '1', 'Spring', 2007, 'B-');
	insert into takes values('52157', '991', '1', 'Spring', 2008, 'C-');
	insert into takes values('21552', '445', '1', 'Spring', 2001, 'B+');
	insert into takes values('36265', '486', '1', 'Fall', 2009, 'B-');
	insert into takes values('70235', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('56139', '493', '1', 'Spring', 2010, 'C ');
	insert into takes values('70807', '631', '1', 'Spring', 2007, 'C+');
	insert into takes values('63612', '571', '1', 'Spring', 2004, 'A-');
	insert into takes values('89234', '408', '2', 'Spring', 2003, 'C ');
	insert into takes values('49873', '338', '1', 'Spring', 2007, 'A-');
	insert into takes values('16035', '679', '1', 'Spring', 2010, 'C-');
	insert into takes values('18338', '319', '1', 'Spring', 2003, 'B-');
	insert into takes values('36881', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('49873', '489', '1', 'Fall', 2007, 'A ');
	insert into takes values('45300', '468', '1', 'Fall', 2005, 'A-');
	insert into takes values('66259', '489', '1', 'Fall', 2007, 'A ');
	insert into takes values('29390', '604', '1', 'Spring', 2009, 'B ');
	insert into takes values('75273', '696', '1', 'Spring', 2002, 'A-');
	insert into takes values('12979', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('56078', '237', '1', 'Spring', 2008, 'B-');
	insert into takes values('41818', '338', '2', 'Spring', 2006, 'B ');
	insert into takes values('96227', '561', '1', 'Fall', 2006, 'C ');
	insert into takes values('65208', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('32385', '927', '1', 'Fall', 2002, 'A-');
	insert into takes values('53485', '747', '1', 'Spring', 2004, 'C ');
	insert into takes values('50038', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('259', '843', '1', 'Fall', 2010, 'C+');
	insert into takes values('83838', '561', '1', 'Fall', 2006, 'A+');
	insert into takes values('30858', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('435', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('25525', '702', '1', 'Spring', 2001, 'B ');
	insert into takes values('87651', '795', '1', 'Spring', 2004, 'A-');
	insert into takes values('1000', '959', '1', 'Fall', 2006, 'B+');
	insert into takes values('52929', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('96203', '747', '1', 'Spring', 2004, 'A ');
	insert into takes values('70299', '158', '1', 'Fall', 2008, 'C ');
	insert into takes values('19735', '962', '1', 'Spring', 2008, 'C-');
	insert into takes values('90089', '626', '1', 'Fall', 2006, 'B-');
	insert into takes values('14668', '704', '1', 'Spring', 2008, 'B ');
	insert into takes values('15070', '468', '2', 'Fall', 2007, 'A-');
	insert into takes values('53424', '867', '2', 'Fall', 2010, 'C-');
	insert into takes values('45300', '338', '1', 'Spring', 2007, 'A ');
	insert into takes values('70807', '867', '2', 'Fall', 2010, 'B-');
	insert into takes values('52876', '408', '2', 'Spring', 2003, 'A ');
	insert into takes values('93004', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('98843', '137', '1', 'Spring', 2002, 'A ');
	insert into takes values('23475', '421', '1', 'Fall', 2004, 'A-');
	insert into takes values('42298', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('2848', '735', '1', 'Spring', 2003, 'C ');
	insert into takes values('70061', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('52929', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('95027', '200', '2', 'Fall', 2002, 'B+');
	insert into takes values('86641', '702', '1', 'Spring', 2001, 'B ');
	insert into takes values('24932', '612', '1', 'Fall', 2007, 'A-');
	insert into takes values('17911', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('55859', '960', '2', 'Fall', 2006, 'A-');
	insert into takes values('56212', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('13741', '237', '1', 'Spring', 2008, 'B-');
	insert into takes values('87222', '376', '1', 'Fall', 2006, 'A-');
	insert into takes values('55915', '949', '1', 'Fall', 2007, 'A-');
	insert into takes values('62152', '334', '1', 'Fall', 2009, 'C ');
	insert into takes values('75173', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('2178', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('20540', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('52494', '748', '1', 'Fall', 2003, 'A-');
	insert into takes values('42688', '604', '1', 'Spring', 2009, 'B+');
	insert into takes values('64196', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('97694', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('77415', '793', '1', 'Spring', 2002, 'C+');
	insert into takes values('62520', '482', '1', 'Fall', 2005, 'B ');
	insert into takes values('83686', '200', '2', 'Fall', 2002, 'A+');
	insert into takes values('86375', '599', '1', 'Spring', 2003, 'B+');
	insert into takes values('90814', '443', '2', 'Spring', 2002, 'B-');
	insert into takes values('48462', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('83573', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('30110', '702', '1', 'Spring', 2001, 'B-');
	insert into takes values('12666', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('95366', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('50664', '629', '1', 'Spring', 2003, 'A+');
	insert into takes values('95366', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('96067', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('5336', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('48861', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('96722', '376', '1', 'Fall', 2006, 'B-');
	insert into takes values('43495', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('51997', '694', '1', 'Fall', 2002, 'C ');
	insert into takes values('86529', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('51203', '338', '2', 'Spring', 2006, 'B+');
	insert into takes values('99422', '875', '1', 'Spring', 2005, 'B-');
	insert into takes values('83003', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('69850', '457', '1', 'Spring', 2001, 'C-');
	insert into takes values('76672', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('31250', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('88389', '735', '2', 'Spring', 2010, 'A+');
	insert into takes values('47677', '748', '1', 'Fall', 2003, 'C-');
	insert into takes values('61444', '408', '2', 'Spring', 2003, 'C ');
	insert into takes values('1087', '443', '2', 'Spring', 2002, 'C+');
	insert into takes values('80057', '408', '1', 'Spring', 2007, 'C ');
	insert into takes values('87651', '927', '1', 'Fall', 2002, 'C ');
	insert into takes values('99730', '408', '1', 'Spring', 2007, 'C ');
	insert into takes values('53047', '663', '1', 'Spring', 2005, 'B-');
	insert into takes values('82707', '692', '1', 'Spring', 2010, 'C-');
	insert into takes values('80799', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('31266', '496', '1', 'Fall', 2001, 'C-');
	insert into takes values('39704', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('90132', '696', '1', 'Spring', 2002, 'C+');
	insert into takes values('15083', '927', '1', 'Fall', 2002, 'B-');
	insert into takes values('81789', '319', '1', 'Spring', 2003, 'C-');
	insert into takes values('99764', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('91915', '599', '1', 'Spring', 2003, 'C ');
	insert into takes values('35362', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('2795', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('87193', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('76049', '493', '1', 'Spring', 2010, 'B ');
	insert into takes values('23270', '793', '1', 'Spring', 2002, 'C ');
	insert into takes values('85063', '376', '1', 'Fall', 2006, 'C+');
	insert into takes values('38712', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('45436', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('1812', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('1080', '747', '1', 'Spring', 2004, 'C-');
	insert into takes values('41261', '852', '1', 'Spring', 2008, 'A ');
	insert into takes values('52134', '270', '1', 'Spring', 2010, 'B+');
	insert into takes values('57213', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('53547', '274', '1', 'Fall', 2002, 'B-');
	insert into takes values('71630', '158', '1', 'Fall', 2008, 'C-');
	insert into takes values('52656', '696', '1', 'Spring', 2002, 'B-');
	insert into takes values('24197', '400', '1', 'Spring', 2007, 'A+');
	insert into takes values('36513', '105', '2', 'Fall', 2002, 'A-');
	insert into takes values('10705', '258', '1', 'Fall', 2007, 'C-');
	insert into takes values('931', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('77130', '345', '1', 'Spring', 2008, 'A-');
	insert into takes values('40080', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('75423', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('44271', '304', '1', 'Fall', 2009, 'A+');
	insert into takes values('94894', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('65987', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('57242', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('6400', '561', '1', 'Fall', 2006, 'C+');
	insert into takes values('49214', '158', '2', 'Spring', 2008, 'C-');
	insert into takes values('53047', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('90372', '629', '1', 'Spring', 2003, 'A ');
	insert into takes values('5298', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('10838', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('16993', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('96227', '496', '1', 'Fall', 2001, 'B+');
	insert into takes values('17424', '581', '1', 'Spring', 2005, 'A ');
	insert into takes values('94894', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('12979', '376', '1', 'Fall', 2006, 'A ');
	insert into takes values('44706', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('21692', '313', '1', 'Fall', 2010, 'C ');
	insert into takes values('50331', '631', '1', 'Spring', 2007, 'B+');
	insert into takes values('99268', '808', '1', 'Fall', 2003, 'C ');
	insert into takes values('34392', '642', '1', 'Fall', 2004, 'A+');
	insert into takes values('72501', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('14284', '696', '1', 'Spring', 2002, 'B+');
	insert into takes values('51238', '362', '3', 'Spring', 2008, 'C+');
	insert into takes values('83039', '793', '1', 'Spring', 2002, 'C+');
	insert into takes values('96772', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('93171', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('78572', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('28538', '696', '1', 'Spring', 2002, 'A-');
	insert into takes values('20445', '137', '1', 'Spring', 2002, 'B ');
	insert into takes values('31086', '200', '2', 'Fall', 2002, 'A+');
	insert into takes values('1402', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('68070', '591', '1', 'Spring', 2005, 'B ');
	insert into takes values('72501', '401', '1', 'Fall', 2003, 'A ');
	insert into takes values('79329', '258', '1', 'Fall', 2007, 'B+');
	insert into takes values('3739', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('74464', '927', '1', 'Fall', 2002, 'A ');
	insert into takes values('59530', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('50414', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('46980', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('4435', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('58889', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('41683', '559', '1', 'Fall', 2002, 'B ');
	insert into takes values('56882', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('22003', '960', '1', 'Fall', 2009, 'B-');
	insert into takes values('5005', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('14284', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('67021', '991', '1', 'Spring', 2008, 'A ');
	insert into takes values('31250', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('76169', '338', '2', 'Spring', 2006, 'B+');
	insert into takes values('9460', '852', '1', 'Spring', 2008, 'B ');
	insert into takes values('898', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('13211', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('13757', '482', '1', 'Fall', 2005, 'B ');
	insert into takes values('65101', '400', '2', 'Fall', 2003, 'B-');
	insert into takes values('74974', '376', '1', 'Fall', 2006, 'A ');
	insert into takes values('78922', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('3545', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('9947', '258', '1', 'Fall', 2007, 'B-');
	insert into takes values('29192', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('46155', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('3493', '237', '2', 'Fall', 2009, 'C ');
	insert into takes values('87965', '408', '2', 'Spring', 2003, 'B ');
	insert into takes values('11076', '629', '1', 'Spring', 2003, 'A ');
	insert into takes values('70395', '345', '1', 'Spring', 2008, 'C+');
	insert into takes values('70807', '489', '1', 'Fall', 2007, 'B ');
	insert into takes values('89571', '867', '2', 'Fall', 2010, 'A+');
	insert into takes values('73492', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('45570', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('46106', '461', '1', 'Fall', 2002, 'C-');
	insert into takes values('79170', '349', '1', 'Spring', 2008, 'C-');
	insert into takes values('96206', '875', '1', 'Spring', 2005, 'B-');
	insert into takes values('79170', '461', '1', 'Fall', 2002, 'B ');
	insert into takes values('96067', '400', '2', 'Fall', 2003, 'B-');
	insert into takes values('73328', '338', '1', 'Spring', 2007, 'B ');
	insert into takes values('52929', '893', '1', 'Fall', 2007, 'B+');
	insert into takes values('38336', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('39901', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('31302', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('40371', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('23457', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('5144', '338', '1', 'Spring', 2007, 'A+');
	insert into takes values('78434', '747', '1', 'Spring', 2004, 'C-');
	insert into takes values('38545', '400', '1', 'Spring', 2007, 'C+');
	insert into takes values('7973', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('88389', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('34055', '581', '1', 'Spring', 2005, 'C ');
	insert into takes values('40677', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('33546', '169', '2', 'Fall', 2002, 'A-');
	insert into takes values('14596', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('96193', '793', '1', 'Spring', 2002, 'A ');
	insert into takes values('44816', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('18821', '927', '1', 'Fall', 2002, 'C ');
	insert into takes values('60867', '692', '1', 'Spring', 2010, 'A ');
	insert into takes values('82868', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('89246', '200', '2', 'Fall', 2002, 'A ');
	insert into takes values('60748', '581', '1', 'Spring', 2005, 'C-');
	insert into takes values('38476', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('7149', '612', '1', 'Fall', 2007, 'B ');
	insert into takes values('61783', '105', '2', 'Fall', 2002, 'A ');
	insert into takes values('10663', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('20378', '591', '1', 'Spring', 2005, 'A ');
	insert into takes values('39046', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('28738', '960', '1', 'Fall', 2009, 'B+');
	insert into takes values('65688', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('22179', '581', '1', 'Spring', 2005, 'C+');
	insert into takes values('19824', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('63582', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('37350', '270', '1', 'Spring', 2010, 'B-');
	insert into takes values('27044', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('56276', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('63449', '791', '1', 'Spring', 2006, 'A ');
	insert into takes values('90609', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('22050', '338', '1', 'Spring', 2007, 'A+');
	insert into takes values('27662', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('23794', '270', '1', 'Spring', 2010, 'B+');
	insert into takes values('88085', '735', '1', 'Spring', 2003, 'A+');
	insert into takes values('23311', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('51975', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('91343', '974', '1', 'Fall', 2003, 'C-');
	insert into takes values('58935', '960', '2', 'Fall', 2006, 'B+');
	insert into takes values('79911', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('2967', '200', '2', 'Fall', 2002, 'C+');
	insert into takes values('94371', '400', '1', 'Spring', 2007, 'C+');
	insert into takes values('7602', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('85356', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('16523', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('84727', '843', '1', 'Fall', 2010, 'B-');
	insert into takes values('52157', '867', '1', 'Fall', 2006, 'B ');
	insert into takes values('85211', '415', '1', 'Fall', 2010, 'C-');
	insert into takes values('22620', '401', '1', 'Fall', 2003, 'C-');
	insert into takes values('8912', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('20180', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('32119', '237', '1', 'Spring', 2008, 'A+');
	insert into takes values('85234', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('18499', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('86833', '949', '1', 'Fall', 2007, 'C+');
	insert into takes values('99754', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('53728', '694', '1', 'Fall', 2002, 'B ');
	insert into takes values('77148', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('77231', '338', '2', 'Spring', 2006, 'C+');
	insert into takes values('42960', '808', '1', 'Fall', 2003, 'A+');
	insert into takes values('11966', '158', '1', 'Fall', 2008, 'C-');
	insert into takes values('78469', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('61403', '270', '1', 'Spring', 2010, 'A-');
	insert into takes values('98690', '334', '1', 'Fall', 2009, 'C ');
	insert into takes values('41280', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('16480', '366', '1', 'Fall', 2005, 'C ');
	insert into takes values('63040', '352', '1', 'Spring', 2006, 'A+');
	insert into takes values('95175', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('23439', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('10033', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('29002', '338', '2', 'Spring', 2006, 'C+');
	insert into takes values('89571', '760', '1', 'Spring', 2004, 'C-');
	insert into takes values('28352', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('50583', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('66054', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('99271', '735', '2', 'Spring', 2010, 'A ');
	insert into takes values('68150', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('35687', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('69732', '443', '2', 'Spring', 2002, 'A+');
	insert into takes values('69285', '760', '1', 'Spring', 2004, 'A-');
	insert into takes values('35357', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('32065', '158', '2', 'Spring', 2008, 'B+');
	insert into takes values('95697', '747', '1', 'Spring', 2004, 'A ');
	insert into takes values('61166', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('38545', '960', '1', 'Fall', 2009, 'A+');
	insert into takes values('61332', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('69752', '334', '1', 'Fall', 2009, 'B ');
	insert into takes values('37284', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('21552', '169', '1', 'Spring', 2007, 'C ');
	insert into takes values('3693', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('89571', '747', '1', 'Spring', 2004, 'C ');
	insert into takes values('78581', '105', '1', 'Fall', 2009, 'B+');
	insert into takes values('74911', '808', '1', 'Fall', 2003, 'B-');
	insert into takes values('64249', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('16297', '581', '1', 'Spring', 2005, 'C+');
	insert into takes values('57538', '415', '1', 'Fall', 2010, 'B ');
	insert into takes values('19638', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('97590', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('98359', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('16631', '200', '1', 'Spring', 2007, 'A ');
	insert into takes values('89106', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('39204', '496', '1', 'Fall', 2001, 'B-');
	insert into takes values('56232', '867', '1', 'Fall', 2006, 'B ');
	insert into takes values('47824', '867', '2', 'Fall', 2010, 'C-');
	insert into takes values('81294', '338', '1', 'Spring', 2007, 'B-');
	insert into takes values('98140', '489', '1', 'Fall', 2007, 'A-');
	insert into takes values('67033', '445', '1', 'Spring', 2001, 'B-');
	insert into takes values('48247', '237', '2', 'Fall', 2009, 'C ');
	insert into takes values('24865', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('58307', '401', '1', 'Fall', 2003, 'C+');
	insert into takes values('93814', '927', '1', 'Fall', 2002, 'C-');
	insert into takes values('24374', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('41491', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('83511', '972', '1', 'Spring', 2009, 'A ');
	insert into takes values('5298', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('45300', '561', '1', 'Fall', 2006, 'A+');
	insert into takes values('6523', '959', '1', 'Fall', 2006, 'A ');
	insert into takes values('60267', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('16297', '421', '1', 'Fall', 2004, 'C-');
	insert into takes values('8426', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('11578', '200', '1', 'Spring', 2007, 'C ');
	insert into takes values('39046', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('99711', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('12078', '679', '1', 'Spring', 2010, 'B-');
	insert into takes values('9953', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('32954', '793', '1', 'Spring', 2002, 'C ');
	insert into takes values('51084', '802', '1', 'Spring', 2003, 'B+');
	insert into takes values('46694', '489', '1', 'Fall', 2007, 'C ');
	insert into takes values('65190', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('93653', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('34542', '631', '1', 'Spring', 2007, 'B ');
	insert into takes values('51416', '581', '1', 'Spring', 2005, 'B+');
	insert into takes values('76057', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('8251', '137', '1', 'Spring', 2002, 'B ');
	insert into takes values('41890', '486', '1', 'Fall', 2009, 'B ');
	insert into takes values('82082', '319', '1', 'Spring', 2003, 'C+');
	insert into takes values('19603', '239', '1', 'Fall', 2006, 'C+');
	insert into takes values('80420', '158', '1', 'Fall', 2008, 'A-');
	insert into takes values('3143', '415', '1', 'Fall', 2010, 'B-');
	insert into takes values('19917', '105', '1', 'Fall', 2009, 'B+');
	insert into takes values('52750', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('35175', '401', '1', 'Fall', 2003, 'C-');
	insert into takes values('20974', '158', '1', 'Fall', 2008, 'A-');
	insert into takes values('70235', '426', '1', 'Spring', 2006, 'C ');
	insert into takes values('60688', '376', '1', 'Fall', 2006, 'C ');
	insert into takes values('66293', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('89059', '974', '1', 'Fall', 2003, 'A-');
	insert into takes values('78143', '747', '1', 'Spring', 2004, 'C ');
	insert into takes values('94814', '747', '1', 'Spring', 2004, 'B+');
	insert into takes values('27898', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('15328', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('73268', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('53172', '489', '1', 'Fall', 2007, 'B ');
	insert into takes values('17831', '599', '1', 'Spring', 2003, 'A ');
	insert into takes values('36303', '304', '1', 'Fall', 2009, 'A+');
	insert into takes values('56276', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('987', '366', '1', 'Fall', 2005, 'B ');
	insert into takes values('82868', '169', '1', 'Spring', 2007, 'A ');
	insert into takes values('41299', '629', '1', 'Spring', 2003, 'B ');
	insert into takes values('25942', '694', '1', 'Fall', 2002, 'B ');
	insert into takes values('5399', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('29803', '349', '1', 'Spring', 2008, 'A-');
	insert into takes values('45083', '313', '1', 'Fall', 2010, 'A+');
	insert into takes values('47670', '493', '1', 'Spring', 2010, 'C-');
	insert into takes values('11510', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('78454', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('69225', '169', '2', 'Fall', 2002, 'B-');
	insert into takes values('52385', '559', '1', 'Fall', 2002, 'B+');
	insert into takes values('22258', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('53728', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('48462', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('64140', '158', '2', 'Spring', 2008, 'A ');
	insert into takes values('70807', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('71944', '457', '1', 'Spring', 2001, 'A ');
	insert into takes values('81396', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('72657', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('35', '468', '1', 'Fall', 2005, 'B ');
	insert into takes values('18809', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('69850', '489', '1', 'Fall', 2007, 'B ');
	insert into takes values('95027', '527', '1', 'Fall', 2004, 'C+');
	insert into takes values('72177', '893', '1', 'Fall', 2007, 'B ');
	insert into takes values('98359', '408', '2', 'Spring', 2003, 'A ');
	insert into takes values('80285', '599', '1', 'Spring', 2003, 'B+');
	insert into takes values('51084', '258', '1', 'Fall', 2007, 'A ');
	insert into takes values('64642', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('55857', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('58874', '338', '2', 'Spring', 2006, 'C ');
	insert into takes values('34542', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('68395', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('86327', '169', '2', 'Fall', 2002, 'B-');
	insert into takes values('30896', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('81538', '642', '1', 'Fall', 2004, 'B-');
	insert into takes values('23311', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('11455', '959', '1', 'Fall', 2006, 'C+');
	insert into takes values('17133', '352', '1', 'Spring', 2006, 'A-');
	insert into takes values('34770', '313', '1', 'Fall', 2010, 'B+');
	insert into takes values('37284', '408', '2', 'Spring', 2003, 'A ');
	insert into takes values('77234', '319', '1', 'Spring', 2003, 'C+');
	insert into takes values('66293', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('7287', '599', '1', 'Spring', 2003, 'A+');
	insert into takes values('34329', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('27044', '496', '1', 'Fall', 2001, 'A+');
	insert into takes values('99422', '704', '1', 'Spring', 2008, 'C-');
	insert into takes values('29031', '482', '1', 'Fall', 2005, 'B ');
	insert into takes values('56499', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('48469', '959', '1', 'Fall', 2006, 'B ');
	insert into takes values('94522', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('29863', '408', '2', 'Spring', 2003, 'A+');
	insert into takes values('51203', '400', '1', 'Spring', 2007, 'C ');
	insert into takes values('32490', '338', '2', 'Spring', 2006, 'B ');
	insert into takes values('81566', '457', '1', 'Spring', 2001, 'A ');
	insert into takes values('58701', '415', '1', 'Fall', 2010, 'A-');
	insert into takes values('21246', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('38013', '242', '1', 'Fall', 2009, 'C+');
	insert into takes values('33338', '349', '1', 'Spring', 2008, 'B+');
	insert into takes values('75231', '704', '1', 'Spring', 2008, 'B ');
	insert into takes values('59455', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('83002', '313', '1', 'Fall', 2010, 'C+');
	insert into takes values('93004', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('90567', '313', '1', 'Fall', 2010, 'B+');
	insert into takes values('81028', '401', '1', 'Fall', 2003, 'C ');
	insert into takes values('71025', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('67018', '694', '1', 'Fall', 2002, 'C+');
	insert into takes values('78758', '960', '1', 'Fall', 2009, 'C-');
	insert into takes values('17600', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('75173', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('11510', '591', '1', 'Spring', 2005, 'C+');
	insert into takes values('48053', '476', '1', 'Fall', 2010, 'C-');
	insert into takes values('87831', '927', '1', 'Fall', 2002, 'A+');
	insert into takes values('7490', '692', '1', 'Spring', 2010, 'C+');
	insert into takes values('72165', '867', '1', 'Fall', 2006, 'B+');
	insert into takes values('33546', '962', '1', 'Spring', 2008, 'C+');
	insert into takes values('52872', '445', '1', 'Spring', 2001, 'B-');
	insert into takes values('35293', '949', '1', 'Fall', 2007, 'A-');
	insert into takes values('94766', '258', '1', 'Fall', 2007, 'A ');
	insert into takes values('62549', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('282', '493', '1', 'Spring', 2010, 'B+');
	insert into takes values('7970', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('49339', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('4435', '559', '1', 'Fall', 2002, 'B+');
	insert into takes values('13511', '545', '1', 'Fall', 2001, 'B ');
	insert into takes values('19293', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('81258', '345', '1', 'Spring', 2008, 'C+');
	insert into takes values('88884', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('78332', '445', '1', 'Spring', 2001, 'C+');
	insert into takes values('38013', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('63288', '105', '1', 'Fall', 2009, 'A+');
	insert into takes values('94173', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('24746', '679', '1', 'Spring', 2010, 'A+');
	insert into takes values('79697', '169', '1', 'Spring', 2007, 'A-');
	insert into takes values('49214', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('15457', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('3335', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('23311', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('66484', '704', '1', 'Spring', 2008, 'C ');
	insert into takes values('84515', '421', '1', 'Fall', 2004, 'C ');
	insert into takes values('89734', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('75791', '793', '1', 'Spring', 2002, 'C ');
	insert into takes values('107', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('25468', '571', '1', 'Spring', 2004, 'B+');
	insert into takes values('17424', '158', '2', 'Spring', 2008, 'A-');
	insert into takes values('89140', '864', '1', 'Spring', 2006, 'A+');
	insert into takes values('92839', '401', '1', 'Fall', 2003, 'C+');
	insert into takes values('87015', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('61332', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('94142', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('89234', '561', '1', 'Fall', 2006, 'B-');
	insert into takes values('68248', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('68395', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('61364', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('48469', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('38902', '561', '1', 'Fall', 2006, 'A-');
	insert into takes values('58081', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('61003', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('86344', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('28361', '791', '1', 'Spring', 2006, 'A ');
	insert into takes values('80610', '345', '1', 'Spring', 2008, 'C+');
	insert into takes values('8252', '875', '1', 'Spring', 2005, 'A-');
	insert into takes values('25528', '545', '1', 'Fall', 2001, 'A ');
	insert into takes values('41988', '345', '1', 'Spring', 2008, 'B ');
	insert into takes values('58300', '735', '1', 'Spring', 2003, 'A ');
	insert into takes values('79534', '972', '1', 'Spring', 2009, 'B+');
	insert into takes values('9953', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('53048', '137', '1', 'Spring', 2002, 'A ');
	insert into takes values('35498', '319', '1', 'Spring', 2003, 'B ');
	insert into takes values('48861', '345', '1', 'Spring', 2008, 'B ');
	insert into takes values('53077', '408', '1', 'Spring', 2007, 'C+');
	insert into takes values('96134', '415', '1', 'Fall', 2010, 'C-');
	insert into takes values('26028', '631', '1', 'Spring', 2007, 'A+');
	insert into takes values('2629', '696', '1', 'Spring', 2002, 'A-');
	insert into takes values('45650', '949', '1', 'Fall', 2007, 'C+');
	insert into takes values('12069', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('69081', '631', '1', 'Spring', 2007, 'B+');
	insert into takes values('63289', '345', '1', 'Spring', 2008, 'A-');
	insert into takes values('26695', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('40059', '962', '1', 'Spring', 2008, 'B ');
	insert into takes values('82126', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('21556', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('52471', '169', '2', 'Fall', 2002, 'A ');
	insert into takes values('43432', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('36019', '571', '1', 'Spring', 2004, 'C ');
	insert into takes values('32368', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('14065', '692', '1', 'Spring', 2010, 'B-');
	insert into takes values('60249', '349', '1', 'Spring', 2008, 'C-');
	insert into takes values('68516', '545', '1', 'Fall', 2001, 'C ');
	insert into takes values('93366', '496', '1', 'Fall', 2001, 'B+');
	insert into takes values('58874', '581', '1', 'Spring', 2005, 'C-');
	insert into takes values('89051', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('52203', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('24002', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('19638', '468', '1', 'Fall', 2005, 'B ');
	insert into takes values('25143', '461', '1', 'Fall', 2002, 'A-');
	insert into takes values('5871', '960', '2', 'Fall', 2006, 'B+');
	insert into takes values('68278', '457', '1', 'Spring', 2001, 'C-');
	insert into takes values('45200', '468', '2', 'Fall', 2007, 'A+');
	insert into takes values('52120', '352', '1', 'Spring', 2006, 'B+');
	insert into takes values('62832', '599', '1', 'Spring', 2003, 'B ');
	insert into takes values('16593', '242', '1', 'Fall', 2009, 'A+');
	insert into takes values('16075', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('86327', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('34329', '338', '2', 'Spring', 2006, 'A-');
	insert into takes values('84808', '486', '1', 'Fall', 2009, 'C+');
	insert into takes values('3005', '927', '1', 'Fall', 2002, 'C-');
	insert into takes values('1533', '626', '1', 'Fall', 2006, 'B ');
	insert into takes values('53496', '445', '1', 'Spring', 2001, 'A-');
	insert into takes values('3651', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('72014', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('81245', '559', '1', 'Fall', 2002, 'B ');
	insert into takes values('88302', '304', '1', 'Fall', 2009, 'A ');
	insert into takes values('96178', '443', '1', 'Spring', 2010, 'A ');
	insert into takes values('51868', '304', '1', 'Fall', 2009, 'A+');
	insert into takes values('72165', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('80698', '239', '1', 'Fall', 2006, 'C-');
	insert into takes values('39520', '443', '2', 'Spring', 2002, 'C-');
	insert into takes values('4355', '760', '1', 'Spring', 2004, 'A ');
	insert into takes values('53077', '366', '1', 'Fall', 2005, 'A ');
	insert into takes values('4645', '482', '1', 'Fall', 2005, 'C ');
	insert into takes values('79352', '603', '1', 'Fall', 2003, 'B-');
	insert into takes values('3493', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('71904', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('52120', '604', '1', 'Spring', 2009, 'A ');
	insert into takes values('27898', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('11152', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('99226', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('37856', '927', '1', 'Fall', 2002, 'B-');
	insert into takes values('24784', '626', '1', 'Fall', 2006, 'B ');
	insert into takes values('36244', '496', '1', 'Fall', 2001, 'A+');
	insert into takes values('50664', '960', '1', 'Fall', 2009, 'B-');
	insert into takes values('94894', '237', '1', 'Spring', 2008, 'B-');
	insert into takes values('23373', '169', '2', 'Fall', 2002, 'C ');
	insert into takes values('13506', '793', '1', 'Spring', 2002, 'C ');
	insert into takes values('50944', '415', '1', 'Fall', 2010, 'A-');
	insert into takes values('89051', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('22179', '366', '1', 'Fall', 2005, 'C ');
	insert into takes values('44584', '158', '2', 'Spring', 2008, 'A-');
	insert into takes values('4682', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('26494', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('94894', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('47379', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('14829', '443', '2', 'Spring', 2002, 'B-');
	insert into takes values('72485', '642', '1', 'Fall', 2004, 'B-');
	insert into takes values('97658', '631', '1', 'Spring', 2007, 'A-');
	insert into takes values('60224', '875', '1', 'Spring', 2005, 'A ');
	insert into takes values('79487', '867', '2', 'Fall', 2010, 'B-');
	insert into takes values('45436', '443', '2', 'Spring', 2002, 'C ');
	insert into takes values('95366', '105', '1', 'Fall', 2009, 'B ');
	insert into takes values('9933', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('97228', '258', '1', 'Fall', 2007, 'A+');
	insert into takes values('99250', '482', '1', 'Fall', 2005, 'A-');
	insert into takes values('53424', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('90004', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('74163', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('99289', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('81638', '489', '1', 'Fall', 2007, 'B-');
	insert into takes values('65121', '795', '1', 'Spring', 2004, 'A-');
	insert into takes values('79469', '366', '1', 'Fall', 2005, 'C ');
	insert into takes values('1727', '559', '1', 'Fall', 2002, 'A-');
	insert into takes values('96193', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('88045', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('54610', '457', '1', 'Spring', 2001, 'B-');
	insert into takes values('66008', '974', '1', 'Fall', 2003, 'A+');
	insert into takes values('14023', '443', '1', 'Spring', 2010, 'B+');
	insert into takes values('30772', '457', '1', 'Spring', 2001, 'C+');
	insert into takes values('25068', '581', '1', 'Spring', 2005, 'A-');
	insert into takes values('43016', '270', '1', 'Spring', 2010, 'B-');
	insert into takes values('28738', '747', '1', 'Spring', 2004, 'B-');
	insert into takes values('23449', '366', '1', 'Fall', 2005, 'C ');
	insert into takes values('66293', '304', '1', 'Fall', 2009, 'A+');
	insert into takes values('42991', '270', '1', 'Spring', 2010, 'C+');
	insert into takes values('23794', '169', '2', 'Fall', 2002, 'B+');
	insert into takes values('14621', '137', '1', 'Spring', 2002, 'A-');
	insert into takes values('72055', '200', '2', 'Fall', 2002, 'B+');
	insert into takes values('75560', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('10267', '793', '1', 'Spring', 2002, 'C ');
	insert into takes values('39892', '875', '1', 'Spring', 2005, 'B+');
	insert into takes values('14032', '338', '1', 'Spring', 2007, 'A+');
	insert into takes values('37653', '313', '1', 'Fall', 2010, 'C-');
	insert into takes values('33837', '599', '1', 'Spring', 2003, 'C ');
	insert into takes values('57941', '496', '1', 'Fall', 2001, 'B-');
	insert into takes values('89000', '852', '1', 'Spring', 2008, 'B-');
	insert into takes values('59530', '482', '1', 'Fall', 2005, 'A ');
	insert into takes values('67560', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('55354', '793', '1', 'Spring', 2002, 'B+');
	insert into takes values('23392', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('20540', '486', '1', 'Fall', 2009, 'A-');
	insert into takes values('50414', '258', '1', 'Fall', 2007, 'A+');
	insert into takes values('30650', '748', '1', 'Fall', 2003, 'B-');
	insert into takes values('35687', '571', '1', 'Spring', 2004, 'C+');
	insert into takes values('37449', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('41491', '960', '1', 'Fall', 2009, 'B+');
	insert into takes values('3639', '237', '2', 'Fall', 2009, 'C+');
	insert into takes values('30943', '631', '1', 'Spring', 2007, 'A+');
	insert into takes values('28977', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('40558', '313', '1', 'Fall', 2010, 'C ');
	insert into takes values('32065', '349', '1', 'Spring', 2008, 'C-');
	insert into takes values('19293', '158', '2', 'Spring', 2008, 'A ');
	insert into takes values('31476', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('29803', '426', '1', 'Spring', 2006, 'A+');
	insert into takes values('48471', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('16347', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('92332', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('69122', '457', '1', 'Spring', 2001, 'A-');
	insert into takes values('11419', '663', '1', 'Spring', 2005, 'B ');
	insert into takes values('90353', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('51862', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('19450', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('89759', '461', '1', 'Fall', 2002, 'B-');
	insert into takes values('11377', '169', '1', 'Spring', 2007, 'A ');
	insert into takes values('5925', '626', '1', 'Fall', 2006, 'A-');
	insert into takes values('6367', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('68242', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('80941', '242', '1', 'Fall', 2009, 'C+');
	insert into takes values('38899', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('79329', '158', '1', 'Fall', 2008, 'B+');
	insert into takes values('39925', '239', '1', 'Fall', 2006, 'B-');
	insert into takes values('35357', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('13211', '571', '1', 'Spring', 2004, 'C ');
	insert into takes values('67655', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('23525', '962', '1', 'Spring', 2008, 'B-');
	insert into takes values('67542', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('31820', '426', '1', 'Spring', 2006, 'A ');
	insert into takes values('99710', '415', '1', 'Fall', 2010, 'B ');
	insert into takes values('98870', '158', '2', 'Spring', 2008, 'C-');
	insert into takes values('35523', '352', '1', 'Spring', 2006, 'B+');
	insert into takes values('75510', '169', '1', 'Spring', 2007, 'C+');
	insert into takes values('8807', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('49982', '843', '1', 'Fall', 2010, 'B-');
	insert into takes values('64222', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('95205', '692', '1', 'Spring', 2010, 'C+');
	insert into takes values('667', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('5617', '401', '1', 'Fall', 2003, 'C+');
	insert into takes values('11530', '702', '1', 'Spring', 2001, 'C ');
	insert into takes values('36513', '334', '1', 'Fall', 2009, 'C-');
	insert into takes values('16311', '629', '1', 'Spring', 2003, 'B+');
	insert into takes values('61403', '927', '1', 'Fall', 2002, 'C-');
	insert into takes values('40937', '663', '1', 'Spring', 2005, 'B ');
	insert into takes values('1220', '493', '1', 'Spring', 2010, 'A-');
	insert into takes values('75123', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('34197', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('35362', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('75596', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('52523', '158', '1', 'Fall', 2008, 'B-');
	insert into takes values('45083', '702', '1', 'Spring', 2001, 'C-');
	insert into takes values('83557', '793', '1', 'Spring', 2002, 'B ');
	insert into takes values('95320', '991', '1', 'Spring', 2008, 'C-');
	insert into takes values('7498', '366', '1', 'Fall', 2005, 'C-');
	insert into takes values('2133', '362', '2', 'Fall', 2006, 'A ');
	insert into takes values('44352', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('1220', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('96178', '793', '1', 'Spring', 2002, 'B+');
	insert into takes values('34788', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('49073', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('46337', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('40080', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('987', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('90914', '631', '1', 'Spring', 2007, 'B ');
	insert into takes values('66495', '468', '1', 'Fall', 2005, 'B+');
	insert into takes values('6474', '795', '1', 'Spring', 2004, 'A-');
	insert into takes values('19450', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('1018', '239', '1', 'Fall', 2006, 'B-');
	insert into takes values('56139', '362', '1', 'Fall', 2005, 'C ');
	insert into takes values('33817', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('49205', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('89000', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('29871', '843', '1', 'Fall', 2010, 'C ');
	insert into takes values('95574', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('85356', '401', '1', 'Fall', 2003, 'C-');
	insert into takes values('14596', '334', '1', 'Fall', 2009, 'B ');
	insert into takes values('10267', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('88085', '702', '1', 'Spring', 2001, 'A-');
	insert into takes values('58300', '400', '2', 'Fall', 2003, 'B+');
	insert into takes values('38668', '400', '1', 'Spring', 2007, 'A-');
	insert into takes values('10736', '571', '1', 'Spring', 2004, 'B+');
	insert into takes values('18469', '366', '1', 'Fall', 2005, 'A ');
	insert into takes values('24116', '629', '1', 'Spring', 2003, 'B ');
	insert into takes values('61364', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('28133', '338', '1', 'Spring', 2007, 'B-');
	insert into takes values('66763', '843', '1', 'Fall', 2010, 'C ');
	insert into takes values('15430', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('92776', '867', '2', 'Fall', 2010, 'C-');
	insert into takes values('49391', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('52057', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('21009', '591', '1', 'Spring', 2005, 'C+');
	insert into takes values('2561', '949', '1', 'Fall', 2007, 'B ');
	insert into takes values('7390', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('87193', '366', '1', 'Fall', 2005, 'B ');
	insert into takes values('24387', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('7970', '445', '1', 'Spring', 2001, 'B+');
	insert into takes values('98359', '376', '1', 'Fall', 2006, 'C+');
	insert into takes values('18821', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('10556', '561', '1', 'Fall', 2006, 'C-');
	insert into takes values('22260', '258', '1', 'Fall', 2007, 'A+');
	insert into takes values('59530', '599', '1', 'Spring', 2003, 'B-');
	insert into takes values('15024', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('59046', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('77172', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('76173', '867', '2', 'Fall', 2010, 'A+');
	insert into takes values('15487', '867', '1', 'Fall', 2006, 'A ');
	insert into takes values('88358', '401', '1', 'Fall', 2003, 'B+');
	insert into takes values('89414', '962', '1', 'Spring', 2008, 'B-');
	insert into takes values('18809', '493', '1', 'Spring', 2010, 'A ');
	insert into takes values('85211', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('35293', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('39657', '376', '1', 'Fall', 2006, 'B ');
	insert into takes values('59517', '631', '1', 'Spring', 2007, 'A-');
	insert into takes values('90234', '158', '2', 'Spring', 2008, 'C+');
	insert into takes values('66356', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('5961', '867', '2', 'Fall', 2010, 'C-');
	insert into takes values('45359', '239', '1', 'Fall', 2006, 'C+');
	insert into takes values('61356', '631', '1', 'Spring', 2007, 'C+');
	insert into takes values('11055', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('41280', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('82126', '349', '1', 'Spring', 2008, 'B+');
	insert into takes values('81538', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('56941', '258', '1', 'Fall', 2007, 'A ');
	insert into takes values('25077', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('21789', '457', '1', 'Spring', 2001, 'C+');
	insert into takes values('53588', '468', '1', 'Fall', 2005, 'C+');
	insert into takes values('69632', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('62429', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('35175', '362', '3', 'Spring', 2008, 'A+');
	insert into takes values('34542', '603', '1', 'Fall', 2003, 'A+');
	insert into takes values('63289', '571', '1', 'Spring', 2004, 'A+');
	insert into takes values('27898', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('22618', '105', '2', 'Fall', 2002, 'B+');
	insert into takes values('61854', '313', '1', 'Fall', 2010, 'C+');
	insert into takes values('63361', '581', '1', 'Spring', 2005, 'C-');
	insert into takes values('22258', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('98120', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('4682', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('69960', '362', '2', 'Fall', 2006, 'B-');
	insert into takes values('499', '352', '1', 'Spring', 2006, 'C ');
	insert into takes values('94178', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('62728', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('66054', '735', '2', 'Spring', 2010, 'B-');
	insert into takes values('34197', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('99422', '603', '1', 'Fall', 2003, 'B-');
	insert into takes values('95089', '338', '2', 'Spring', 2006, 'A ');
	insert into takes values('52187', '443', '1', 'Spring', 2010, 'A-');
	insert into takes values('99289', '237', '1', 'Spring', 2008, 'C+');
	insert into takes values('67725', '468', '2', 'Fall', 2007, 'B ');
	insert into takes values('14628', '808', '1', 'Fall', 2003, 'B ');
	insert into takes values('10076', '696', '1', 'Spring', 2002, 'A-');
	insert into takes values('70389', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('41211', '852', '1', 'Spring', 2008, 'C+');
	insert into takes values('68280', '972', '1', 'Spring', 2009, 'C ');
	insert into takes values('39612', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('41674', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('84727', '493', '1', 'Spring', 2010, 'B ');
	insert into takes values('19848', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('62795', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('47487', '169', '2', 'Fall', 2002, 'A+');
	insert into takes values('15487', '603', '1', 'Fall', 2003, 'B+');
	insert into takes values('83002', '927', '1', 'Fall', 2002, 'C+');
	insert into takes values('39580', '559', '1', 'Fall', 2002, 'C-');
	insert into takes values('33206', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('41894', '415', '1', 'Fall', 2010, 'C ');
	insert into takes values('93354', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('3127', '591', '1', 'Spring', 2005, 'B-');
	insert into takes values('73387', '258', '1', 'Fall', 2007, 'C ');
	insert into takes values('72959', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('53788', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('82083', '338', '1', 'Spring', 2007, 'A-');
	insert into takes values('17676', '867', '1', 'Fall', 2006, 'A-');
	insert into takes values('61127', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('13352', '338', '1', 'Spring', 2007, 'B ');
	insert into takes values('16528', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('67542', '694', '1', 'Fall', 2002, 'A+');
	insert into takes values('22003', '559', '1', 'Fall', 2002, 'A ');
	insert into takes values('90089', '304', '1', 'Fall', 2009, 'C+');
	insert into takes values('40059', '694', '1', 'Fall', 2002, 'C ');
	insert into takes values('58081', '443', '1', 'Spring', 2010, 'A ');
	insert into takes values('94620', '482', '1', 'Fall', 2005, 'B ');
	insert into takes values('4173', '400', '1', 'Spring', 2007, 'A+');
	insert into takes values('74530', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('91580', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('68150', '843', '1', 'Fall', 2010, 'B+');
	insert into takes values('108', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('33759', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('17607', '642', '1', 'Fall', 2004, 'B-');
	insert into takes values('13504', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('8986', '319', '1', 'Spring', 2003, 'C+');
	insert into takes values('81984', '852', '1', 'Spring', 2008, 'A ');
	insert into takes values('51093', '237', '1', 'Spring', 2008, 'B+');
	insert into takes values('83592', '949', '1', 'Fall', 2007, 'C-');
	insert into takes values('26028', '457', '1', 'Spring', 2001, 'A-');
	insert into takes values('59290', '893', '1', 'Fall', 2007, 'B-');
	insert into takes values('9084', '274', '1', 'Fall', 2002, 'B ');
	insert into takes values('10267', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('20195', '338', '2', 'Spring', 2006, 'A ');
	insert into takes values('40303', '893', '1', 'Fall', 2007, 'A ');
	insert into takes values('97590', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('36845', '974', '1', 'Fall', 2003, 'C-');
	insert into takes values('8807', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('52076', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('2795', '631', '1', 'Spring', 2007, 'C+');
	insert into takes values('32881', '927', '1', 'Fall', 2002, 'B-');
	insert into takes values('62728', '694', '1', 'Fall', 2002, 'B ');
	insert into takes values('29514', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('69730', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('65299', '362', '2', 'Fall', 2006, 'A ');
	insert into takes values('25362', '489', '1', 'Fall', 2007, 'A ');
	insert into takes values('81258', '258', '1', 'Fall', 2007, 'C-');
	insert into takes values('56139', '443', '1', 'Spring', 2010, 'A-');
	insert into takes values('37653', '105', '1', 'Fall', 2009, 'B ');
	insert into takes values('88389', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('51723', '258', '1', 'Fall', 2007, 'B+');
	insert into takes values('23457', '867', '1', 'Fall', 2006, 'B+');
	insert into takes values('28829', '843', '1', 'Fall', 2010, 'A+');
	insert into takes values('26802', '200', '1', 'Spring', 2007, 'A+');
	insert into takes values('31820', '559', '1', 'Fall', 2002, 'B ');
	insert into takes values('32245', '200', '1', 'Spring', 2007, 'A+');
	insert into takes values('7732', '663', '1', 'Spring', 2005, 'B-');
	insert into takes values('36513', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('11604', '599', '1', 'Spring', 2003, 'A-');
	insert into takes values('31486', '962', '1', 'Spring', 2008, 'A+');
	insert into takes values('77218', '105', '1', 'Fall', 2009, 'C+');
	insert into takes values('23373', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('19766', '960', '2', 'Fall', 2006, 'B-');
	insert into takes values('8347', '338', '2', 'Spring', 2006, 'A ');
	insert into takes values('760', '489', '1', 'Fall', 2007, 'A ');
	insert into takes values('27898', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('22170', '702', '1', 'Spring', 2001, 'C ');
	insert into takes values('66212', '991', '1', 'Spring', 2008, 'A ');
	insert into takes values('67657', '748', '1', 'Fall', 2003, 'C ');
	insert into takes values('544', '527', '1', 'Fall', 2004, 'C-');
	insert into takes values('30289', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('75513', '239', '1', 'Fall', 2006, 'C-');
	insert into takes values('49813', '408', '1', 'Spring', 2007, 'B ');
	insert into takes values('78758', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('51923', '545', '1', 'Fall', 2001, 'A ');
	insert into takes values('71025', '927', '1', 'Fall', 2002, 'C ');
	insert into takes values('80254', '376', '1', 'Fall', 2006, 'B ');
	insert into takes values('13757', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('1812', '571', '1', 'Spring', 2004, 'A+');
	insert into takes values('46106', '258', '1', 'Fall', 2007, 'C ');
	insert into takes values('18740', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('31761', '991', '1', 'Spring', 2008, 'B ');
	insert into takes values('16075', '137', '1', 'Spring', 2002, 'A-');
	insert into takes values('36102', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('56232', '274', '1', 'Fall', 2002, 'A+');
	insert into takes values('62152', '352', '1', 'Spring', 2006, 'C+');
	insert into takes values('72358', '313', '1', 'Fall', 2010, 'A+');
	insert into takes values('31560', '747', '1', 'Spring', 2004, 'B+');
	insert into takes values('27528', '242', '1', 'Fall', 2009, 'A ');
	insert into takes values('90009', '527', '1', 'Fall', 2004, 'C ');
	insert into takes values('81566', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('18821', '599', '1', 'Spring', 2003, 'A-');
	insert into takes values('57377', '545', '1', 'Fall', 2001, 'B ');
	insert into takes values('49813', '631', '1', 'Spring', 2007, 'B ');
	insert into takes values('63243', '445', '1', 'Spring', 2001, 'C ');
	insert into takes values('41345', '875', '1', 'Spring', 2005, 'A+');
	insert into takes values('24010', '692', '1', 'Spring', 2010, 'C+');
	insert into takes values('81883', '169', '2', 'Fall', 2002, 'B-');
	insert into takes values('77231', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('65987', '169', '1', 'Spring', 2007, 'A ');
	insert into takes values('56882', '696', '1', 'Spring', 2002, 'B+');
	insert into takes values('74530', '270', '1', 'Spring', 2010, 'C-');
	insert into takes values('32119', '443', '2', 'Spring', 2002, 'A ');
	insert into takes values('81031', '362', '2', 'Fall', 2006, 'A ');
	insert into takes values('21401', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('80698', '200', '1', 'Spring', 2007, 'B+');
	insert into takes values('93653', '376', '1', 'Fall', 2006, 'B ');
	insert into takes values('39254', '415', '1', 'Fall', 2010, 'C+');
	insert into takes values('32065', '443', '1', 'Spring', 2010, 'C+');
	insert into takes values('27956', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('56003', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('65979', '927', '1', 'Fall', 2002, 'C+');
	insert into takes values('61527', '696', '1', 'Spring', 2002, 'B-');
	insert into takes values('95631', '949', '1', 'Fall', 2007, 'C-');
	insert into takes values('72485', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('36303', '626', '1', 'Fall', 2006, 'B+');
	insert into takes values('31761', '457', '1', 'Spring', 2001, 'C-');
	insert into takes values('24865', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('55859', '443', '2', 'Spring', 2002, 'C-');
	insert into takes values('99754', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('8140', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('28977', '679', '1', 'Spring', 2010, 'C+');
	insert into takes values('50013', '443', '1', 'Spring', 2010, 'B+');
	insert into takes values('44703', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('57456', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('82688', '927', '1', 'Fall', 2002, 'A-');
	insert into takes values('1000', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('65396', '599', '1', 'Spring', 2003, 'B-');
	insert into takes values('11152', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('61166', '793', '1', 'Spring', 2002, 'A+');
	insert into takes values('87280', '808', '1', 'Fall', 2003, 'C ');
	insert into takes values('32490', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('50873', '334', '1', 'Fall', 2009, 'B-');
	insert into takes values('69628', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('57377', '105', '2', 'Fall', 2002, 'C-');
	insert into takes values('22532', '735', '2', 'Spring', 2010, 'A+');
	insert into takes values('13749', '457', '1', 'Spring', 2001, 'B+');
	insert into takes values('79170', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('43505', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('6990', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('38676', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('22325', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('30289', '239', '1', 'Fall', 2006, 'B-');
	insert into takes values('47627', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('15538', '400', '2', 'Fall', 2003, 'A+');
	insert into takes values('73268', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('37715', '443', '1', 'Spring', 2010, 'B ');
	insert into takes values('75362', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('57123', '629', '1', 'Spring', 2003, 'B-');
	insert into takes values('78787', '237', '1', 'Spring', 2008, 'B+');
	insert into takes values('40897', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('81566', '599', '1', 'Spring', 2003, 'B+');
	insert into takes values('76173', '692', '1', 'Spring', 2010, 'A ');
	insert into takes values('15030', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('68263', '169', '1', 'Spring', 2007, 'C ');
	insert into takes values('22003', '468', '1', 'Fall', 2005, 'B ');
	insert into takes values('45083', '400', '1', 'Spring', 2007, 'C+');
	insert into takes values('19862', '793', '1', 'Spring', 2002, 'A ');
	insert into takes values('64938', '445', '1', 'Spring', 2001, 'B+');
	insert into takes values('27556', '604', '1', 'Spring', 2009, 'A-');
	insert into takes values('41774', '200', '1', 'Spring', 2007, 'C ');
	insert into takes values('12941', '421', '1', 'Fall', 2004, 'A ');
	insert into takes values('33338', '158', '2', 'Spring', 2008, 'A ');
	insert into takes values('99451', '158', '1', 'Fall', 2008, 'A ');
	insert into takes values('7498', '962', '1', 'Spring', 2008, 'B-');
	insert into takes values('35293', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('29462', '400', '1', 'Spring', 2007, 'C ');
	insert into takes values('35498', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('72055', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('22912', '242', '1', 'Fall', 2009, 'C+');
	insert into takes values('5381', '376', '1', 'Fall', 2006, 'A-');
	insert into takes values('94142', '760', '1', 'Spring', 2004, 'C+');
	insert into takes values('22620', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('8603', '258', '1', 'Fall', 2007, 'A-');
	insert into takes values('72521', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('98940', '468', '2', 'Fall', 2007, 'A-');
	insert into takes values('69285', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('42565', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('32772', '808', '1', 'Fall', 2003, 'B ');
	insert into takes values('66054', '489', '1', 'Fall', 2007, 'C+');
	insert into takes values('16515', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('39115', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('37809', '604', '1', 'Spring', 2009, 'C ');
	insert into takes values('14829', '545', '1', 'Fall', 2001, 'A-');
	insert into takes values('29002', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('31137', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('92659', '105', '2', 'Fall', 2002, 'B+');
	insert into takes values('46981', '237', '1', 'Spring', 2008, 'A+');
	insert into takes values('95260', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('21008', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('46074', '270', '1', 'Spring', 2010, 'B-');
	insert into takes values('95205', '867', '2', 'Fall', 2010, 'A-');
	insert into takes values('27950', '561', '1', 'Fall', 2006, 'A ');
	insert into takes values('42991', '482', '1', 'Fall', 2005, 'B-');
	insert into takes values('25718', '338', '2', 'Spring', 2006, 'C ');
	insert into takes values('57431', '352', '1', 'Spring', 2006, 'C-');
	insert into takes values('27727', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('80941', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('72186', '489', '1', 'Fall', 2007, 'A ');
	insert into takes values('81031', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('32506', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('77172', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('33817', '949', '1', 'Fall', 2007, 'C+');
	insert into takes values('30334', '258', '1', 'Fall', 2007, 'B+');
	insert into takes values('96117', '400', '1', 'Spring', 2007, 'C ');
	insert into takes values('43123', '192', '1', 'Fall', 2002, 'C ');
	insert into takes values('34126', '408', '2', 'Spring', 2003, 'A ');
	insert into takes values('17339', '696', '1', 'Spring', 2002, 'B ');
	insert into takes values('71904', '192', '1', 'Fall', 2002, 'A+');
	insert into takes values('40044', '200', '2', 'Fall', 2002, 'B-');
	insert into takes values('92274', '559', '1', 'Fall', 2002, 'C+');
	insert into takes values('99422', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('6523', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('544', '629', '1', 'Spring', 2003, 'A ');
	insert into takes values('858', '468', '2', 'Fall', 2007, 'A-');
	insert into takes values('11126', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('32369', '313', '1', 'Fall', 2010, 'A-');
	insert into takes values('99399', '169', '1', 'Spring', 2007, 'A ');
	insert into takes values('68999', '493', '1', 'Spring', 2010, 'B+');
	insert into takes values('17128', '408', '1', 'Spring', 2007, 'C-');
	insert into takes values('43658', '457', '1', 'Spring', 2001, 'C+');
	insert into takes values('66269', '760', '1', 'Spring', 2004, 'A-');
	insert into takes values('5298', '972', '1', 'Spring', 2009, 'B+');
	insert into takes values('18775', '962', '1', 'Spring', 2008, 'C+');
	insert into takes values('68453', '258', '1', 'Fall', 2007, 'B-');
	insert into takes values('48009', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('46337', '694', '1', 'Fall', 2002, 'B ');
	insert into takes values('97551', '991', '1', 'Spring', 2008, 'C-');
	insert into takes values('87268', '735', '2', 'Spring', 2010, 'C ');
	insert into takes values('96772', '974', '1', 'Fall', 2003, 'B-');
	insert into takes values('29920', '457', '1', 'Spring', 2001, 'C-');
	insert into takes values('74163', '960', '1', 'Fall', 2009, 'A-');
	insert into takes values('75596', '959', '1', 'Fall', 2006, 'A ');
	insert into takes values('17911', '334', '1', 'Fall', 2009, 'C-');
	insert into takes values('19321', '843', '1', 'Fall', 2010, 'B-');
	insert into takes values('33460', '760', '1', 'Spring', 2004, 'B ');
	insert into takes values('72768', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('44551', '972', '1', 'Spring', 2009, 'B+');
	insert into takes values('97101', '959', '1', 'Fall', 2006, 'C+');
	insert into takes values('90381', '791', '1', 'Spring', 2006, 'A ');
	insert into takes values('5703', '169', '1', 'Spring', 2007, 'C ');
	insert into takes values('57787', '959', '1', 'Fall', 2006, 'C+');
	insert into takes values('70924', '352', '1', 'Spring', 2006, 'C+');
	insert into takes values('36265', '400', '1', 'Spring', 2007, 'B ');
	insert into takes values('89051', '962', '1', 'Spring', 2008, 'A+');
	insert into takes values('43130', '802', '1', 'Spring', 2003, 'C-');
	insert into takes values('4004', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('71628', '791', '1', 'Spring', 2006, 'A ');
	insert into takes values('12078', '962', '1', 'Spring', 2008, 'A ');
	insert into takes values('59455', '960', '2', 'Fall', 2006, 'A ');
	insert into takes values('19603', '696', '1', 'Spring', 2002, 'A-');
	insert into takes values('13290', '401', '1', 'Fall', 2003, 'C ');
	insert into takes values('88793', '962', '1', 'Spring', 2008, 'A ');
	insert into takes values('66484', '415', '1', 'Fall', 2010, 'C+');
	insert into takes values('4015', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('49339', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('52523', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('51997', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('7732', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('53788', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('91132', '338', '2', 'Spring', 2006, 'C ');
	insert into takes values('90132', '559', '1', 'Fall', 2002, 'B+');
	insert into takes values('99463', '169', '1', 'Spring', 2007, 'A-');
	insert into takes values('36265', '694', '1', 'Fall', 2002, 'B ');
	insert into takes values('43016', '791', '1', 'Spring', 2006, 'A-');
	insert into takes values('39254', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('58081', '468', '2', 'Fall', 2007, 'C+');
	insert into takes values('42956', '962', '1', 'Spring', 2008, 'C+');
	insert into takes values('91788', '426', '1', 'Spring', 2006, 'A-');
	insert into takes values('75928', '748', '1', 'Fall', 2003, 'C ');
	insert into takes values('87193', '694', '1', 'Fall', 2002, 'B-');
	insert into takes values('97551', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('84167', '612', '1', 'Fall', 2007, 'A-');
	insert into takes values('53547', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('9183', '242', '1', 'Fall', 2009, 'A ');
	insert into takes values('86736', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('81028', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('56089', '486', '1', 'Fall', 2009, 'A-');
	insert into takes values('62716', '258', '1', 'Fall', 2007, 'A-');
	insert into takes values('35523', '867', '2', 'Fall', 2010, 'C ');
	insert into takes values('847', '663', '1', 'Spring', 2005, 'B-');
	insert into takes values('83003', '591', '1', 'Spring', 2005, 'A-');
	insert into takes values('68096', '581', '1', 'Spring', 2005, 'C ');
	insert into takes values('98019', '893', '1', 'Fall', 2007, 'A-');
	insert into takes values('24010', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('60249', '345', '1', 'Spring', 2008, 'B-');
	insert into takes values('87015', '334', '1', 'Fall', 2009, 'A-');
	insert into takes values('86344', '468', '2', 'Fall', 2007, 'A+');
	insert into takes values('65101', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('68779', '270', '1', 'Spring', 2010, 'B-');
	insert into takes values('1232', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('77218', '105', '2', 'Fall', 2002, 'B-');
	insert into takes values('53048', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('47824', '704', '1', 'Spring', 2008, 'C-');
	insert into takes values('88417', '237', '1', 'Spring', 2008, 'A-');
	insert into takes values('36494', '927', '1', 'Fall', 2002, 'A+');
	insert into takes values('15726', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('67425', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('8819', '702', '1', 'Spring', 2001, 'C ');
	insert into takes values('80610', '626', '1', 'Fall', 2006, 'C+');
	insert into takes values('69241', '599', '1', 'Spring', 2003, 'A ');
	insert into takes values('94730', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('72741', '362', '2', 'Fall', 2006, 'C-');
	insert into takes values('13290', '626', '1', 'Fall', 2006, 'A ');
	insert into takes values('4004', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('27044', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('92864', '401', '1', 'Fall', 2003, 'B+');
	insert into takes values('65258', '663', '1', 'Spring', 2005, 'C-');
	insert into takes values('3640', '991', '1', 'Spring', 2008, 'B ');
	insert into takes values('5208', '974', '1', 'Fall', 2003, 'B-');
	insert into takes values('4355', '692', '1', 'Spring', 2010, 'B-');
	insert into takes values('20540', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('97679', '169', '2', 'Fall', 2002, 'B ');
	insert into takes values('66212', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('68453', '482', '1', 'Fall', 2005, 'A ');
	insert into takes values('90181', '791', '1', 'Spring', 2006, 'A-');
	insert into takes values('76911', '137', '1', 'Spring', 2002, 'B+');
	insert into takes values('18554', '468', '1', 'Fall', 2005, 'B-');
	insert into takes values('11126', '334', '1', 'Fall', 2009, 'A-');
	insert into takes values('48053', '192', '1', 'Fall', 2002, 'A+');
	insert into takes values('28316', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('23457', '927', '1', 'Fall', 2002, 'A ');
	insert into takes values('90194', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('43130', '105', '2', 'Fall', 2002, 'B-');
	insert into takes values('93043', '200', '2', 'Fall', 2002, 'B+');
	insert into takes values('62124', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('97573', '158', '2', 'Spring', 2008, 'A-');
	insert into takes values('23392', '489', '1', 'Fall', 2007, 'B+');
	insert into takes values('86651', '612', '1', 'Fall', 2007, 'A ');
	insert into takes values('6400', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('44816', '527', '1', 'Fall', 2004, 'B+');
	insert into takes values('41818', '421', '1', 'Fall', 2004, 'C+');
	insert into takes values('58172', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('17996', '493', '1', 'Spring', 2010, 'A ');
	insert into takes values('86001', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('90814', '400', '1', 'Spring', 2007, 'A+');
	insert into takes values('61356', '747', '1', 'Spring', 2004, 'A ');
	insert into takes values('66763', '927', '1', 'Fall', 2002, 'C ');
	insert into takes values('71426', '426', '1', 'Spring', 2006, 'A+');
	insert into takes values('49873', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('82063', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('36494', '867', '1', 'Fall', 2006, 'B+');
	insert into takes values('49214', '545', '1', 'Fall', 2001, 'C ');
	insert into takes values('52945', '486', '1', 'Fall', 2009, 'A ');
	insert into takes values('70359', '962', '1', 'Spring', 2008, 'C-');
	insert into takes values('14554', '692', '1', 'Spring', 2010, 'C+');
	insert into takes values('57941', '349', '1', 'Spring', 2008, 'A-');
	insert into takes values('6195', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('42843', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('36126', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('64138', '489', '1', 'Fall', 2007, 'B ');
	insert into takes values('95175', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('82974', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('3039', '852', '1', 'Spring', 2008, 'B+');
	insert into takes values('39394', '242', '1', 'Fall', 2009, 'A-');
	insert into takes values('60406', '362', '1', 'Fall', 2005, 'C ');
	insert into takes values('23934', '702', '1', 'Spring', 2001, 'C ');
	insert into takes values('76270', '571', '1', 'Spring', 2004, 'A-');
	insert into takes values('28004', '338', '2', 'Spring', 2006, 'C ');
	insert into takes values('73213', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('48678', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('54612', '496', '1', 'Fall', 2001, 'C-');
	insert into takes values('54153', '376', '1', 'Fall', 2006, 'A ');
	insert into takes values('65443', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('53185', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('75040', '237', '1', 'Spring', 2008, 'C-');
	insert into takes values('68720', '960', '1', 'Fall', 2009, 'A+');
	insert into takes values('88418', '408', '1', 'Spring', 2007, 'A-');
	insert into takes values('36402', '642', '1', 'Fall', 2004, 'C+');
	insert into takes values('86806', '270', '1', 'Spring', 2010, 'B+');
	insert into takes values('29920', '962', '1', 'Spring', 2008, 'C-');
	insert into takes values('52134', '893', '1', 'Fall', 2007, 'B+');
	insert into takes values('13757', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('1285', '599', '1', 'Spring', 2003, 'A-');
	insert into takes values('57083', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('37809', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('42960', '867', '2', 'Fall', 2010, 'A+');
	insert into takes values('59673', '612', '1', 'Fall', 2007, 'B ');
	insert into takes values('86969', '468', '1', 'Fall', 2005, 'A+');
	insert into takes values('80976', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('33546', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('17507', '599', '1', 'Spring', 2003, 'A+');
	insert into takes values('74840', '415', '1', 'Fall', 2010, 'C+');
	insert into takes values('98940', '962', '1', 'Spring', 2008, 'B-');
	insert into takes values('23457', '545', '1', 'Fall', 2001, 'B ');
	insert into takes values('81175', '642', '1', 'Fall', 2004, 'A+');
	insert into takes values('92703', '893', '1', 'Fall', 2007, 'B-');
	insert into takes values('26080', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('19917', '426', '1', 'Spring', 2006, 'C ');
	insert into takes values('85746', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('51203', '626', '1', 'Fall', 2006, 'C+');
	insert into takes values('3639', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('25942', '334', '1', 'Fall', 2009, 'B-');
	insert into takes values('93125', '696', '1', 'Spring', 2002, 'A-');
	insert into takes values('83039', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('57190', '735', '1', 'Spring', 2003, 'C-');
	insert into takes values('66269', '426', '1', 'Spring', 2006, 'C ');
	insert into takes values('50873', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('31486', '408', '2', 'Spring', 2003, 'B ');
	insert into takes values('27366', '401', '1', 'Fall', 2003, 'A-');
	insert into takes values('18367', '843', '1', 'Fall', 2010, 'C+');
	insert into takes values('57431', '421', '1', 'Fall', 2004, 'A ');
	insert into takes values('108', '443', '1', 'Spring', 2010, 'B-');
	insert into takes values('46928', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('36379', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('8347', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('74016', '258', '1', 'Fall', 2007, 'C ');
	insert into takes values('23525', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('70395', '875', '1', 'Spring', 2005, 'B+');
	insert into takes values('52669', '679', '1', 'Spring', 2010, 'C-');
	insert into takes values('62152', '591', '1', 'Spring', 2005, 'A+');
	insert into takes values('65433', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('37818', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('57780', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('52523', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('11422', '581', '1', 'Spring', 2005, 'C ');
	insert into takes values('42560', '334', '1', 'Fall', 2009, 'B+');
	insert into takes values('39514', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('82082', '612', '1', 'Fall', 2007, 'B+');
	insert into takes values('75362', '581', '1', 'Spring', 2005, 'A+');
	insert into takes values('59455', '313', '1', 'Fall', 2010, 'B+');
	insert into takes values('47487', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('69285', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('15578', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('77021', '581', '1', 'Spring', 2005, 'C+');
	insert into takes values('67657', '571', '1', 'Spring', 2004, 'C-');
	insert into takes values('39876', '545', '1', 'Fall', 2001, 'B-');
	insert into takes values('48611', '795', '1', 'Spring', 2004, 'C+');
	insert into takes values('86001', '415', '1', 'Fall', 2010, 'C ');
	insert into takes values('18367', '489', '1', 'Fall', 2007, 'A-');
	insert into takes values('40897', '400', '1', 'Spring', 2007, 'B+');
	insert into takes values('43993', '960', '1', 'Fall', 2009, 'B-');
	insert into takes values('86707', '239', '1', 'Fall', 2006, 'C+');
	insert into takes values('8251', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('6367', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('58469', '258', '1', 'Fall', 2007, 'A-');
	insert into takes values('75231', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('25528', '401', '1', 'Fall', 2003, 'C+');
	insert into takes values('48462', '559', '1', 'Fall', 2002, 'A ');
	insert into takes values('41674', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('88884', '200', '1', 'Spring', 2007, 'B-');
	insert into takes values('8986', '604', '1', 'Spring', 2009, 'C ');
	insert into takes values('21126', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('95859', '626', '1', 'Fall', 2006, 'A ');
	insert into takes values('52371', '599', '1', 'Spring', 2003, 'C ');
	insert into takes values('22396', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('65121', '443', '2', 'Spring', 2002, 'C+');
	insert into takes values('52120', '400', '2', 'Fall', 2003, 'A+');
	insert into takes values('27898', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('20002', '445', '1', 'Spring', 2001, 'B+');
	insert into takes values('21692', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('8251', '239', '1', 'Fall', 2006, 'B ');
	insert into takes values('61232', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('91370', '476', '1', 'Fall', 2010, 'B ');
	insert into takes values('44271', '591', '1', 'Spring', 2005, 'C-');
	insert into takes values('53152', '599', '1', 'Spring', 2003, 'C ');
	insert into takes values('79911', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('40189', '352', '1', 'Spring', 2006, 'A-');
	insert into takes values('7956', '366', '1', 'Fall', 2005, 'C ');
	insert into takes values('95850', '545', '1', 'Fall', 2001, 'C ');
	insert into takes values('83691', '421', '1', 'Fall', 2004, 'B-');
	insert into takes values('26881', '237', '2', 'Fall', 2009, 'C ');
	insert into takes values('8252', '793', '1', 'Spring', 2002, 'B ');
	insert into takes values('23525', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('31079', '663', '1', 'Spring', 2005, 'A-');
	insert into takes values('51868', '158', '2', 'Spring', 2008, 'A-');
	insert into takes values('99399', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('19362', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('39927', '802', '1', 'Spring', 2003, 'C-');
	insert into takes values('32368', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('13081', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('18859', '791', '1', 'Spring', 2006, 'A ');
	insert into takes values('59455', '169', '1', 'Spring', 2007, 'A ');
	insert into takes values('91788', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('38696', '421', '1', 'Fall', 2004, 'C+');
	insert into takes values('34158', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('28409', '571', '1', 'Spring', 2004, 'C ');
	insert into takes values('96324', '489', '1', 'Fall', 2007, 'B+');
	insert into takes values('10727', '352', '1', 'Spring', 2006, 'C-');
	insert into takes values('21395', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('70299', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('90353', '735', '1', 'Spring', 2003, 'A ');
	insert into takes values('71426', '852', '1', 'Spring', 2008, 'A-');
	insert into takes values('65400', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('21766', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('15457', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('78332', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('41280', '760', '1', 'Spring', 2004, 'A-');
	insert into takes values('55859', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('2177', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('79502', '748', '1', 'Fall', 2003, 'B ');
	insert into takes values('88389', '445', '1', 'Spring', 2001, 'B-');
	insert into takes values('22620', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('2133', '486', '1', 'Fall', 2009, 'A ');
	insert into takes values('82591', '338', '2', 'Spring', 2006, 'A ');
	insert into takes values('73542', '242', '1', 'Fall', 2009, 'A ');
	insert into takes values('544', '760', '1', 'Spring', 2004, 'B-');
	insert into takes values('1737', '200', '2', 'Fall', 2002, 'B+');
	insert into takes values('64297', '239', '1', 'Fall', 2006, 'C-');
	insert into takes values('41596', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('18367', '401', '1', 'Fall', 2003, 'A ');
	insert into takes values('86552', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('34392', '735', '2', 'Spring', 2010, 'A ');
	insert into takes values('13028', '959', '1', 'Fall', 2006, 'A-');
	insert into takes values('48640', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('3039', '242', '1', 'Fall', 2009, 'C-');
	insert into takes values('95260', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('28128', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('42114', '376', '1', 'Fall', 2006, 'B+');
	insert into takes values('19603', '158', '2', 'Spring', 2008, 'C+');
	insert into takes values('20099', '192', '1', 'Fall', 2002, 'C ');
	insert into takes values('78481', '105', '2', 'Fall', 2002, 'A+');
	insert into takes values('57190', '313', '1', 'Fall', 2010, 'A-');
	insert into takes values('8426', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('65433', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('50598', '843', '1', 'Fall', 2010, 'A+');
	insert into takes values('46725', '960', '1', 'Fall', 2009, 'A+');
	insert into takes values('80227', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('83039', '893', '1', 'Fall', 2007, 'A+');
	insert into takes values('56882', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('98830', '962', '1', 'Spring', 2008, 'C+');
	insert into takes values('39580', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('89246', '239', '1', 'Fall', 2006, 'C+');
	insert into takes values('4248', '629', '1', 'Spring', 2003, 'B ');
	insert into takes values('97355', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('55354', '702', '1', 'Spring', 2001, 'C-');
	insert into takes values('41938', '169', '1', 'Spring', 2007, 'A-');
	insert into takes values('53225', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('24809', '468', '1', 'Fall', 2005, 'A-');
	insert into takes values('59908', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('84654', '962', '1', 'Spring', 2008, 'A+');
	insert into takes values('99730', '795', '1', 'Spring', 2004, 'B ');
	insert into takes values('23224', '793', '1', 'Spring', 2002, 'A ');
	insert into takes values('37869', '581', '1', 'Spring', 2005, 'A-');
	insert into takes values('23311', '735', '1', 'Spring', 2003, 'B-');
	insert into takes values('1087', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('4449', '468', '1', 'Fall', 2005, 'B+');
	insert into takes values('11377', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('667', '443', '1', 'Spring', 2010, 'A-');
	insert into takes values('16969', '461', '1', 'Fall', 2002, 'B-');
	insert into takes values('32385', '972', '1', 'Spring', 2009, 'C-');
	insert into takes values('44352', '735', '1', 'Spring', 2003, 'C ');
	insert into takes values('96117', '158', '1', 'Fall', 2008, 'C-');
	insert into takes values('75596', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('54620', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('61332', '493', '1', 'Spring', 2010, 'A ');
	insert into takes values('99647', '631', '1', 'Spring', 2007, 'A+');
	insert into takes values('30896', '612', '1', 'Fall', 2007, 'B ');
	insert into takes values('75772', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('760', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('19603', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('30299', '169', '2', 'Fall', 2002, 'B+');
	insert into takes values('12683', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('27044', '599', '1', 'Spring', 2003, 'A ');
	insert into takes values('11194', '421', '1', 'Fall', 2004, 'A ');
	insert into takes values('44998', '457', '1', 'Spring', 2001, 'A+');
	insert into takes values('56139', '991', '1', 'Spring', 2008, 'A ');
	insert into takes values('29002', '468', '2', 'Fall', 2007, 'C+');
	insert into takes values('1533', '960', '1', 'Fall', 2009, 'A-');
	insert into takes values('827', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('52741', '349', '1', 'Spring', 2008, 'A ');
	insert into takes values('16593', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('65205', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('39876', '105', '2', 'Fall', 2002, 'B+');
	insert into takes values('22226', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('88553', '401', '1', 'Fall', 2003, 'C ');
	insert into takes values('98056', '362', '1', 'Fall', 2005, 'B ');
	insert into takes values('81550', '239', '1', 'Fall', 2006, 'C+');
	insert into takes values('76672', '334', '1', 'Fall', 2009, 'B ');
	insert into takes values('6712', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('28977', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('41299', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('71628', '362', '2', 'Fall', 2006, 'A ');
	insert into takes values('15698', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('30017', '401', '1', 'Fall', 2003, 'A+');
	insert into takes values('93491', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('99611', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('19293', '338', '2', 'Spring', 2006, 'B ');
	insert into takes values('31624', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('68999', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('38696', '334', '1', 'Fall', 2009, 'A ');
	insert into takes values('12078', '486', '1', 'Fall', 2009, 'C+');
	insert into takes values('10693', '415', '1', 'Fall', 2010, 'C+');
	insert into takes values('99611', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('96067', '949', '1', 'Fall', 2007, 'C ');
	insert into takes values('65400', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('31364', '169', '1', 'Spring', 2007, 'A ');
	insert into takes values('499', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('83557', '561', '1', 'Fall', 2006, 'B+');
	insert into takes values('94846', '852', '1', 'Spring', 2008, 'B ');
	insert into takes values('58874', '319', '1', 'Spring', 2003, 'C-');
	insert into takes values('11377', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('81207', '496', '1', 'Fall', 2001, 'A+');
	insert into takes values('81610', '626', '1', 'Fall', 2006, 'A-');
	insert into takes values('48640', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('44038', '334', '1', 'Fall', 2009, 'A-');
	insert into takes values('60984', '137', '1', 'Spring', 2002, 'B ');
	insert into takes values('70389', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('75231', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('61127', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('72177', '603', '1', 'Fall', 2003, 'A+');
	insert into takes values('88525', '319', '1', 'Spring', 2003, 'B-');
	insert into takes values('52945', '604', '1', 'Spring', 2009, 'A ');
	insert into takes values('17128', '192', '1', 'Fall', 2002, 'C-');
	insert into takes values('79446', '313', '1', 'Fall', 2010, 'C ');
	insert into takes values('8807', '571', '1', 'Spring', 2004, 'C+');
	insert into takes values('64121', '581', '1', 'Spring', 2005, 'C+');
	insert into takes values('9947', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('60366', '696', '1', 'Spring', 2002, 'A ');
	insert into takes values('56598', '545', '1', 'Fall', 2001, 'B ');
	insert into takes values('86573', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('83003', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('70389', '867', '1', 'Fall', 2006, 'C+');
	insert into takes values('25331', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('667', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('20803', '313', '1', 'Fall', 2010, 'A ');
	insert into takes values('52385', '795', '1', 'Spring', 2004, 'B+');
	insert into takes values('19293', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('85234', '338', '2', 'Spring', 2006, 'A-');
	insert into takes values('66356', '489', '1', 'Fall', 2007, 'B+');
	insert into takes values('18941', '960', '2', 'Fall', 2006, 'B+');
	insert into takes values('93708', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('10904', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('38973', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('74974', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('93061', '702', '1', 'Spring', 2001, 'B ');
	insert into takes values('72186', '875', '1', 'Spring', 2005, 'B+');
	insert into takes values('42843', '476', '1', 'Fall', 2010, 'B+');
	insert into takes values('14284', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('69307', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('98359', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('44998', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('32065', '679', '1', 'Spring', 2010, 'A+');
	insert into takes values('43123', '927', '1', 'Fall', 2002, 'C ');
	insert into takes values('41450', '696', '1', 'Spring', 2002, 'B ');
	insert into takes values('33882', '137', '1', 'Spring', 2002, 'B ');
	insert into takes values('23457', '696', '1', 'Spring', 2002, 'C ');
	insert into takes values('18752', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('90372', '802', '1', 'Spring', 2003, 'C-');
	insert into takes values('99289', '461', '1', 'Fall', 2002, 'A-');
	insert into takes values('89393', '237', '2', 'Fall', 2009, 'A-');
	insert into takes values('8252', '408', '1', 'Spring', 2007, 'C ');
	insert into takes values('98019', '974', '1', 'Fall', 2003, 'A+');
	insert into takes values('63582', '242', '1', 'Fall', 2009, 'B+');
	insert into takes values('96153', '960', '2', 'Fall', 2006, 'A ');
	insert into takes values('31079', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('53547', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('71630', '960', '2', 'Fall', 2006, 'C+');
	insert into takes values('55915', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('96324', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('55531', '445', '1', 'Spring', 2001, 'B-');
	insert into takes values('53172', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('81884', '169', '2', 'Fall', 2002, 'C ');
	insert into takes values('107', '304', '1', 'Fall', 2009, 'B ');
	insert into takes values('3127', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('91063', '319', '1', 'Spring', 2003, 'C+');
	insert into takes values('14182', '408', '1', 'Spring', 2007, 'A+');
	insert into takes values('2848', '843', '1', 'Fall', 2010, 'C-');
	insert into takes values('10693', '105', '2', 'Fall', 2002, 'A+');
	insert into takes values('19861', '169', '2', 'Fall', 2002, 'B+');
	insert into takes values('90814', '696', '1', 'Spring', 2002, 'B ');
	insert into takes values('39472', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('17607', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('97355', '960', '2', 'Fall', 2006, 'C-');
	insert into takes values('37946', '959', '1', 'Fall', 2006, 'B ');
	insert into takes values('19050', '793', '1', 'Spring', 2002, 'C+');
	insert into takes values('10705', '362', '2', 'Fall', 2006, 'A-');
	insert into takes values('66090', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('19245', '692', '1', 'Spring', 2010, 'A ');
	insert into takes values('35293', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('645', '400', '1', 'Spring', 2007, 'A+');
	insert into takes values('42114', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('92849', '962', '1', 'Spring', 2008, 'C+');
	insert into takes values('49701', '468', '1', 'Fall', 2005, 'B-');
	insert into takes values('83871', '735', '2', 'Spring', 2010, 'C ');
	insert into takes values('93004', '400', '2', 'Fall', 2003, 'B-');
	insert into takes values('16969', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('69307', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('99660', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('25331', '313', '1', 'Fall', 2010, 'C ');
	insert into takes values('23500', '237', '2', 'Fall', 2009, 'A-');
	insert into takes values('43505', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('99764', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('41280', '808', '1', 'Fall', 2003, 'A-');
	insert into takes values('50537', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('77580', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('82697', '304', '1', 'Fall', 2009, 'C-');
	insert into takes values('83462', '274', '1', 'Fall', 2002, 'C+');
	insert into takes values('5336', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('66293', '893', '1', 'Fall', 2007, 'B ');
	insert into takes values('79911', '612', '1', 'Fall', 2007, 'C ');
	insert into takes values('94726', '571', '1', 'Spring', 2004, 'A+');
	insert into takes values('90004', '237', '1', 'Spring', 2008, 'B+');
	insert into takes values('90567', '237', '1', 'Spring', 2008, 'A+');
	insert into takes values('42298', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('74840', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('17507', '626', '1', 'Fall', 2006, 'C+');
	insert into takes values('74840', '489', '1', 'Fall', 2007, 'A ');
	insert into takes values('1533', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('92659', '169', '1', 'Spring', 2007, 'C+');
	insert into takes values('26619', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('60406', '793', '1', 'Spring', 2002, 'C-');
	insert into takes values('29849', '489', '1', 'Fall', 2007, 'C ');
	insert into takes values('34322', '808', '1', 'Fall', 2003, 'B-');
	insert into takes values('68779', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('95574', '603', '1', 'Fall', 2003, 'C-');
	insert into takes values('14094', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('4182', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('16057', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('50013', '735', '1', 'Spring', 2003, 'A-');
	insert into takes values('71085', '692', '1', 'Spring', 2010, 'B-');
	insert into takes values('58606', '349', '1', 'Spring', 2008, 'C-');
	insert into takes values('19917', '408', '2', 'Spring', 2003, 'C ');
	insert into takes values('12069', '237', '2', 'Fall', 2009, 'C-');
	insert into takes values('85356', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('38676', '702', '1', 'Spring', 2001, 'C-');
	insert into takes values('72979', '603', '1', 'Fall', 2003, 'A+');
	insert into takes values('46970', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('14484', '105', '2', 'Fall', 2002, 'B-');
	insert into takes values('62705', '313', '1', 'Fall', 2010, 'C-');
	insert into takes values('75123', '748', '1', 'Fall', 2003, 'B-');
	insert into takes values('96710', '893', '1', 'Fall', 2007, 'C ');
	insert into takes values('34569', '748', '1', 'Fall', 2003, 'B-');
	insert into takes values('82591', '561', '1', 'Fall', 2006, 'B-');
	insert into takes values('65190', '338', '2', 'Spring', 2006, 'B+');
	insert into takes values('15074', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('52669', '237', '1', 'Spring', 2008, 'B+');
	insert into takes values('27956', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('14628', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('89297', '443', '1', 'Spring', 2010, 'B ');
	insert into takes values('31554', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('69783', '962', '1', 'Spring', 2008, 'B-');
	insert into takes values('3127', '408', '1', 'Spring', 2007, 'C+');
	insert into takes values('96227', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('81789', '158', '1', 'Fall', 2008, 'C-');
	insert into takes values('35293', '626', '1', 'Fall', 2006, 'C ');
	insert into takes values('4173', '376', '1', 'Fall', 2006, 'B ');
	insert into takes values('56003', '362', '1', 'Fall', 2005, 'C+');
	insert into takes values('69960', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('56299', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('95953', '482', '1', 'Fall', 2005, 'C ');
	insert into takes values('58355', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('59920', '408', '1', 'Spring', 2007, 'C-');
	insert into takes values('8192', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('24374', '415', '1', 'Fall', 2010, 'C+');
	insert into takes values('21101', '169', '2', 'Fall', 2002, 'B+');
	insert into takes values('30124', '631', '1', 'Spring', 2007, 'A-');
	insert into takes values('9114', '791', '1', 'Spring', 2006, 'C+');
	insert into takes values('16543', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('50467', '319', '1', 'Spring', 2003, 'B ');
	insert into takes values('78911', '457', '1', 'Spring', 2001, 'A-');
	insert into takes values('858', '864', '1', 'Spring', 2006, 'A ');
	insert into takes values('32483', '959', '1', 'Fall', 2006, 'B ');
	insert into takes values('84654', '561', '1', 'Fall', 2006, 'A-');
	insert into takes values('15430', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('91788', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('4248', '748', '1', 'Fall', 2003, 'B ');
	insert into takes values('29192', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('11202', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('37586', '352', '1', 'Spring', 2006, 'A+');
	insert into takes values('94620', '457', '1', 'Spring', 2001, 'C+');
	insert into takes values('25187', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('58701', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('9933', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('7390', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('67024', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('75547', '242', '1', 'Fall', 2009, 'B ');
	insert into takes values('83573', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('33546', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('88389', '960', '1', 'Fall', 2009, 'A-');
	insert into takes values('71628', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('7854', '352', '1', 'Spring', 2006, 'C-');
	insert into takes values('58889', '319', '1', 'Spring', 2003, 'B ');
	insert into takes values('14628', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('27804', '663', '1', 'Spring', 2005, 'A-');
	insert into takes values('26427', '974', '1', 'Fall', 2003, 'B-');
	insert into takes values('34126', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('2139', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('66356', '959', '1', 'Fall', 2006, 'A ');
	insert into takes values('73186', '793', '1', 'Spring', 2002, 'A+');
	insert into takes values('62487', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('75596', '239', '1', 'Fall', 2006, 'A-');
	insert into takes values('760', '237', '1', 'Spring', 2008, 'C-');
	insert into takes values('49214', '793', '1', 'Spring', 2002, 'C ');
	insert into takes values('29192', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('8860', '791', '1', 'Spring', 2006, 'C-');
	insert into takes values('47670', '974', '1', 'Fall', 2003, 'C-');
	insert into takes values('97590', '802', '1', 'Spring', 2003, 'C-');
	insert into takes values('9659', '612', '1', 'Fall', 2007, 'B ');
	insert into takes values('78858', '591', '1', 'Spring', 2005, 'C-');
	insert into takes values('32490', '760', '1', 'Spring', 2004, 'A ');
	insert into takes values('25552', '421', '1', 'Fall', 2004, 'A-');
	insert into takes values('12236', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('73387', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('24325', '319', '1', 'Spring', 2003, 'C+');
	insert into takes values('23475', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('11201', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('39704', '242', '1', 'Fall', 2009, 'A ');
	insert into takes values('89188', '334', '1', 'Fall', 2009, 'C ');
	insert into takes values('99775', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('61166', '735', '2', 'Spring', 2010, 'C ');
	insert into takes values('89759', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('47379', '200', '2', 'Fall', 2002, 'C-');
	insert into takes values('36494', '496', '1', 'Fall', 2001, 'A-');
	insert into takes values('91799', '338', '2', 'Spring', 2006, 'B+');
	insert into takes values('15328', '927', '1', 'Fall', 2002, 'A ');
	insert into takes values('63502', '735', '2', 'Spring', 2010, 'A+');
	insert into takes values('73186', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('5943', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('95850', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('84432', '581', '1', 'Spring', 2005, 'A ');
	insert into takes values('99271', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('11152', '200', '1', 'Spring', 2007, 'B+');
	insert into takes values('22417', '704', '1', 'Spring', 2008, 'C-');
	insert into takes values('30252', '960', '2', 'Fall', 2006, 'B-');
	insert into takes values('75510', '629', '1', 'Spring', 2003, 'B ');
	insert into takes values('30341', '338', '2', 'Spring', 2006, 'A-');
	insert into takes values('73165', '445', '1', 'Spring', 2001, 'A-');
	insert into takes values('40481', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('59397', '239', '1', 'Fall', 2006, 'B ');
	insert into takes values('3639', '258', '1', 'Fall', 2007, 'A ');
	insert into takes values('67793', '974', '1', 'Fall', 2003, 'B-');
	insert into takes values('57242', '274', '1', 'Fall', 2002, 'B-');
	insert into takes values('93491', '991', '1', 'Spring', 2008, 'A ');
	insert into takes values('51093', '313', '1', 'Fall', 2010, 'A ');
	insert into takes values('847', '338', '2', 'Spring', 2006, 'A ');
	insert into takes values('14023', '561', '1', 'Fall', 2006, 'C+');
	insert into takes values('12711', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('79329', '169', '2', 'Fall', 2002, 'B+');
	insert into takes values('85904', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('39619', '663', '1', 'Spring', 2005, 'B ');
	insert into takes values('6673', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('17057', '603', '1', 'Fall', 2003, 'A+');
	insert into takes values('94311', '843', '1', 'Fall', 2010, 'C+');
	insert into takes values('10705', '663', '1', 'Spring', 2005, 'C-');
	insert into takes values('57135', '345', '1', 'Spring', 2008, 'B ');
	insert into takes values('90567', '875', '1', 'Spring', 2005, 'C ');
	insert into takes values('44038', '599', '1', 'Spring', 2003, 'A-');
	insert into takes values('32954', '169', '1', 'Spring', 2007, 'B+');
	insert into takes values('36379', '270', '1', 'Spring', 2010, 'C ');
	insert into takes values('71904', '258', '1', 'Fall', 2007, 'A-');
	insert into takes values('83170', '400', '2', 'Fall', 2003, 'C-');
	insert into takes values('19766', '561', '1', 'Fall', 2006, 'C-');
	insert into takes values('39046', '486', '1', 'Fall', 2009, 'B-');
	insert into takes values('62520', '443', '1', 'Spring', 2010, 'C+');
	insert into takes values('99710', '338', '1', 'Spring', 2007, 'B-');
	insert into takes values('90448', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('78572', '960', '1', 'Fall', 2009, 'B ');
	insert into takes values('39115', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('2133', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('53490', '559', '1', 'Fall', 2002, 'B ');
	insert into takes values('52076', '319', '1', 'Spring', 2003, 'B ');
	insert into takes values('75794', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('21401', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('53728', '421', '1', 'Fall', 2004, 'B+');
	insert into takes values('82082', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('31080', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('48611', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('32886', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('30474', '493', '1', 'Spring', 2010, 'A-');
	insert into takes values('16057', '200', '2', 'Fall', 2002, 'A-');
	insert into takes values('31993', '612', '1', 'Fall', 2007, 'B ');
	insert into takes values('1827', '352', '1', 'Spring', 2006, 'B ');
	insert into takes values('27952', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('82039', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('81550', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('37653', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('35588', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('66090', '489', '1', 'Fall', 2007, 'A ');
	insert into takes values('59848', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('88525', '362', '3', 'Spring', 2008, 'C-');
	insert into takes values('17057', '612', '1', 'Fall', 2007, 'C ');
	insert into takes values('24325', '991', '1', 'Spring', 2008, 'B ');
	insert into takes values('26494', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('23373', '443', '2', 'Spring', 2002, 'B+');
	insert into takes values('66753', '692', '1', 'Spring', 2010, 'C+');
	insert into takes values('17911', '362', '1', 'Fall', 2005, 'C ');
	insert into takes values('63645', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('12236', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('20445', '663', '1', 'Spring', 2005, 'C ');
	insert into takes values('11855', '376', '1', 'Fall', 2006, 'B-');
	insert into takes values('70918', '893', '1', 'Fall', 2007, 'B ');
	insert into takes values('5961', '258', '1', 'Fall', 2007, 'B-');
	insert into takes values('14432', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('51416', '468', '1', 'Fall', 2005, 'C ');
	insert into takes values('80698', '158', '1', 'Fall', 2008, 'C-');
	insert into takes values('8986', '482', '1', 'Fall', 2005, 'B-');
	insert into takes values('99348', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('31341', '974', '1', 'Fall', 2003, 'C-');
	insert into takes values('75596', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('31337', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('24796', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('16405', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('28361', '105', '1', 'Fall', 2009, 'C+');
	insert into takes values('38121', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('76173', '489', '1', 'Fall', 2007, 'A-');
	insert into takes values('83462', '748', '1', 'Fall', 2003, 'A-');
	insert into takes values('37734', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('72521', '867', '2', 'Fall', 2010, 'A+');
	insert into takes values('57160', '735', '2', 'Spring', 2010, 'A ');
	insert into takes values('75252', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('24746', '486', '1', 'Fall', 2009, 'B ');
	insert into takes values('65038', '960', '1', 'Fall', 2009, 'A-');
	insert into takes values('89196', '974', '1', 'Fall', 2003, 'C-');
	insert into takes values('65056', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('64893', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('8843', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('86529', '702', '1', 'Spring', 2001, 'A-');
	insert into takes values('22057', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('31560', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('88302', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('31250', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('37653', '793', '1', 'Spring', 2002, 'C-');
	insert into takes values('43854', '461', '1', 'Fall', 2002, 'B ');
	insert into takes values('14432', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('98140', '852', '1', 'Spring', 2008, 'C-');
	insert into takes values('8251', '959', '1', 'Fall', 2006, 'A ');
	insert into takes values('25143', '626', '1', 'Fall', 2006, 'B ');
	insert into takes values('11126', '735', '2', 'Spring', 2010, 'B ');
	insert into takes values('13023', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('64642', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('74840', '242', '1', 'Fall', 2009, 'A ');
	insert into takes values('62716', '496', '1', 'Fall', 2001, 'B-');
	insert into takes values('19582', '612', '1', 'Fall', 2007, 'C ');
	insert into takes values('93354', '349', '1', 'Spring', 2008, 'C-');
	insert into takes values('35042', '258', '1', 'Fall', 2007, 'B+');
	insert into takes values('43226', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('85366', '852', '1', 'Spring', 2008, 'B+');
	insert into takes values('63243', '461', '1', 'Fall', 2002, 'B ');
	insert into takes values('163', '468', '2', 'Fall', 2007, 'C+');
	insert into takes values('95850', '527', '1', 'Fall', 2004, 'A ');
	insert into takes values('36494', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('79772', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('57156', '192', '1', 'Fall', 2002, 'C ');
	insert into takes values('55286', '362', '1', 'Fall', 2005, 'B ');
	insert into takes values('36303', '200', '2', 'Fall', 2002, 'A-');
	insert into takes values('49205', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('68554', '663', '1', 'Spring', 2005, 'C-');
	insert into takes values('39978', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('83214', '694', '1', 'Fall', 2002, 'A ');
	insert into takes values('6990', '408', '1', 'Spring', 2007, 'A+');
	insert into takes values('83511', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('64820', '169', '2', 'Fall', 2002, 'C ');
	insert into takes values('59848', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('33201', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('82697', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('52866', '457', '1', 'Spring', 2001, 'B+');
	insert into takes values('72358', '362', '2', 'Fall', 2006, 'B-');
	insert into takes values('81884', '313', '1', 'Fall', 2010, 'C ');
	insert into takes values('61402', '242', '1', 'Fall', 2009, 'C+');
	insert into takes values('65144', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('29192', '875', '1', 'Spring', 2005, 'C ');
	insert into takes values('163', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('80254', '482', '1', 'Fall', 2005, 'C ');
	insert into takes values('22170', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('83039', '496', '1', 'Fall', 2001, 'C-');
	insert into takes values('78637', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('91799', '991', '1', 'Spring', 2008, 'B-');
	insert into takes values('40682', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('75395', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('29863', '443', '1', 'Spring', 2010, 'A-');
	insert into takes values('41894', '795', '1', 'Spring', 2004, 'B+');
	insert into takes values('51203', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('39241', '571', '1', 'Spring', 2004, 'C-');
	insert into takes values('66495', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('22345', '663', '1', 'Spring', 2005, 'C ');
	insert into takes values('50013', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('79697', '366', '1', 'Fall', 2005, 'C ');
	insert into takes values('37430', '334', '1', 'Fall', 2009, 'B ');
	insert into takes values('5017', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('81789', '408', '1', 'Spring', 2007, 'A+');
	insert into takes values('72485', '237', '2', 'Fall', 2009, 'A-');
	insert into takes values('63502', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('67033', '875', '1', 'Spring', 2005, 'C-');
	insert into takes values('67514', '629', '1', 'Spring', 2003, 'A+');
	insert into takes values('6895', '426', '1', 'Spring', 2006, 'A-');
	insert into takes values('19638', '105', '1', 'Fall', 2009, 'A+');
	insert into takes values('33817', '631', '1', 'Spring', 2007, 'C-');
	insert into takes values('13023', '468', '1', 'Fall', 2005, 'C ');
	insert into takes values('95697', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('59172', '962', '1', 'Spring', 2008, 'C+');
	insert into takes values('61783', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('90124', '748', '1', 'Fall', 2003, 'B-');
	insert into takes values('17507', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('95089', '591', '1', 'Spring', 2005, 'A+');
	insert into takes values('85356', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('99760', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('65681', '319', '1', 'Spring', 2003, 'C+');
	insert into takes values('41345', '239', '1', 'Fall', 2006, 'B-');
	insert into takes values('27662', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('64249', '200', '1', 'Spring', 2007, 'A-');
	insert into takes values('96772', '959', '1', 'Fall', 2006, 'A+');
	insert into takes values('33817', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('21401', '169', '2', 'Fall', 2002, 'C ');
	insert into takes values('5463', '457', '1', 'Spring', 2001, 'B-');
	insert into takes values('74163', '791', '1', 'Spring', 2006, 'C+');
	insert into takes values('57135', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('33759', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('63502', '760', '1', 'Spring', 2004, 'B ');
	insert into takes values('54622', '960', '2', 'Fall', 2006, 'C ');
	insert into takes values('51817', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('32065', '692', '1', 'Spring', 2010, 'A-');
	insert into takes values('31993', '599', '1', 'Spring', 2003, 'A ');
	insert into takes values('75040', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('53496', '696', '1', 'Spring', 2002, 'B ');
	insert into takes values('75534', '486', '1', 'Fall', 2009, 'A-');
	insert into takes values('26473', '352', '1', 'Spring', 2006, 'C+');
	insert into takes values('40937', '352', '1', 'Spring', 2006, 'C ');
	insert into takes values('94998', '843', '1', 'Fall', 2010, 'C+');
	insert into takes values('27017', '493', '1', 'Spring', 2010, 'C+');
	insert into takes values('40303', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('64724', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('92965', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('22396', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('82697', '545', '1', 'Fall', 2001, 'B ');
	insert into takes values('31101', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('44998', '334', '1', 'Fall', 2009, 'A-');
	insert into takes values('16075', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('70395', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('41988', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('11966', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('85904', '345', '1', 'Spring', 2008, 'C ');
	insert into takes values('81538', '482', '1', 'Fall', 2005, 'A-');
	insert into takes values('95089', '158', '2', 'Spring', 2008, 'C+');
	insert into takes values('9659', '105', '1', 'Fall', 2009, 'C-');
	insert into takes values('51238', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('33201', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('53588', '200', '2', 'Fall', 2002, 'B-');
	insert into takes values('7498', '496', '1', 'Fall', 2001, 'B ');
	insert into takes values('64938', '476', '1', 'Fall', 2010, 'C-');
	insert into takes values('50944', '527', '1', 'Fall', 2004, 'C-');
	insert into takes values('70384', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('50743', '972', '1', 'Spring', 2009, 'B-');
	insert into takes values('50598', '793', '1', 'Spring', 2002, 'A ');
	insert into takes values('61854', '468', '1', 'Fall', 2005, 'B ');
	insert into takes values('96134', '457', '1', 'Spring', 2001, 'C ');
	insert into takes values('34392', '679', '1', 'Spring', 2010, 'C+');
	insert into takes values('5399', '334', '1', 'Fall', 2009, 'C-');
	insert into takes values('12173', '192', '1', 'Fall', 2002, 'A+');
	insert into takes values('64138', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('46442', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('76270', '362', '3', 'Spring', 2008, 'B ');
	insert into takes values('76759', '843', '1', 'Fall', 2010, 'A ');
	insert into takes values('39520', '875', '1', 'Spring', 2005, 'B+');
	insert into takes values('49813', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('32368', '867', '2', 'Fall', 2010, 'A-');
	insert into takes values('30289', '962', '1', 'Spring', 2008, 'A+');
	insert into takes values('97435', '545', '1', 'Fall', 2001, 'A+');
	insert into takes values('53788', '443', '1', 'Spring', 2010, 'B+');
	insert into takes values('98388', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('60224', '362', '3', 'Spring', 2008, 'A+');
	insert into takes values('44584', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('62728', '400', '1', 'Spring', 2007, 'C ');
	insert into takes values('68330', '663', '1', 'Spring', 2005, 'B ');
	insert into takes values('78637', '400', '2', 'Fall', 2003, 'B+');
	insert into takes values('2970', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('39520', '468', '2', 'Fall', 2007, 'A+');
	insert into takes values('36019', '692', '1', 'Spring', 2010, 'C+');
	insert into takes values('64082', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('80912', '258', '1', 'Fall', 2007, 'C-');
	insert into takes values('8457', '319', '1', 'Spring', 2003, 'C+');
	insert into takes values('62832', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('46442', '443', '2', 'Spring', 2002, 'C ');
	insert into takes values('92659', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('43505', '795', '1', 'Spring', 2004, 'C+');
	insert into takes values('4034', '319', '1', 'Spring', 2003, 'C+');
	insert into takes values('96227', '158', '2', 'Spring', 2008, 'A ');
	insert into takes values('79534', '443', '2', 'Spring', 2002, 'B-');
	insert into takes values('29920', '237', '1', 'Spring', 2008, 'A+');
	insert into takes values('89140', '760', '1', 'Spring', 2004, 'C+');
	insert into takes values('38013', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('3545', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('90353', '735', '2', 'Spring', 2010, 'A-');
	insert into takes values('14214', '927', '1', 'Fall', 2002, 'B-');
	insert into takes values('87785', '793', '1', 'Spring', 2002, 'A+');
	insert into takes values('72521', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('46769', '949', '1', 'Fall', 2007, 'C-');
	insert into takes values('29849', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('35588', '401', '1', 'Fall', 2003, 'C ');
	insert into takes values('49280', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('76246', '362', '1', 'Fall', 2005, 'C+');
	insert into takes values('98388', '304', '1', 'Fall', 2009, 'A+');
	insert into takes values('84039', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('76953', '242', '1', 'Fall', 2009, 'B ');
	insert into takes values('5843', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('45650', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('40303', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('10693', '949', '1', 'Fall', 2007, 'A-');
	insert into takes values('55940', '631', '1', 'Spring', 2007, 'A+');
	insert into takes values('3487', '200', '2', 'Fall', 2002, 'B+');
	insert into takes values('97551', '457', '1', 'Spring', 2001, 'B ');
	insert into takes values('56499', '158', '1', 'Fall', 2008, 'A+');
	insert into takes values('76604', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('26102', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('90220', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('27956', '591', '1', 'Spring', 2005, 'A ');
	insert into takes values('14284', '169', '1', 'Spring', 2007, 'B ');
	insert into takes values('52019', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('64893', '603', '1', 'Fall', 2003, 'C-');
	insert into takes values('39619', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('18367', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('87965', '852', '1', 'Spring', 2008, 'A-');
	insert into takes values('72014', '991', '1', 'Spring', 2008, 'B ');
	insert into takes values('30858', '345', '1', 'Spring', 2008, 'C+');
	insert into takes values('43616', '591', '1', 'Spring', 2005, 'A+');
	insert into takes values('92839', '338', '2', 'Spring', 2006, 'C ');
	insert into takes values('26619', '362', '2', 'Fall', 2006, 'A ');
	insert into takes values('67660', '334', '1', 'Fall', 2009, 'A ');
	insert into takes values('45720', '376', '1', 'Fall', 2006, 'B+');
	insert into takes values('24201', '960', '1', 'Fall', 2009, 'B ');
	insert into takes values('2848', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('53048', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('6367', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('81610', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('14182', '237', '1', 'Spring', 2008, 'B ');
	insert into takes values('74672', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('557', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('54620', '158', '2', 'Spring', 2008, 'B+');
	insert into takes values('77244', '158', '2', 'Spring', 2008, 'B-');
	insert into takes values('57377', '349', '1', 'Spring', 2008, 'A-');
	insert into takes values('86806', '991', '1', 'Spring', 2008, 'B-');
	insert into takes values('64731', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('62549', '626', '1', 'Fall', 2006, 'C+');
	insert into takes values('64642', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('40481', '692', '1', 'Spring', 2010, 'C+');
	insert into takes values('57107', '692', '1', 'Spring', 2010, 'C-');
	insert into takes values('55915', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('65979', '493', '1', 'Spring', 2010, 'B ');
	insert into takes values('90448', '489', '1', 'Fall', 2007, 'B ');
	insert into takes values('84704', '242', '1', 'Fall', 2009, 'A ');
	insert into takes values('50414', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('35588', '158', '1', 'Fall', 2008, 'B+');
	insert into takes values('94535', '468', '1', 'Fall', 2005, 'A+');
	insert into takes values('44998', '270', '1', 'Spring', 2010, 'B-');
	insert into takes values('78454', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('65433', '421', '1', 'Fall', 2004, 'C-');
	insert into takes values('99780', '974', '1', 'Fall', 2003, 'A+');
	insert into takes values('86552', '959', '1', 'Fall', 2006, 'B+');
	insert into takes values('58413', '445', '1', 'Spring', 2001, 'B-');
	insert into takes values('33882', '445', '1', 'Spring', 2001, 'B-');
	insert into takes values('34502', '338', '1', 'Spring', 2007, 'C+');
	insert into takes values('97023', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('18234', '408', '2', 'Spring', 2003, 'C ');
	insert into takes values('58701', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('53185', '760', '1', 'Spring', 2004, 'C ');
	insert into takes values('77664', '352', '1', 'Spring', 2006, 'B+');
	insert into takes values('39472', '561', '1', 'Fall', 2006, 'A ');
	insert into takes values('19362', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('56124', '258', '1', 'Fall', 2007, 'C-');
	insert into takes values('82687', '242', '1', 'Fall', 2009, 'A+');
	insert into takes values('5871', '239', '1', 'Fall', 2006, 'C+');
	insert into takes values('20195', '408', '1', 'Spring', 2007, 'C ');
	insert into takes values('61232', '482', '1', 'Fall', 2005, 'A+');
	insert into takes values('84845', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('50719', '791', '1', 'Spring', 2006, 'B+');
	insert into takes values('92442', '158', '2', 'Spring', 2008, 'A-');
	insert into takes values('80821', '626', '1', 'Fall', 2006, 'A ');
	insert into takes values('67810', '362', '2', 'Fall', 2006, 'A-');
	insert into takes values('39521', '338', '2', 'Spring', 2006, 'A+');
	insert into takes values('24201', '486', '1', 'Fall', 2009, 'C ');
	insert into takes values('56755', '802', '1', 'Spring', 2003, 'B+');
	insert into takes values('97101', '169', '1', 'Spring', 2007, 'B+');
	insert into takes values('1836', '864', '1', 'Spring', 2006, 'C-');
	insert into takes values('28352', '476', '1', 'Fall', 2010, 'B ');
	insert into takes values('52187', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('83686', '591', '1', 'Spring', 2005, 'A ');
	insert into takes values('16297', '642', '1', 'Fall', 2004, 'C+');
	insert into takes values('43989', '793', '1', 'Spring', 2002, 'C-');
	insert into takes values('87280', '468', '2', 'Fall', 2007, 'B ');
	insert into takes values('61354', '960', '2', 'Fall', 2006, 'A ');
	insert into takes values('82697', '349', '1', 'Spring', 2008, 'A ');
	insert into takes values('13403', '696', '1', 'Spring', 2002, 'C+');
	insert into takes values('97228', '408', '2', 'Spring', 2003, 'B-');
	insert into takes values('94726', '604', '1', 'Spring', 2009, 'A-');
	insert into takes values('39892', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('56499', '974', '1', 'Fall', 2003, 'C ');
	insert into takes values('38676', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('95631', '237', '1', 'Spring', 2008, 'A-');
	insert into takes values('2178', '400', '1', 'Spring', 2007, 'B+');
	insert into takes values('99754', '972', '1', 'Spring', 2009, 'A-');
	insert into takes values('57456', '760', '1', 'Spring', 2004, 'A-');
	insert into takes values('83747', '313', '1', 'Fall', 2010, 'B-');
	insert into takes values('19245', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('72669', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('32483', '960', '2', 'Fall', 2006, 'A ');
	insert into takes values('67810', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('17831', '663', '1', 'Spring', 2005, 'A ');
	insert into takes values('96246', '694', '1', 'Fall', 2002, 'C+');
	insert into takes values('70061', '962', '1', 'Spring', 2008, 'B ');
	insert into takes values('41674', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('46762', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('5463', '843', '1', 'Fall', 2010, 'B+');
	insert into takes values('30650', '991', '1', 'Spring', 2008, 'C-');
	insert into takes values('70099', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('9605', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('12069', '852', '1', 'Spring', 2008, 'C ');
	insert into takes values('46694', '694', '1', 'Fall', 2002, 'A ');
	insert into takes values('55170', '376', '1', 'Fall', 2006, 'B+');
	insert into takes values('9460', '362', '2', 'Fall', 2006, 'C-');
	insert into takes values('82974', '591', '1', 'Spring', 2005, 'B ');
	insert into takes values('58469', '704', '1', 'Spring', 2008, 'A+');
	insert into takes values('67514', '692', '1', 'Spring', 2010, 'A ');
	insert into takes values('73602', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('10663', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('34404', '338', '2', 'Spring', 2006, 'A-');
	insert into takes values('19861', '408', '1', 'Spring', 2007, 'C-');
	insert into takes values('38895', '421', '1', 'Fall', 2004, 'B+');
	insert into takes values('19050', '415', '1', 'Fall', 2010, 'B+');
	insert into takes values('987', '959', '1', 'Fall', 2006, 'C+');
	insert into takes values('89140', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('97400', '571', '1', 'Spring', 2004, 'C ');
	insert into takes values('33107', '105', '1', 'Fall', 2009, 'C-');
	insert into takes values('75241', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('88553', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('65299', '105', '2', 'Fall', 2002, 'B-');
	insert into takes values('74911', '338', '2', 'Spring', 2006, 'A ');
	insert into takes values('91343', '893', '1', 'Fall', 2007, 'A ');
	insert into takes values('13511', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('13403', '319', '1', 'Spring', 2003, 'B ');
	insert into takes values('28004', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('99073', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('44816', '105', '2', 'Fall', 2002, 'A ');
	insert into takes values('86981', '426', '1', 'Spring', 2006, 'A+');
	insert into takes values('50537', '867', '2', 'Fall', 2010, 'C ');
	insert into takes values('65443', '345', '1', 'Spring', 2008, 'A+');
	insert into takes values('84654', '795', '1', 'Spring', 2004, 'B ');
	insert into takes values('72485', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('7287', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('46970', '704', '1', 'Spring', 2008, 'B ');
	insert into takes values('12683', '400', '2', 'Fall', 2003, 'A ');
	insert into takes values('288', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('82697', '158', '1', 'Fall', 2008, 'A ');
	insert into takes values('97065', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('37430', '808', '1', 'Fall', 2003, 'A-');
	insert into takes values('85614', '581', '1', 'Spring', 2005, 'A ');
	insert into takes values('75173', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('61354', '927', '1', 'Fall', 2002, 'C ');
	insert into takes values('92949', '960', '2', 'Fall', 2006, 'B+');
	insert into takes values('10076', '663', '1', 'Spring', 2005, 'A ');
	insert into takes values('13081', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('27687', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('45083', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('50719', '559', '1', 'Fall', 2002, 'C+');
	insert into takes values('1836', '345', '1', 'Spring', 2008, 'B ');
	insert into takes values('34542', '415', '1', 'Fall', 2010, 'A+');
	insert into takes values('25331', '629', '1', 'Spring', 2003, 'B-');
	insert into takes values('82301', '581', '1', 'Spring', 2005, 'C+');
	insert into takes values('28977', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('24002', '400', '1', 'Spring', 2007, 'C-');
	insert into takes values('75173', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('5250', '561', '1', 'Fall', 2006, 'A+');
	insert into takes values('65144', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('86001', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('77729', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('95284', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('73606', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('78581', '735', '1', 'Spring', 2003, 'B-');
	insert into takes values('64121', '991', '1', 'Spring', 2008, 'A ');
	insert into takes values('3335', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('97355', '604', '1', 'Spring', 2009, 'B+');
	insert into takes values('41596', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('60748', '349', '1', 'Spring', 2008, 'A ');
	insert into takes values('1110', '400', '1', 'Spring', 2007, 'C+');
	insert into takes values('94324', '692', '1', 'Spring', 2010, 'C ');
	insert into takes values('80057', '843', '1', 'Fall', 2010, 'A ');
	insert into takes values('12683', '362', '1', 'Fall', 2005, 'C+');
	insert into takes values('95089', '270', '1', 'Spring', 2010, 'C+');
	insert into takes values('10076', '493', '1', 'Spring', 2010, 'B+');
	insert into takes values('8853', '445', '1', 'Spring', 2001, 'C ');
	insert into takes values('15083', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('82918', '642', '1', 'Fall', 2004, 'B+');
	insert into takes values('76743', '793', '1', 'Spring', 2002, 'B ');
	insert into takes values('14581', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('11530', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('94371', '612', '1', 'Fall', 2007, 'B-');
	insert into takes values('29002', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('59455', '362', '1', 'Fall', 2005, 'C+');
	insert into takes values('7514', '561', '1', 'Fall', 2006, 'C-');
	insert into takes values('41299', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('59117', '960', '1', 'Fall', 2009, 'B-');
	insert into takes values('12563', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('12078', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('40682', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('78637', '875', '1', 'Spring', 2005, 'A+');
	insert into takes values('63040', '581', '1', 'Spring', 2005, 'A-');
	insert into takes values('62749', '867', '2', 'Fall', 2010, 'A+');
	insert into takes values('99553', '927', '1', 'Fall', 2002, 'A ');
	insert into takes values('89312', '663', '1', 'Spring', 2005, 'B ');
	insert into takes values('38712', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('7861', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('76049', '476', '1', 'Fall', 2010, 'B ');
	insert into takes values('56299', '304', '1', 'Fall', 2009, 'C+');
	insert into takes values('24116', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('81175', '960', '1', 'Fall', 2009, 'B-');
	insert into takes values('56143', '735', '1', 'Spring', 2003, 'A+');
	insert into takes values('64013', '864', '1', 'Spring', 2006, 'B+');
	insert into takes values('26147', '694', '1', 'Fall', 2002, 'C ');
	insert into takes values('72521', '959', '1', 'Fall', 2006, 'B ');
	insert into takes values('46260', '313', '1', 'Fall', 2010, 'A-');
	insert into takes values('35462', '334', '1', 'Fall', 2009, 'B-');
	insert into takes values('63288', '747', '1', 'Spring', 2004, 'A ');
	insert into takes values('38895', '959', '1', 'Fall', 2006, 'B ');
	insert into takes values('85211', '200', '2', 'Fall', 2002, 'A ');
	insert into takes values('3651', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('56078', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('94311', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('9947', '362', '2', 'Fall', 2006, 'A ');
	insert into takes values('41261', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('58935', '604', '1', 'Spring', 2009, 'A ');
	insert into takes values('59172', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('46450', '496', '1', 'Fall', 2001, 'B+');
	insert into takes values('36303', '496', '1', 'Fall', 2001, 'B-');
	insert into takes values('33791', '631', '1', 'Spring', 2007, 'A+');
	insert into takes values('67340', '959', '1', 'Fall', 2006, 'C+');
	insert into takes values('1812', '663', '1', 'Spring', 2005, 'C ');
	insert into takes values('53077', '408', '2', 'Spring', 2003, 'A ');
	insert into takes values('32245', '867', '1', 'Fall', 2006, 'A ');
	insert into takes values('50966', '735', '2', 'Spring', 2010, 'A-');
	insert into takes values('69581', '843', '1', 'Fall', 2010, 'B-');
	insert into takes values('41741', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('86075', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('36494', '400', '2', 'Fall', 2003, 'C+');
	insert into takes values('58701', '200', '2', 'Fall', 2002, 'C+');
	insert into takes values('64138', '443', '2', 'Spring', 2002, 'C ');
	insert into takes values('83836', '445', '1', 'Spring', 2001, 'C+');
	insert into takes values('978', '760', '1', 'Spring', 2004, 'B-');
	insert into takes values('1826', '735', '2', 'Spring', 2010, 'A ');
	insert into takes values('7035', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('79911', '345', '1', 'Spring', 2008, 'A-');
	insert into takes values('52669', '802', '1', 'Spring', 2003, 'C+');
	insert into takes values('83480', '345', '1', 'Spring', 2008, 'A ');
	insert into takes values('86707', '791', '1', 'Spring', 2006, 'C+');
	insert into takes values('98563', '345', '1', 'Spring', 2008, 'C-');
	insert into takes values('6673', '200', '1', 'Spring', 2007, 'A ');
	insert into takes values('64121', '169', '2', 'Fall', 2002, 'A ');
	insert into takes values('27044', '795', '1', 'Spring', 2004, 'B+');
	insert into takes values('56078', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('96895', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('51923', '795', '1', 'Spring', 2004, 'C+');
	insert into takes values('99553', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('67310', '599', '1', 'Spring', 2003, 'A+');
	insert into takes values('21789', '612', '1', 'Fall', 2007, 'A-');
	insert into takes values('17769', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('7390', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('67810', '366', '1', 'Fall', 2005, 'A ');
	insert into takes values('78782', '304', '1', 'Fall', 2009, 'B ');
	insert into takes values('99977', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('70384', '304', '1', 'Fall', 2009, 'B ');
	insert into takes values('16993', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('14023', '591', '1', 'Spring', 2005, 'A ');
	insert into takes values('91569', '496', '1', 'Fall', 2001, 'B+');
	insert into takes values('49813', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('86674', '105', '2', 'Fall', 2002, 'A-');
	insert into takes values('82697', '366', '1', 'Fall', 2005, 'C ');
	insert into takes values('66106', '366', '1', 'Fall', 2005, 'A ');
	insert into takes values('98940', '679', '1', 'Spring', 2010, 'B+');
	insert into takes values('61444', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('91063', '457', '1', 'Spring', 2001, 'C+');
	insert into takes values('39472', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('53185', '304', '1', 'Fall', 2009, 'B ');
	insert into takes values('34502', '867', '1', 'Fall', 2006, 'A+');
	insert into takes values('50944', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('24630', '468', '2', 'Fall', 2007, 'A+');
	insert into takes values('31442', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('22057', '158', '1', 'Fall', 2008, 'B-');
	insert into takes values('14032', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('70572', '137', '1', 'Spring', 2002, 'A-');
	insert into takes values('1460', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('7970', '486', '1', 'Fall', 2009, 'C+');
	insert into takes values('26802', '626', '1', 'Fall', 2006, 'C+');
	insert into takes values('6523', '581', '1', 'Spring', 2005, 'A-');
	insert into takes values('55170', '158', '2', 'Spring', 2008, 'B-');
	insert into takes values('43495', '338', '1', 'Spring', 2007, 'A+');
	insert into takes values('888', '274', '1', 'Fall', 2002, 'A+');
	insert into takes values('82063', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('30772', '200', '2', 'Fall', 2002, 'C+');
	insert into takes values('49759', '426', '1', 'Spring', 2006, 'C ');
	insert into takes values('78143', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('62520', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('11422', '694', '1', 'Fall', 2002, 'C+');
	insert into takes values('40116', '105', '1', 'Fall', 2009, 'B+');
	insert into takes values('67657', '237', '1', 'Spring', 2008, 'B-');
	insert into takes values('47670', '362', '1', 'Fall', 2005, 'C+');
	insert into takes values('94836', '927', '1', 'Fall', 2002, 'A-');
	insert into takes values('30723', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('20445', '972', '1', 'Spring', 2009, 'B ');
	insert into takes values('90448', '748', '1', 'Fall', 2003, 'A-');
	insert into takes values('64140', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('44206', '158', '1', 'Fall', 2008, 'A+');
	insert into takes values('42565', '158', '2', 'Spring', 2008, 'A-');
	insert into takes values('49618', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('81396', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('86833', '400', '1', 'Spring', 2007, 'C+');
	insert into takes values('65258', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('60984', '421', '1', 'Fall', 2004, 'C ');
	insert into takes values('34055', '864', '1', 'Spring', 2006, 'A ');
	insert into takes values('94324', '237', '1', 'Spring', 2008, 'B ');
	insert into takes values('97101', '791', '1', 'Spring', 2006, 'C+');
	insert into takes values('57780', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('88884', '270', '1', 'Spring', 2010, 'A-');
	insert into takes values('76604', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('75791', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('64550', '702', '1', 'Spring', 2001, 'C-');
	insert into takes values('99073', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('46769', '599', '1', 'Spring', 2003, 'A-');
	insert into takes values('58701', '270', '1', 'Spring', 2010, 'B-');
	insert into takes values('19245', '527', '1', 'Fall', 2004, 'C-');
	insert into takes values('49982', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('4034', '696', '1', 'Spring', 2002, 'A+');
	insert into takes values('32772', '760', '1', 'Spring', 2004, 'A-');
	insert into takes values('81566', '960', '2', 'Fall', 2006, 'B-');
	insert into takes values('21100', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('52057', '415', '1', 'Fall', 2010, 'A+');
	insert into takes values('31560', '972', '1', 'Spring', 2009, 'B ');
	insert into takes values('108', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('42991', '362', '3', 'Spring', 2008, 'C+');
	insert into takes values('31442', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('52134', '482', '1', 'Fall', 2005, 'B ');
	insert into takes values('76743', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('85451', '349', '1', 'Spring', 2008, 'A ');
	insert into takes values('74509', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('26147', '629', '1', 'Spring', 2003, 'A+');
	insert into takes values('58465', '445', '1', 'Spring', 2001, 'B-');
	insert into takes values('91915', '581', '1', 'Spring', 2005, 'A ');
	insert into takes values('77234', '489', '1', 'Fall', 2007, 'B-');
	insert into takes values('76173', '352', '1', 'Spring', 2006, 'C ');
	insert into takes values('78481', '408', '1', 'Spring', 2007, 'A+');
	insert into takes values('59517', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('34404', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('73411', '242', '1', 'Fall', 2009, 'C-');
	insert into takes values('11237', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('15517', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('45300', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('2629', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('99780', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('10705', '642', '1', 'Fall', 2004, 'A-');
	insert into takes values('98315', '158', '2', 'Spring', 2008, 'B-');
	insert into takes values('19293', '376', '1', 'Fall', 2006, 'A-');
	insert into takes values('76743', '867', '2', 'Fall', 2010, 'C ');
	insert into takes values('17607', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('8483', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('18808', '631', '1', 'Spring', 2007, 'C+');
	insert into takes values('85534', '461', '1', 'Fall', 2002, 'B ');
	insert into takes values('72358', '158', '2', 'Spring', 2008, 'B-');
	insert into takes values('89132', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('88287', '972', '1', 'Spring', 2009, 'C-');
	insert into takes values('55000', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('71389', '893', '1', 'Fall', 2007, 'B ');
	insert into takes values('65190', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('11083', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('2629', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('40303', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('99780', '366', '1', 'Fall', 2005, 'A+');
	insert into takes values('59455', '468', '2', 'Fall', 2007, 'C+');
	insert into takes values('67793', '702', '1', 'Spring', 2001, 'A-');
	insert into takes values('57925', '304', '1', 'Fall', 2009, 'B+');
	insert into takes values('72657', '408', '1', 'Spring', 2007, 'C-');
	insert into takes values('24116', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('64164', '591', '1', 'Spring', 2005, 'B ');
	insert into takes values('1968', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('68330', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('54728', '545', '1', 'Fall', 2001, 'C ');
	insert into takes values('70918', '960', '1', 'Fall', 2009, 'A-');
	insert into takes values('26427', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('90353', '760', '1', 'Spring', 2004, 'B-');
	insert into takes values('46956', '352', '1', 'Spring', 2006, 'C ');
	insert into takes values('73542', '735', '1', 'Spring', 2003, 'B-');
	insert into takes values('78116', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('66106', '631', '1', 'Spring', 2007, 'A+');
	insert into takes values('26028', '927', '1', 'Fall', 2002, 'A-');
	insert into takes values('44304', '561', '1', 'Fall', 2006, 'C ');
	insert into takes values('53788', '401', '1', 'Fall', 2003, 'A ');
	insert into takes values('49280', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('21789', '852', '1', 'Spring', 2008, 'B ');
	insert into takes values('2629', '962', '1', 'Spring', 2008, 'A+');
	insert into takes values('85680', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('42625', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('17911', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('49873', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('29031', '561', '1', 'Fall', 2006, 'B-');
	insert into takes values('34055', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('50365', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('69471', '581', '1', 'Spring', 2005, 'A-');
	insert into takes values('92965', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('45770', '559', '1', 'Fall', 2002, 'B+');
	insert into takes values('28994', '843', '1', 'Fall', 2010, 'C ');
	insert into takes values('99730', '362', '1', 'Fall', 2005, 'B ');
	insert into takes values('24796', '169', '2', 'Fall', 2002, 'C ');
	insert into takes values('52076', '663', '1', 'Spring', 2005, 'A-');
	insert into takes values('6729', '345', '1', 'Spring', 2008, 'C+');
	insert into takes values('52371', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('34569', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('39612', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('64082', '791', '1', 'Spring', 2006, 'C-');
	insert into takes values('50703', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('96134', '631', '1', 'Spring', 2007, 'A ');
	insert into takes values('7514', '349', '1', 'Spring', 2008, 'A-');
	insert into takes values('58326', '468', '2', 'Fall', 2007, 'C+');
	insert into takes values('64082', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('61403', '795', '1', 'Spring', 2004, 'C+');
	insert into takes values('8603', '735', '2', 'Spring', 2010, 'C ');
	insert into takes values('80248', '694', '1', 'Fall', 2002, 'C+');
	insert into takes values('49684', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('52120', '274', '1', 'Fall', 2002, 'A+');
	insert into takes values('88993', '704', '1', 'Spring', 2008, 'C-');
	insert into takes values('26080', '493', '1', 'Spring', 2010, 'C ');
	insert into takes values('65258', '239', '1', 'Fall', 2006, 'C+');
	insert into takes values('23525', '400', '2', 'Fall', 2003, 'A+');
	insert into takes values('58469', '808', '1', 'Fall', 2003, 'A-');
	insert into takes values('75116', '604', '1', 'Spring', 2009, 'A-');
	insert into takes values('69122', '338', '1', 'Spring', 2007, 'B-');
	insert into takes values('5017', '696', '1', 'Spring', 2002, 'B ');
	insert into takes values('69081', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('15283', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('43616', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('15726', '893', '1', 'Fall', 2007, 'A ');
	insert into takes values('78116', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('73328', '545', '1', 'Fall', 2001, 'A ');
	insert into takes values('94990', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('37350', '603', '1', 'Fall', 2003, 'A ');
	insert into takes values('86001', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('75040', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('51538', '642', '1', 'Fall', 2004, 'A+');
	insert into takes values('51868', '852', '1', 'Spring', 2008, 'A-');
	insert into takes values('87784', '169', '2', 'Fall', 2002, 'A+');
	insert into takes values('12971', '696', '1', 'Spring', 2002, 'C+');
	insert into takes values('463', '852', '1', 'Spring', 2008, 'A ');
	insert into takes values('83214', '158', '1', 'Fall', 2008, 'C ');
	insert into takes values('70688', '581', '1', 'Spring', 2005, 'C ');
	insert into takes values('46074', '545', '1', 'Fall', 2001, 'B ');
	insert into takes values('64169', '239', '1', 'Fall', 2006, 'B ');
	insert into takes values('56598', '962', '1', 'Spring', 2008, 'C-');
	insert into takes values('51093', '867', '1', 'Fall', 2006, 'A+');
	insert into takes values('19861', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('22258', '408', '2', 'Spring', 2003, 'A+');
	insert into takes values('65433', '345', '1', 'Spring', 2008, 'A-');
	insert into takes values('99711', '415', '1', 'Fall', 2010, 'B-');
	insert into takes values('14065', '791', '1', 'Spring', 2006, 'C+');
	insert into takes values('88793', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('60267', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('75596', '599', '1', 'Spring', 2003, 'A ');
	insert into takes values('88287', '864', '1', 'Spring', 2006, 'A ');
	insert into takes values('99369', '158', '2', 'Spring', 2008, 'A ');
	insert into takes values('39241', '631', '1', 'Spring', 2007, 'B+');
	insert into takes values('10838', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('36384', '476', '1', 'Fall', 2010, 'B ');
	insert into takes values('18675', '696', '1', 'Spring', 2002, 'A+');
	insert into takes values('37946', '748', '1', 'Fall', 2003, 'C-');
	insert into takes values('1737', '679', '1', 'Spring', 2010, 'B+');
	insert into takes values('77415', '158', '1', 'Fall', 2008, 'A-');
	insert into takes values('3545', '959', '1', 'Fall', 2006, 'B ');
	insert into takes values('13403', '400', '2', 'Fall', 2003, 'C-');
	insert into takes values('44816', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('1836', '747', '1', 'Spring', 2004, 'B-');
	insert into takes values('83728', '581', '1', 'Spring', 2005, 'C-');
	insert into takes values('89246', '962', '1', 'Spring', 2008, 'A+');
	insert into takes values('56058', '702', '1', 'Spring', 2001, 'C+');
	insert into takes values('7956', '105', '2', 'Fall', 2002, 'B-');
	insert into takes values('92703', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('8192', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('41596', '960', '1', 'Fall', 2009, 'C-');
	insert into takes values('54460', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('97041', '795', '1', 'Spring', 2004, 'A-');
	insert into takes values('39520', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('90132', '527', '1', 'Fall', 2004, 'C+');
	insert into takes values('5414', '482', '1', 'Fall', 2005, 'A ');
	insert into takes values('40677', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('73165', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('92949', '581', '1', 'Spring', 2005, 'A-');
	insert into takes values('29031', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('9408', '748', '1', 'Fall', 2003, 'A-');
	insert into takes values('13403', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('44551', '852', '1', 'Spring', 2008, 'B ');
	insert into takes values('58355', '760', '1', 'Spring', 2004, 'B ');
	insert into takes values('46106', '974', '1', 'Fall', 2003, 'A-');
	insert into takes values('87044', '893', '1', 'Fall', 2007, 'B ');
	insert into takes values('667', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('94697', '239', '1', 'Fall', 2006, 'B ');
	insert into takes values('85680', '864', '1', 'Spring', 2006, 'B+');
	insert into takes values('37038', '400', '2', 'Fall', 2003, 'C-');
	insert into takes values('32506', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('6990', '158', '2', 'Spring', 2008, 'B-');
	insert into takes values('21008', '366', '1', 'Fall', 2005, 'A+');
	insert into takes values('52134', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('70021', '974', '1', 'Fall', 2003, 'C-');
	insert into takes values('89051', '400', '1', 'Spring', 2007, 'A-');
	insert into takes values('16453', '401', '1', 'Fall', 2003, 'A+');
	insert into takes values('80990', '748', '1', 'Fall', 2003, 'B-');
	insert into takes values('25940', '258', '1', 'Fall', 2007, 'C-');
	insert into takes values('97065', '400', '1', 'Spring', 2007, 'A+');
	insert into takes values('10033', '338', '2', 'Spring', 2006, 'C ');
	insert into takes values('32385', '349', '1', 'Spring', 2008, 'A-');
	insert into takes values('34126', '702', '1', 'Spring', 2001, 'B ');
	insert into takes values('30397', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('21337', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('76895', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('96741', '696', '1', 'Spring', 2002, 'C-');
	insert into takes values('99271', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('17924', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('36657', '169', '1', 'Spring', 2007, 'A ');
	insert into takes values('14874', '200', '1', 'Spring', 2007, 'C ');
	insert into takes values('27950', '105', '1', 'Fall', 2009, 'A+');
	insert into takes values('63502', '795', '1', 'Spring', 2004, 'C+');
	insert into takes values('47627', '137', '1', 'Spring', 2002, 'B+');
	insert into takes values('6367', '158', '1', 'Fall', 2008, 'B-');
	insert into takes values('90181', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('42388', '735', '2', 'Spring', 2010, 'B-');
	insert into takes values('40276', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('80698', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('72177', '158', '2', 'Spring', 2008, 'B-');
	insert into takes values('6474', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('99451', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('6400', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('83214', '527', '1', 'Fall', 2004, 'B-');
	insert into takes values('81610', '274', '1', 'Fall', 2002, 'B ');
	insert into takes values('20985', '793', '1', 'Spring', 2002, 'C ');
	insert into takes values('20084', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('90194', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('87965', '258', '1', 'Fall', 2007, 'A-');
	insert into takes values('82063', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('52291', '461', '1', 'Fall', 2002, 'B ');
	insert into takes values('42019', '791', '1', 'Spring', 2006, 'C-');
	insert into takes values('33791', '795', '1', 'Spring', 2004, 'B+');
	insert into takes values('64164', '443', '1', 'Spring', 2010, 'A ');
	insert into takes values('46928', '493', '1', 'Spring', 2010, 'C ');
	insert into takes values('87048', '400', '1', 'Spring', 2007, 'A+');
	insert into takes values('66090', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('16250', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('84432', '802', '1', 'Spring', 2003, 'A+');
	insert into takes values('64196', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('62549', '401', '1', 'Fall', 2003, 'C ');
	insert into takes values('86753', '169', '1', 'Spring', 2007, 'B ');
	insert into takes values('15578', '258', '1', 'Fall', 2007, 'C ');
	insert into takes values('35357', '893', '1', 'Fall', 2007, 'A-');
	insert into takes values('30021', '313', '1', 'Fall', 2010, 'C-');
	insert into takes values('88417', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('93366', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('85534', '974', '1', 'Fall', 2003, 'C ');
	insert into takes values('43123', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('17676', '559', '1', 'Fall', 2002, 'A ');
	insert into takes values('66494', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('26473', '468', '1', 'Fall', 2005, 'A ');
	insert into takes values('23344', '486', '1', 'Fall', 2009, 'C+');
	insert into takes values('98423', '692', '1', 'Spring', 2010, 'C-');
	insert into takes values('3833', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('88417', '362', '2', 'Fall', 2006, 'A-');
	insert into takes values('96193', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('40481', '237', '1', 'Spring', 2008, 'C+');
	insert into takes values('46762', '760', '1', 'Spring', 2004, 'B ');
	insert into takes values('76291', '319', '1', 'Spring', 2003, 'B-');
	insert into takes values('44551', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('47025', '735', '1', 'Spring', 2003, 'A-');
	insert into takes values('24784', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('34126', '345', '1', 'Spring', 2008, 'C-');
	insert into takes values('58081', '489', '1', 'Fall', 2007, 'B+');
	insert into takes values('914', '852', '1', 'Spring', 2008, 'C+');
	insert into takes values('86001', '545', '1', 'Fall', 2001, 'A-');
	insert into takes values('86802', '345', '1', 'Spring', 2008, 'C-');
	insert into takes values('30397', '631', '1', 'Spring', 2007, 'B+');
	insert into takes values('15430', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('22086', '400', '2', 'Fall', 2003, 'A+');
	insert into takes values('94998', '496', '1', 'Fall', 2001, 'B+');
	insert into takes values('55915', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('83953', '468', '2', 'Fall', 2007, 'C+');
	insert into takes values('98563', '960', '1', 'Fall', 2009, 'B ');
	insert into takes values('57925', '694', '1', 'Fall', 2002, 'A+');
	insert into takes values('80113', '461', '1', 'Fall', 2002, 'C+');
	insert into takes values('11262', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('69285', '591', '1', 'Spring', 2005, 'B-');
	insert into takes values('32245', '338', '2', 'Spring', 2006, 'A ');
	insert into takes values('45570', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('68010', '702', '1', 'Spring', 2001, 'B ');
	insert into takes values('50039', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('47001', '457', '1', 'Spring', 2001, 'C+');
	insert into takes values('11855', '400', '1', 'Spring', 2007, 'C+');
	insert into takes values('26473', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('80821', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('17128', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('25046', '735', '2', 'Spring', 2010, 'B ');
	insert into takes values('75560', '319', '1', 'Spring', 2003, 'A-');
	insert into takes values('58307', '626', '1', 'Fall', 2006, 'C ');
	insert into takes values('69241', '415', '1', 'Fall', 2010, 'B-');
	insert into takes values('24374', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('58634', '852', '1', 'Spring', 2008, 'A-');
	insert into takes values('43211', '559', '1', 'Fall', 2002, 'B+');
	insert into takes values('38371', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('97065', '791', '1', 'Spring', 2006, 'A-');
	insert into takes values('16907', '629', '1', 'Spring', 2003, 'B ');
	insert into takes values('55859', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('36402', '527', '1', 'Fall', 2004, 'C-');
	insert into takes values('36019', '489', '1', 'Fall', 2007, 'C+');
	insert into takes values('83314', '457', '1', 'Spring', 2001, 'A-');
	insert into takes values('54296', '376', '1', 'Fall', 2006, 'A-');
	insert into takes values('99719', '270', '1', 'Spring', 2010, 'C-');
	insert into takes values('32483', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('15430', '200', '2', 'Fall', 2002, 'B-');
	insert into takes values('32345', '376', '1', 'Fall', 2006, 'B-');
	insert into takes values('36657', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('3545', '591', '1', 'Spring', 2005, 'A-');
	insert into takes values('89132', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('43211', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('60040', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('76953', '443', '2', 'Spring', 2002, 'B-');
	insert into takes values('5243', '545', '1', 'Fall', 2001, 'A ');
	insert into takes values('2139', '239', '1', 'Fall', 2006, 'A-');
	insert into takes values('99553', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('76049', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('30334', '867', '1', 'Fall', 2006, 'A-');
	insert into takes values('25525', '401', '1', 'Fall', 2003, 'C+');
	insert into takes values('67033', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('83214', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('99719', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('48778', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('47265', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('94173', '169', '1', 'Spring', 2007, 'B ');
	insert into takes values('58465', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('75046', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('58413', '795', '1', 'Spring', 2004, 'A-');
	insert into takes values('107', '599', '1', 'Spring', 2003, 'A ');
	insert into takes values('84792', '421', '1', 'Fall', 2004, 'C+');
	insert into takes values('91616', '443', '1', 'Spring', 2010, 'A-');
	insert into takes values('30943', '345', '1', 'Spring', 2008, 'C ');
	insert into takes values('1220', '960', '2', 'Fall', 2006, 'C ');
	insert into takes values('36845', '802', '1', 'Spring', 2003, 'C+');
	insert into takes values('16515', '591', '1', 'Spring', 2005, 'B-');
	insert into takes values('92693', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('97629', '561', '1', 'Fall', 2006, 'A-');
	insert into takes values('18809', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('48776', '631', '1', 'Spring', 2007, 'B+');
	insert into takes values('5336', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('47824', '692', '1', 'Spring', 2010, 'A ');
	insert into takes values('39580', '362', '2', 'Fall', 2006, 'A-');
	insert into takes values('54620', '105', '2', 'Fall', 2002, 'C-');
	insert into takes values('41988', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('28252', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('3739', '581', '1', 'Spring', 2005, 'A ');
	insert into takes values('73268', '237', '2', 'Fall', 2009, 'C-');
	insert into takes values('61444', '692', '1', 'Spring', 2010, 'A-');
	insert into takes values('63288', '612', '1', 'Fall', 2007, 'B+');
	insert into takes values('58889', '604', '1', 'Spring', 2009, 'A ');
	insert into takes values('42625', '696', '1', 'Spring', 2002, 'A-');
	insert into takes values('32345', '748', '1', 'Fall', 2003, 'C-');
	insert into takes values('2177', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('93366', '852', '1', 'Spring', 2008, 'A-');
	insert into takes values('11422', '345', '1', 'Spring', 2008, 'A+');
	insert into takes values('81884', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('41450', '192', '1', 'Fall', 2002, 'C ');
	insert into takes values('83022', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('74639', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('58874', '426', '1', 'Spring', 2006, 'A+');
	insert into takes values('3005', '239', '1', 'Fall', 2006, 'B-');
	insert into takes values('71768', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('67146', '400', '2', 'Fall', 2003, 'C+');
	insert into takes values('43211', '137', '1', 'Spring', 2002, 'A ');
	insert into takes values('72165', '376', '1', 'Fall', 2006, 'C+');
	insert into takes values('32119', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('5336', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('20084', '421', '1', 'Fall', 2004, 'B+');
	insert into takes values('4435', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('81566', '692', '1', 'Spring', 2010, 'C+');
	insert into takes values('43981', '376', '1', 'Fall', 2006, 'C ');
	insert into takes values('96772', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('34329', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('2970', '927', '1', 'Fall', 2002, 'C-');
	insert into takes values('22268', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('80941', '334', '1', 'Fall', 2009, 'A ');
	insert into takes values('4508', '875', '1', 'Spring', 2005, 'B-');
	insert into takes values('463', '400', '2', 'Fall', 2003, 'A+');
	insert into takes values('98726', '591', '1', 'Spring', 2005, 'B+');
	insert into takes values('82580', '338', '1', 'Spring', 2007, 'A ');
	insert into takes values('24442', '489', '1', 'Fall', 2007, 'B-');
	insert into takes values('67436', '561', '1', 'Fall', 2006, 'A+');
	insert into takes values('85445', '237', '2', 'Fall', 2009, 'B+');
	insert into takes values('38973', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('49701', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('11201', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('1402', '319', '1', 'Spring', 2003, 'C-');
	insert into takes values('73206', '443', '1', 'Spring', 2010, 'A+');
	insert into takes values('25187', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('97953', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('78469', '415', '1', 'Fall', 2010, 'B ');
	insert into takes values('86934', '443', '2', 'Spring', 2002, 'B ');
	insert into takes values('67560', '334', '1', 'Fall', 2009, 'B-');
	insert into takes values('66212', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('61920', '893', '1', 'Fall', 2007, 'C+');
	insert into takes values('56143', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('50537', '795', '1', 'Spring', 2004, 'C+');
	insert into takes values('35523', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('83136', '642', '1', 'Fall', 2004, 'A+');
	insert into takes values('46956', '421', '1', 'Fall', 2004, 'A ');
	insert into takes values('20445', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('83557', '408', '1', 'Spring', 2007, 'A+');
	insert into takes values('667', '561', '1', 'Fall', 2006, 'C ');
	insert into takes values('65190', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('94522', '748', '1', 'Fall', 2003, 'A-');
	insert into takes values('61402', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('86969', '486', '1', 'Fall', 2009, 'B-');
	insert into takes values('12683', '421', '1', 'Fall', 2004, 'A-');
	insert into takes values('59539', '626', '1', 'Fall', 2006, 'A-');
	insert into takes values('98359', '527', '1', 'Fall', 2004, 'B+');
	insert into takes values('19862', '169', '1', 'Spring', 2007, 'B+');
	insert into takes values('13211', '893', '1', 'Fall', 2007, 'B ');
	insert into takes values('9933', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('18859', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('12563', '468', '1', 'Fall', 2005, 'A ');
	insert into takes values('88417', '443', '1', 'Spring', 2010, 'A-');
	insert into takes values('75299', '468', '1', 'Fall', 2005, 'B+');
	insert into takes values('15328', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('53547', '603', '1', 'Fall', 2003, 'B+');
	insert into takes values('90089', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('80420', '591', '1', 'Spring', 2005, 'A-');
	insert into takes values('17944', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('98047', '760', '1', 'Spring', 2004, 'A ');
	insert into takes values('52385', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('77548', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('85680', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('38973', '748', '1', 'Fall', 2003, 'A-');
	insert into takes values('50467', '457', '1', 'Spring', 2001, 'B-');
	insert into takes values('75510', '735', '1', 'Spring', 2003, 'C-');
	insert into takes values('68248', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('75772', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('67033', '808', '1', 'Fall', 2003, 'B ');
	insert into takes values('28952', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('11682', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('52929', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('58413', '242', '1', 'Fall', 2009, 'C+');
	insert into takes values('89106', '345', '1', 'Spring', 2008, 'C ');
	insert into takes values('78787', '352', '1', 'Spring', 2006, 'B ');
	insert into takes values('8192', '376', '1', 'Fall', 2006, 'B-');
	insert into takes values('90041', '704', '1', 'Spring', 2008, 'B ');
	insert into takes values('4015', '345', '1', 'Spring', 2008, 'B ');
	insert into takes values('67436', '581', '1', 'Spring', 2005, 'C-');
	insert into takes values('16057', '603', '1', 'Fall', 2003, 'C-');
	insert into takes values('14284', '843', '1', 'Fall', 2010, 'C ');
	insert into takes values('39552', '808', '1', 'Fall', 2003, 'A+');
	insert into takes values('18469', '962', '1', 'Spring', 2008, 'B ');
	insert into takes values('75123', '692', '1', 'Spring', 2010, 'A+');
	insert into takes values('14554', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('70310', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('74016', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('76250', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('8483', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('62152', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('58081', '991', '1', 'Spring', 2008, 'A ');
	insert into takes values('73387', '400', '1', 'Spring', 2007, 'B ');
	insert into takes values('39657', '349', '1', 'Spring', 2008, 'B+');
	insert into takes values('16405', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('68278', '679', '1', 'Spring', 2010, 'A+');
	insert into takes values('52157', '581', '1', 'Spring', 2005, 'B+');
	insert into takes values('86344', '200', '2', 'Fall', 2002, 'A ');
	insert into takes values('53788', '527', '1', 'Fall', 2004, 'C ');
	insert into takes values('19536', '105', '1', 'Fall', 2009, 'A+');
	insert into takes values('38973', '270', '1', 'Spring', 2010, 'B+');
	insert into takes values('76246', '704', '1', 'Spring', 2008, 'A+');
	insert into takes values('61332', '345', '1', 'Spring', 2008, 'C-');
	insert into takes values('65056', '461', '1', 'Fall', 2002, 'B-');
	insert into takes values('52187', '457', '1', 'Spring', 2001, 'B-');
	insert into takes values('22179', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('51698', '192', '1', 'Fall', 2002, 'C-');
	insert into takes values('46769', '408', '2', 'Spring', 2003, 'A+');
	insert into takes values('48053', '169', '1', 'Spring', 2007, 'B ');
	insert into takes values('64550', '338', '1', 'Spring', 2007, 'A+');
	insert into takes values('54622', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('30334', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('76768', '237', '1', 'Spring', 2008, 'A+');
	insert into takes values('58469', '338', '2', 'Spring', 2006, 'A+');
	insert into takes values('78787', '629', '1', 'Spring', 2003, 'B ');
	insert into takes values('21394', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('75046', '338', '2', 'Spring', 2006, 'C ');
	insert into takes values('98843', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('88577', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('93061', '696', '1', 'Spring', 2002, 'B+');
	insert into takes values('53728', '200', '2', 'Fall', 2002, 'B-');
	insert into takes values('5250', '642', '1', 'Fall', 2004, 'C+');
	insert into takes values('38895', '242', '1', 'Fall', 2009, 'C ');
	insert into takes values('53469', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('35198', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('59455', '960', '1', 'Fall', 2009, 'B ');
	insert into takes values('15030', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('22532', '352', '1', 'Spring', 2006, 'C+');
	insert into takes values('8192', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('30182', '591', '1', 'Spring', 2005, 'C+');
	insert into takes values('97065', '875', '1', 'Spring', 2005, 'A-');
	insert into takes values('36513', '864', '1', 'Spring', 2006, 'C+');
	insert into takes values('72485', '334', '1', 'Fall', 2009, 'A-');
	insert into takes values('15249', '169', '2', 'Fall', 2002, 'A-');
	insert into takes values('8860', '489', '1', 'Fall', 2007, 'C ');
	insert into takes values('46106', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('65688', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('98940', '443', '2', 'Spring', 2002, 'C+');
	insert into takes values('46956', '274', '1', 'Fall', 2002, 'C+');
	insert into takes values('931', '192', '1', 'Fall', 2002, 'C-');
	insert into takes values('69730', '561', '1', 'Fall', 2006, 'A-');
	insert into takes values('61444', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('40481', '631', '1', 'Spring', 2007, 'A-');
	insert into takes values('26802', '338', '2', 'Spring', 2006, 'A ');
	insert into takes values('68070', '603', '1', 'Fall', 2003, 'B-');
	insert into takes values('63090', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('22467', '735', '1', 'Spring', 2003, 'A ');
	insert into takes values('20489', '242', '1', 'Fall', 2009, 'C ');
	insert into takes values('22057', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('2423', '793', '1', 'Spring', 2002, 'C ');
	insert into takes values('57238', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('39704', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('58595', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('43495', '591', '1', 'Spring', 2005, 'B ');
	insert into takes values('15030', '400', '2', 'Fall', 2003, 'A ');
	insert into takes values('44881', '338', '2', 'Spring', 2006, 'A ');
	insert into takes values('8860', '408', '1', 'Spring', 2007, 'A ');
	insert into takes values('5017', '960', '1', 'Fall', 2009, 'B-');
	insert into takes values('48471', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('84727', '735', '1', 'Spring', 2003, 'C-');
	insert into takes values('17339', '793', '1', 'Spring', 2002, 'B+');
	insert into takes values('54875', '443', '2', 'Spring', 2002, 'A ');
	insert into takes values('18752', '415', '1', 'Fall', 2010, 'A+');
	insert into takes values('86552', '631', '1', 'Spring', 2007, 'C+');
	insert into takes values('59290', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('72979', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('15487', '200', '1', 'Spring', 2007, 'A+');
	insert into takes values('61003', '400', '2', 'Fall', 2003, 'B-');
	insert into takes values('49982', '893', '1', 'Fall', 2007, 'A+');
	insert into takes values('16907', '366', '1', 'Fall', 2005, 'A+');
	insert into takes values('44271', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('77548', '493', '1', 'Spring', 2010, 'A+');
	insert into takes values('1954', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('76049', '338', '1', 'Spring', 2007, 'C-');
	insert into takes values('61332', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('24325', '735', '1', 'Spring', 2003, 'C ');
	insert into takes values('64169', '864', '1', 'Spring', 2006, 'A+');
	insert into takes values('91132', '489', '1', 'Fall', 2007, 'B-');
	insert into takes values('91063', '571', '1', 'Spring', 2004, 'A+');
	insert into takes values('52523', '760', '1', 'Spring', 2004, 'A-');
	insert into takes values('96968', '334', '1', 'Fall', 2009, 'C-');
	insert into takes values('39157', '237', '1', 'Spring', 2008, 'C+');
	insert into takes values('78481', '338', '1', 'Spring', 2007, 'B ');
	insert into takes values('12326', '158', '2', 'Spring', 2008, 'A ');
	insert into takes values('99553', '105', '1', 'Fall', 2009, 'C ');
	insert into takes values('86934', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('45002', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('28738', '237', '2', 'Fall', 2009, 'A ');
	insert into takes values('12216', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('23457', '421', '1', 'Fall', 2004, 'A-');
	insert into takes values('827', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('435', '735', '1', 'Spring', 2003, 'A-');
	insert into takes values('63538', '702', '1', 'Spring', 2001, 'C+');
	insert into takes values('70688', '599', '1', 'Spring', 2003, 'A-');
	insert into takes values('93814', '694', '1', 'Fall', 2002, 'C ');
	insert into takes values('77361', '864', '1', 'Spring', 2006, 'C-');
	insert into takes values('2177', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('18007', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('35257', '974', '1', 'Fall', 2003, 'C-');
	insert into takes values('71543', '242', '1', 'Fall', 2009, 'C-');
	insert into takes values('21126', '239', '1', 'Fall', 2006, 'A-');
	insert into takes values('86833', '852', '1', 'Spring', 2008, 'B ');
	insert into takes values('76768', '704', '1', 'Spring', 2008, 'B ');
	insert into takes values('11453', '843', '1', 'Fall', 2010, 'C-');
	insert into takes values('43505', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('57511', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('17911', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('95260', '366', '1', 'Fall', 2005, 'C ');
	insert into takes values('64196', '415', '1', 'Fall', 2010, 'B+');
	insert into takes values('86127', '274', '1', 'Fall', 2002, 'C+');
	insert into takes values('13028', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('95260', '702', '1', 'Spring', 2001, 'C+');
	insert into takes values('4435', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('86075', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('66494', '875', '1', 'Spring', 2005, 'A+');
	insert into takes values('3833', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('61414', '791', '1', 'Spring', 2006, 'C+');
	insert into takes values('66293', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('2423', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('72177', '867', '2', 'Fall', 2010, 'A+');
	insert into takes values('75082', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('33817', '571', '1', 'Spring', 2004, 'C-');
	insert into takes values('16543', '242', '1', 'Fall', 2009, 'A+');
	insert into takes values('17128', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('94846', '349', '1', 'Spring', 2008, 'A-');
	insert into takes values('50969', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('59455', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('52385', '604', '1', 'Spring', 2009, 'B+');
	insert into takes values('25940', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('45817', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('99268', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('16593', '313', '1', 'Fall', 2010, 'B+');
	insert into takes values('53185', '493', '1', 'Spring', 2010, 'B+');
	insert into takes values('55000', '867', '2', 'Fall', 2010, 'A-');
	insert into takes values('3833', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('19735', '692', '1', 'Spring', 2010, 'A ');
	insert into takes values('99611', '626', '1', 'Fall', 2006, 'A-');
	insert into takes values('96085', '604', '1', 'Spring', 2009, 'B ');
	insert into takes values('89571', '626', '1', 'Fall', 2006, 'C ');
	insert into takes values('96722', '415', '1', 'Fall', 2010, 'C ');
	insert into takes values('68779', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('80227', '808', '1', 'Fall', 2003, 'A-');
	insert into takes values('67542', '476', '1', 'Fall', 2010, 'B+');
	insert into takes values('86707', '949', '1', 'Fall', 2007, 'C+');
	insert into takes values('59673', '793', '1', 'Spring', 2002, 'C-');
	insert into takes values('2201', '421', '1', 'Fall', 2004, 'C+');
	insert into takes values('34236', '270', '1', 'Spring', 2010, 'C ');
	insert into takes values('40059', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('94173', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('30222', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('36265', '169', '2', 'Fall', 2002, 'A-');
	insert into takes values('44703', '843', '1', 'Fall', 2010, 'C+');
	insert into takes values('11237', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('95859', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('35175', '642', '1', 'Fall', 2004, 'B-');
	insert into takes values('42114', '401', '1', 'Fall', 2003, 'C+');
	insert into takes values('31690', '571', '1', 'Spring', 2004, 'B+');
	insert into takes values('16035', '352', '1', 'Spring', 2006, 'A-');
	insert into takes values('79352', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('79911', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('6195', '408', '2', 'Spring', 2003, 'B-');
	insert into takes values('24201', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('18859', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('39876', '443', '1', 'Spring', 2010, 'C ');
	insert into takes values('30188', '496', '1', 'Fall', 2001, 'C-');
	insert into takes values('16969', '843', '1', 'Fall', 2010, 'A ');
	insert into takes values('15328', '362', '3', 'Spring', 2008, 'B ');
	insert into takes values('27430', '169', '2', 'Fall', 2002, 'A-');
	insert into takes values('64893', '476', '1', 'Fall', 2010, 'B ');
	insert into takes values('77548', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('23500', '527', '1', 'Fall', 2004, 'B-');
	insert into takes values('92332', '795', '1', 'Spring', 2004, 'A-');
	insert into takes values('39394', '169', '2', 'Fall', 2002, 'B ');
	insert into takes values('91442', '352', '1', 'Spring', 2006, 'B+');
	insert into takes values('66229', '334', '1', 'Fall', 2009, 'B+');
	insert into takes values('40558', '401', '1', 'Fall', 2003, 'C+');
	insert into takes values('96615', '527', '1', 'Fall', 2004, 'C-');
	insert into takes values('63502', '408', '1', 'Spring', 2007, 'C ');
	insert into takes values('91370', '192', '1', 'Fall', 2002, 'A+');
	insert into takes values('17676', '334', '1', 'Fall', 2009, 'A ');
	insert into takes values('9659', '631', '1', 'Spring', 2007, 'B+');
	insert into takes values('4248', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('67371', '304', '1', 'Fall', 2009, 'C+');
	insert into takes values('13741', '338', '2', 'Spring', 2006, 'B ');
	insert into takes values('6523', '349', '1', 'Spring', 2008, 'C-');
	insert into takes values('81207', '527', '1', 'Fall', 2004, 'A-');
	insert into takes values('26473', '704', '1', 'Spring', 2008, 'B ');
	insert into takes values('90132', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('5017', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('65987', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('10454', '158', '1', 'Fall', 2008, 'A ');
	insert into takes values('1954', '270', '1', 'Spring', 2010, 'B-');
	insert into takes values('25068', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('37103', '960', '2', 'Fall', 2006, 'C ');
	insert into takes values('73387', '991', '1', 'Spring', 2008, 'B ');
	insert into takes values('9993', '867', '1', 'Fall', 2006, 'B ');
	insert into takes values('32345', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('76768', '352', '1', 'Spring', 2006, 'C-');
	insert into takes values('91580', '408', '2', 'Spring', 2003, 'A ');
	insert into takes values('89106', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('63310', '468', '1', 'Fall', 2005, 'C ');
	insert into takes values('36052', '415', '1', 'Fall', 2010, 'A-');
	insert into takes values('61920', '581', '1', 'Spring', 2005, 'C-');
	insert into takes values('48053', '270', '1', 'Spring', 2010, 'C+');
	insert into takes values('61354', '561', '1', 'Fall', 2006, 'B-');
	insert into takes values('64550', '200', '2', 'Fall', 2002, 'A+');
	insert into takes values('4248', '867', '1', 'Fall', 2006, 'B+');
	insert into takes values('23224', '319', '1', 'Spring', 2003, 'C+');
	insert into takes values('67657', '972', '1', 'Spring', 2009, 'A-');
	insert into takes values('53469', '242', '1', 'Fall', 2009, 'C ');
	insert into takes values('13506', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('16849', '489', '1', 'Fall', 2007, 'B-');
	insert into takes values('54605', '445', '1', 'Spring', 2001, 'C+');
	insert into takes values('12615', '629', '1', 'Spring', 2003, 'A+');
	insert into takes values('16515', '489', '1', 'Fall', 2007, 'B-');
	insert into takes values('89196', '991', '1', 'Spring', 2008, 'B ');
	insert into takes values('79469', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('30650', '692', '1', 'Spring', 2010, 'A ');
	insert into takes values('8483', '105', '1', 'Fall', 2009, 'C ');
	insert into takes values('51862', '408', '1', 'Spring', 2007, 'A-');
	insert into takes values('91799', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('53048', '875', '1', 'Spring', 2005, 'C-');
	insert into takes values('52741', '843', '1', 'Fall', 2010, 'C+');
	insert into takes values('98423', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('24865', '493', '1', 'Spring', 2010, 'C+');
	insert into takes values('56755', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('39514', '200', '1', 'Spring', 2007, 'A+');
	insert into takes values('15430', '352', '1', 'Spring', 2006, 'C+');
	insert into takes values('48469', '696', '1', 'Spring', 2002, 'C-');
	insert into takes values('20244', '629', '1', 'Spring', 2003, 'A ');
	insert into takes values('81538', '200', '1', 'Spring', 2007, 'A+');
	insert into takes values('42625', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('2795', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('49244', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('21102', '242', '1', 'Fall', 2009, 'A+');
	insert into takes values('23311', '158', '1', 'Fall', 2008, 'C ');
	insert into takes values('19203', '258', '1', 'Fall', 2007, 'B-');
	insert into takes values('71944', '200', '2', 'Fall', 2002, 'A-');
	insert into takes values('55000', '486', '1', 'Fall', 2009, 'C ');
	insert into takes values('19245', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('8426', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('37103', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('12979', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('16297', '313', '1', 'Fall', 2010, 'C ');
	insert into takes values('67436', '400', '2', 'Fall', 2003, 'B+');
	insert into takes values('97868', '949', '1', 'Fall', 2007, 'C-');
	insert into takes values('10904', '105', '1', 'Fall', 2009, 'B+');
	insert into takes values('74974', '702', '1', 'Spring', 2001, 'C-');
	insert into takes values('94324', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('69783', '927', '1', 'Fall', 2002, 'C-');
	insert into takes values('89000', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('79210', '843', '1', 'Fall', 2010, 'C ');
	insert into takes values('20489', '158', '2', 'Spring', 2008, 'C+');
	insert into takes values('90663', '960', '1', 'Fall', 2009, 'B+');
	insert into takes values('98056', '338', '2', 'Spring', 2006, 'A-');
	insert into takes values('38712', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('10834', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('1080', '200', '1', 'Spring', 2007, 'C-');
	insert into takes values('95840', '559', '1', 'Fall', 2002, 'B ');
	insert into takes values('61854', '408', '1', 'Spring', 2007, 'A-');
	insert into takes values('96710', '604', '1', 'Spring', 2009, 'A ');
	insert into takes values('51975', '960', '1', 'Fall', 2009, 'B+');
	insert into takes values('12941', '696', '1', 'Spring', 2002, 'A+');
	insert into takes values('86674', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('98047', '972', '1', 'Spring', 2009, 'A ');
	insert into takes values('41683', '489', '1', 'Fall', 2007, 'B ');
	insert into takes values('24442', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('30252', '408', '1', 'Spring', 2007, 'B ');
	insert into takes values('82707', '972', '1', 'Spring', 2009, 'A+');
	insert into takes values('66484', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('46074', '591', '1', 'Spring', 2005, 'C-');
	insert into takes values('10834', '612', '1', 'Fall', 2007, 'A ');
	insert into takes values('16480', '137', '1', 'Spring', 2002, 'B+');
	insert into takes values('79352', '105', '1', 'Fall', 2009, 'C ');
	insert into takes values('64067', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('95046', '493', '1', 'Spring', 2010, 'A+');
	insert into takes values('84702', '626', '1', 'Fall', 2006, 'C+');
	insert into takes values('21394', '893', '1', 'Fall', 2007, 'A ');
	insert into takes values('92274', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('39704', '158', '2', 'Spring', 2008, 'A-');
	insert into takes values('89759', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('57456', '304', '1', 'Fall', 2009, 'A ');
	insert into takes values('64297', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('98563', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('35462', '400', '1', 'Spring', 2007, 'C ');
	insert into takes values('61854', '692', '1', 'Spring', 2010, 'A-');
	insert into takes values('38668', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('75794', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('80742', '362', '1', 'Fall', 2005, 'C ');
	insert into takes values('85746', '352', '1', 'Spring', 2006, 'B+');
	insert into takes values('8347', '559', '1', 'Fall', 2002, 'C+');
	insert into takes values('74464', '843', '1', 'Fall', 2010, 'A ');
	insert into takes values('83622', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('91091', '927', '1', 'Fall', 2002, 'C ');
	insert into takes values('15024', '313', '1', 'Fall', 2010, 'A ');
	insert into takes values('31341', '679', '1', 'Spring', 2010, 'A ');
	insert into takes values('84432', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('10527', '604', '1', 'Spring', 2009, 'A-');
	insert into takes values('54728', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('44703', '270', '1', 'Spring', 2010, 'A-');
	insert into takes values('6209', '158', '2', 'Spring', 2008, 'B-');
	insert into takes values('63288', '338', '2', 'Spring', 2006, 'A+');
	insert into takes values('43348', '468', '1', 'Fall', 2005, 'A ');
	insert into takes values('62487', '960', '1', 'Fall', 2009, 'B-');
	insert into takes values('46337', '421', '1', 'Fall', 2004, 'C-');
	insert into takes values('86075', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('99760', '169', '2', 'Fall', 2002, 'B+');
	insert into takes values('65101', '748', '1', 'Fall', 2003, 'A-');
	insert into takes values('30772', '105', '2', 'Fall', 2002, 'B-');
	insert into takes values('22050', '376', '1', 'Fall', 2006, 'A ');
	insert into takes values('78552', '105', '2', 'Fall', 2002, 'C+');
	insert into takes values('19861', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('39580', '338', '1', 'Spring', 2007, 'C+');
	insert into takes values('75273', '362', '2', 'Fall', 2006, 'A-');
	insert into takes values('52872', '443', '1', 'Spring', 2010, 'B-');
	insert into takes values('76799', '319', '1', 'Spring', 2003, 'B-');
	insert into takes values('33645', '927', '1', 'Fall', 2002, 'A ');
	insert into takes values('25143', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('20099', '237', '2', 'Fall', 2009, 'B+');
	insert into takes values('87784', '426', '1', 'Spring', 2006, 'A ');
	insert into takes values('58701', '972', '1', 'Spring', 2009, 'B-');
	insert into takes values('23992', '591', '1', 'Spring', 2005, 'A-');
	insert into takes values('1367', '692', '1', 'Spring', 2010, 'C-');
	insert into takes values('48247', '679', '1', 'Spring', 2010, 'B ');
	insert into takes values('83444', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('12078', '493', '1', 'Spring', 2010, 'A-');
	insert into takes values('16467', '401', '1', 'Fall', 2003, 'B+');
	insert into takes values('9953', '443', '1', 'Spring', 2010, 'B ');
	insert into takes values('50658', '626', '1', 'Fall', 2006, 'A-');
	insert into takes values('7498', '893', '1', 'Fall', 2007, 'A ');
	insert into takes values('70688', '443', '1', 'Spring', 2010, 'B ');
	insert into takes values('36263', '457', '1', 'Spring', 2001, 'A ');
	insert into takes values('58874', '468', '2', 'Fall', 2007, 'C+');
	insert into takes values('37759', '362', '1', 'Fall', 2005, 'B ');
	insert into takes values('65258', '493', '1', 'Spring', 2010, 'B ');
	insert into takes values('37449', '493', '1', 'Spring', 2010, 'A-');
	insert into takes values('6712', '612', '1', 'Fall', 2007, 'B ');
	insert into takes values('12941', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('78922', '591', '1', 'Spring', 2005, 'A ');
	insert into takes values('42388', '270', '1', 'Spring', 2010, 'A+');
	insert into takes values('24374', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('23500', '603', '1', 'Fall', 2003, 'C-');
	insert into takes values('93491', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('25525', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('30334', '334', '1', 'Fall', 2009, 'A ');
	insert into takes values('99369', '867', '1', 'Fall', 2006, 'B+');
	insert into takes values('6367', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('18338', '169', '2', 'Fall', 2002, 'B-');
	insert into takes values('8957', '735', '2', 'Spring', 2010, 'C ');
	insert into takes values('63090', '415', '1', 'Fall', 2010, 'A-');
	insert into takes values('65396', '527', '1', 'Fall', 2004, 'A-');
	insert into takes values('27430', '581', '1', 'Spring', 2005, 'B+');
	insert into takes values('64067', '702', '1', 'Spring', 2001, 'B ');
	insert into takes values('75123', '457', '1', 'Spring', 2001, 'B-');
	insert into takes values('67018', '962', '1', 'Spring', 2008, 'C+');
	insert into takes values('7973', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('80976', '200', '2', 'Fall', 2002, 'C+');
	insert into takes values('35498', '959', '1', 'Fall', 2006, 'C+');
	insert into takes values('45826', '169', '2', 'Fall', 2002, 'B+');
	insert into takes values('23439', '158', '2', 'Spring', 2008, 'A-');
	insert into takes values('23794', '960', '2', 'Fall', 2006, 'C+');
	insert into takes values('5843', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('12216', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('1402', '415', '1', 'Fall', 2010, 'C+');
	insert into takes values('99369', '137', '1', 'Spring', 2002, 'B ');
	insert into takes values('15024', '258', '1', 'Fall', 2007, 'B+');
	insert into takes values('36052', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('41965', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('84039', '599', '1', 'Spring', 2003, 'B ');
	insert into takes values('17397', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('47487', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('28352', '242', '1', 'Fall', 2009, 'B+');
	insert into takes values('43226', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('97551', '972', '1', 'Spring', 2009, 'A ');
	insert into takes values('11377', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('14065', '960', '2', 'Fall', 2006, 'C-');
	insert into takes values('39612', '352', '1', 'Spring', 2006, 'C+');
	insert into takes values('2629', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('14484', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('19848', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('70061', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('19582', '875', '1', 'Spring', 2005, 'B+');
	insert into takes values('16250', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('77289', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('85211', '376', '1', 'Fall', 2006, 'C ');
	insert into takes values('63288', '352', '1', 'Spring', 2006, 'A-');
	insert into takes values('48009', '843', '1', 'Fall', 2010, 'A-');
	insert into takes values('59046', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('95201', '679', '1', 'Spring', 2010, 'B+');
	insert into takes values('51549', '169', '1', 'Spring', 2007, 'C ');
	insert into takes values('90567', '192', '1', 'Fall', 2002, 'C ');
	insert into takes values('97694', '626', '1', 'Fall', 2006, 'A-');
	insert into takes values('95099', '545', '1', 'Fall', 2001, 'A-');
	insert into takes values('81883', '352', '1', 'Spring', 2006, 'A-');
	insert into takes values('15430', '443', '2', 'Spring', 2002, 'A-');
	insert into takes values('83838', '626', '1', 'Fall', 2006, 'B-');
	insert into takes values('7287', '493', '1', 'Spring', 2010, 'C+');
	insert into takes values('53424', '626', '1', 'Fall', 2006, 'A ');
	insert into takes values('55698', '158', '1', 'Fall', 2008, 'A ');
	insert into takes values('34392', '735', '1', 'Spring', 2003, 'A+');
	insert into takes values('32490', '527', '1', 'Fall', 2004, 'B-');
	insert into takes values('36791', '304', '1', 'Fall', 2009, 'C-');
	insert into takes values('62226', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('64259', '893', '1', 'Fall', 2007, 'C+');
	insert into takes values('10454', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('25143', '604', '1', 'Spring', 2009, 'C ');
	insert into takes values('5399', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('3640', '313', '1', 'Fall', 2010, 'A-');
	insert into takes values('35220', '960', '1', 'Fall', 2009, 'C-');
	insert into takes values('2133', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('97355', '704', '1', 'Spring', 2008, 'C-');
	insert into takes values('5898', '972', '1', 'Spring', 2009, 'A+');
	insert into takes values('47379', '158', '2', 'Spring', 2008, 'C ');
	insert into takes values('74911', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('14874', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('52876', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('6523', '591', '1', 'Spring', 2005, 'B+');
	insert into takes values('58701', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('16250', '927', '1', 'Fall', 2002, 'A-');
	insert into takes values('29959', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('39520', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('22417', '352', '1', 'Spring', 2006, 'C+');
	insert into takes values('29390', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('62728', '401', '1', 'Fall', 2003, 'B+');
	insert into takes values('59553', '864', '1', 'Spring', 2006, 'A ');
	insert into takes values('63040', '864', '1', 'Spring', 2006, 'C-');
	insert into takes values('20099', '864', '1', 'Spring', 2006, 'A ');
	insert into takes values('69853', '974', '1', 'Fall', 2003, 'B-');
	insert into takes values('96193', '408', '1', 'Spring', 2007, 'A-');
	insert into takes values('98047', '239', '1', 'Fall', 2006, 'B ');
	insert into takes values('27366', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('37219', '793', '1', 'Spring', 2002, 'B+');
	insert into takes values('76270', '237', '2', 'Fall', 2009, 'C-');
	insert into takes values('83728', '366', '1', 'Fall', 2005, 'C-');
	insert into takes values('16993', '747', '1', 'Spring', 2004, 'C ');
	insert into takes values('96178', '960', '2', 'Fall', 2006, 'A-');
	insert into takes values('11966', '694', '1', 'Fall', 2002, 'C+');
	insert into takes values('1087', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('95852', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('38899', '319', '1', 'Spring', 2003, 'C-');
	insert into takes values('39114', '927', '1', 'Fall', 2002, 'A ');
	insert into takes values('31341', '864', '1', 'Spring', 2006, 'B+');
	insert into takes values('42956', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('47487', '493', '1', 'Spring', 2010, 'C ');
	insert into takes values('37715', '105', '1', 'Fall', 2009, 'C+');
	insert into takes values('36881', '137', '1', 'Spring', 2002, 'A-');
	insert into takes values('32376', '319', '1', 'Spring', 2003, 'B-');
	insert into takes values('32056', '270', '1', 'Spring', 2010, 'C+');
	insert into takes values('34197', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('667', '415', '1', 'Fall', 2010, 'C-');
	insert into takes values('92385', '612', '1', 'Fall', 2007, 'B+');
	insert into takes values('96085', '192', '1', 'Fall', 2002, 'A+');
	insert into takes values('29260', '169', '2', 'Fall', 2002, 'C ');
	insert into takes values('50977', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('59553', '313', '1', 'Fall', 2010, 'A+');
	insert into takes values('17207', '735', '2', 'Spring', 2010, 'B-');
	insert into takes values('89051', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('30017', '468', '1', 'Fall', 2005, 'B+');
	insert into takes values('99250', '200', '1', 'Spring', 2007, 'A+');
	insert into takes values('26881', '793', '1', 'Spring', 2002, 'C-');
	insert into takes values('99611', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('11126', '631', '1', 'Spring', 2007, 'C-');
	insert into takes values('36102', '158', '1', 'Fall', 2008, 'A ');
	insert into takes values('73186', '760', '1', 'Spring', 2004, 'C+');
	insert into takes values('45083', '105', '2', 'Fall', 2002, 'C+');
	insert into takes values('87222', '793', '1', 'Spring', 2002, 'A+');
	insert into takes values('95850', '679', '1', 'Spring', 2010, 'A+');
	insert into takes values('92965', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('41450', '960', '1', 'Fall', 2009, 'B ');
	insert into takes values('55286', '426', '1', 'Spring', 2006, 'A-');
	insert into takes values('11101', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('20974', '408', '1', 'Spring', 2007, 'A ');
	insert into takes values('96203', '461', '1', 'Fall', 2002, 'A-');
	insert into takes values('67371', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('53165', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('71768', '362', '2', 'Fall', 2006, 'C-');
	insert into takes values('12236', '852', '1', 'Spring', 2008, 'C ');
	insert into takes values('40116', '599', '1', 'Spring', 2003, 'B ');
	insert into takes values('53089', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('31690', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('16528', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('26730', '401', '1', 'Fall', 2003, 'C ');
	insert into takes values('2848', '496', '1', 'Fall', 2001, 'A+');
	insert into takes values('51008', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('13023', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('35362', '426', '1', 'Spring', 2006, 'A+');
	insert into takes values('97590', '313', '1', 'Fall', 2010, 'A+');
	insert into takes values('34322', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('85445', '443', '1', 'Spring', 2010, 'B-');
	insert into takes values('24387', '599', '1', 'Spring', 2003, 'A ');
	insert into takes values('19824', '867', '1', 'Fall', 2006, 'C+');
	insert into takes values('37284', '338', '2', 'Spring', 2006, 'A+');
	insert into takes values('2629', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('70452', '445', '1', 'Spring', 2001, 'A-');
	insert into takes values('48640', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('96052', '476', '1', 'Fall', 2010, 'C ');
	insert into takes values('83170', '496', '1', 'Fall', 2001, 'A-');
	insert into takes values('55915', '962', '1', 'Spring', 2008, 'C-');
	insert into takes values('49339', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('13495', '571', '1', 'Spring', 2004, 'A-');
	insert into takes values('63243', '169', '1', 'Spring', 2007, 'C ');
	insert into takes values('8347', '461', '1', 'Fall', 2002, 'A-');
	insert into takes values('11095', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('3833', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('35175', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('86833', '242', '1', 'Fall', 2009, 'A-');
	insert into takes values('1367', '559', '1', 'Fall', 2002, 'A-');
	insert into takes values('34569', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('1954', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('38288', '702', '1', 'Spring', 2001, 'C+');
	insert into takes values('68516', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('49214', '960', '2', 'Fall', 2006, 'C ');
	insert into takes values('8457', '626', '1', 'Fall', 2006, 'A ');
	insert into takes values('25143', '702', '1', 'Spring', 2001, 'B ');
	insert into takes values('93814', '349', '1', 'Spring', 2008, 'A ');
	insert into takes values('72643', '629', '1', 'Spring', 2003, 'A+');
	insert into takes values('45770', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('336', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('41299', '631', '1', 'Spring', 2007, 'A+');
	insert into takes values('95205', '319', '1', 'Spring', 2003, 'A-');
	insert into takes values('18554', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('15726', '239', '1', 'Fall', 2006, 'B ');
	insert into takes values('64938', '200', '1', 'Spring', 2007, 'A-');
	insert into takes values('20244', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('44206', '338', '1', 'Spring', 2007, 'C-');
	insert into takes values('61065', '559', '1', 'Fall', 2002, 'B ');
	insert into takes values('95840', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('53699', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('11126', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('46762', '408', '1', 'Spring', 2007, 'C ');
	insert into takes values('5399', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('13408', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('95574', '747', '1', 'Spring', 2004, 'B-');
	insert into takes values('32464', '105', '2', 'Fall', 2002, 'A ');
	insert into takes values('32506', '400', '2', 'Fall', 2003, 'C-');
	insert into takes values('2970', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('92385', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('57925', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('25525', '808', '1', 'Fall', 2003, 'A-');
	insert into takes values('12326', '843', '1', 'Fall', 2010, 'C-');
	insert into takes values('89551', '692', '1', 'Spring', 2010, 'A+');
	insert into takes values('36102', '867', '1', 'Fall', 2006, 'B ');
	insert into takes values('42843', '972', '1', 'Spring', 2009, 'B-');
	insert into takes values('72643', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('31266', '400', '1', 'Spring', 2007, 'A-');
	insert into takes values('13880', '571', '1', 'Spring', 2004, 'A+');
	insert into takes values('66753', '867', '1', 'Fall', 2006, 'B+');
	insert into takes values('37350', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('37734', '527', '1', 'Fall', 2004, 'B+');
	insert into takes values('77898', '400', '2', 'Fall', 2003, 'A+');
	insert into takes values('17507', '274', '1', 'Fall', 2002, 'B ');
	insert into takes values('97435', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('5703', '612', '1', 'Fall', 2007, 'A-');
	insert into takes values('30723', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('36494', '748', '1', 'Fall', 2003, 'C-');
	insert into takes values('62716', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('69222', '561', '1', 'Fall', 2006, 'C ');
	insert into takes values('67407', '960', '2', 'Fall', 2006, 'C ');
	insert into takes values('17192', '482', '1', 'Fall', 2005, 'B ');
	insert into takes values('82301', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('82066', '476', '1', 'Fall', 2010, 'C ');
	insert into takes values('76224', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('99760', '581', '1', 'Spring', 2005, 'C-');
	insert into takes values('97023', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('76270', '591', '1', 'Spring', 2005, 'A-');
	insert into takes values('85575', '927', '1', 'Fall', 2002, 'A+');
	insert into takes values('18108', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('8853', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('74796', '959', '1', 'Fall', 2006, 'C+');
	insert into takes values('54153', '561', '1', 'Fall', 2006, 'C+');
	insert into takes values('11237', '747', '1', 'Spring', 2004, 'B+');
	insert into takes values('67146', '242', '1', 'Fall', 2009, 'B ');
	insert into takes values('19791', '581', '1', 'Spring', 2005, 'B+');
	insert into takes values('57474', '604', '1', 'Spring', 2009, 'B ');
	insert into takes values('90004', '960', '1', 'Fall', 2009, 'C-');
	insert into takes values('56276', '631', '1', 'Spring', 2007, 'A-');
	insert into takes values('38121', '631', '1', 'Spring', 2007, 'C+');
	insert into takes values('36126', '338', '2', 'Spring', 2006, 'C+');
	insert into takes values('22417', '875', '1', 'Spring', 2005, 'B-');
	insert into takes values('47677', '338', '1', 'Spring', 2007, 'A ');
	insert into takes values('15487', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('64820', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('37521', '748', '1', 'Fall', 2003, 'A-');
	insert into takes values('14869', '237', '2', 'Fall', 2009, 'C ');
	insert into takes values('85904', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('70099', '696', '1', 'Spring', 2002, 'A+');
	insert into takes values('68263', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('89297', '696', '1', 'Spring', 2002, 'B+');
	insert into takes values('59455', '486', '1', 'Fall', 2009, 'C ');
	insert into takes values('37734', '366', '1', 'Fall', 2005, 'A ');
	insert into takes values('10917', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('96206', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('31761', '200', '1', 'Spring', 2007, 'C ');
	insert into takes values('95852', '867', '2', 'Fall', 2010, 'A-');
	insert into takes values('54875', '631', '1', 'Spring', 2007, 'A+');
	insert into takes values('85356', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('847', '415', '1', 'Fall', 2010, 'C ');
	insert into takes values('77231', '426', '1', 'Spring', 2006, 'A-');
	insert into takes values('67425', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('48778', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('29803', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('1087', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('18554', '696', '1', 'Spring', 2002, 'C-');
	insert into takes values('70522', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('9114', '949', '1', 'Fall', 2007, 'C-');
	insert into takes values('68263', '304', '1', 'Fall', 2009, 'A ');
	insert into takes values('67033', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('85680', '237', '2', 'Fall', 2009, 'A ');
	insert into takes values('83511', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('21100', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('44551', '258', '1', 'Fall', 2007, 'C-');
	insert into takes values('16467', '258', '1', 'Fall', 2007, 'A+');
	insert into takes values('78782', '400', '2', 'Fall', 2003, 'B-');
	insert into takes values('92274', '319', '1', 'Spring', 2003, 'A-');
	insert into takes values('88140', '270', '1', 'Spring', 2010, 'C ');
	insert into takes values('79170', '169', '2', 'Fall', 2002, 'A ');
	insert into takes values('52872', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('25331', '663', '1', 'Spring', 2005, 'A ');
	insert into takes values('80113', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('24809', '496', '1', 'Fall', 2001, 'B ');
	insert into takes values('49073', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('65688', '400', '1', 'Spring', 2007, 'A+');
	insert into takes values('28994', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('27528', '445', '1', 'Spring', 2001, 'B+');
	insert into takes values('12069', '642', '1', 'Fall', 2004, 'C+');
	insert into takes values('77664', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('77289', '527', '1', 'Fall', 2004, 'C+');
	insert into takes values('55000', '313', '1', 'Fall', 2010, 'C-');
	insert into takes values('59553', '843', '1', 'Fall', 2010, 'B-');
	insert into takes values('99553', '960', '1', 'Fall', 2009, 'A+');
	insert into takes values('55009', '571', '1', 'Spring', 2004, 'A-');
	insert into takes values('79446', '468', '1', 'Fall', 2005, 'C+');
	insert into takes values('64724', '604', '1', 'Spring', 2009, 'B ');
	insert into takes values('85602', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('56080', '735', '2', 'Spring', 2010, 'B ');
	insert into takes values('50267', '527', '1', 'Fall', 2004, 'A ');
	insert into takes values('77664', '760', '1', 'Spring', 2004, 'C ');
	insert into takes values('15024', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('40677', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('3640', '960', '2', 'Fall', 2006, 'C+');
	insert into takes values('29871', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('30858', '400', '1', 'Spring', 2007, 'A-');
	insert into takes values('71529', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('645', '694', '1', 'Fall', 2002, 'C ');
	insert into takes values('56882', '476', '1', 'Fall', 2010, 'C ');
	insert into takes values('42688', '408', '1', 'Spring', 2007, 'C ');
	insert into takes values('43616', '169', '1', 'Spring', 2007, 'B-');
	insert into takes values('25785', '612', '1', 'Fall', 2007, 'A ');
	insert into takes values('42092', '482', '1', 'Fall', 2005, 'A+');
	insert into takes values('96206', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('39901', '735', '1', 'Spring', 2003, 'C ');
	insert into takes values('51817', '400', '1', 'Spring', 2007, 'C-');
	insert into takes values('23475', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('93171', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('82591', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('3576', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('5399', '376', '1', 'Fall', 2006, 'C+');
	insert into takes values('6304', '489', '1', 'Fall', 2007, 'A ');
	insert into takes values('90779', '334', '1', 'Fall', 2009, 'A ');
	insert into takes values('10556', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('39612', '571', '1', 'Spring', 2004, 'B+');
	insert into takes values('99977', '704', '1', 'Spring', 2008, 'C-');
	insert into takes values('46066', '559', '1', 'Fall', 2002, 'A ');
	insert into takes values('72528', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('32744', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('61232', '338', '1', 'Spring', 2007, 'A-');
	insert into takes values('62754', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('57083', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('91616', '352', '1', 'Spring', 2006, 'A-');
	insert into takes values('65688', '960', '2', 'Fall', 2006, 'C-');
	insert into takes values('107', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('87246', '852', '1', 'Spring', 2008, 'A ');
	insert into takes values('74070', '258', '1', 'Fall', 2007, 'A-');
	insert into takes values('14065', '376', '1', 'Fall', 2006, 'A-');
	insert into takes values('7035', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('76953', '476', '1', 'Fall', 2010, 'B ');
	insert into takes values('2178', '571', '1', 'Spring', 2004, 'B+');
	insert into takes values('18108', '604', '1', 'Spring', 2009, 'B-');
	insert into takes values('91343', '461', '1', 'Fall', 2002, 'C+');
	insert into takes values('17424', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('72669', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('4449', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('43505', '489', '1', 'Fall', 2007, 'A-');
	insert into takes values('84704', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('43854', '893', '1', 'Fall', 2007, 'B ');
	insert into takes values('59290', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('28829', '408', '1', 'Spring', 2007, 'A+');
	insert into takes values('17944', '642', '1', 'Fall', 2004, 'B-');
	insert into takes values('63612', '581', '1', 'Spring', 2005, 'A+');
	insert into takes values('48423', '972', '1', 'Spring', 2009, 'B-');
	insert into takes values('24630', '338', '2', 'Spring', 2006, 'A-');
	insert into takes values('95175', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('67146', '105', '2', 'Fall', 2002, 'C-');
	insert into takes values('61364', '496', '1', 'Fall', 2001, 'C-');
	insert into takes values('77130', '408', '2', 'Spring', 2003, 'A ');
	insert into takes values('41894', '875', '1', 'Spring', 2005, 'C-');
	insert into takes values('84704', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('46260', '242', '1', 'Fall', 2009, 'A ');
	insert into takes values('57213', '599', '1', 'Spring', 2003, 'C+');
	insert into takes values('41299', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('71085', '461', '1', 'Fall', 2002, 'B-');
	insert into takes values('55238', '169', '2', 'Fall', 2002, 'B ');
	insert into takes values('69732', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('39520', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('41774', '105', '2', 'Fall', 2002, 'A+');
	insert into takes values('61232', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('31266', '158', '1', 'Fall', 2008, 'B+');
	insert into takes values('1533', '242', '1', 'Fall', 2009, 'A+');
	insert into takes values('4355', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('93004', '591', '1', 'Spring', 2005, 'C-');
	insert into takes values('11578', '158', '1', 'Fall', 2008, 'C-');
	insert into takes values('66259', '527', '1', 'Fall', 2004, 'C+');
	insert into takes values('79772', '612', '1', 'Fall', 2007, 'A ');
	insert into takes values('16523', '313', '1', 'Fall', 2010, 'A-');
	insert into takes values('44706', '200', '2', 'Fall', 2002, 'B-');
	insert into takes values('27950', '795', '1', 'Spring', 2004, 'C+');
	insert into takes values('96895', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('36513', '867', '1', 'Fall', 2006, 'B ');
	insert into takes values('86707', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('3487', '867', '1', 'Fall', 2006, 'B ');
	insert into takes values('61354', '735', '2', 'Spring', 2010, 'B ');
	insert into takes values('94178', '561', '1', 'Fall', 2006, 'C ');
	insert into takes values('86969', '795', '1', 'Spring', 2004, 'A-');
	insert into takes values('8807', '631', '1', 'Spring', 2007, 'A+');
	insert into takes values('47379', '461', '1', 'Fall', 2002, 'B ');
	insert into takes values('52523', '631', '1', 'Spring', 2007, 'C+');
	insert into takes values('44352', '972', '1', 'Spring', 2009, 'A-');
	insert into takes values('92417', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('25725', '258', '1', 'Fall', 2007, 'A ');
	insert into takes values('49450', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('76768', '561', '1', 'Fall', 2006, 'C+');
	insert into takes values('88358', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('45770', '747', '1', 'Spring', 2004, 'B+');
	insert into takes values('42956', '313', '1', 'Fall', 2010, 'C+');
	insert into takes values('75772', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('70098', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('51093', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('59538', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('69521', '313', '1', 'Fall', 2010, 'B ');
	insert into takes values('71628', '591', '1', 'Spring', 2005, 'C+');
	insert into takes values('67310', '192', '1', 'Fall', 2002, 'C-');
	insert into takes values('98690', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('14032', '237', '2', 'Fall', 2009, 'A ');
	insert into takes values('65208', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('32464', '270', '1', 'Spring', 2010, 'A+');
	insert into takes values('45650', '345', '1', 'Spring', 2008, 'C+');
	insert into takes values('44258', '237', '1', 'Spring', 2008, 'C-');
	insert into takes values('71630', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('13408', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('90004', '631', '1', 'Spring', 2007, 'B+');
	insert into takes values('8957', '581', '1', 'Spring', 2005, 'A+');
	insert into takes values('54153', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('70395', '974', '1', 'Fall', 2003, 'A-');
	insert into takes values('75560', '559', '1', 'Fall', 2002, 'A ');
	insert into takes values('99451', '408', '1', 'Spring', 2007, 'C ');
	insert into takes values('54672', '486', '1', 'Fall', 2009, 'B ');
	insert into takes values('83170', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('64893', '696', '1', 'Spring', 2002, 'A+');
	insert into takes values('92417', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('98563', '304', '1', 'Fall', 2009, 'C+');
	insert into takes values('94173', '748', '1', 'Fall', 2003, 'B ');
	insert into takes values('99348', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('86127', '527', '1', 'Fall', 2004, 'B-');
	insert into takes values('66212', '591', '1', 'Spring', 2005, 'B-');
	insert into takes values('23525', '169', '1', 'Spring', 2007, 'A-');
	insert into takes values('36126', '486', '1', 'Fall', 2009, 'C+');
	insert into takes values('14432', '482', '1', 'Fall', 2005, 'B-');
	insert into takes values('41938', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('36244', '461', '1', 'Fall', 2002, 'B ');
	insert into takes values('31080', '735', '1', 'Spring', 2003, 'A+');
	insert into takes values('94990', '927', '1', 'Fall', 2002, 'B-');
	insert into takes values('54728', '304', '1', 'Fall', 2009, 'B+');
	insert into takes values('22618', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('57941', '239', '1', 'Fall', 2006, 'C+');
	insert into takes values('57538', '962', '1', 'Spring', 2008, 'A ');
	insert into takes values('88085', '692', '1', 'Spring', 2010, 'C ');
	insert into takes values('95852', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('91370', '875', '1', 'Spring', 2005, 'A ');
	insert into takes values('97023', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('72669', '334', '1', 'Fall', 2009, 'B ');
	insert into takes values('96085', '527', '1', 'Fall', 2004, 'C ');
	insert into takes values('28989', '629', '1', 'Spring', 2003, 'B+');
	insert into takes values('16543', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('4860', '401', '1', 'Fall', 2003, 'C+');
	insert into takes values('74672', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('28316', '313', '1', 'Fall', 2010, 'B ');
	insert into takes values('84704', '362', '1', 'Fall', 2005, 'B ');
	insert into takes values('32217', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('86753', '962', '1', 'Spring', 2008, 'B-');
	insert into takes values('7602', '169', '1', 'Spring', 2007, 'C ');
	insert into takes values('90194', '735', '2', 'Spring', 2010, 'A+');
	insert into takes values('75173', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('78637', '867', '1', 'Fall', 2006, 'A ');
	insert into takes values('13506', '561', '1', 'Fall', 2006, 'A ');
	insert into takes values('28994', '200', '2', 'Fall', 2002, 'A+');
	insert into takes values('28352', '960', '2', 'Fall', 2006, 'C ');
	insert into takes values('37430', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('58469', '169', '2', 'Fall', 2002, 'A ');
	insert into takes values('76173', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('41973', '169', '2', 'Fall', 2002, 'A-');
	insert into takes values('99719', '468', '1', 'Fall', 2005, 'C ');
	insert into takes values('15726', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('83686', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('67660', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('63243', '362', '2', 'Fall', 2006, 'B-');
	insert into takes values('64724', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('77588', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('95027', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('29435', '663', '1', 'Spring', 2005, 'B-');
	insert into takes values('63538', '468', '2', 'Fall', 2007, 'C+');
	insert into takes values('1737', '105', '2', 'Fall', 2002, 'A-');
	insert into takes values('50583', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('17397', '338', '2', 'Spring', 2006, 'A-');
	insert into takes values('86753', '735', '2', 'Spring', 2010, 'B ');
	insert into takes values('13365', '603', '1', 'Fall', 2003, 'C-');
	insert into takes values('30845', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('78792', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('13403', '443', '2', 'Spring', 2002, 'B-');
	insert into takes values('43993', '591', '1', 'Spring', 2005, 'B ');
	insert into takes values('93171', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('55940', '571', '1', 'Spring', 2004, 'A-');
	insert into takes values('29959', '612', '1', 'Fall', 2007, 'B-');
	insert into takes values('28019', '476', '1', 'Fall', 2010, 'A+');
	insert into takes values('10736', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('17128', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('37715', '408', '2', 'Spring', 2003, 'C-');
	insert into takes values('85451', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('67310', '158', '1', 'Fall', 2008, 'B+');
	insert into takes values('47379', '959', '1', 'Fall', 2006, 'A-');
	insert into takes values('44352', '735', '2', 'Spring', 2010, 'B-');
	insert into takes values('8140', '476', '1', 'Fall', 2010, 'A ');
	insert into takes values('24201', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('95029', '642', '1', 'Fall', 2004, 'C+');
	insert into takes values('38899', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('16057', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('40937', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('17076', '400', '1', 'Spring', 2007, 'C-');
	insert into takes values('35881', '137', '1', 'Spring', 2002, 'A-');
	insert into takes values('10481', '747', '1', 'Spring', 2004, 'B+');
	insert into takes values('52656', '319', '1', 'Spring', 2003, 'B-');
	insert into takes values('75241', '408', '1', 'Spring', 2007, 'A+');
	insert into takes values('64192', '400', '1', 'Spring', 2007, 'C+');
	insert into takes values('94846', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('84410', '960', '2', 'Fall', 2006, 'B-');
	insert into takes values('10838', '631', '1', 'Spring', 2007, 'B ');
	insert into takes values('20803', '591', '1', 'Spring', 2005, 'A+');
	insert into takes values('2561', '352', '1', 'Spring', 2006, 'A-');
	insert into takes values('29849', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('73542', '561', '1', 'Fall', 2006, 'C ');
	insert into takes values('2133', '400', '1', 'Spring', 2007, 'C+');
	insert into takes values('56212', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('62373', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('27094', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('97679', '692', '1', 'Spring', 2010, 'C+');
	insert into takes values('98830', '401', '1', 'Fall', 2003, 'A ');
	insert into takes values('84792', '972', '1', 'Spring', 2009, 'B+');
	insert into takes values('1922', '169', '2', 'Fall', 2002, 'A-');
	insert into takes values('51678', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('65400', '867', '1', 'Fall', 2006, 'A-');
	insert into takes values('42625', '974', '1', 'Fall', 2003, 'A+');
	insert into takes values('16993', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('76672', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('65681', '158', '2', 'Spring', 2008, 'A ');
	insert into takes values('13365', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('27956', '692', '1', 'Spring', 2010, 'C-');
	insert into takes values('91132', '313', '1', 'Fall', 2010, 'A+');
	insert into takes values('96178', '581', '1', 'Spring', 2005, 'A-');
	insert into takes values('30161', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('84239', '345', '1', 'Spring', 2008, 'C-');
	insert into takes values('82868', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('53077', '571', '1', 'Spring', 2004, 'A-');
	insert into takes values('18809', '376', '1', 'Fall', 2006, 'C ');
	insert into takes values('49450', '169', '2', 'Fall', 2002, 'B-');
	insert into takes values('3639', '496', '1', 'Fall', 2001, 'C-');
	insert into takes values('2795', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('63560', '704', '1', 'Spring', 2008, 'C ');
	insert into takes values('21126', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('45680', '445', '1', 'Spring', 2001, 'B+');
	insert into takes values('49073', '304', '1', 'Fall', 2009, 'C+');
	insert into takes values('16453', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('33817', '867', '2', 'Fall', 2010, 'A-');
	insert into takes values('26028', '972', '1', 'Spring', 2009, 'A ');
	insert into takes values('4435', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('4004', '486', '1', 'Fall', 2009, 'A ');
	insert into takes values('22620', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('65438', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('49391', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('15070', '559', '1', 'Fall', 2002, 'A-');
	insert into takes values('11510', '443', '2', 'Spring', 2002, 'A+');
	insert into takes values('51238', '476', '1', 'Fall', 2010, 'A+');
	insert into takes values('61527', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('68554', '626', '1', 'Fall', 2006, 'C+');
	insert into takes values('53588', '959', '1', 'Fall', 2006, 'A+');
	insert into takes values('9183', '571', '1', 'Spring', 2004, 'C ');
	insert into takes values('68070', '443', '2', 'Spring', 2002, 'C-');
	insert into takes values('44258', '603', '1', 'Fall', 2003, 'B ');
	insert into takes values('97658', '694', '1', 'Fall', 2002, 'A+');
	insert into takes values('99348', '559', '1', 'Fall', 2002, 'C-');
	insert into takes values('90372', '158', '2', 'Spring', 2008, 'A-');
	insert into takes values('19536', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('99348', '421', '1', 'Fall', 2004, 'A ');
	insert into takes values('16523', '802', '1', 'Spring', 2003, 'C+');
	insert into takes values('7956', '200', '1', 'Spring', 2007, 'C ');
	insert into takes values('29239', '401', '1', 'Fall', 2003, 'B+');
	insert into takes values('40116', '366', '1', 'Fall', 2005, 'A+');
	insert into takes values('96772', '696', '1', 'Spring', 2002, 'C+');
	insert into takes values('22345', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('80651', '237', '1', 'Spring', 2008, 'B-');
	insert into takes values('92385', '443', '1', 'Spring', 2010, 'A ');
	insert into takes values('36303', '338', '2', 'Spring', 2006, 'B ');
	insert into takes values('97868', '679', '1', 'Spring', 2010, 'C-');
	insert into takes values('17076', '960', '1', 'Fall', 2009, 'A-');
	insert into takes values('10917', '696', '1', 'Spring', 2002, 'A+');
	insert into takes values('43616', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('34331', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('4449', '793', '1', 'Spring', 2002, 'B+');
	insert into takes values('827', '704', '1', 'Spring', 2008, 'A+');
	insert into takes values('96615', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('50583', '461', '1', 'Fall', 2002, 'A-');
	insert into takes values('21394', '679', '1', 'Spring', 2010, 'C-');
	insert into takes values('76768', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('7204', '696', '1', 'Spring', 2002, 'B ');
	insert into takes values('65443', '527', '1', 'Fall', 2004, 'C+');
	insert into takes values('94173', '867', '1', 'Fall', 2006, 'B+');
	insert into takes values('5399', '561', '1', 'Fall', 2006, 'A-');
	insert into takes values('95201', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('87651', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('557', '991', '1', 'Spring', 2008, 'C-');
	insert into takes values('43032', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('86127', '489', '1', 'Fall', 2007, 'B+');
	insert into takes values('26427', '545', '1', 'Fall', 2001, 'A ');
	insert into takes values('72165', '486', '1', 'Fall', 2009, 'B ');
	insert into takes values('14581', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('30164', '376', '1', 'Fall', 2006, 'B ');
	insert into takes values('34957', '313', '1', 'Fall', 2010, 'A ');
	insert into takes values('53424', '200', '1', 'Spring', 2007, 'A-');
	insert into takes values('14499', '843', '1', 'Fall', 2010, 'B-');
	insert into takes values('41894', '852', '1', 'Spring', 2008, 'A-');
	insert into takes values('86969', '345', '1', 'Spring', 2008, 'B ');
	insert into takes values('46436', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('17057', '852', '1', 'Spring', 2008, 'C+');
	insert into takes values('38676', '421', '1', 'Fall', 2004, 'B-');
	insert into takes values('82591', '408', '1', 'Spring', 2007, 'B ');
	insert into takes values('931', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('58594', '169', '2', 'Fall', 2002, 'B+');
	insert into takes values('10727', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('41299', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('9460', '760', '1', 'Spring', 2004, 'B+');
	insert into takes values('13826', '843', '1', 'Fall', 2010, 'A+');
	insert into takes values('66763', '626', '1', 'Fall', 2006, 'B-');
	insert into takes values('14829', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('79487', '486', '1', 'Fall', 2009, 'B ');
	insert into takes values('50537', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('26102', '468', '2', 'Fall', 2007, 'C-');
	insert into takes values('30222', '242', '1', 'Fall', 2009, 'A-');
	insert into takes values('30858', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('46928', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('45002', '401', '1', 'Fall', 2003, 'C-');
	insert into takes values('32056', '338', '1', 'Spring', 2007, 'A ');
	insert into takes values('73542', '702', '1', 'Spring', 2001, 'A-');
	insert into takes values('94766', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('59530', '443', '1', 'Spring', 2010, 'C+');
	insert into takes values('76759', '791', '1', 'Spring', 2006, 'C+');
	insert into takes values('16969', '105', '2', 'Fall', 2002, 'B-');
	insert into takes values('32385', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('63538', '105', '1', 'Fall', 2009, 'B ');
	insert into takes values('57511', '735', '1', 'Spring', 2003, 'B-');
	insert into takes values('5843', '960', '1', 'Fall', 2009, 'A-');
	insert into takes values('8957', '864', '1', 'Spring', 2006, 'C+');
	insert into takes values('16593', '545', '1', 'Fall', 2001, 'C ');
	insert into takes values('72768', '747', '1', 'Spring', 2004, 'B-');
	insert into takes values('4248', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('41988', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('77000', '237', '1', 'Spring', 2008, 'A-');
	insert into takes values('88287', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('22170', '629', '1', 'Spring', 2003, 'B+');
	insert into takes values('90448', '169', '1', 'Spring', 2007, 'B-');
	insert into takes values('8986', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('65443', '158', '2', 'Spring', 2008, 'B-');
	insert into takes values('37101', '319', '1', 'Spring', 2003, 'B ');
	insert into takes values('52371', '426', '1', 'Spring', 2006, 'C ');
	insert into takes values('57156', '408', '1', 'Spring', 2007, 'A ');
	insert into takes values('23392', '561', '1', 'Fall', 2006, 'C+');
	insert into takes values('15249', '338', '1', 'Spring', 2007, 'B-');
	insert into takes values('40937', '545', '1', 'Fall', 2001, 'A ');
	insert into takes values('71630', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('78787', '735', '2', 'Spring', 2010, 'A+');
	insert into takes values('69471', '808', '1', 'Fall', 2003, 'B-');
	insert into takes values('47627', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('74840', '696', '1', 'Spring', 2002, 'C-');
	insert into takes values('93039', '561', '1', 'Fall', 2006, 'A ');
	insert into takes values('96741', '791', '1', 'Spring', 2006, 'C-');
	insert into takes values('31337', '960', '1', 'Fall', 2009, 'C-');
	insert into takes values('17057', '591', '1', 'Spring', 2005, 'A-');
	insert into takes values('18499', '631', '1', 'Spring', 2007, 'B+');
	insert into takes values('92776', '612', '1', 'Fall', 2007, 'C ');
	insert into takes values('76895', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('70452', '401', '1', 'Fall', 2003, 'A ');
	insert into takes values('82970', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('61444', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('72669', '319', '1', 'Spring', 2003, 'C-');
	insert into takes values('62429', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('31516', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('86707', '760', '1', 'Spring', 2004, 'A ');
	insert into takes values('11578', '319', '1', 'Spring', 2003, 'B ');
	insert into takes values('75299', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('94814', '239', '1', 'Fall', 2006, 'C-');
	insert into takes values('1285', '626', '1', 'Fall', 2006, 'C ');
	insert into takes values('47627', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('35523', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('58935', '802', '1', 'Spring', 2003, 'C+');
	insert into takes values('89132', '561', '1', 'Fall', 2006, 'C-');
	insert into takes values('70522', '927', '1', 'Fall', 2002, 'B-');
	insert into takes values('37946', '338', '1', 'Spring', 2007, 'C+');
	insert into takes values('67655', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('58919', '237', '1', 'Spring', 2008, 'C+');
	insert into takes values('53451', '599', '1', 'Spring', 2003, 'C ');
	insert into takes values('88884', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('34404', '612', '1', 'Fall', 2007, 'B-');
	insert into takes values('63860', '443', '2', 'Spring', 2002, 'B-');
	insert into takes values('50966', '760', '1', 'Spring', 2004, 'C+');
	insert into takes values('44258', '927', '1', 'Fall', 2002, 'A ');
	insert into takes values('19766', '559', '1', 'Fall', 2002, 'A ');
	insert into takes values('69960', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('59172', '959', '1', 'Fall', 2006, 'C+');
	insert into takes values('43854', '415', '1', 'Fall', 2010, 'A-');
	insert into takes values('64013', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('66054', '400', '1', 'Spring', 2007, 'B ');
	insert into takes values('92965', '338', '2', 'Spring', 2006, 'A+');
	insert into takes values('30397', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('37103', '242', '1', 'Fall', 2009, 'C-');
	insert into takes values('40371', '334', '1', 'Fall', 2009, 'A-');
	insert into takes values('96067', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('9514', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('97629', '362', '3', 'Spring', 2008, 'C-');
	insert into takes values('91992', '334', '1', 'Fall', 2009, 'A-');
	insert into takes values('37869', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('90004', '376', '1', 'Fall', 2006, 'B ');
	insert into takes values('39978', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('5144', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('11377', '545', '1', 'Fall', 2001, 'B ');
	insert into takes values('15613', '468', '1', 'Fall', 2005, 'A-');
	insert into takes values('8252', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('84808', '642', '1', 'Fall', 2004, 'A+');
	insert into takes values('33882', '843', '1', 'Fall', 2010, 'A ');
	insert into takes values('91197', '349', '1', 'Spring', 2008, 'B+');
	insert into takes values('15698', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('78782', '362', '1', 'Fall', 2005, 'C+');
	insert into takes values('18234', '527', '1', 'Fall', 2004, 'A-');
	insert into takes values('86651', '169', '1', 'Spring', 2007, 'B-');
	insert into takes values('44703', '345', '1', 'Spring', 2008, 'C-');
	insert into takes values('4004', '960', '1', 'Fall', 2009, 'B+');
	insert into takes values('38013', '793', '1', 'Spring', 2002, 'B ');
	insert into takes values('60249', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('42565', '571', '1', 'Spring', 2004, 'C-');
	insert into takes values('98726', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('37449', '747', '1', 'Spring', 2004, 'B-');
	insert into takes values('75273', '270', '1', 'Spring', 2010, 'B-');
	insert into takes values('50013', '169', '2', 'Fall', 2002, 'A-');
	insert into takes values('17676', '457', '1', 'Spring', 2001, 'C-');
	insert into takes values('74509', '461', '1', 'Fall', 2002, 'B-');
	insert into takes values('7287', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('86641', '421', '1', 'Fall', 2004, 'B+');
	insert into takes values('65438', '457', '1', 'Spring', 2001, 'B ');
	insert into takes values('29091', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('41988', '793', '1', 'Spring', 2002, 'B+');
	insert into takes values('48901', '468', '1', 'Fall', 2005, 'A+');
	insert into takes values('55238', '408', '1', 'Spring', 2007, 'A+');
	insert into takes values('51203', '735', '2', 'Spring', 2010, 'A-');
	insert into takes values('56003', '137', '1', 'Spring', 2002, 'A ');
	insert into takes values('27952', '443', '1', 'Spring', 2010, 'A-');
	insert into takes values('50598', '581', '1', 'Spring', 2005, 'A-');
	insert into takes values('90381', '893', '1', 'Fall', 2007, 'B+');
	insert into takes values('73602', '974', '1', 'Fall', 2003, 'A+');
	insert into takes values('11453', '591', '1', 'Spring', 2005, 'B ');
	insert into takes values('15980', '319', '1', 'Spring', 2003, 'C-');
	insert into takes values('847', '158', '1', 'Fall', 2008, 'B-');
	insert into takes values('18583', '366', '1', 'Fall', 2005, 'A+');
	insert into takes values('78469', '612', '1', 'Fall', 2007, 'B ');
	insert into takes values('69122', '852', '1', 'Spring', 2008, 'B ');
	insert into takes values('49244', '200', '2', 'Fall', 2002, 'B-');
	insert into takes values('16297', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('59530', '843', '1', 'Fall', 2010, 'C-');
	insert into takes values('96206', '791', '1', 'Spring', 2006, 'A-');
	insert into takes values('69471', '760', '1', 'Spring', 2004, 'B+');
	insert into takes values('71944', '408', '2', 'Spring', 2003, 'B-');
	insert into takes values('14214', '408', '2', 'Spring', 2003, 'B ');
	insert into takes values('80912', '702', '1', 'Spring', 2001, 'C-');
	insert into takes values('30896', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('86707', '545', '1', 'Fall', 2001, 'A ');
	insert into takes values('6367', '468', '2', 'Fall', 2007, 'C+');
	insert into takes values('24197', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('65400', '852', '1', 'Spring', 2008, 'B+');
	insert into takes values('41299', '200', '1', 'Spring', 2007, 'A+');
	insert into takes values('58935', '949', '1', 'Fall', 2007, 'B ');
	insert into takes values('8517', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('9953', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('45200', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('46451', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('58307', '415', '1', 'Fall', 2010, 'B-');
	insert into takes values('26080', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('1812', '962', '1', 'Spring', 2008, 'C-');
	insert into takes values('30017', '760', '1', 'Spring', 2004, 'C ');
	insert into takes values('38336', '991', '1', 'Spring', 2008, 'B-');
	insert into takes values('18821', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('61127', '852', '1', 'Spring', 2008, 'C-');
	insert into takes values('68263', '545', '1', 'Fall', 2001, 'A+');
	insert into takes values('40738', '960', '1', 'Fall', 2009, 'A+');
	insert into takes values('13921', '927', '1', 'Fall', 2002, 'A-');
	insert into takes values('32245', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('67514', '169', '1', 'Spring', 2007, 'B-');
	insert into takes values('46769', '694', '1', 'Fall', 2002, 'C+');
	insert into takes values('43854', '338', '2', 'Spring', 2006, 'B ');
	insert into takes values('41091', '158', '1', 'Fall', 2008, 'B+');
	insert into takes values('10527', '864', '1', 'Spring', 2006, 'B+');
	insert into takes values('90448', '274', '1', 'Fall', 2002, 'A+');
	insert into takes values('5243', '663', '1', 'Spring', 2005, 'C-');
	insert into takes values('22467', '445', '1', 'Spring', 2001, 'B-');
	insert into takes values('41818', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('49503', '702', '1', 'Spring', 2001, 'B ');
	insert into takes values('63289', '631', '1', 'Spring', 2007, 'C-');
	insert into takes values('65205', '400', '1', 'Spring', 2007, 'C ');
	insert into takes values('96052', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('18709', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('13757', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('74460', '545', '1', 'Fall', 2001, 'A-');
	insert into takes values('64724', '852', '1', 'Spring', 2008, 'B ');
	insert into takes values('12711', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('32954', '313', '1', 'Fall', 2010, 'C-');
	insert into takes values('77664', '421', '1', 'Fall', 2004, 'B-');
	insert into takes values('91992', '972', '1', 'Spring', 2009, 'C-');
	insert into takes values('1080', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('93039', '735', '1', 'Spring', 2003, 'B-');
	insert into takes values('46451', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('45200', '489', '1', 'Fall', 2007, 'C ');
	insert into takes values('52876', '443', '2', 'Spring', 2002, 'C ');
	insert into takes values('95260', '200', '2', 'Fall', 2002, 'A ');
	insert into takes values('12971', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('96052', '304', '1', 'Fall', 2009, 'B ');
	insert into takes values('73492', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('30124', '158', '1', 'Fall', 2008, 'A-');
	insert into takes values('48009', '362', '3', 'Spring', 2008, 'A+');
	insert into takes values('63288', '304', '1', 'Fall', 2009, 'A ');
	insert into takes values('52494', '545', '1', 'Fall', 2001, 'A ');
	insert into takes values('18821', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('19862', '875', '1', 'Spring', 2005, 'B-');
	insert into takes values('26147', '421', '1', 'Fall', 2004, 'C+');
	insert into takes values('81884', '468', '1', 'Fall', 2005, 'B-');
	insert into takes values('75791', '949', '1', 'Fall', 2007, 'C+');
	insert into takes values('72741', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('57107', '663', '1', 'Spring', 2005, 'A-');
	insert into takes values('74796', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('28133', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('5703', '545', '1', 'Fall', 2001, 'A+');
	insert into takes values('8517', '875', '1', 'Spring', 2005, 'C ');
	insert into takes values('67793', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('29192', '158', '2', 'Spring', 2008, 'C ');
	insert into takes values('50598', '258', '1', 'Fall', 2007, 'A ');
	insert into takes values('24746', '237', '2', 'Fall', 2009, 'C ');
	insert into takes values('70359', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('89571', '795', '1', 'Spring', 2004, 'A-');
	insert into takes values('63502', '313', '1', 'Fall', 2010, 'B ');
	insert into takes values('53799', '304', '1', 'Fall', 2009, 'C-');
	insert into takes values('64820', '105', '2', 'Fall', 2002, 'C-');
	insert into takes values('55698', '960', '2', 'Fall', 2006, 'C ');
	insert into takes values('39204', '581', '1', 'Spring', 2005, 'A+');
	insert into takes values('38121', '362', '3', 'Spring', 2008, 'A+');
	insert into takes values('4860', '843', '1', 'Fall', 2010, 'A+');
	insert into takes values('12971', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('64192', '158', '1', 'Fall', 2008, 'A+');
	insert into takes values('50658', '352', '1', 'Spring', 2006, 'B+');
	insert into takes values('842', '696', '1', 'Spring', 2002, 'B+');
	insert into takes values('59538', '482', '1', 'Fall', 2005, 'A-');
	insert into takes values('71543', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('53699', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('87193', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('54296', '237', '2', 'Fall', 2009, 'C-');
	insert into takes values('58170', '867', '1', 'Fall', 2006, 'C+');
	insert into takes values('77148', '400', '1', 'Spring', 2007, 'C ');
	insert into takes values('72006', '158', '2', 'Spring', 2008, 'C+');
	insert into takes values('68330', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('47487', '559', '1', 'Fall', 2002, 'C-');
	insert into takes values('9605', '461', '1', 'Fall', 2002, 'B-');
	insert into takes values('42096', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('63489', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('89734', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('80912', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('20489', '352', '1', 'Spring', 2006, 'B+');
	insert into takes values('79772', '415', '1', 'Fall', 2010, 'C-');
	insert into takes values('23992', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('94173', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('99289', '604', '1', 'Spring', 2009, 'B ');
	insert into takes values('66969', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('74163', '304', '1', 'Fall', 2009, 'B ');
	insert into takes values('1018', '401', '1', 'Fall', 2003, 'C ');
	insert into takes values('60040', '105', '2', 'Fall', 2002, 'A ');
	insert into takes values('73602', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('26102', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('86753', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('25780', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('17207', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('58889', '694', '1', 'Fall', 2002, 'A+');
	insert into takes values('88140', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('11510', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('52669', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('27662', '443', '1', 'Spring', 2010, 'B+');
	insert into takes values('30222', '867', '1', 'Fall', 2006, 'A+');
	insert into takes values('97400', '270', '1', 'Spring', 2010, 'C ');
	insert into takes values('96772', '401', '1', 'Fall', 2003, 'A-');
	insert into takes values('53496', '760', '1', 'Spring', 2004, 'B ');
	insert into takes values('87831', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('98726', '959', '1', 'Fall', 2006, 'C+');
	insert into takes values('52371', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('95320', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('33460', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('72741', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('19824', '867', '2', 'Fall', 2010, 'A-');
	insert into takes values('40189', '991', '1', 'Spring', 2008, 'B ');
	insert into takes values('29849', '704', '1', 'Spring', 2008, 'B ');
	insert into takes values('41894', '468', '2', 'Fall', 2007, 'A-');
	insert into takes values('41938', '362', '2', 'Fall', 2006, 'C-');
	insert into takes values('15086', '443', '2', 'Spring', 2002, 'C-');
	insert into takes values('17600', '735', '2', 'Spring', 2010, 'A ');
	insert into takes values('390', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('76270', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('43130', '561', '1', 'Fall', 2006, 'C+');
	insert into takes values('4355', '237', '1', 'Spring', 2008, 'A+');
	insert into takes values('83728', '843', '1', 'Fall', 2010, 'C-');
	insert into takes values('21100', '345', '1', 'Spring', 2008, 'C+');
	insert into takes values('52371', '486', '1', 'Fall', 2009, 'B ');
	insert into takes values('83204', '599', '1', 'Spring', 2003, 'C ');
	insert into takes values('50013', '599', '1', 'Spring', 2003, 'B-');
	insert into takes values('5381', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('8860', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('42019', '401', '1', 'Fall', 2003, 'B+');
	insert into takes values('77130', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('37430', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('72501', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('11202', '457', '1', 'Spring', 2001, 'A+');
	insert into takes values('44998', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('64222', '692', '1', 'Spring', 2010, 'B-');
	insert into takes values('63502', '400', '2', 'Fall', 2003, 'A ');
	insert into takes values('11510', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('5824', '461', '1', 'Fall', 2002, 'B ');
	insert into takes values('31364', '443', '1', 'Spring', 2010, 'B-');
	insert into takes values('88553', '692', '1', 'Spring', 2010, 'C ');
	insert into takes values('52669', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('46655', '461', '1', 'Fall', 2002, 'B-');
	insert into takes values('25068', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('15030', '489', '1', 'Fall', 2007, 'B ');
	insert into takes values('75878', '972', '1', 'Spring', 2009, 'C ');
	insert into takes values('1826', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('5703', '158', '1', 'Fall', 2008, 'B+');
	insert into takes values('53588', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('993', '927', '1', 'Fall', 2002, 'B-');
	insert into takes values('80113', '867', '1', 'Fall', 2006, 'B+');
	insert into takes values('29462', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('11057', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('92417', '408', '1', 'Spring', 2007, 'A ');
	insert into takes values('888', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('11057', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('37759', '603', '1', 'Fall', 2003, 'B-');
	insert into takes values('35138', '496', '1', 'Fall', 2001, 'B-');
	insert into takes values('49339', '867', '2', 'Fall', 2010, 'C-');
	insert into takes values('26802', '158', '2', 'Spring', 2008, 'C-');
	insert into takes values('11510', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('70021', '349', '1', 'Spring', 2008, 'A ');
	insert into takes values('38712', '169', '2', 'Fall', 2002, 'A ');
	insert into takes values('56882', '867', '2', 'Fall', 2010, 'A-');
	insert into takes values('10693', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('73165', '545', '1', 'Fall', 2001, 'B ');
	insert into takes values('8426', '443', '2', 'Spring', 2002, 'B ');
	insert into takes values('92274', '960', '1', 'Fall', 2009, 'B-');
	insert into takes values('56058', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('87439', '457', '1', 'Spring', 2001, 'B+');
	insert into takes values('1727', '158', '1', 'Fall', 2008, 'B+');
	insert into takes values('21225', '158', '2', 'Spring', 2008, 'B-');
	insert into takes values('1232', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('59538', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('42565', '527', '1', 'Fall', 2004, 'B-');
	insert into takes values('76895', '696', '1', 'Spring', 2002, 'C ');
	insert into takes values('1827', '626', '1', 'Fall', 2006, 'B-');
	insert into takes values('53469', '571', '1', 'Spring', 2004, 'B+');
	insert into takes values('65241', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('99226', '400', '1', 'Spring', 2007, 'A-');
	insert into takes values('65205', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('50467', '692', '1', 'Spring', 2010, 'C ');
	insert into takes values('25552', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('90082', '545', '1', 'Fall', 2001, 'C ');
	insert into takes values('76224', '496', '1', 'Fall', 2001, 'C ');
	insert into takes values('67021', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('80990', '561', '1', 'Fall', 2006, 'B+');
	insert into takes values('16057', '793', '1', 'Spring', 2002, 'C ');
	insert into takes values('49280', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('76953', '401', '1', 'Fall', 2003, 'C+');
	insert into takes values('68999', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('51868', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('60040', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('72177', '793', '1', 'Spring', 2002, 'A+');
	insert into takes values('31476', '408', '1', 'Spring', 2007, 'C ');
	insert into takes values('31080', '696', '1', 'Spring', 2002, 'A ');
	insert into takes values('48850', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('64934', '591', '1', 'Spring', 2005, 'C+');
	insert into takes values('63289', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('76743', '603', '1', 'Fall', 2003, 'A ');
	insert into takes values('31761', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('42096', '735', '1', 'Spring', 2003, 'C-');
	insert into takes values('95260', '959', '1', 'Fall', 2006, 'C+');
	insert into takes values('44816', '200', '1', 'Spring', 2007, 'A-');
	insert into takes values('43658', '362', '2', 'Fall', 2006, 'A ');
	insert into takes values('55000', '366', '1', 'Fall', 2005, 'A+');
	insert into takes values('56143', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('67793', '349', '1', 'Spring', 2008, 'C-');
	insert into takes values('74530', '239', '1', 'Fall', 2006, 'B ');
	insert into takes values('7149', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('61364', '893', '1', 'Fall', 2007, 'C ');
	insert into takes values('61444', '626', '1', 'Fall', 2006, 'C ');
	insert into takes values('40059', '242', '1', 'Fall', 2009, 'B+');
	insert into takes values('14432', '426', '1', 'Spring', 2006, 'B ');
	insert into takes values('3576', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('6287', '362', '2', 'Fall', 2006, 'A-');
	insert into takes values('98140', '960', '1', 'Fall', 2009, 'C-');
	insert into takes values('9993', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('62636', '679', '1', 'Spring', 2010, 'B-');
	insert into takes values('99764', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('41299', '493', '1', 'Spring', 2010, 'A ');
	insert into takes values('48640', '445', '1', 'Spring', 2001, 'C+');
	insert into takes values('81028', '493', '1', 'Spring', 2010, 'C ');
	insert into takes values('645', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('25528', '527', '1', 'Fall', 2004, 'C ');
	insert into takes values('99399', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('54605', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('3143', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('70235', '445', '1', 'Spring', 2001, 'C ');
	insert into takes values('22268', '793', '1', 'Spring', 2002, 'B+');
	insert into takes values('69285', '960', '1', 'Fall', 2009, 'A+');
	insert into takes values('81245', '313', '1', 'Fall', 2010, 'B-');
	insert into takes values('36102', '443', '1', 'Spring', 2010, 'A+');
	insert into takes values('69747', '486', '1', 'Fall', 2009, 'B ');
	insert into takes values('51955', '239', '1', 'Fall', 2006, 'B ');
	insert into takes values('16907', '972', '1', 'Spring', 2009, 'B+');
	insert into takes values('79763', '400', '1', 'Spring', 2007, 'C ');
	insert into takes values('80698', '169', '1', 'Spring', 2007, 'B-');
	insert into takes values('50873', '760', '1', 'Spring', 2004, 'B-');
	insert into takes values('4173', '239', '1', 'Fall', 2006, 'C-');
	insert into takes values('44836', '400', '1', 'Spring', 2007, 'B+');
	insert into takes values('28252', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('71085', '679', '1', 'Spring', 2010, 'B ');
	insert into takes values('15086', '239', '1', 'Fall', 2006, 'B ');
	insert into takes values('42960', '561', '1', 'Fall', 2006, 'B-');
	insert into takes values('34788', '237', '1', 'Spring', 2008, 'C-');
	insert into takes values('61332', '893', '1', 'Fall', 2007, 'C ');
	insert into takes values('96324', '137', '1', 'Spring', 2002, 'B+');
	insert into takes values('45720', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('27662', '735', '1', 'Spring', 2003, 'A ');
	insert into takes values('50365', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('97355', '599', '1', 'Spring', 2003, 'B ');
	insert into takes values('29920', '443', '1', 'Spring', 2010, 'B ');
	insert into takes values('66813', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('72528', '631', '1', 'Spring', 2007, 'A+');
	insert into takes values('90181', '679', '1', 'Spring', 2010, 'B-');
	insert into takes values('66054', '169', '2', 'Fall', 2002, 'B+');
	insert into takes values('29920', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('75252', '927', '1', 'Fall', 2002, 'C ');
	insert into takes values('86641', '663', '1', 'Spring', 2005, 'C ');
	insert into takes values('30188', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('99647', '400', '2', 'Fall', 2003, 'A ');
	insert into takes values('54605', '599', '1', 'Spring', 2003, 'C ');
	insert into takes values('34055', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('29140', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('2423', '991', '1', 'Spring', 2008, 'B-');
	insert into takes values('26802', '362', '3', 'Spring', 2008, 'B ');
	insert into takes values('65443', '561', '1', 'Fall', 2006, 'A-');
	insert into takes values('60267', '603', '1', 'Fall', 2003, 'A+');
	insert into takes values('86327', '443', '1', 'Spring', 2010, 'C+');
	insert into takes values('91978', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('82687', '158', '1', 'Fall', 2008, 'B-');
	insert into takes values('73807', '258', '1', 'Fall', 2007, 'A+');
	insert into takes values('56003', '591', '1', 'Spring', 2005, 'A+');
	insert into takes values('79697', '304', '1', 'Fall', 2009, 'B ');
	insert into takes values('32886', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('47670', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('52523', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('62549', '408', '2', 'Spring', 2003, 'A+');
	insert into takes values('65190', '304', '1', 'Fall', 2009, 'B ');
	insert into takes values('56078', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('54153', '791', '1', 'Spring', 2006, 'A-');
	insert into takes values('14563', '581', '1', 'Spring', 2005, 'C+');
	insert into takes values('94257', '679', '1', 'Spring', 2010, 'C+');
	insert into takes values('42560', '748', '1', 'Fall', 2003, 'C-');
	insert into takes values('76953', '631', '1', 'Spring', 2007, 'C-');
	insert into takes values('70362', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('86001', '875', '1', 'Spring', 2005, 'C ');
	insert into takes values('36052', '457', '1', 'Spring', 2001, 'C-');
	insert into takes values('85849', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('53803', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('71287', '972', '1', 'Spring', 2009, 'A+');
	insert into takes values('69225', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('85746', '445', '1', 'Spring', 2001, 'C+');
	insert into takes values('67310', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('72177', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('2419', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('48589', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('24784', '304', '1', 'Fall', 2009, 'A+');
	insert into takes values('14554', '237', '2', 'Fall', 2009, 'B+');
	insert into takes values('96117', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('31080', '482', '1', 'Fall', 2005, 'A ');
	insert into takes values('73394', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('95260', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('40682', '591', '1', 'Spring', 2005, 'B ');
	insert into takes values('14639', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('32385', '376', '1', 'Fall', 2006, 'C+');
	insert into takes values('6304', '867', '1', 'Fall', 2006, 'A ');
	insert into takes values('43032', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('85910', '692', '1', 'Spring', 2010, 'A-');
	insert into takes values('336', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('73411', '408', '1', 'Spring', 2007, 'C+');
	insert into takes values('35293', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('93986', '748', '1', 'Fall', 2003, 'B-');
	insert into takes values('15883', '864', '1', 'Spring', 2006, 'A+');
	insert into takes values('58889', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('88302', '400', '1', 'Spring', 2007, 'A ');
	insert into takes values('47630', '692', '1', 'Spring', 2010, 'C-');
	insert into takes values('46451', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('67024', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('41406', '237', '1', 'Spring', 2008, 'A+');
	insert into takes values('67024', '274', '1', 'Fall', 2002, 'B-');
	insert into takes values('59908', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('17996', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('24002', '200', '1', 'Spring', 2007, 'A-');
	insert into takes values('64067', '482', '1', 'Fall', 2005, 'C ');
	insert into takes values('70021', '702', '1', 'Spring', 2001, 'C ');
	insert into takes values('17676', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('8347', '696', '1', 'Spring', 2002, 'A ');
	insert into takes values('65753', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('18941', '642', '1', 'Fall', 2004, 'B-');
	insert into takes values('48469', '376', '1', 'Fall', 2006, 'A-');
	insert into takes values('56849', '960', '1', 'Fall', 2009, 'B-');
	insert into takes values('5925', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('63039', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('70099', '808', '1', 'Fall', 2003, 'A+');
	insert into takes values('78911', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('3739', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('99611', '270', '1', 'Spring', 2010, 'C-');
	insert into takes values('83511', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('51723', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('81207', '482', '1', 'Fall', 2005, 'A ');
	insert into takes values('10917', '237', '1', 'Spring', 2008, 'B ');
	insert into takes values('46066', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('11152', '893', '1', 'Fall', 2007, 'B-');
	insert into takes values('76224', '319', '1', 'Spring', 2003, 'B ');
	insert into takes values('39046', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('64140', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('36494', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('16347', '200', '1', 'Spring', 2007, 'A ');
	insert into takes values('95099', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('8517', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('1884', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('92703', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('35', '760', '1', 'Spring', 2004, 'A ');
	insert into takes values('95201', '959', '1', 'Fall', 2006, 'A-');
	insert into takes values('56089', '105', '1', 'Fall', 2009, 'B+');
	insert into takes values('61081', '581', '1', 'Spring', 2005, 'A-');
	insert into takes values('71387', '679', '1', 'Spring', 2010, 'C-');
	insert into takes values('3335', '169', '1', 'Spring', 2007, 'B-');
	insert into takes values('14563', '408', '2', 'Spring', 2003, 'B ');
	insert into takes values('16631', '105', '2', 'Fall', 2002, 'B-');
	insert into takes values('78756', '692', '1', 'Spring', 2010, 'B-');
	insert into takes values('37809', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('92849', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('65987', '270', '1', 'Spring', 2010, 'A+');
	insert into takes values('35905', '482', '1', 'Fall', 2005, 'A ');
	insert into takes values('66356', '679', '1', 'Spring', 2010, 'A+');
	insert into takes values('97065', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('95260', '457', '1', 'Spring', 2001, 'C+');
	insert into takes values('14639', '415', '1', 'Fall', 2010, 'B-');
	insert into takes values('88793', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('21008', '960', '2', 'Fall', 2006, 'B+');
	insert into takes values('85211', '426', '1', 'Spring', 2006, 'B ');
	insert into takes values('46260', '352', '1', 'Spring', 2006, 'C ');
	insert into takes values('36019', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('5144', '559', '1', 'Fall', 2002, 'C-');
	insert into takes values('75772', '702', '1', 'Spring', 2001, 'A-');
	insert into takes values('55170', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('88045', '169', '2', 'Fall', 2002, 'B ');
	insert into takes values('22467', '696', '1', 'Spring', 2002, 'A-');
	insert into takes values('13511', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('888', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('36657', '704', '1', 'Spring', 2008, 'B ');
	insert into takes values('88577', '362', '2', 'Fall', 2006, 'A-');
	insert into takes values('4645', '893', '1', 'Fall', 2007, 'B+');
	insert into takes values('19861', '559', '1', 'Fall', 2002, 'C-');
	insert into takes values('53490', '200', '2', 'Fall', 2002, 'B+');
	insert into takes values('52656', '408', '2', 'Spring', 2003, 'B-');
	insert into takes values('65753', '694', '1', 'Fall', 2002, 'A+');
	insert into takes values('88417', '338', '1', 'Spring', 2007, 'B-');
	insert into takes values('24932', '476', '1', 'Fall', 2010, 'C ');
	insert into takes values('15249', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('34331', '105', '2', 'Fall', 2002, 'B-');
	insert into takes values('23392', '366', '1', 'Fall', 2005, 'A ');
	insert into takes values('78922', '696', '1', 'Spring', 2002, 'A+');
	insert into takes values('20099', '747', '1', 'Spring', 2004, 'B-');
	insert into takes values('37350', '704', '1', 'Spring', 2008, 'C ');
	insert into takes values('51538', '200', '2', 'Fall', 2002, 'A+');
	insert into takes values('30124', '105', '2', 'Fall', 2002, 'B-');
	insert into takes values('75878', '443', '1', 'Spring', 2010, 'C ');
	insert into takes values('27919', '319', '1', 'Spring', 2003, 'C-');
	insert into takes values('36926', '400', '2', 'Fall', 2003, 'C-');
	insert into takes values('35357', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('23934', '400', '1', 'Spring', 2007, 'C+');
	insert into takes values('85234', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('28361', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('75241', '461', '1', 'Fall', 2002, 'A-');
	insert into takes values('13290', '802', '1', 'Spring', 2003, 'C-');
	insert into takes values('43211', '443', '1', 'Spring', 2010, 'C+');
	insert into takes values('31101', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('43348', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('13408', '735', '1', 'Spring', 2003, 'B-');
	insert into takes values('74796', '629', '1', 'Spring', 2003, 'A ');
	insert into takes values('96203', '105', '1', 'Fall', 2009, 'C-');
	insert into takes values('2139', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('68453', '974', '1', 'Fall', 2003, 'C ');
	insert into takes values('9514', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('56276', '169', '1', 'Spring', 2007, 'B ');
	insert into takes values('14094', '200', '1', 'Spring', 2007, 'A+');
	insert into takes values('48247', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('56143', '408', '2', 'Spring', 2003, 'B-');
	insert into takes values('10838', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('75938', '642', '1', 'Fall', 2004, 'A+');
	insert into takes values('75510', '972', '1', 'Spring', 2009, 'B-');
	insert into takes values('33338', '334', '1', 'Fall', 2009, 'C-');
	insert into takes values('15883', '270', '1', 'Spring', 2010, 'B-');
	insert into takes values('73186', '852', '1', 'Spring', 2008, 'A ');
	insert into takes values('73213', '735', '1', 'Spring', 2003, 'A+');
	insert into takes values('33401', '493', '1', 'Spring', 2010, 'C-');
	insert into takes values('10527', '972', '1', 'Spring', 2009, 'B+');
	insert into takes values('22620', '991', '1', 'Spring', 2008, 'C-');
	insert into takes values('15083', '304', '1', 'Fall', 2009, 'A+');
	insert into takes values('44206', '200', '1', 'Spring', 2007, 'A+');
	insert into takes values('78911', '239', '1', 'Fall', 2006, 'B ');
	insert into takes values('57985', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('70099', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('18583', '949', '1', 'Fall', 2007, 'C ');
	insert into takes values('95046', '415', '1', 'Fall', 2010, 'A-');
	insert into takes values('60224', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('29435', '791', '1', 'Spring', 2006, 'B+');
	insert into takes values('69285', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('36513', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('82974', '735', '2', 'Spring', 2010, 'A-');
	insert into takes values('16543', '334', '1', 'Fall', 2009, 'B-');
	insert into takes values('37101', '852', '1', 'Spring', 2008, 'B-');
	insert into takes values('14874', '694', '1', 'Fall', 2002, 'C ');
	insert into takes values('94815', '591', '1', 'Spring', 2005, 'A ');
	insert into takes values('67793', '735', '1', 'Spring', 2003, 'C+');
	insert into takes values('33546', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('42019', '200', '2', 'Fall', 2002, 'A+');
	insert into takes values('90181', '345', '1', 'Spring', 2008, 'A-');
	insert into takes values('50331', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('91091', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('63289', '376', '1', 'Fall', 2006, 'C ');
	insert into takes values('62520', '105', '1', 'Fall', 2009, 'A+');
	insert into takes values('85754', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('12563', '545', '1', 'Fall', 2001, 'A-');
	insert into takes values('61354', '960', '1', 'Fall', 2009, 'B-');
	insert into takes values('86404', '376', '1', 'Fall', 2006, 'C ');
	insert into takes values('14182', '694', '1', 'Fall', 2002, 'A+');
	insert into takes values('81789', '599', '1', 'Spring', 2003, 'B-');
	insert into takes values('35357', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('40457', '237', '2', 'Fall', 2009, 'C ');
	insert into takes values('37818', '852', '1', 'Spring', 2008, 'B ');
	insert into takes values('72622', '974', '1', 'Fall', 2003, 'B-');
	insert into takes values('38696', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('10917', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('22258', '401', '1', 'Fall', 2003, 'A+');
	insert into takes values('36657', '376', '1', 'Fall', 2006, 'A ');
	insert into takes values('72177', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('11194', '345', '1', 'Spring', 2008, 'A-');
	insert into takes values('95850', '237', '1', 'Spring', 2008, 'B+');
	insert into takes values('39978', '702', '1', 'Spring', 2001, 'C-');
	insert into takes values('792', '457', '1', 'Spring', 2001, 'B-');
	insert into takes values('75040', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('31035', '270', '1', 'Spring', 2010, 'A-');
	insert into takes values('62636', '137', '1', 'Spring', 2002, 'A-');
	insert into takes values('15070', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('40558', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('65676', '603', '1', 'Fall', 2003, 'A ');
	insert into takes values('85308', '808', '1', 'Fall', 2003, 'A+');
	insert into takes values('95175', '400', '1', 'Spring', 2007, 'C+');
	insert into takes values('6287', '192', '1', 'Fall', 2002, 'C-');
	insert into takes values('63243', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('91091', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('39927', '493', '1', 'Spring', 2010, 'C+');
	insert into takes values('77003', '843', '1', 'Fall', 2010, 'C ');
	insert into takes values('62754', '345', '1', 'Spring', 2008, 'A ');
	insert into takes values('66356', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('557', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('38271', '604', '1', 'Spring', 2009, 'B+');
	insert into takes values('87268', '875', '1', 'Spring', 2005, 'C-');
	insert into takes values('19848', '400', '1', 'Spring', 2007, 'C+');
	insert into takes values('94990', '338', '2', 'Spring', 2006, 'C+');
	insert into takes values('64401', '468', '1', 'Fall', 2005, 'A ');
	insert into takes values('26494', '237', '1', 'Spring', 2008, 'C+');
	insert into takes values('34404', '864', '1', 'Spring', 2006, 'C-');
	insert into takes values('14829', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('32245', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('97435', '274', '1', 'Fall', 2002, 'B ');
	insert into takes values('99730', '496', '1', 'Fall', 2001, 'B ');
	insert into takes values('11095', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('62749', '843', '1', 'Fall', 2010, 'C+');
	insert into takes values('90089', '631', '1', 'Spring', 2007, 'A-');
	insert into takes values('54460', '875', '1', 'Spring', 2005, 'B-');
	insert into takes values('40932', '735', '2', 'Spring', 2010, 'B-');
	insert into takes values('57925', '200', '2', 'Fall', 2002, 'C+');
	insert into takes values('99760', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('83398', '559', '1', 'Fall', 2002, 'C-');
	insert into takes values('80420', '313', '1', 'Fall', 2010, 'A ');
	insert into takes values('11237', '702', '1', 'Spring', 2001, 'B-');
	insert into takes values('61081', '400', '2', 'Fall', 2003, 'B+');
	insert into takes values('5336', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('18821', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('76049', '604', '1', 'Spring', 2009, 'A ');
	insert into takes values('92442', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('55915', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('58595', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('94620', '401', '1', 'Fall', 2003, 'A ');
	insert into takes values('41890', '482', '1', 'Fall', 2005, 'B ');
	insert into takes values('76759', '200', '2', 'Fall', 2002, 'C+');
	insert into takes values('58935', '468', '2', 'Fall', 2007, 'A-');
	insert into takes values('79534', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('61232', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('92965', '468', '2', 'Fall', 2007, 'C+');
	insert into takes values('48861', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('88884', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('14032', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('65714', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('46762', '591', '1', 'Spring', 2005, 'C-');
	insert into takes values('71878', '468', '2', 'Fall', 2007, 'B ');
	insert into takes values('57160', '334', '1', 'Fall', 2009, 'C-');
	insert into takes values('34170', '629', '1', 'Spring', 2003, 'B+');
	insert into takes values('36657', '852', '1', 'Spring', 2008, 'A-');
	insert into takes values('18941', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('2795', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('88801', '426', '1', 'Spring', 2006, 'A+');
	insert into takes values('56080', '461', '1', 'Fall', 2002, 'B ');
	insert into takes values('90082', '591', '1', 'Spring', 2005, 'A+');
	insert into takes values('86327', '349', '1', 'Spring', 2008, 'A ');
	insert into takes values('18709', '960', '1', 'Fall', 2009, 'A-');
	insert into takes values('81031', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('18740', '496', '1', 'Fall', 2001, 'C ');
	insert into takes values('41491', '482', '1', 'Fall', 2005, 'C ');
	insert into takes values('30222', '239', '1', 'Fall', 2006, 'A-');
	insert into takes values('3493', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('50969', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('39520', '192', '1', 'Fall', 2002, 'C-');
	insert into takes values('55857', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('35905', '852', '1', 'Spring', 2008, 'C+');
	insert into takes values('9183', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('16515', '270', '1', 'Spring', 2010, 'A+');
	insert into takes values('61232', '200', '2', 'Fall', 2002, 'B-');
	insert into takes values('65901', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('61737', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('96988', '237', '1', 'Spring', 2008, 'A+');
	insert into takes values('29645', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('56299', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('75040', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('92949', '105', '2', 'Fall', 2002, 'B-');
	insert into takes values('22396', '991', '1', 'Spring', 2008, 'C-');
	insert into takes values('81396', '927', '1', 'Fall', 2002, 'A ');
	insert into takes values('90372', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('1087', '486', '1', 'Fall', 2009, 'B ');
	insert into takes values('30474', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('78758', '949', '1', 'Fall', 2007, 'B ');
	insert into takes values('12979', '158', '1', 'Fall', 2008, 'B+');
	insert into takes values('70688', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('73394', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('19536', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('85451', '748', '1', 'Fall', 2003, 'A-');
	insert into takes values('74911', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('56499', '493', '1', 'Spring', 2010, 'B ');
	insert into takes values('24201', '468', '1', 'Fall', 2005, 'B-');
	insert into takes values('9993', '599', '1', 'Spring', 2003, 'A-');
	insert into takes values('85887', '366', '1', 'Fall', 2005, 'C-');
	insert into takes values('37581', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('29665', '401', '1', 'Fall', 2003, 'C+');
	insert into takes values('57377', '960', '2', 'Fall', 2006, 'C ');
	insert into takes values('29031', '735', '2', 'Spring', 2010, 'A-');
	insert into takes values('67018', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('60366', '991', '1', 'Spring', 2008, 'B ');
	insert into takes values('38696', '631', '1', 'Spring', 2007, 'B ');
	insert into takes values('93171', '169', '1', 'Spring', 2007, 'A-');
	insert into takes values('27950', '760', '1', 'Spring', 2004, 'C-');
	insert into takes values('48861', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('86833', '401', '1', 'Fall', 2003, 'C-');
	insert into takes values('9495', '457', '1', 'Spring', 2001, 'C-');
	insert into takes values('64082', '468', '1', 'Fall', 2005, 'C+');
	insert into takes values('94178', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('31086', '468', '1', 'Fall', 2005, 'B-');
	insert into takes values('19791', '239', '1', 'Fall', 2006, 'C-');
	insert into takes values('93508', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('88417', '482', '1', 'Fall', 2005, 'A+');
	insert into takes values('65714', '696', '1', 'Spring', 2002, 'C-');
	insert into takes values('99694', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('31364', '791', '1', 'Spring', 2006, 'C-');
	insert into takes values('12216', '760', '1', 'Spring', 2004, 'A ');
	insert into takes values('53118', '457', '1', 'Spring', 2001, 'C-');
	insert into takes values('35257', '960', '1', 'Fall', 2009, 'B+');
	insert into takes values('93004', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('65258', '802', '1', 'Spring', 2003, 'A+');
	insert into takes values('19342', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('39241', '735', '2', 'Spring', 2010, 'C ');
	insert into takes values('6367', '962', '1', 'Spring', 2008, 'A ');
	insert into takes values('89246', '496', '1', 'Fall', 2001, 'B-');
	insert into takes values('5843', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('2139', '352', '1', 'Spring', 2006, 'C+');
	insert into takes values('46655', '694', '1', 'Fall', 2002, 'B-');
	insert into takes values('37653', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('72528', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('90663', '461', '1', 'Fall', 2002, 'C+');
	insert into takes values('98388', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('82039', '345', '1', 'Spring', 2008, 'B ');
	insert into takes values('14432', '345', '1', 'Spring', 2008, 'A-');
	insert into takes values('63502', '599', '1', 'Spring', 2003, 'B+');
	insert into takes values('123', '561', '1', 'Fall', 2006, 'B+');
	insert into takes values('35', '893', '1', 'Fall', 2007, 'B ');
	insert into takes values('70395', '158', '1', 'Fall', 2008, 'C-');
	insert into takes values('72528', '192', '1', 'Fall', 2002, 'C-');
	insert into takes values('33759', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('94620', '489', '1', 'Fall', 2007, 'B ');
	insert into takes values('69307', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('72669', '457', '1', 'Spring', 2001, 'C+');
	insert into takes values('81175', '270', '1', 'Spring', 2010, 'C-');
	insert into takes values('41894', '443', '1', 'Spring', 2010, 'B ');
	insert into takes values('53496', '642', '1', 'Fall', 2004, 'A-');
	insert into takes values('14639', '735', '1', 'Spring', 2003, 'C-');
	insert into takes values('23311', '527', '1', 'Fall', 2004, 'C+');
	insert into takes values('15487', '105', '1', 'Fall', 2009, 'C+');
	insert into takes values('7043', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('49244', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('64169', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('67021', '105', '2', 'Fall', 2002, 'A ');
	insert into takes values('39619', '489', '1', 'Fall', 2007, 'A ');
	insert into takes values('46725', '486', '1', 'Fall', 2009, 'A-');
	insert into takes values('60984', '581', '1', 'Spring', 2005, 'A-');
	insert into takes values('7287', '760', '1', 'Spring', 2004, 'C ');
	insert into takes values('81638', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('12615', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('80821', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('2178', '527', '1', 'Fall', 2004, 'B-');
	insert into takes values('71426', '468', '1', 'Fall', 2005, 'B ');
	insert into takes values('94178', '443', '1', 'Spring', 2010, 'A ');
	insert into takes values('82063', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('61998', '493', '1', 'Spring', 2010, 'C+');
	insert into takes values('2178', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('39978', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('5871', '843', '1', 'Fall', 2010, 'B+');
	insert into takes values('88140', '400', '2', 'Fall', 2003, 'C+');
	insert into takes values('48678', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('83573', '366', '1', 'Fall', 2005, 'C ');
	insert into takes values('3487', '200', '1', 'Spring', 2007, 'A ');
	insert into takes values('84702', '345', '1', 'Spring', 2008, 'C ');
	insert into takes values('64550', '105', '1', 'Fall', 2009, 'B+');
	insert into takes values('97868', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('47001', '401', '1', 'Fall', 2003, 'A ');
	insert into takes values('15578', '457', '1', 'Spring', 2001, 'B+');
	insert into takes values('68396', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('64297', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('14874', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('31266', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('22532', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('92385', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('90381', '581', '1', 'Spring', 2005, 'C ');
	insert into takes values('69679', '760', '1', 'Spring', 2004, 'B+');
	insert into takes values('81610', '200', '1', 'Spring', 2007, 'C ');
	insert into takes values('10267', '545', '1', 'Fall', 2001, 'A+');
	insert into takes values('88085', '631', '1', 'Spring', 2007, 'C+');
	insert into takes values('91370', '974', '1', 'Fall', 2003, 'C ');
	insert into takes values('57055', '959', '1', 'Fall', 2006, 'B ');
	insert into takes values('30161', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('99271', '313', '1', 'Fall', 2010, 'B+');
	insert into takes values('13403', '158', '1', 'Fall', 2008, 'B-');
	insert into takes values('23373', '960', '2', 'Fall', 2006, 'B+');
	insert into takes values('38371', '581', '1', 'Spring', 2005, 'B+');
	insert into takes values('95850', '561', '1', 'Fall', 2006, 'C+');
	insert into takes values('108', '696', '1', 'Spring', 2002, 'B-');
	insert into takes values('27236', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('65681', '612', '1', 'Fall', 2007, 'A ');
	insert into takes values('46066', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('11682', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('57156', '270', '1', 'Spring', 2010, 'B+');
	insert into takes values('70359', '527', '1', 'Fall', 2004, 'B-');
	insert into takes values('53803', '400', '1', 'Spring', 2007, 'A-');
	insert into takes values('43981', '169', '1', 'Spring', 2007, 'B+');
	insert into takes values('23311', '843', '1', 'Fall', 2010, 'C-');
	insert into takes values('34957', '270', '1', 'Spring', 2010, 'B+');
	insert into takes values('93508', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('88525', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('87831', '158', '1', 'Fall', 2008, 'A-');
	insert into takes values('24116', '808', '1', 'Fall', 2003, 'C ');
	insert into takes values('83003', '239', '1', 'Fall', 2006, 'C-');
	insert into takes values('56849', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('36019', '927', '1', 'Fall', 2002, 'A+');
	insert into takes values('10705', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('34158', '352', '1', 'Spring', 2006, 'B ');
	insert into takes values('60867', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('14432', '239', '1', 'Fall', 2006, 'A-');
	insert into takes values('40371', '496', '1', 'Fall', 2001, 'C ');
	insert into takes values('108', '401', '1', 'Fall', 2003, 'C ');
	insert into takes values('11095', '612', '1', 'Fall', 2007, 'A ');
	insert into takes values('23994', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('6195', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('36379', '561', '1', 'Fall', 2006, 'C+');
	insert into takes values('61920', '927', '1', 'Fall', 2002, 'C+');
	insert into takes values('73908', '795', '1', 'Spring', 2004, 'B-');
	insert into takes values('78116', '352', '1', 'Spring', 2006, 'C-');
	insert into takes values('123', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('25942', '875', '1', 'Spring', 2005, 'C ');
	insert into takes values('38712', '972', '1', 'Spring', 2009, 'A-');
	insert into takes values('35293', '795', '1', 'Spring', 2004, 'B-');
	insert into takes values('52929', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('83953', '599', '1', 'Spring', 2003, 'B-');
	insert into takes values('95859', '571', '1', 'Spring', 2004, 'A+');
	insert into takes values('67542', '760', '1', 'Spring', 2004, 'C-');
	insert into takes values('58081', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('58935', '927', '1', 'Fall', 2002, 'A-');
	insert into takes values('55329', '802', '1', 'Spring', 2003, 'C-');
	insert into takes values('10727', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('3493', '949', '1', 'Fall', 2007, 'A-');
	insert into takes values('86651', '443', '2', 'Spring', 2002, 'A ');
	insert into takes values('68453', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('15726', '960', '1', 'Fall', 2009, 'B+');
	insert into takes values('30124', '960', '2', 'Fall', 2006, 'B-');
	insert into takes values('83314', '493', '1', 'Spring', 2010, 'A ');
	insert into takes values('72501', '631', '1', 'Spring', 2007, 'B ');
	insert into takes values('13352', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('4173', '760', '1', 'Spring', 2004, 'A-');
	insert into takes values('97023', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('97658', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('27956', '843', '1', 'Fall', 2010, 'B+');
	insert into takes values('80248', '200', '2', 'Fall', 2002, 'A ');
	insert into takes values('99399', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('19541', '408', '2', 'Spring', 2003, 'A ');
	insert into takes values('85445', '802', '1', 'Spring', 2003, 'C+');
	insert into takes values('1533', '663', '1', 'Spring', 2005, 'B ');
	insert into takes values('24010', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('30289', '304', '1', 'Fall', 2009, 'C+');
	insert into takes values('49684', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('57456', '489', '1', 'Fall', 2007, 'B-');
	insert into takes values('42956', '489', '1', 'Fall', 2007, 'B-');
	insert into takes values('96067', '795', '1', 'Spring', 2004, 'B ');
	insert into takes values('76953', '581', '1', 'Spring', 2005, 'C+');
	insert into takes values('99399', '959', '1', 'Fall', 2006, 'A+');
	insert into takes values('88525', '105', '2', 'Fall', 2002, 'B-');
	insert into takes values('86127', '242', '1', 'Fall', 2009, 'A-');
	insert into takes values('65714', '192', '1', 'Fall', 2002, 'A+');
	insert into takes values('73606', '468', '1', 'Fall', 2005, 'A+');
	insert into takes values('31554', '663', '1', 'Spring', 2005, 'B-');
	insert into takes values('88993', '200', '2', 'Fall', 2002, 'C-');
	insert into takes values('99271', '852', '1', 'Spring', 2008, 'C ');
	insert into takes values('96741', '793', '1', 'Spring', 2002, 'A+');
	insert into takes values('14554', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('21337', '747', '1', 'Spring', 2004, 'C ');
	insert into takes values('93366', '415', '1', 'Fall', 2010, 'B+');
	insert into takes values('33759', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('84432', '960', '1', 'Fall', 2009, 'C-');
	insert into takes values('88302', '591', '1', 'Spring', 2005, 'A-');
	insert into takes values('82591', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('16885', '808', '1', 'Fall', 2003, 'A+');
	insert into takes values('61783', '338', '1', 'Spring', 2007, 'A+');
	insert into takes values('88140', '852', '1', 'Spring', 2008, 'A-');
	insert into takes values('75791', '401', '1', 'Fall', 2003, 'C-');
	insert into takes values('92274', '313', '1', 'Fall', 2010, 'C ');
	insert into takes values('33759', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('44206', '795', '1', 'Spring', 2004, 'B ');
	insert into takes values('94311', '468', '1', 'Fall', 2005, 'C+');
	insert into takes values('52157', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('61414', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('53490', '443', '1', 'Spring', 2010, 'B ');
	insert into takes values('32483', '679', '1', 'Spring', 2010, 'A+');
	insert into takes values('85505', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('987', '270', '1', 'Spring', 2010, 'B+');
	insert into takes values('26102', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('72055', '867', '1', 'Fall', 2006, 'A+');
	insert into takes values('77289', '893', '1', 'Fall', 2007, 'A-');
	insert into takes values('55531', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('65676', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('58595', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('86344', '864', '1', 'Spring', 2006, 'C+');
	insert into takes values('1080', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('54612', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('72186', '158', '1', 'Fall', 2008, 'A-');
	insert into takes values('10693', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('14065', '875', '1', 'Spring', 2005, 'A-');
	insert into takes values('36244', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('557', '545', '1', 'Fall', 2001, 'C ');
	insert into takes values('14182', '334', '1', 'Fall', 2009, 'C ');
	insert into takes values('87965', '445', '1', 'Spring', 2001, 'B+');
	insert into takes values('32056', '599', '1', 'Spring', 2003, 'B-');
	insert into takes values('70389', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('46928', '747', '1', 'Spring', 2004, 'B-');
	insert into takes values('41299', '893', '1', 'Fall', 2007, 'B ');
	insert into takes values('13753', '408', '2', 'Spring', 2003, 'B ');
	insert into takes values('86651', '760', '1', 'Spring', 2004, 'C ');
	insert into takes values('74672', '748', '1', 'Fall', 2003, 'A-');
	insert into takes values('31690', '867', '1', 'Fall', 2006, 'A+');
	insert into takes values('9605', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('56849', '949', '1', 'Fall', 2007, 'C-');
	insert into takes values('14621', '486', '1', 'Fall', 2009, 'A-');
	insert into takes values('22004', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('36881', '415', '1', 'Fall', 2010, 'B-');
	insert into takes values('27043', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('71387', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('2177', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('52707', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('46451', '867', '1', 'Fall', 2006, 'B+');
	insert into takes values('38371', '612', '1', 'Fall', 2007, 'A+');
	insert into takes values('8483', '258', '1', 'Fall', 2007, 'B+');
	insert into takes values('65241', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('60406', '802', '1', 'Spring', 2003, 'B+');
	insert into takes values('32744', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('82646', '443', '1', 'Spring', 2010, 'B-');
	insert into takes values('42956', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('72741', '735', '2', 'Spring', 2010, 'B-');
	insert into takes values('21337', '991', '1', 'Spring', 2008, 'A ');
	insert into takes values('50944', '629', '1', 'Spring', 2003, 'A+');
	insert into takes values('99422', '349', '1', 'Spring', 2008, 'A-');
	insert into takes values('53496', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('24796', '426', '1', 'Spring', 2006, 'C ');
	insert into takes values('34502', '974', '1', 'Fall', 2003, 'A-');
	insert into takes values('51416', '960', '1', 'Fall', 2009, 'B ');
	insert into takes values('10033', '604', '1', 'Spring', 2009, 'A-');
	insert into takes values('30341', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('39514', '949', '1', 'Fall', 2007, 'A-');
	insert into takes values('20974', '791', '1', 'Spring', 2006, 'C-');
	insert into takes values('89759', '893', '1', 'Fall', 2007, 'A-');
	insert into takes values('93043', '631', '1', 'Spring', 2007, 'B ');
	insert into takes values('65979', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('30252', '468', '2', 'Fall', 2007, 'B ');
	insert into takes values('10917', '843', '1', 'Fall', 2010, 'B-');
	insert into takes values('99553', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('29514', '599', '1', 'Spring', 2003, 'A+');
	insert into takes values('1367', '362', '3', 'Spring', 2008, 'A+');
	insert into takes values('5898', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('61166', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('20195', '795', '1', 'Spring', 2004, 'C+');
	insert into takes values('67407', '105', '2', 'Fall', 2002, 'B-');
	insert into takes values('83314', '760', '1', 'Spring', 2004, 'B+');
	insert into takes values('25187', '604', '1', 'Spring', 2009, 'A-');
	insert into takes values('64820', '571', '1', 'Spring', 2004, 'A+');
	insert into takes values('52134', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('39881', '426', '1', 'Spring', 2006, 'C ');
	insert into takes values('16969', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('25143', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('13511', '158', '2', 'Spring', 2008, 'C+');
	insert into takes values('36494', '702', '1', 'Spring', 2001, 'C ');
	insert into takes values('84495', '242', '1', 'Fall', 2009, 'A ');
	insert into takes values('53048', '760', '1', 'Spring', 2004, 'C-');
	insert into takes values('47627', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('25718', '893', '1', 'Fall', 2007, 'C ');
	insert into takes values('89393', '158', '2', 'Spring', 2008, 'C-');
	insert into takes values('54610', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('7861', '345', '1', 'Spring', 2008, 'B-');
	insert into takes values('14023', '704', '1', 'Spring', 2008, 'C ');
	insert into takes values('65329', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('36244', '415', '1', 'Fall', 2010, 'A-');
	insert into takes values('16347', '631', '1', 'Spring', 2007, 'C+');
	insert into takes values('72669', '258', '1', 'Fall', 2007, 'C+');
	insert into takes values('23992', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('91091', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('25468', '559', '1', 'Fall', 2002, 'B+');
	insert into takes values('47265', '972', '1', 'Spring', 2009, 'A-');
	insert into takes values('63310', '599', '1', 'Spring', 2003, 'A+');
	insert into takes values('21337', '694', '1', 'Fall', 2002, 'B-');
	insert into takes values('23449', '345', '1', 'Spring', 2008, 'A+');
	insert into takes values('92659', '972', '1', 'Spring', 2009, 'A+');
	insert into takes values('96153', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('68096', '561', '1', 'Fall', 2006, 'C ');
	insert into takes values('43993', '421', '1', 'Fall', 2004, 'C+');
	insert into takes values('70924', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('84808', '760', '1', 'Spring', 2004, 'C+');
	insert into takes values('59673', '313', '1', 'Fall', 2010, 'A-');
	insert into takes values('96206', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('79329', '747', '1', 'Spring', 2004, 'B+');
	insert into takes values('13028', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('87706', '169', '2', 'Fall', 2002, 'A+');
	insert into takes values('67024', '200', '1', 'Spring', 2007, 'C ');
	insert into takes values('35293', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('12941', '591', '1', 'Spring', 2005, 'A ');
	insert into takes values('23794', '679', '1', 'Spring', 2010, 'A+');
	insert into takes values('30222', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('83314', '867', '2', 'Fall', 2010, 'C ');
	insert into takes values('95284', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('16907', '352', '1', 'Spring', 2006, 'C ');
	insert into takes values('33837', '366', '1', 'Fall', 2005, 'A+');
	insert into takes values('79697', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('99949', '972', '1', 'Spring', 2009, 'B-');
	insert into takes values('78332', '486', '1', 'Fall', 2009, 'B-');
	insert into takes values('87784', '852', '1', 'Spring', 2008, 'C ');
	insert into takes values('95284', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('79534', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('21774', '169', '1', 'Spring', 2007, 'C ');
	insert into takes values('62054', '313', '1', 'Fall', 2010, 'A ');
	insert into takes values('88302', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('89393', '468', '2', 'Fall', 2007, 'A+');
	insert into takes values('59397', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('32886', '158', '1', 'Fall', 2008, 'A ');
	insert into takes values('25942', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('16849', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('49205', '362', '1', 'Fall', 2005, 'C-');
	insert into takes values('59848', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('14581', '631', '1', 'Spring', 2007, 'C+');
	insert into takes values('82066', '468', '1', 'Fall', 2005, 'A-');
	insert into takes values('26494', '527', '1', 'Fall', 2004, 'B-');
	insert into takes values('28316', '927', '1', 'Fall', 2002, 'C-');
	insert into takes values('46694', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('83314', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('51678', '468', '1', 'Fall', 2005, 'A-');
	insert into takes values('22325', '735', '1', 'Spring', 2003, 'A ');
	insert into takes values('39927', '237', '2', 'Fall', 2009, 'B+');
	insert into takes values('5961', '599', '1', 'Spring', 2003, 'A+');
	insert into takes values('26881', '571', '1', 'Spring', 2004, 'A-');
	insert into takes values('10527', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('62487', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('64297', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('45826', '748', '1', 'Fall', 2003, 'A-');
	insert into takes values('50658', '461', '1', 'Fall', 2002, 'C-');
	insert into takes values('9605', '808', '1', 'Fall', 2003, 'A-');
	insert into takes values('80247', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('99977', '338', '2', 'Spring', 2006, 'A ');
	insert into takes values('22618', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('52872', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('72014', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('67810', '642', '1', 'Fall', 2004, 'B-');
	insert into takes values('33338', '400', '2', 'Fall', 2003, 'B-');
	insert into takes values('30896', '631', '1', 'Spring', 2007, 'C+');
	insert into takes values('28004', '468', '1', 'Fall', 2005, 'B+');
	insert into takes values('47670', '461', '1', 'Fall', 2002, 'A-');
	insert into takes values('30858', '468', '1', 'Fall', 2005, 'A ');
	insert into takes values('44352', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('23500', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('37521', '352', '1', 'Spring', 2006, 'C-');
	insert into takes values('17507', '704', '1', 'Spring', 2008, 'C-');
	insert into takes values('61166', '631', '1', 'Spring', 2007, 'B ');
	insert into takes values('92693', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('9605', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('79329', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('70807', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('16885', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('38271', '527', '1', 'Fall', 2004, 'A-');
	insert into takes values('17911', '401', '1', 'Fall', 2003, 'A-');
	insert into takes values('89104', '304', '1', 'Fall', 2009, 'B+');
	insert into takes values('15883', '642', '1', 'Fall', 2004, 'C+');
	insert into takes values('96722', '304', '1', 'Fall', 2009, 'A+');
	insert into takes values('90914', '626', '1', 'Fall', 2006, 'A ');
	insert into takes values('72657', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('34788', '581', '1', 'Spring', 2005, 'A ');
	insert into takes values('12971', '457', '1', 'Spring', 2001, 'A ');
	insert into takes values('85356', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('48423', '561', '1', 'Fall', 2006, 'A-');
	insert into takes values('90124', '927', '1', 'Fall', 2002, 'C+');
	insert into takes values('87785', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('93491', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('77580', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('85809', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('76173', '867', '1', 'Fall', 2006, 'B ');
	insert into takes values('80248', '426', '1', 'Spring', 2006, 'C ');
	insert into takes values('13880', '237', '2', 'Fall', 2009, 'C+');
	insert into takes values('7123', '345', '1', 'Spring', 2008, 'A+');
	insert into takes values('22254', '808', '1', 'Fall', 2003, 'C ');
	insert into takes values('29390', '603', '1', 'Fall', 2003, 'B+');
	insert into takes values('70807', '493', '1', 'Spring', 2010, 'A-');
	insert into takes values('92776', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('72014', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('5463', '349', '1', 'Spring', 2008, 'A ');
	insert into takes values('50331', '629', '1', 'Spring', 2003, 'B+');
	insert into takes values('25068', '959', '1', 'Fall', 2006, 'A+');
	insert into takes values('55238', '401', '1', 'Fall', 2003, 'C+');
	insert into takes values('71543', '345', '1', 'Spring', 2008, 'B-');
	insert into takes values('37586', '867', '1', 'Fall', 2006, 'A-');
	insert into takes values('25611', '793', '1', 'Spring', 2002, 'C-');
	insert into takes values('4438', '867', '2', 'Fall', 2010, 'C ');
	insert into takes values('6400', '242', '1', 'Fall', 2009, 'B ');
	insert into takes values('45570', '489', '1', 'Fall', 2007, 'B-');
	insert into takes values('23110', '927', '1', 'Fall', 2002, 'C ');
	insert into takes values('34055', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('72669', '793', '1', 'Spring', 2002, 'A+');
	insert into takes values('42092', '362', '1', 'Fall', 2005, 'C ');
	insert into takes values('63310', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('16849', '237', '1', 'Spring', 2008, 'C+');
	insert into takes values('61127', '376', '1', 'Fall', 2006, 'B-');
	insert into takes values('67407', '400', '2', 'Fall', 2003, 'A+');
	insert into takes values('28952', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('23344', '313', '1', 'Fall', 2010, 'C+');
	insert into takes values('83136', '974', '1', 'Fall', 2003, 'C-');
	insert into takes values('85910', '443', '2', 'Spring', 2002, 'C ');
	insert into takes values('20084', '875', '1', 'Spring', 2005, 'A ');
	insert into takes values('5943', '527', '1', 'Fall', 2004, 'C+');
	insert into takes values('50977', '408', '1', 'Spring', 2007, 'A-');
	insert into takes values('63310', '959', '1', 'Fall', 2006, 'B+');
	insert into takes values('42556', '735', '2', 'Spring', 2010, 'A-');
	insert into takes values('55915', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('27727', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('23392', '415', '1', 'Fall', 2010, 'C+');
	insert into takes values('87651', '802', '1', 'Spring', 2003, 'C-');
	insert into takes values('28019', '345', '1', 'Spring', 2008, 'B-');
	insert into takes values('96085', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('96203', '200', '2', 'Fall', 2002, 'C-');
	insert into takes values('42960', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('58919', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('25468', '376', '1', 'Fall', 2006, 'B ');
	insert into takes values('27687', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('6287', '200', '1', 'Spring', 2007, 'A ');
	insert into takes values('77588', '200', '1', 'Spring', 2007, 'A+');
	insert into takes values('79329', '242', '1', 'Fall', 2009, 'A+');
	insert into takes values('68280', '362', '3', 'Spring', 2008, 'C+');
	insert into takes values('46970', '571', '1', 'Spring', 2004, 'A-');
	insert into takes values('2201', '559', '1', 'Fall', 2002, 'C+');
	insert into takes values('30723', '338', '1', 'Spring', 2007, 'B ');
	insert into takes values('2201', '169', '1', 'Spring', 2007, 'B ');
	insert into takes values('63582', '843', '1', 'Fall', 2010, 'B+');
	insert into takes values('31079', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('7149', '626', '1', 'Fall', 2006, 'C ');
	insert into takes values('7970', '960', '1', 'Fall', 2009, 'B+');
	insert into takes values('14554', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('45720', '631', '1', 'Spring', 2007, 'C-');
	insert into takes values('54296', '694', '1', 'Fall', 2002, 'B ');
	insert into takes values('99977', '468', '2', 'Fall', 2007, 'A-');
	insert into takes values('84654', '482', '1', 'Fall', 2005, 'C ');
	insert into takes values('57123', '443', '2', 'Spring', 2002, 'A+');
	insert into takes values('37653', '457', '1', 'Spring', 2001, 'A+');
	insert into takes values('16753', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('66484', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('85505', '258', '1', 'Fall', 2007, 'C-');
	insert into takes values('52291', '581', '1', 'Spring', 2005, 'A ');
	insert into takes values('35498', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('95953', '401', '1', 'Fall', 2003, 'A-');
	insert into takes values('93631', '527', '1', 'Fall', 2004, 'C ');
	insert into takes values('5298', '867', '1', 'Fall', 2006, 'A-');
	insert into takes values('94990', '158', '2', 'Spring', 2008, 'A ');
	insert into takes values('3493', '959', '1', 'Fall', 2006, 'A ');
	insert into takes values('47126', '237', '1', 'Spring', 2008, 'A+');
	insert into takes values('14874', '991', '1', 'Spring', 2008, 'A ');
	insert into takes values('27094', '352', '1', 'Spring', 2006, 'B ');
	insert into takes values('28004', '735', '2', 'Spring', 2010, 'A-');
	insert into takes values('2629', '604', '1', 'Spring', 2009, 'C ');
	insert into takes values('27044', '852', '1', 'Spring', 2008, 'A ');
	insert into takes values('48901', '376', '1', 'Fall', 2006, 'A-');
	insert into takes values('17676', '169', '1', 'Spring', 2007, 'A-');
	insert into takes values('17924', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('31337', '366', '1', 'Fall', 2005, 'C ');
	insert into takes values('1460', '258', '1', 'Fall', 2007, 'C-');
	insert into takes values('52385', '319', '1', 'Spring', 2003, 'C-');
	insert into takes values('2629', '408', '2', 'Spring', 2003, 'C-');
	insert into takes values('54672', '692', '1', 'Spring', 2010, 'C-');
	insert into takes values('32464', '443', '1', 'Spring', 2010, 'B ');
	insert into takes values('8912', '105', '1', 'Fall', 2009, 'C ');
	insert into takes values('46762', '237', '2', 'Fall', 2009, 'C-');
	insert into takes values('77289', '496', '1', 'Fall', 2001, 'B-');
	insert into takes values('40178', '486', '1', 'Fall', 2009, 'A ');
	insert into takes values('80698', '258', '1', 'Fall', 2007, 'A+');
	insert into takes values('22226', '612', '1', 'Fall', 2007, 'B ');
	insert into takes values('7620', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('39619', '545', '1', 'Fall', 2001, 'B ');
	insert into takes values('65753', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('22179', '489', '1', 'Fall', 2007, 'A ');
	insert into takes values('68070', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('87831', '242', '1', 'Fall', 2009, 'C-');
	insert into takes values('70384', '927', '1', 'Fall', 2002, 'A+');
	insert into takes values('41491', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('62705', '482', '1', 'Fall', 2005, 'B-');
	insert into takes values('88358', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('99451', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('75596', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('86641', '338', '2', 'Spring', 2006, 'B ');
	insert into takes values('98563', '366', '1', 'Fall', 2005, 'B ');
	insert into takes values('27002', '802', '1', 'Spring', 2003, 'C+');
	insert into takes values('39238', '527', '1', 'Fall', 2004, 'C-');
	insert into takes values('66763', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('31341', '376', '1', 'Fall', 2006, 'C ');
	insert into takes values('63243', '338', '2', 'Spring', 2006, 'C ');
	insert into takes values('62754', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('21401', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('55915', '169', '2', 'Fall', 2002, 'B+');
	insert into takes values('59553', '376', '1', 'Fall', 2006, 'A-');
	insert into takes values('34018', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('92776', '400', '1', 'Spring', 2007, 'B ');
	insert into takes values('90567', '239', '1', 'Fall', 2006, 'C+');
	insert into takes values('29645', '702', '1', 'Spring', 2001, 'C+');
	insert into takes values('95029', '604', '1', 'Spring', 2009, 'B ');
	insert into takes values('82126', '270', '1', 'Spring', 2010, 'C+');
	insert into takes values('6474', '735', '1', 'Spring', 2003, 'B-');
	insert into takes values('53803', '599', '1', 'Spring', 2003, 'A ');
	insert into takes values('5250', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('62152', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('22912', '338', '2', 'Spring', 2006, 'B ');
	insert into takes values('78581', '791', '1', 'Spring', 2006, 'A-');
	insert into takes values('13504', '612', '1', 'Fall', 2007, 'B-');
	insert into takes values('39521', '893', '1', 'Fall', 2007, 'A-');
	insert into takes values('39115', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('59530', '486', '1', 'Fall', 2009, 'A-');
	insert into takes values('52187', '793', '1', 'Spring', 2002, 'C+');
	insert into takes values('31137', '338', '2', 'Spring', 2006, 'A+');
	insert into takes values('62716', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('41491', '599', '1', 'Spring', 2003, 'B+');
	insert into takes values('54605', '489', '1', 'Fall', 2007, 'C ');
	insert into takes values('53805', '105', '2', 'Fall', 2002, 'B-');
	insert into takes values('58889', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('51549', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('50702', '408', '2', 'Spring', 2003, 'A ');
	insert into takes values('70807', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('20489', '445', '1', 'Spring', 2001, 'B-');
	insert into takes values('32483', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('13028', '629', '1', 'Spring', 2003, 'B+');
	insert into takes values('24746', '376', '1', 'Fall', 2006, 'B-');
	insert into takes values('64067', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('65433', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('36881', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('25468', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('20540', '867', '2', 'Fall', 2010, 'C-');
	insert into takes values('98984', '893', '1', 'Fall', 2007, 'A ');
	insert into takes values('58935', '631', '1', 'Spring', 2007, 'A-');
	insert into takes values('78858', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('81207', '319', '1', 'Spring', 2003, 'A-');
	insert into takes values('61166', '599', '1', 'Spring', 2003, 'A ');
	insert into takes values('43616', '629', '1', 'Spring', 2003, 'B ');
	insert into takes values('23449', '960', '1', 'Fall', 2009, 'C-');
	insert into takes values('25528', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('27662', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('21101', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('59538', '408', '1', 'Spring', 2007, 'A-');
	insert into takes values('5414', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('9947', '169', '1', 'Spring', 2007, 'B-');
	insert into takes values('67725', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('61356', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('27898', '313', '1', 'Fall', 2010, 'B ');
	insert into takes values('88793', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('41890', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('39552', '443', '2', 'Spring', 2002, 'C-');
	insert into takes values('31364', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('95697', '304', '1', 'Fall', 2009, 'B ');
	insert into takes values('12216', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('57787', '304', '1', 'Fall', 2009, 'B+');
	insert into takes values('11057', '270', '1', 'Spring', 2010, 'B+');
	insert into takes values('65329', '334', '1', 'Fall', 2009, 'A-');
	insert into takes values('77580', '561', '1', 'Fall', 2006, 'C-');
	insert into takes values('25068', '795', '1', 'Spring', 2004, 'B ');
	insert into takes values('68096', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('98563', '169', '1', 'Spring', 2007, 'B+');
	insert into takes values('65205', '345', '1', 'Spring', 2008, 'C+');
	insert into takes values('39876', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('27430', '237', '1', 'Spring', 2008, 'C-');
	insert into takes values('73394', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('39204', '599', '1', 'Spring', 2003, 'B-');
	insert into takes values('90004', '735', '1', 'Spring', 2003, 'C-');
	insert into takes values('29959', '795', '1', 'Spring', 2004, 'C+');
	insert into takes values('22057', '974', '1', 'Fall', 2003, 'C ');
	insert into takes values('91799', '376', '1', 'Fall', 2006, 'C+');
	insert into takes values('80821', '242', '1', 'Fall', 2009, 'C-');
	insert into takes values('78581', '258', '1', 'Fall', 2007, 'A-');
	insert into takes values('60688', '408', '2', 'Spring', 2003, 'C ');
	insert into takes values('22532', '304', '1', 'Fall', 2009, 'A ');
	insert into takes values('32368', '808', '1', 'Fall', 2003, 'B ');
	insert into takes values('4582', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('99949', '808', '1', 'Fall', 2003, 'A+');
	insert into takes values('18338', '760', '1', 'Spring', 2004, 'B-');
	insert into takes values('80941', '571', '1', 'Spring', 2004, 'C+');
	insert into takes values('84039', '468', '1', 'Fall', 2005, 'B-');
	insert into takes values('90220', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('37339', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('89140', '631', '1', 'Spring', 2007, 'A+');
	insert into takes values('32490', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('32385', '401', '1', 'Fall', 2003, 'B+');
	insert into takes values('52669', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('44584', '158', '1', 'Fall', 2008, 'A+');
	insert into takes values('43912', '445', '1', 'Spring', 2001, 'A-');
	insert into takes values('99730', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('57238', '972', '1', 'Spring', 2009, 'B-');
	insert into takes values('12711', '735', '1', 'Spring', 2003, 'A-');
	insert into takes values('78767', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('77729', '408', '2', 'Spring', 2003, 'A+');
	insert into takes values('71025', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('31337', '545', '1', 'Fall', 2001, 'C ');
	insert into takes values('99949', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('49792', '158', '1', 'Fall', 2008, 'C-');
	insert into takes values('95225', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('32119', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('55286', '258', '1', 'Fall', 2007, 'C ');
	insert into takes values('23506', '338', '1', 'Spring', 2007, 'A-');
	insert into takes values('35198', '468', '1', 'Fall', 2005, 'A-');
	insert into takes values('28299', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('66356', '972', '1', 'Spring', 2009, 'B ');
	insert into takes values('1726', '747', '1', 'Spring', 2004, 'C-');
	insert into takes values('18859', '962', '1', 'Spring', 2008, 'A+');
	insert into takes values('88525', '571', '1', 'Spring', 2004, 'C ');
	insert into takes values('27366', '482', '1', 'Fall', 2005, 'A ');
	insert into takes values('45300', '642', '1', 'Fall', 2004, 'A-');
	insert into takes values('83002', '893', '1', 'Fall', 2007, 'A+');
	insert into takes values('31486', '461', '1', 'Fall', 2002, 'B ');
	insert into takes values('42092', '747', '1', 'Spring', 2004, 'B+');
	insert into takes values('89234', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('63612', '486', '1', 'Fall', 2009, 'B ');
	insert into takes values('20099', '476', '1', 'Fall', 2010, 'B ');
	insert into takes values('52494', '242', '1', 'Fall', 2009, 'B ');
	insert into takes values('49792', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('66281', '748', '1', 'Fall', 2003, 'C-');
	insert into takes values('71944', '258', '1', 'Fall', 2007, 'C-');
	insert into takes values('41491', '604', '1', 'Spring', 2009, 'A-');
	insert into takes values('37818', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('17207', '591', '1', 'Spring', 2005, 'C+');
	insert into takes values('53118', '571', '1', 'Spring', 2004, 'C+');
	insert into takes values('81396', '443', '1', 'Spring', 2010, 'B+');
	insert into takes values('8251', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('35220', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('1884', '237', '1', 'Spring', 2008, 'C-');
	insert into takes values('11152', '415', '1', 'Fall', 2010, 'C+');
	insert into takes values('108', '631', '1', 'Spring', 2007, 'B ');
	insert into takes values('15698', '545', '1', 'Fall', 2001, 'B ');
	insert into takes values('31266', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('92274', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('90009', '200', '2', 'Fall', 2002, 'A-');
	insert into takes values('31137', '735', '2', 'Spring', 2010, 'A+');
	insert into takes values('8957', '461', '1', 'Fall', 2002, 'B ');
	insert into takes values('64731', '545', '1', 'Fall', 2001, 'A-');
	insert into takes values('94535', '527', '1', 'Fall', 2004, 'B+');
	insert into takes values('59848', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('37038', '927', '1', 'Fall', 2002, 'A ');
	insert into takes values('85754', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('48640', '443', '2', 'Spring', 2002, 'C-');
	insert into takes values('94814', '237', '2', 'Fall', 2009, 'A ');
	insert into takes values('65703', '960', '1', 'Fall', 2009, 'B-');
	insert into takes values('57985', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('14874', '545', '1', 'Fall', 2001, 'A+');
	insert into takes values('88884', '591', '1', 'Spring', 2005, 'B-');
	insert into takes values('54153', '362', '2', 'Fall', 2006, 'A ');
	insert into takes values('97355', '376', '1', 'Fall', 2006, 'A ');
	insert into takes values('888', '559', '1', 'Fall', 2002, 'B ');
	insert into takes values('4435', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('1018', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('33206', '415', '1', 'Fall', 2010, 'B-');
	insert into takes values('31442', '795', '1', 'Spring', 2004, 'B-');
	insert into takes values('76270', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('28361', '408', '2', 'Spring', 2003, 'A+');
	insert into takes values('858', '599', '1', 'Spring', 2003, 'B ');
	insert into takes values('73268', '962', '1', 'Spring', 2008, 'C+');
	insert into takes values('78767', '334', '1', 'Fall', 2009, 'A-');
	insert into takes values('12326', '735', '2', 'Spring', 2010, 'C ');
	insert into takes values('27898', '793', '1', 'Spring', 2002, 'C ');
	insert into takes values('74840', '626', '1', 'Fall', 2006, 'A-');
	insert into takes values('57941', '415', '1', 'Fall', 2010, 'C-');
	insert into takes values('2561', '867', '1', 'Fall', 2006, 'A+');
	insert into takes values('83838', '482', '1', 'Fall', 2005, 'A+');
	insert into takes values('7602', '313', '1', 'Fall', 2010, 'B+');
	insert into takes values('65208', '496', '1', 'Fall', 2001, 'C ');
	insert into takes values('12563', '366', '1', 'Fall', 2005, 'C ');
	insert into takes values('1726', '604', '1', 'Spring', 2009, 'B+');
	insert into takes values('72669', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('69960', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('41596', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('97590', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('77580', '893', '1', 'Fall', 2007, 'A-');
	insert into takes values('15883', '581', '1', 'Spring', 2005, 'A+');
	insert into takes values('14874', '468', '1', 'Fall', 2005, 'A+');
	insert into takes values('4940', '158', '2', 'Spring', 2008, 'B-');
	insert into takes values('81984', '760', '1', 'Spring', 2004, 'B-');
	insert into takes values('56089', '270', '1', 'Spring', 2010, 'C+');
	insert into takes values('51817', '960', '1', 'Fall', 2009, 'A-');
	insert into takes values('31486', '352', '1', 'Spring', 2006, 'B ');
	insert into takes values('64297', '401', '1', 'Fall', 2003, 'A-');
	insert into takes values('22254', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('75878', '362', '1', 'Fall', 2005, 'C-');
	insert into takes values('65038', '694', '1', 'Fall', 2002, 'A+');
	insert into takes values('69747', '338', '1', 'Spring', 2007, 'A+');
	insert into takes values('60366', '274', '1', 'Fall', 2002, 'B-');
	insert into takes values('8853', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('507', '400', '2', 'Fall', 2003, 'C-');
	insert into takes values('78911', '400', '1', 'Spring', 2007, 'A+');
	insert into takes values('64121', '852', '1', 'Spring', 2008, 'B+');
	insert into takes values('6895', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('25718', '408', '1', 'Spring', 2007, 'A ');
	insert into takes values('87784', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('86651', '415', '1', 'Fall', 2010, 'A-');
	insert into takes values('39612', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('34422', '242', '1', 'Fall', 2009, 'C-');
	insert into takes values('53485', '258', '1', 'Fall', 2007, 'B+');
	insert into takes values('57242', '692', '1', 'Spring', 2010, 'B-');
	insert into takes values('10033', '443', '2', 'Spring', 2002, 'C-');
	insert into takes values('76049', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('99226', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('60040', '400', '1', 'Spring', 2007, 'A+');
	insert into takes values('71543', '663', '1', 'Spring', 2005, 'B-');
	insert into takes values('53047', '843', '1', 'Fall', 2010, 'A-');
	insert into takes values('7390', '313', '1', 'Fall', 2010, 'C+');
	insert into takes values('22170', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('65676', '843', '1', 'Fall', 2010, 'C ');
	insert into takes values('91063', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('19450', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('83622', '461', '1', 'Fall', 2002, 'C-');
	insert into takes values('14563', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('51093', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('65438', '137', '1', 'Spring', 2002, 'A-');
	insert into takes values('11453', '366', '1', 'Fall', 2005, 'C-');
	insert into takes values('64082', '313', '1', 'Fall', 2010, 'A-');
	insert into takes values('49391', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('72768', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('18499', '843', '1', 'Fall', 2010, 'A+');
	insert into takes values('97041', '496', '1', 'Fall', 2001, 'C ');
	insert into takes values('10454', '169', '1', 'Spring', 2007, 'B+');
	insert into takes values('85451', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('52076', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('26427', '875', '1', 'Spring', 2005, 'A ');
	insert into takes values('89312', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('41751', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('25725', '476', '1', 'Fall', 2010, 'C-');
	insert into takes values('19861', '735', '1', 'Spring', 2003, 'C-');
	insert into takes values('38895', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('544', '443', '1', 'Spring', 2010, 'C+');
	insert into takes values('64013', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('64169', '694', '1', 'Fall', 2002, 'B-');
	insert into takes values('70384', '169', '1', 'Spring', 2007, 'C+');
	insert into takes values('8853', '489', '1', 'Fall', 2007, 'A-');
	insert into takes values('46337', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('23224', '747', '1', 'Spring', 2004, 'C-');
	insert into takes values('23373', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('4248', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('19791', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('98690', '415', '1', 'Fall', 2010, 'B-');
	insert into takes values('39619', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('11422', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('52494', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('52076', '366', '1', 'Fall', 2005, 'A ');
	insert into takes values('61332', '875', '1', 'Spring', 2005, 'B-');
	insert into takes values('61527', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('89104', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('74473', '349', '1', 'Spring', 2008, 'A ');
	insert into takes values('67033', '258', '1', 'Fall', 2007, 'A+');
	insert into takes values('84702', '457', '1', 'Spring', 2001, 'A ');
	insert into takes values('51975', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('47001', '692', '1', 'Spring', 2010, 'B-');
	insert into takes values('25077', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('22417', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('68516', '571', '1', 'Spring', 2004, 'A-');
	insert into takes values('57431', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('41674', '200', '2', 'Fall', 2002, 'B-');
	insert into takes values('76291', '158', '2', 'Spring', 2008, 'A-');
	insert into takes values('6895', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('89104', '974', '1', 'Fall', 2003, 'B-');
	insert into takes values('52876', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('31442', '496', '1', 'Fall', 2001, 'B ');
	insert into takes values('51203', '795', '1', 'Spring', 2004, 'C+');
	insert into takes values('81876', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('19048', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('14668', '352', '1', 'Spring', 2006, 'C+');
	insert into takes values('6209', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('92839', '319', '1', 'Spring', 2003, 'B-');
	insert into takes values('81610', '105', '2', 'Fall', 2002, 'A+');
	insert into takes values('21394', '864', '1', 'Spring', 2006, 'B+');
	insert into takes values('60224', '760', '1', 'Spring', 2004, 'C-');
	insert into takes values('56882', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('8986', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('70965', '468', '2', 'Fall', 2007, 'C+');
	insert into takes values('62152', '443', '1', 'Spring', 2010, 'C+');
	insert into takes values('92442', '338', '1', 'Spring', 2007, 'A-');
	insert into takes values('40558', '304', '1', 'Fall', 2009, 'C+');
	insert into takes values('85575', '591', '1', 'Spring', 2005, 'C-');
	insert into takes values('29002', '760', '1', 'Spring', 2004, 'B-');
	insert into takes values('63489', '748', '1', 'Fall', 2003, 'C ');
	insert into takes values('28361', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('29871', '561', '1', 'Fall', 2006, 'B+');
	insert into takes values('842', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('79329', '237', '2', 'Fall', 2009, 'A ');
	insert into takes values('5298', '793', '1', 'Spring', 2002, 'A ');
	insert into takes values('30397', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('91851', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('91063', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('27898', '867', '1', 'Fall', 2006, 'B+');
	insert into takes values('57474', '679', '1', 'Spring', 2010, 'B ');
	insert into takes values('13921', '421', '1', 'Fall', 2004, 'A-');
	insert into takes values('86552', '468', '2', 'Fall', 2007, 'A-');
	insert into takes values('5961', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('64169', '338', '2', 'Spring', 2006, 'A-');
	insert into takes values('12078', '974', '1', 'Fall', 2003, 'B-');
	insert into takes values('50039', '200', '1', 'Spring', 2007, 'B+');
	insert into takes values('22003', '476', '1', 'Fall', 2010, 'C ');
	insert into takes values('99977', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('41894', '239', '1', 'Fall', 2006, 'A-');
	insert into takes values('64401', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('7970', '629', '1', 'Spring', 2003, 'A ');
	insert into takes values('66212', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('92849', '599', '1', 'Spring', 2003, 'C+');
	insert into takes values('24784', '972', '1', 'Spring', 2009, 'B-');
	insert into takes values('56078', '696', '1', 'Spring', 2002, 'C-');
	insert into takes values('83314', '482', '1', 'Fall', 2005, 'B ');
	insert into takes values('47627', '852', '1', 'Spring', 2008, 'B-');
	insert into takes values('28299', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('75040', '158', '2', 'Spring', 2008, 'B+');
	insert into takes values('69081', '960', '1', 'Fall', 2009, 'A+');
	insert into takes values('17128', '239', '1', 'Fall', 2006, 'C-');
	insert into takes values('14596', '457', '1', 'Spring', 2001, 'B+');
	insert into takes values('6287', '949', '1', 'Fall', 2007, 'C ');
	insert into takes values('30017', '591', '1', 'Spring', 2005, 'B+');
	insert into takes values('52471', '137', '1', 'Spring', 2002, 'C-');
	insert into takes values('51549', '852', '1', 'Spring', 2008, 'C ');
	insert into takes values('6209', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('67514', '591', '1', 'Spring', 2005, 'B-');
	insert into takes values('14182', '679', '1', 'Spring', 2010, 'C+');
	insert into takes values('14621', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('14432', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('33349', '401', '1', 'Fall', 2003, 'A-');
	insert into takes values('96085', '581', '1', 'Spring', 2005, 'B+');
	insert into takes values('92949', '304', '1', 'Fall', 2009, 'C+');
	insert into takes values('86075', '748', '1', 'Fall', 2003, 'C ');
	insert into takes values('66259', '591', '1', 'Spring', 2005, 'B+');
	insert into takes values('71426', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('28518', '704', '1', 'Spring', 2008, 'C ');
	insert into takes values('34788', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('7498', '493', '1', 'Spring', 2010, 'C-');
	insert into takes values('16250', '400', '1', 'Spring', 2007, 'A+');
	insert into takes values('28977', '591', '1', 'Spring', 2005, 'A-');
	insert into takes values('43123', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('71085', '468', '2', 'Fall', 2007, 'A+');
	insert into takes values('97101', '415', '1', 'Fall', 2010, 'C+');
	insert into takes values('55531', '960', '2', 'Fall', 2006, 'C ');
	insert into takes values('78332', '158', '1', 'Fall', 2008, 'A-');
	insert into takes values('16907', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('67021', '972', '1', 'Spring', 2009, 'C-');
	insert into takes values('2848', '105', '1', 'Fall', 2009, 'C+');
	insert into takes values('27002', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('59848', '415', '1', 'Fall', 2010, 'B-');
	insert into takes values('68263', '349', '1', 'Spring', 2008, 'C-');
	insert into takes values('26619', '137', '1', 'Spring', 2002, 'A-');
	insert into takes values('24374', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('38973', '482', '1', 'Fall', 2005, 'A-');
	insert into takes values('2423', '581', '1', 'Spring', 2005, 'C-');
	insert into takes values('16528', '105', '2', 'Fall', 2002, 'C-');
	insert into takes values('5399', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('30188', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('94257', '486', '1', 'Fall', 2009, 'B-');
	insert into takes values('11578', '352', '1', 'Spring', 2006, 'A+');
	insert into takes values('64082', '482', '1', 'Fall', 2005, 'C ');
	insert into takes values('29863', '852', '1', 'Spring', 2008, 'C ');
	insert into takes values('80912', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('83039', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('29920', '476', '1', 'Fall', 2010, 'C ');
	insert into takes values('11966', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('17133', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('31761', '960', '2', 'Fall', 2006, 'B-');
	insert into takes values('24796', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('53185', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('8603', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('86375', '795', '1', 'Spring', 2004, 'B ');
	insert into takes values('28538', '571', '1', 'Spring', 2004, 'C ');
	insert into takes values('8251', '376', '1', 'Fall', 2006, 'B+');
	insert into takes values('27366', '696', '1', 'Spring', 2002, 'B-');
	insert into takes values('59290', '603', '1', 'Fall', 2003, 'A+');
	insert into takes values('69230', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('97041', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('77234', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('62429', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('46694', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('85910', '105', '2', 'Fall', 2002, 'B-');
	insert into takes values('99660', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('43505', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('58465', '443', '2', 'Spring', 2002, 'B ');
	insert into takes values('72055', '476', '1', 'Fall', 2010, 'A+');
	insert into takes values('25468', '748', '1', 'Fall', 2003, 'C ');
	insert into takes values('78858', '408', '2', 'Spring', 2003, 'A+');
	insert into takes values('24630', '334', '1', 'Fall', 2009, 'B+');
	insert into takes values('99553', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('97023', '489', '1', 'Fall', 2007, 'B+');
	insert into takes values('48776', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('41973', '158', '2', 'Spring', 2008, 'C+');
	insert into takes values('49982', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('32954', '408', '2', 'Spring', 2003, 'B-');
	insert into takes values('61402', '852', '1', 'Spring', 2008, 'C+');
	insert into takes values('35721', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('57511', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('44304', '808', '1', 'Fall', 2003, 'B ');
	insert into takes values('82301', '400', '2', 'Fall', 2003, 'B-');
	insert into takes values('47025', '169', '2', 'Fall', 2002, 'A+');
	insert into takes values('86833', '237', '1', 'Spring', 2008, 'C-');
	insert into takes values('1285', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('88085', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('35462', '338', '2', 'Spring', 2006, 'C+');
	insert into takes values('78572', '376', '1', 'Fall', 2006, 'B ');
	insert into takes values('86327', '696', '1', 'Spring', 2002, 'A ');
	insert into takes values('56941', '603', '1', 'Fall', 2003, 'B+');
	insert into takes values('36926', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('36845', '626', '1', 'Fall', 2006, 'B ');
	insert into takes values('30943', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('1812', '338', '1', 'Spring', 2007, 'A+');
	insert into takes values('41211', '400', '1', 'Spring', 2007, 'B ');
	insert into takes values('52157', '949', '1', 'Fall', 2007, 'C ');
	insert into takes values('81883', '626', '1', 'Fall', 2006, 'A ');
	insert into takes values('69081', '338', '1', 'Spring', 2007, 'C-');
	insert into takes values('43032', '599', '1', 'Spring', 2003, 'B-');
	insert into takes values('63449', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('50969', '571', '1', 'Spring', 2004, 'B+');
	insert into takes values('52203', '867', '1', 'Fall', 2006, 'A-');
	insert into takes values('55859', '972', '1', 'Spring', 2009, 'B-');
	insert into takes values('74464', '696', '1', 'Spring', 2002, 'B-');
	insert into takes values('15083', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('22086', '735', '2', 'Spring', 2010, 'B ');
	insert into takes values('23439', '443', '2', 'Spring', 2002, 'A ');
	insert into takes values('30772', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('56276', '867', '1', 'Fall', 2006, 'C+');
	insert into takes values('57787', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('70061', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('48901', '972', '1', 'Spring', 2009, 'B+');
	insert into takes values('83747', '571', '1', 'Spring', 2004, 'C+');
	insert into takes values('65433', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('72979', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('55698', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('89393', '237', '1', 'Spring', 2008, 'C+');
	insert into takes values('11076', '631', '1', 'Spring', 2007, 'B+');
	insert into takes values('70384', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('98120', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('25942', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('993', '626', '1', 'Fall', 2006, 'C+');
	insert into takes values('44271', '571', '1', 'Spring', 2004, 'C+');
	insert into takes values('73328', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('43226', '192', '1', 'Fall', 2002, 'C ');
	insert into takes values('42114', '962', '1', 'Spring', 2008, 'B ');
	insert into takes values('93366', '493', '1', 'Spring', 2010, 'C+');
	insert into takes values('23449', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('14829', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('83747', '959', '1', 'Fall', 2006, 'B ');
	insert into takes values('9256', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('31624', '362', '3', 'Spring', 2008, 'C+');
	insert into takes values('16480', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('20099', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('10917', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('74460', '352', '1', 'Spring', 2006, 'A+');
	insert into takes values('17831', '482', '1', 'Fall', 2005, 'C ');
	insert into takes values('39204', '476', '1', 'Fall', 2010, 'B ');
	insert into takes values('8853', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('81884', '415', '1', 'Fall', 2010, 'C+');
	insert into takes values('78787', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('17676', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('24116', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('38895', '345', '1', 'Spring', 2008, 'A-');
	insert into takes values('64039', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('11126', '408', '1', 'Spring', 2007, 'A-');
	insert into takes values('15980', '960', '1', 'Fall', 2009, 'B+');
	insert into takes values('52523', '626', '1', 'Fall', 2006, 'B ');
	insert into takes values('23475', '482', '1', 'Fall', 2005, 'A ');
	insert into takes values('8192', '486', '1', 'Fall', 2009, 'A ');
	insert into takes values('66969', '304', '1', 'Fall', 2009, 'C+');
	insert into takes values('68396', '334', '1', 'Fall', 2009, 'C-');
	insert into takes values('2133', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('30124', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('6990', '192', '1', 'Fall', 2002, 'C ');
	insert into takes values('90089', '864', '1', 'Spring', 2006, 'C+');
	insert into takes values('52134', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('17086', '960', '2', 'Fall', 2006, 'A ');
	insert into takes values('58085', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('9953', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('71904', '527', '1', 'Fall', 2004, 'C ');
	insert into takes values('63645', '304', '1', 'Fall', 2009, 'C-');
	insert into takes values('94998', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('61444', '545', '1', 'Fall', 2001, 'A+');
	insert into takes values('7204', '802', '1', 'Spring', 2003, 'B+');
	insert into takes values('39881', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('4940', '408', '1', 'Spring', 2007, 'A+');
	insert into takes values('4004', '345', '1', 'Spring', 2008, 'C-');
	insert into takes values('69230', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('91132', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('50206', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('24116', '443', '1', 'Spring', 2010, 'B-');
	insert into takes values('63289', '559', '1', 'Fall', 2002, 'C-');
	insert into takes values('36685', '991', '1', 'Spring', 2008, 'B-');
	insert into takes values('94569', '612', '1', 'Fall', 2007, 'A ');
	insert into takes values('67340', '237', '2', 'Fall', 2009, 'C-');
	insert into takes values('931', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('35523', '571', '1', 'Spring', 2004, 'B+');
	insert into takes values('42092', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('90448', '401', '1', 'Fall', 2003, 'A+');
	insert into takes values('17600', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('11855', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('88884', '421', '1', 'Fall', 2004, 'C+');
	insert into takes values('93354', '105', '1', 'Fall', 2009, 'A+');
	insert into takes values('11095', '345', '1', 'Spring', 2008, 'C+');
	insert into takes values('81566', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('98120', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('43505', '400', '1', 'Spring', 2007, 'A ');
	insert into takes values('54612', '626', '1', 'Fall', 2006, 'A ');
	insert into takes values('69132', '760', '1', 'Spring', 2004, 'A ');
	insert into takes values('64039', '959', '1', 'Fall', 2006, 'C+');
	insert into takes values('28829', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('96895', '313', '1', 'Fall', 2010, 'C ');
	insert into takes values('49205', '735', '1', 'Spring', 2003, 'A-');
	insert into takes values('37734', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('89312', '493', '1', 'Spring', 2010, 'A+');
	insert into takes values('96246', '137', '1', 'Spring', 2002, 'B+');
	insert into takes values('99754', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('57666', '559', '1', 'Fall', 2002, 'B ');
	insert into takes values('67810', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('65753', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('37101', '561', '1', 'Fall', 2006, 'A ');
	insert into takes values('43032', '443', '1', 'Spring', 2010, 'A-');
	insert into takes values('39881', '599', '1', 'Spring', 2003, 'C+');
	insert into takes values('60688', '791', '1', 'Spring', 2006, 'C-');
	insert into takes values('31079', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('63538', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('73072', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('62124', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('54605', '802', '1', 'Spring', 2003, 'A+');
	insert into takes values('72643', '972', '1', 'Spring', 2009, 'C-');
	insert into takes values('15457', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('70362', '631', '1', 'Spring', 2007, 'A ');
	insert into takes values('54612', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('49214', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('33201', '599', '1', 'Spring', 2003, 'A ');
	insert into takes values('25380', '974', '1', 'Fall', 2003, 'A-');
	insert into takes values('43211', '760', '1', 'Spring', 2004, 'A ');
	insert into takes values('86833', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('70828', '304', '1', 'Fall', 2009, 'A ');
	insert into takes values('10727', '545', '1', 'Fall', 2001, 'B-');
	insert into takes values('61356', '338', '1', 'Spring', 2007, 'C-');
	insert into takes values('7620', '352', '1', 'Spring', 2006, 'A+');
	insert into takes values('48247', '735', '1', 'Spring', 2003, 'C+');
	insert into takes values('15283', '239', '1', 'Fall', 2006, 'C-');
	insert into takes values('49618', '313', '1', 'Fall', 2010, 'C-');
	insert into takes values('73606', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('27956', '408', '2', 'Spring', 2003, 'A ');
	insert into takes values('93708', '735', '2', 'Spring', 2010, 'B-');
	insert into takes values('63489', '415', '1', 'Fall', 2010, 'C ');
	insert into takes values('83557', '559', '1', 'Fall', 2002, 'C+');
	insert into takes values('64121', '200', '2', 'Fall', 2002, 'B+');
	insert into takes values('52866', '581', '1', 'Spring', 2005, 'A-');
	insert into takes values('70828', '400', '2', 'Fall', 2003, 'C-');
	insert into takes values('60040', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('61998', '362', '3', 'Spring', 2008, 'C-');
	insert into takes values('57334', '704', '1', 'Spring', 2008, 'B ');
	insert into takes values('19917', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('37715', '496', '1', 'Fall', 2001, 'C ');
	insert into takes values('61444', '304', '1', 'Fall', 2009, 'C+');
	insert into takes values('66229', '972', '1', 'Spring', 2009, 'A ');
	insert into takes values('23392', '581', '1', 'Spring', 2005, 'C ');
	insert into takes values('75510', '604', '1', 'Spring', 2009, 'A ');
	insert into takes values('16405', '443', '1', 'Spring', 2010, 'C+');
	insert into takes values('63538', '496', '1', 'Fall', 2001, 'A+');
	insert into takes values('94142', '338', '2', 'Spring', 2006, 'C+');
	insert into takes values('94894', '445', '1', 'Spring', 2001, 'B+');
	insert into takes values('86375', '319', '1', 'Spring', 2003, 'C+');
	insert into takes values('78332', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('16057', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('87222', '443', '2', 'Spring', 2002, 'B-');
	insert into takes values('55238', '642', '1', 'Fall', 2004, 'B-');
	insert into takes values('792', '802', '1', 'Spring', 2003, 'A+');
	insert into takes values('56057', '972', '1', 'Spring', 2009, 'B ');
	insert into takes values('22226', '949', '1', 'Fall', 2007, 'C ');
	insert into takes values('11530', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('1367', '679', '1', 'Spring', 2010, 'C+');
	insert into takes values('98019', '169', '2', 'Fall', 2002, 'A+');
	insert into takes values('54728', '158', '1', 'Fall', 2008, 'B+');
	insert into takes values('36657', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('59908', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('35220', '604', '1', 'Spring', 2009, 'A-');
	insert into takes values('91788', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('72657', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('60224', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('32345', '401', '1', 'Fall', 2003, 'A+');
	insert into takes values('31266', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('67583', '426', '1', 'Spring', 2006, 'A-');
	insert into takes values('83480', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('55859', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('84865', '426', '1', 'Spring', 2006, 'A ');
	insert into takes values('15578', '482', '1', 'Fall', 2005, 'B ');
	insert into takes values('50664', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('77003', '735', '2', 'Spring', 2010, 'B ');
	insert into takes values('74639', '808', '1', 'Fall', 2003, 'C ');
	insert into takes values('41818', '629', '1', 'Spring', 2003, 'A+');
	insert into takes values('30164', '496', '1', 'Fall', 2001, 'A-');
	insert into takes values('76270', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('38691', '270', '1', 'Spring', 2010, 'A-');
	insert into takes values('21766', '313', '1', 'Fall', 2010, 'A+');
	insert into takes values('30772', '426', '1', 'Spring', 2006, 'A+');
	insert into takes values('16405', '974', '1', 'Fall', 2003, 'B-');
	insert into takes values('34018', '349', '1', 'Spring', 2008, 'A-');
	insert into takes values('69230', '748', '1', 'Fall', 2003, 'A-');
	insert into takes values('19917', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('19917', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('10814', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('63538', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('107', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('51538', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('57083', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('98388', '802', '1', 'Spring', 2003, 'C-');
	insert into takes values('67293', '599', '1', 'Spring', 2003, 'C ');
	insert into takes values('97400', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('71543', '962', '1', 'Spring', 2008, 'B ');
	insert into takes values('17996', '663', '1', 'Spring', 2005, 'C ');
	insert into takes values('19735', '735', '1', 'Spring', 2003, 'A ');
	insert into takes values('50365', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('69783', '696', '1', 'Spring', 2002, 'C ');
	insert into takes values('2561', '927', '1', 'Fall', 2002, 'A-');
	insert into takes values('5005', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('72358', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('63040', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('70807', '591', '1', 'Spring', 2005, 'B ');
	insert into takes values('107', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('67146', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('61414', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('14065', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('72358', '561', '1', 'Fall', 2006, 'B-');
	insert into takes values('987', '864', '1', 'Spring', 2006, 'B ');
	insert into takes values('94178', '401', '1', 'Fall', 2003, 'C-');
	insert into takes values('66090', '482', '1', 'Fall', 2005, 'B ');
	insert into takes values('29435', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('69747', '457', '1', 'Spring', 2001, 'B-');
	insert into takes values('15283', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('41890', '200', '2', 'Fall', 2002, 'C+');
	insert into takes values('90124', '663', '1', 'Spring', 2005, 'B ');
	insert into takes values('56499', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('85366', '158', '2', 'Spring', 2008, 'C+');
	insert into takes values('16528', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('12979', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('84239', '571', '1', 'Spring', 2004, 'C-');
	insert into takes values('91343', '599', '1', 'Spring', 2003, 'A+');
	insert into takes values('69230', '974', '1', 'Fall', 2003, 'C-');
	insert into takes values('38712', '376', '1', 'Fall', 2006, 'A-');
	insert into takes values('123', '802', '1', 'Spring', 2003, 'C-');
	insert into takes values('15457', '808', '1', 'Fall', 2003, 'B-');
	insert into takes values('57135', '867', '2', 'Fall', 2010, 'C-');
	insert into takes values('94998', '169', '2', 'Fall', 2002, 'B ');
	insert into takes values('92776', '496', '1', 'Fall', 2001, 'C ');
	insert into takes values('37581', '242', '1', 'Fall', 2009, 'A ');
	insert into takes values('53165', '258', '1', 'Fall', 2007, 'B+');
	insert into takes values('75423', '702', '1', 'Spring', 2001, 'B ');
	insert into takes values('79352', '626', '1', 'Fall', 2006, 'B ');
	insert into takes values('77898', '893', '1', 'Fall', 2007, 'A ');
	insert into takes values('24809', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('43616', '476', '1', 'Fall', 2010, 'B+');
	insert into takes values('4355', '747', '1', 'Spring', 2004, 'C ');
	insert into takes values('69307', '158', '2', 'Spring', 2008, 'C-');
	insert into takes values('59848', '443', '1', 'Spring', 2010, 'A+');
	insert into takes values('50206', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('18234', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('8807', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('74070', '338', '2', 'Spring', 2006, 'B+');
	insert into takes values('52866', '376', '1', 'Fall', 2006, 'A ');
	insert into takes values('87965', '338', '2', 'Spring', 2006, 'C ');
	insert into takes values('73411', '893', '1', 'Fall', 2007, 'A ');
	insert into takes values('35687', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('96227', '400', '1', 'Spring', 2007, 'A ');
	insert into takes values('58846', '893', '1', 'Fall', 2007, 'A-');
	insert into takes values('21225', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('35138', '242', '1', 'Fall', 2009, 'A+');
	insert into takes values('32376', '591', '1', 'Spring', 2005, 'B+');
	insert into takes values('20489', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('6474', '702', '1', 'Spring', 2001, 'A-');
	insert into takes values('58846', '802', '1', 'Spring', 2003, 'C-');
	insert into takes values('39394', '545', '1', 'Fall', 2001, 'C ');
	insert into takes values('19861', '345', '1', 'Spring', 2008, 'C+');
	insert into takes values('36379', '679', '1', 'Spring', 2010, 'B+');
	insert into takes values('28538', '105', '1', 'Fall', 2009, 'B ');
	insert into takes values('41774', '349', '1', 'Spring', 2008, 'A ');
	insert into takes values('81550', '468', '1', 'Fall', 2005, 'B+');
	insert into takes values('91580', '457', '1', 'Spring', 2001, 'C ');
	insert into takes values('53048', '591', '1', 'Spring', 2005, 'A+');
	insert into takes values('96153', '760', '1', 'Spring', 2004, 'B ');
	insert into takes values('29645', '852', '1', 'Spring', 2008, 'B+');
	insert into takes values('10033', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('54612', '974', '1', 'Fall', 2003, 'A-');
	insert into takes values('90089', '599', '1', 'Spring', 2003, 'B ');
	insert into takes values('68330', '962', '1', 'Spring', 2008, 'A ');
	insert into takes values('40481', '192', '1', 'Fall', 2002, 'C ');
	insert into takes values('35362', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('27898', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('35257', '561', '1', 'Fall', 2006, 'A-');
	insert into takes values('60748', '443', '2', 'Spring', 2002, 'C+');
	insert into takes values('259', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('7973', '702', '1', 'Spring', 2001, 'C+');
	insert into takes values('52872', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('15698', '400', '1', 'Spring', 2007, 'A ');
	insert into takes values('79502', '415', '1', 'Fall', 2010, 'B-');
	insert into takes values('56299', '169', '2', 'Fall', 2002, 'B+');
	insert into takes values('12971', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('49205', '561', '1', 'Fall', 2006, 'A-');
	insert into takes values('88577', '612', '1', 'Fall', 2007, 'B+');
	insert into takes values('26080', '334', '1', 'Fall', 2009, 'B ');
	insert into takes values('69732', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('5961', '445', '1', 'Spring', 2001, 'A-');
	insert into takes values('32065', '408', '2', 'Spring', 2003, 'B-');
	insert into takes values('67017', '237', '1', 'Spring', 2008, 'B+');
	insert into takes values('49618', '408', '2', 'Spring', 2003, 'B ');
	insert into takes values('80610', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('94257', '960', '1', 'Fall', 2009, 'A-');
	insert into takes values('34392', '571', '1', 'Spring', 2004, 'A-');
	insert into takes values('39115', '545', '1', 'Fall', 2001, 'B-');
	insert into takes values('82591', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('85226', '808', '1', 'Fall', 2003, 'B-');
	insert into takes values('61527', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('9183', '496', '1', 'Fall', 2001, 'C-');
	insert into takes values('5925', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('80113', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('43616', '642', '1', 'Fall', 2004, 'B+');
	insert into takes values('29863', '960', '2', 'Fall', 2006, 'A ');
	insert into takes values('41818', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('15517', '974', '1', 'Fall', 2003, 'A-');
	insert into takes values('22086', '169', '2', 'Fall', 2002, 'A+');
	insert into takes values('75252', '400', '2', 'Fall', 2003, 'B-');
	insert into takes values('96227', '694', '1', 'Fall', 2002, 'B-');
	insert into takes values('47824', '843', '1', 'Fall', 2010, 'B-');
	insert into takes values('44551', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('43348', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('19203', '408', '1', 'Spring', 2007, 'A+');
	insert into takes values('64155', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('90220', '793', '1', 'Spring', 2002, 'A-');
	insert into takes values('11682', '960', '2', 'Fall', 2006, 'C+');
	insert into takes values('93354', '867', '2', 'Fall', 2010, 'A+');
	insert into takes values('53172', '735', '2', 'Spring', 2010, 'A+');
	insert into takes values('2967', '599', '1', 'Spring', 2003, 'B ');
	insert into takes values('60267', '443', '1', 'Spring', 2010, 'A+');
	insert into takes values('26494', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('68070', '991', '1', 'Spring', 2008, 'C-');
	insert into takes values('75513', '200', '1', 'Spring', 2007, 'B+');
	insert into takes values('12941', '239', '1', 'Fall', 2006, 'A-');
	insert into takes values('95697', '158', '2', 'Spring', 2008, 'C-');
	insert into takes values('544', '793', '1', 'Spring', 2002, 'C-');
	insert into takes values('75794', '443', '1', 'Spring', 2010, 'A-');
	insert into takes values('51723', '345', '1', 'Spring', 2008, 'B-');
	insert into takes values('54296', '626', '1', 'Fall', 2006, 'A-');
	insert into takes values('92385', '443', '2', 'Spring', 2002, 'C-');
	insert into takes values('24387', '158', '1', 'Fall', 2008, 'A+');
	insert into takes values('26730', '362', '3', 'Spring', 2008, 'A+');
	insert into takes values('37219', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('95850', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('3163', '270', '1', 'Spring', 2010, 'C-');
	insert into takes values('56299', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('26881', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('99271', '867', '2', 'Fall', 2010, 'A+');
	insert into takes values('25068', '169', '2', 'Fall', 2002, 'C ');
	insert into takes values('99780', '867', '2', 'Fall', 2010, 'A-');
	insert into takes values('86806', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('78892', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('24865', '313', '1', 'Fall', 2010, 'A+');
	insert into takes values('87246', '559', '1', 'Fall', 2002, 'B ');
	insert into takes values('96085', '795', '1', 'Spring', 2004, 'B ');
	insert into takes values('65205', '468', '1', 'Fall', 2005, 'C+');
	insert into takes values('64593', '270', '1', 'Spring', 2010, 'B-');
	insert into takes values('20244', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('14432', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('16543', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('19362', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('49792', '461', '1', 'Fall', 2002, 'C-');
	insert into takes values('29399', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('98870', '493', '1', 'Spring', 2010, 'B ');
	insert into takes values('73606', '631', '1', 'Spring', 2007, 'B+');
	insert into takes values('43658', '760', '1', 'Spring', 2004, 'B+');
	insert into takes values('76057', '696', '1', 'Spring', 2002, 'A ');
	insert into takes values('73602', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('75794', '696', '1', 'Spring', 2002, 'A-');
	insert into takes values('64140', '313', '1', 'Fall', 2010, 'B-');
	insert into takes values('71628', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('48462', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('74974', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('97400', '626', '1', 'Fall', 2006, 'B+');
	insert into takes values('66356', '735', '2', 'Spring', 2010, 'A-');
	insert into takes values('86661', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('93125', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('28361', '304', '1', 'Fall', 2009, 'C-');
	insert into takes values('32119', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('13217', '960', '2', 'Fall', 2006, 'C+');
	insert into takes values('62705', '496', '1', 'Fall', 2001, 'C ');
	insert into takes values('89104', '893', '1', 'Fall', 2007, 'C ');
	insert into takes values('29645', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('49450', '795', '1', 'Spring', 2004, 'B ');
	insert into takes values('69850', '338', '1', 'Spring', 2007, 'B ');
	insert into takes values('48053', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('58326', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('52471', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('20180', '345', '1', 'Spring', 2008, 'C ');
	insert into takes values('27002', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('48423', '875', '1', 'Spring', 2005, 'C ');
	insert into takes values('11262', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('50944', '679', '1', 'Spring', 2010, 'B-');
	insert into takes values('38668', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('51997', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('44881', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('65979', '486', '1', 'Fall', 2009, 'B ');
	insert into takes values('70828', '345', '1', 'Spring', 2008, 'A+');
	insert into takes values('98984', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('86127', '843', '1', 'Fall', 2010, 'C-');
	insert into takes values('29260', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('38548', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('82301', '527', '1', 'Fall', 2004, 'C+');
	insert into takes values('63645', '604', '1', 'Spring', 2009, 'A ');
	insert into takes values('65676', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('33338', '421', '1', 'Fall', 2004, 'C ');
	insert into takes values('71287', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('3493', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('16631', '169', '2', 'Fall', 2002, 'A+');
	insert into takes values('71768', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('34055', '421', '1', 'Fall', 2004, 'C ');
	insert into takes values('35357', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('82974', '843', '1', 'Fall', 2010, 'C ');
	insert into takes values('21126', '808', '1', 'Fall', 2003, 'A+');
	insert into takes values('13753', '791', '1', 'Spring', 2006, 'C+');
	insert into takes values('56124', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('26147', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('49759', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('69632', '802', '1', 'Spring', 2003, 'A+');
	insert into takes values('80113', '200', '1', 'Spring', 2007, 'B+');
	insert into takes values('57666', '875', '1', 'Spring', 2005, 'C-');
	insert into takes values('46451', '864', '1', 'Spring', 2006, 'C+');
	insert into takes values('26695', '169', '2', 'Fall', 2002, 'B+');
	insert into takes values('16347', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('57160', '237', '1', 'Spring', 2008, 'B-');
	insert into takes values('82687', '443', '2', 'Spring', 2002, 'B ');
	insert into takes values('72768', '793', '1', 'Spring', 2002, 'C+');
	insert into takes values('38548', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('76291', '169', '2', 'Fall', 2002, 'B+');
	insert into takes values('87784', '461', '1', 'Fall', 2002, 'B+');
	insert into takes values('67018', '852', '1', 'Spring', 2008, 'C-');
	insert into takes values('99694', '852', '1', 'Spring', 2008, 'A ');
	insert into takes values('13028', '599', '1', 'Spring', 2003, 'B-');
	insert into takes values('40044', '875', '1', 'Spring', 2005, 'B+');
	insert into takes values('9183', '158', '2', 'Spring', 2008, 'A ');
	insert into takes values('31690', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('66269', '496', '1', 'Fall', 2001, 'B+');
	insert into takes values('914', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('78792', '867', '2', 'Fall', 2010, 'C-');
	insert into takes values('23934', '169', '2', 'Fall', 2002, 'C ');
	insert into takes values('66813', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('36019', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('72006', '200', '1', 'Spring', 2007, 'B-');
	insert into takes values('75299', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('71878', '642', '1', 'Fall', 2004, 'B+');
	insert into takes values('12069', '105', '1', 'Fall', 2009, 'A+');
	insert into takes values('75273', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('91343', '274', '1', 'Fall', 2002, 'C+');
	insert into takes values('79210', '735', '1', 'Spring', 2003, 'A-');
	insert into takes values('58413', '349', '1', 'Spring', 2008, 'A ');
	insert into takes values('83039', '443', '1', 'Spring', 2010, 'C ');
	insert into takes values('19824', '408', '2', 'Spring', 2003, 'C-');
	insert into takes values('85505', '631', '1', 'Spring', 2007, 'A ');
	insert into takes values('81207', '793', '1', 'Spring', 2002, 'C ');
	insert into takes values('14829', '603', '1', 'Fall', 2003, 'B ');
	insert into takes values('17339', '258', '1', 'Fall', 2007, 'B+');
	insert into takes values('30334', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('89312', '527', '1', 'Fall', 2004, 'C-');
	insert into takes values('39394', '443', '2', 'Spring', 2002, 'B-');
	insert into takes values('71768', '626', '1', 'Fall', 2006, 'A ');
	insert into takes values('15024', '696', '1', 'Spring', 2002, 'A-');
	insert into takes values('73387', '345', '1', 'Spring', 2008, 'C-');
	insert into takes values('67407', '696', '1', 'Spring', 2002, 'C-');
	insert into takes values('667', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('81396', '376', '1', 'Fall', 2006, 'B+');
	insert into takes values('19342', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('91132', '408', '2', 'Spring', 2003, 'B-');
	insert into takes values('80113', '137', '1', 'Spring', 2002, 'A ');
	insert into takes values('86934', '696', '1', 'Spring', 2002, 'B+');
	insert into takes values('20540', '237', '1', 'Spring', 2008, 'B ');
	insert into takes values('10033', '486', '1', 'Fall', 2009, 'C ');
	insert into takes values('90234', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('7123', '795', '1', 'Spring', 2004, 'B+');
	insert into takes values('75938', '704', '1', 'Spring', 2008, 'C-');
	insert into takes values('43130', '581', '1', 'Spring', 2005, 'C-');
	insert into takes values('92864', '408', '1', 'Spring', 2007, 'A ');
	insert into takes values('81028', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('62784', '604', '1', 'Spring', 2009, 'A-');
	insert into takes values('71389', '972', '1', 'Spring', 2009, 'A-');
	insert into takes values('39876', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('27430', '443', '2', 'Spring', 2002, 'C ');
	insert into takes values('1285', '748', '1', 'Fall', 2003, 'B-');
	insert into takes values('41938', '313', '1', 'Fall', 2010, 'C ');
	insert into takes values('96615', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('18775', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('94697', '258', '1', 'Fall', 2007, 'C-');
	insert into takes values('62754', '991', '1', 'Spring', 2008, 'B-');
	insert into takes values('282', '105', '1', 'Fall', 2009, 'C+');
	insert into takes values('81396', '304', '1', 'Fall', 2009, 'B+');
	insert into takes values('73602', '334', '1', 'Fall', 2009, 'B ');
	insert into takes values('51723', '702', '1', 'Spring', 2001, 'B ');
	insert into takes values('30341', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('66763', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('7861', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('65329', '461', '1', 'Fall', 2002, 'B ');
	insert into takes values('39612', '852', '1', 'Spring', 2008, 'C ');
	insert into takes values('17207', '612', '1', 'Fall', 2007, 'C ');
	insert into takes values('31486', '760', '1', 'Spring', 2004, 'B-');
	insert into takes values('41832', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('31337', '663', '1', 'Spring', 2005, 'A-');
	insert into takes values('34569', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('6400', '237', '1', 'Spring', 2008, 'B ');
	insert into takes values('72055', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('2201', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('6710', '642', '1', 'Fall', 2004, 'A-');
	insert into takes values('84410', '867', '1', 'Fall', 2006, 'A+');
	insert into takes values('9953', '581', '1', 'Spring', 2005, 'B+');
	insert into takes values('24796', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('56089', '962', '1', 'Spring', 2008, 'B-');
	insert into takes values('52523', '400', '2', 'Fall', 2003, 'A ');
	insert into takes values('87280', '443', '1', 'Spring', 2010, 'A-');
	insert into takes values('27366', '169', '2', 'Fall', 2002, 'C ');
	insert into takes values('71529', '960', '1', 'Fall', 2009, 'C-');
	insert into takes values('84808', '493', '1', 'Spring', 2010, 'A-');
	insert into takes values('39925', '631', '1', 'Spring', 2007, 'A ');
	insert into takes values('41211', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('65241', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('45300', '626', '1', 'Fall', 2006, 'B-');
	insert into takes values('61065', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('4004', '270', '1', 'Spring', 2010, 'A+');
	insert into takes values('25942', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('44706', '791', '1', 'Spring', 2006, 'B+');
	insert into takes values('19862', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('1285', '960', '2', 'Fall', 2006, 'B+');
	insert into takes values('25785', '599', '1', 'Spring', 2003, 'B ');
	insert into takes values('97590', '237', '2', 'Fall', 2009, 'C-');
	insert into takes values('63090', '991', '1', 'Spring', 2008, 'A ');
	insert into takes values('37101', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('27950', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('31761', '679', '1', 'Spring', 2010, 'A ');
	insert into takes values('66259', '893', '1', 'Fall', 2007, 'A+');
	insert into takes values('91978', '493', '1', 'Spring', 2010, 'C-');
	insert into takes values('49813', '461', '1', 'Fall', 2002, 'B+');
	insert into takes values('40276', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('87784', '493', '1', 'Spring', 2010, 'C ');
	insert into takes values('95089', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('86344', '867', '1', 'Fall', 2006, 'C+');
	insert into takes values('57156', '493', '1', 'Spring', 2010, 'C-');
	insert into takes values('44998', '400', '1', 'Spring', 2007, 'C-');
	insert into takes values('90004', '415', '1', 'Fall', 2010, 'C+');
	insert into takes values('4345', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('11262', '415', '1', 'Fall', 2010, 'C ');
	insert into takes values('94846', '496', '1', 'Fall', 2001, 'A-');
	insert into takes values('59172', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('11419', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('50966', '843', '1', 'Fall', 2010, 'A ');
	insert into takes values('20244', '561', '1', 'Fall', 2006, 'A-');
	insert into takes values('51862', '158', '1', 'Fall', 2008, 'C ');
	insert into takes values('84865', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('17600', '242', '1', 'Fall', 2009, 'C-');
	insert into takes values('36791', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('87280', '338', '1', 'Spring', 2007, 'C ');
	insert into takes values('13217', '527', '1', 'Fall', 2004, 'B+');
	insert into takes values('43432', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('15698', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('92703', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('32119', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('86833', '545', '1', 'Fall', 2001, 'B ');
	insert into takes values('22417', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('57334', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('11966', '962', '1', 'Spring', 2008, 'C-');
	insert into takes values('8252', '304', '1', 'Fall', 2009, 'C+');
	insert into takes values('18775', '169', '2', 'Fall', 2002, 'B+');
	insert into takes values('90220', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('2201', '852', '1', 'Spring', 2008, 'B+');
	insert into takes values('92839', '527', '1', 'Fall', 2004, 'C+');
	insert into takes values('45720', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('45200', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('99463', '679', '1', 'Spring', 2010, 'B ');
	insert into takes values('8251', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('46260', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('72669', '461', '1', 'Fall', 2002, 'C-');
	insert into takes values('58606', '702', '1', 'Spring', 2001, 'C+');
	insert into takes values('76895', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('20002', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('65038', '679', '1', 'Spring', 2010, 'B-');
	insert into takes values('5393', '457', '1', 'Spring', 2001, 'A ');
	insert into takes values('84654', '626', '1', 'Fall', 2006, 'B-');
	insert into takes values('21692', '408', '2', 'Spring', 2003, 'C-');
	insert into takes values('31341', '626', '1', 'Fall', 2006, 'A ');
	insert into takes values('9605', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('21126', '927', '1', 'Fall', 2002, 'C+');
	insert into takes values('69132', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('62749', '158', '1', 'Fall', 2008, 'A+');
	insert into takes values('89759', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('22467', '747', '1', 'Spring', 2004, 'B-');
	insert into takes values('85809', '242', '1', 'Fall', 2009, 'A-');
	insert into takes values('16593', '408', '1', 'Spring', 2007, 'C-');
	insert into takes values('32217', '457', '1', 'Spring', 2001, 'A+');
	insert into takes values('58172', '599', '1', 'Spring', 2003, 'C ');
	insert into takes values('22179', '962', '1', 'Spring', 2008, 'C-');
	insert into takes values('32245', '493', '1', 'Spring', 2010, 'B ');
	insert into takes values('89551', '366', '1', 'Fall', 2005, 'C-');
	insert into takes values('51416', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('75513', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('28019', '696', '1', 'Spring', 2002, 'A+');
	insert into takes values('59539', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('75560', '400', '1', 'Spring', 2007, 'C ');
	insert into takes values('21552', '962', '1', 'Spring', 2008, 'C+');
	insert into takes values('39881', '408', '2', 'Spring', 2003, 'C ');
	insert into takes values('73394', '445', '1', 'Spring', 2001, 'B+');
	insert into takes values('48471', '791', '1', 'Spring', 2006, 'C-');
	insert into takes values('46066', '875', '1', 'Spring', 2005, 'B+');
	insert into takes values('95225', '468', '2', 'Fall', 2007, 'A-');
	insert into takes values('19603', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('14668', '476', '1', 'Fall', 2010, 'C ');
	insert into takes values('12979', '612', '1', 'Fall', 2007, 'B+');
	insert into takes values('71426', '561', '1', 'Fall', 2006, 'B+');
	insert into takes values('42843', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('64121', '496', '1', 'Fall', 2001, 'B+');
	insert into takes values('95175', '237', '2', 'Fall', 2009, 'B+');
	insert into takes values('32119', '338', '1', 'Spring', 2007, 'B ');
	insert into takes values('28409', '735', '2', 'Spring', 2010, 'A ');
	insert into takes values('51768', '893', '1', 'Fall', 2007, 'B+');
	insert into takes values('44816', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('37521', '893', '1', 'Fall', 2007, 'B-');
	insert into takes values('29140', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('94620', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('64164', '679', '1', 'Spring', 2010, 'C-');
	insert into takes values('38691', '482', '1', 'Fall', 2005, 'A+');
	insert into takes values('82301', '237', '2', 'Fall', 2009, 'B+');
	insert into takes values('107', '457', '1', 'Spring', 2001, 'A ');
	insert into takes values('12326', '852', '1', 'Spring', 2008, 'C+');
	insert into takes values('19220', '237', '2', 'Fall', 2009, 'A-');
	insert into takes values('57334', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('1826', '461', '1', 'Fall', 2002, 'C+');
	insert into takes values('33651', '748', '1', 'Fall', 2003, 'A-');
	insert into takes values('88417', '400', '2', 'Fall', 2003, 'B-');
	insert into takes values('27002', '959', '1', 'Fall', 2006, 'A ');
	insert into takes values('16405', '991', '1', 'Spring', 2008, 'B ');
	insert into takes values('7498', '581', '1', 'Spring', 2005, 'A+');
	insert into takes values('66813', '960', '2', 'Fall', 2006, 'A ');
	insert into takes values('80113', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('90041', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('52471', '626', '1', 'Fall', 2006, 'B ');
	insert into takes values('14621', '962', '1', 'Spring', 2008, 'A ');
	insert into takes values('95205', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('95366', '793', '1', 'Spring', 2002, 'A-');
	insert into takes values('3693', '105', '1', 'Fall', 2009, 'A+');
	insert into takes values('80610', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('97435', '137', '1', 'Spring', 2002, 'C-');
	insert into takes values('75560', '735', '1', 'Spring', 2003, 'A-');
	insert into takes values('25380', '468', '1', 'Fall', 2005, 'C+');
	insert into takes values('52120', '105', '2', 'Fall', 2002, 'A+');
	insert into takes values('67021', '408', '2', 'Spring', 2003, 'B-');
	insert into takes values('23311', '545', '1', 'Fall', 2001, 'A+');
	insert into takes values('67542', '362', '1', 'Fall', 2005, 'C ');
	insert into takes values('52656', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('62487', '679', '1', 'Spring', 2010, 'B+');
	insert into takes values('46450', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('43989', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('7514', '486', '1', 'Fall', 2009, 'A ');
	insert into takes values('86001', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('40044', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('89759', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('11095', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('44706', '581', '1', 'Spring', 2005, 'A ');
	insert into takes values('62832', '408', '2', 'Spring', 2003, 'B-');
	insert into takes values('7123', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('20489', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('13023', '692', '1', 'Spring', 2010, 'B-');
	insert into takes values('31035', '362', '2', 'Fall', 2006, 'B-');
	insert into takes values('22254', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('67542', '793', '1', 'Spring', 2002, 'C ');
	insert into takes values('31086', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('64164', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('38691', '974', '1', 'Fall', 2003, 'C ');
	insert into takes values('71904', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('65753', '692', '1', 'Spring', 2010, 'C-');
	insert into takes values('44998', '893', '1', 'Fall', 2007, 'B-');
	insert into takes values('88169', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('17424', '486', '1', 'Fall', 2009, 'C ');
	insert into takes values('73213', '852', '1', 'Spring', 2008, 'B+');
	insert into takes values('66054', '352', '1', 'Spring', 2006, 'C ');
	insert into takes values('57511', '493', '1', 'Spring', 2010, 'B+');
	insert into takes values('31442', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('57962', '366', '1', 'Fall', 2005, 'C ');
	insert into takes values('49873', '408', '1', 'Spring', 2007, 'A+');
	insert into takes values('44258', '338', '1', 'Spring', 2007, 'C ');
	insert into takes values('56080', '496', '1', 'Fall', 2001, 'B ');
	insert into takes values('32483', '949', '1', 'Fall', 2007, 'C-');
	insert into takes values('98619', '400', '1', 'Spring', 2007, 'A ');
	insert into takes values('54672', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('20814', '893', '1', 'Fall', 2007, 'A+');
	insert into takes values('23500', '401', '1', 'Fall', 2003, 'B+');
	insert into takes values('60762', '242', '1', 'Fall', 2009, 'B+');
	insert into takes values('47630', '702', '1', 'Spring', 2001, 'C-');
	insert into takes values('21556', '561', '1', 'Fall', 2006, 'B+');
	insert into takes values('32345', '735', '2', 'Spring', 2010, 'B ');
	insert into takes values('79210', '457', '1', 'Spring', 2001, 'B+');
	insert into takes values('28299', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('68999', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('85505', '679', '1', 'Spring', 2010, 'A ');
	insert into takes values('28952', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('44706', '972', '1', 'Spring', 2009, 'C ');
	insert into takes values('63289', '663', '1', 'Spring', 2005, 'B ');
	insert into takes values('74672', '313', '1', 'Fall', 2010, 'C+');
	insert into takes values('61166', '461', '1', 'Fall', 2002, 'B ');
	insert into takes values('75928', '158', '1', 'Fall', 2008, 'A ');
	insert into takes values('9495', '242', '1', 'Fall', 2009, 'A-');
	insert into takes values('48640', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('5399', '604', '1', 'Spring', 2009, 'B-');
	insert into takes values('60748', '338', '2', 'Spring', 2006, 'A-');
	insert into takes values('46035', '972', '1', 'Spring', 2009, 'A ');
	insert into takes values('86806', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('13290', '304', '1', 'Fall', 2009, 'A+');
	insert into takes values('91197', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('74840', '443', '1', 'Spring', 2010, 'A+');
	insert into takes values('48469', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('88884', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('67583', '352', '1', 'Spring', 2006, 'B ');
	insert into takes values('32886', '426', '1', 'Spring', 2006, 'B ');
	insert into takes values('5414', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('93125', '319', '1', 'Spring', 2003, 'B ');
	insert into takes values('37809', '793', '1', 'Spring', 2002, 'B+');
	insert into takes values('38696', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('73908', '313', '1', 'Fall', 2010, 'C ');
	insert into takes values('7732', '489', '1', 'Fall', 2007, 'C+');
	insert into takes values('82970', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('41345', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('74672', '561', '1', 'Fall', 2006, 'C-');
	insert into takes values('46981', '626', '1', 'Fall', 2006, 'C ');
	insert into takes values('72657', '561', '1', 'Fall', 2006, 'B+');
	insert into takes values('50039', '808', '1', 'Fall', 2003, 'B-');
	insert into takes values('40303', '482', '1', 'Fall', 2005, 'A-');
	insert into takes values('41683', '893', '1', 'Fall', 2007, 'C+');
	insert into takes values('34195', '603', '1', 'Fall', 2003, 'B+');
	insert into takes values('88793', '362', '1', 'Fall', 2005, 'C-');
	insert into takes values('79502', '843', '1', 'Fall', 2010, 'A ');
	insert into takes values('76759', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('931', '867', '1', 'Fall', 2006, 'A ');
	insert into takes values('31302', '974', '1', 'Fall', 2003, 'C ');
	insert into takes values('96085', '313', '1', 'Fall', 2010, 'C-');
	insert into takes values('80976', '791', '1', 'Spring', 2006, 'C+');
	insert into takes values('94257', '400', '2', 'Fall', 2003, 'A+');
	insert into takes values('56849', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('50467', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('75116', '545', '1', 'Fall', 2001, 'A-');
	insert into takes values('95029', '626', '1', 'Fall', 2006, 'C ');
	insert into takes values('40276', '169', '1', 'Spring', 2007, 'B+');
	insert into takes values('17128', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('12362', '352', '1', 'Spring', 2006, 'B ');
	insert into takes values('64039', '793', '1', 'Spring', 2002, 'B+');
	insert into takes values('67660', '400', '2', 'Fall', 2003, 'C-');
	insert into takes values('38371', '960', '2', 'Fall', 2006, 'C-');
	insert into takes values('39619', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('86552', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('22057', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('75513', '401', '1', 'Fall', 2003, 'C ');
	insert into takes values('85887', '237', '1', 'Spring', 2008, 'A-');
	insert into takes values('37454', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('31554', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('53165', '443', '2', 'Spring', 2002, 'B ');
	insert into takes values('92464', '345', '1', 'Spring', 2008, 'B ');
	insert into takes values('22345', '604', '1', 'Spring', 2009, 'B-');
	insert into takes values('29192', '493', '1', 'Spring', 2010, 'A+');
	insert into takes values('51538', '457', '1', 'Spring', 2001, 'C ');
	insert into takes values('50365', '445', '1', 'Spring', 2001, 'B+');
	insert into takes values('4508', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('94836', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('86969', '242', '1', 'Fall', 2009, 'A ');
	insert into takes values('41491', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('86969', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('72055', '338', '2', 'Spring', 2006, 'B ');
	insert into takes values('67310', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('88169', '843', '1', 'Fall', 2010, 'B+');
	insert into takes values('37869', '559', '1', 'Fall', 2002, 'A ');
	insert into takes values('58170', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('58326', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('77244', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('65979', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('34386', '962', '1', 'Spring', 2008, 'B ');
	insert into takes values('93508', '443', '2', 'Spring', 2002, 'B+');
	insert into takes values('32881', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('6209', '949', '1', 'Fall', 2007, 'A-');
	insert into takes values('27950', '791', '1', 'Spring', 2006, 'A-');
	insert into takes values('33460', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('40481', '239', '1', 'Fall', 2006, 'B ');
	insert into takes values('25468', '843', '1', 'Fall', 2010, 'A-');
	insert into takes values('93061', '599', '1', 'Spring', 2003, 'C+');
	insert into takes values('31035', '338', '2', 'Spring', 2006, 'A ');
	insert into takes values('88525', '795', '1', 'Spring', 2004, 'B-');
	insert into takes values('99348', '631', '1', 'Spring', 2007, 'C+');
	insert into takes values('75560', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('39580', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('60748', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('8986', '489', '1', 'Fall', 2007, 'A ');
	insert into takes values('34542', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('71543', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('20084', '960', '1', 'Fall', 2009, 'A+');
	insert into takes values('8483', '349', '1', 'Spring', 2008, 'A ');
	insert into takes values('35721', '702', '1', 'Spring', 2001, 'C+');
	insert into takes values('4860', '239', '1', 'Fall', 2006, 'C-');
	insert into takes values('68280', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('95027', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('54672', '962', '1', 'Spring', 2008, 'B ');
	insert into takes values('85849', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('19293', '867', '2', 'Fall', 2010, 'A+');
	insert into takes values('22086', '972', '1', 'Spring', 2009, 'B ');
	insert into takes values('50013', '237', '1', 'Spring', 2008, 'C+');
	insert into takes values('88801', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('80254', '808', '1', 'Fall', 2003, 'A+');
	insert into takes values('4940', '679', '1', 'Spring', 2010, 'B ');
	insert into takes values('86981', '974', '1', 'Fall', 2003, 'C ');
	insert into takes values('82697', '875', '1', 'Spring', 2005, 'B-');
	insert into takes values('37581', '476', '1', 'Fall', 2010, 'C-');
	insert into takes values('70061', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('7020', '408', '1', 'Spring', 2007, 'A-');
	insert into takes values('11055', '105', '2', 'Fall', 2002, 'B+');
	insert into takes values('61332', '443', '2', 'Spring', 2002, 'B-');
	insert into takes values('28299', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('18821', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('32881', '158', '2', 'Spring', 2008, 'A-');
	insert into takes values('74163', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('68516', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('39704', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('39927', '237', '1', 'Spring', 2008, 'A+');
	insert into takes values('39241', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('23500', '376', '1', 'Fall', 2006, 'A ');
	insert into takes values('7854', '927', '1', 'Fall', 2002, 'B-');
	insert into takes values('29091', '527', '1', 'Fall', 2004, 'A ');
	insert into takes values('25725', '626', '1', 'Fall', 2006, 'C ');
	insert into takes values('98140', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('52494', '603', '1', 'Fall', 2003, 'B ');
	insert into takes values('44271', '468', '1', 'Fall', 2005, 'B ');
	insert into takes values('2419', '349', '1', 'Spring', 2008, 'C-');
	insert into takes values('17397', '571', '1', 'Spring', 2004, 'B+');
	insert into takes values('10838', '457', '1', 'Spring', 2001, 'A ');
	insert into takes values('46981', '338', '1', 'Spring', 2007, 'A-');
	insert into takes values('51538', '443', '1', 'Spring', 2010, 'A-');
	insert into takes values('90567', '461', '1', 'Fall', 2002, 'B ');
	insert into takes values('66813', '345', '1', 'Spring', 2008, 'C-');
	insert into takes values('53048', '258', '1', 'Fall', 2007, 'A+');
	insert into takes values('27043', '366', '1', 'Fall', 2005, 'C ');
	insert into takes values('16467', '468', '1', 'Fall', 2005, 'B+');
	insert into takes values('7035', '702', '1', 'Spring', 2001, 'B ');
	insert into takes values('50873', '457', '1', 'Spring', 2001, 'C+');
	insert into takes values('35935', '626', '1', 'Fall', 2006, 'B ');
	insert into takes values('32483', '991', '1', 'Spring', 2008, 'C-');
	insert into takes values('288', '237', '1', 'Spring', 2008, 'C+');
	insert into takes values('92776', '319', '1', 'Spring', 2003, 'A-');
	insert into takes values('1232', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('83314', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('12941', '735', '1', 'Spring', 2003, 'A-');
	insert into takes values('96722', '893', '1', 'Fall', 2007, 'A+');
	insert into takes values('63288', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('92693', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('99289', '559', '1', 'Fall', 2002, 'B+');
	insert into takes values('43993', '400', '2', 'Fall', 2003, 'A+');
	insert into takes values('47025', '169', '1', 'Spring', 2007, 'C ');
	insert into takes values('8022', '949', '1', 'Fall', 2007, 'A-');
	insert into takes values('68278', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('88045', '362', '2', 'Fall', 2006, 'A-');
	insert into takes values('89551', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('66293', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('2133', '795', '1', 'Spring', 2004, 'B+');
	insert into takes values('74460', '334', '1', 'Fall', 2009, 'B+');
	insert into takes values('19050', '200', '2', 'Fall', 2002, 'C+');
	insert into takes values('36657', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('68096', '571', '1', 'Spring', 2004, 'B+');
	insert into takes values('97042', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('78758', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('71287', '169', '2', 'Fall', 2002, 'A-');
	insert into takes values('6287', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('46155', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('54620', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('84702', '274', '1', 'Fall', 2002, 'B ');
	insert into takes values('59673', '468', '2', 'Fall', 2007, 'A-');
	insert into takes values('19582', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('72768', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('64550', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('59539', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('11422', '559', '1', 'Fall', 2002, 'C+');
	insert into takes values('81031', '105', '2', 'Fall', 2002, 'A-');
	insert into takes values('38895', '489', '1', 'Fall', 2007, 'A-');
	insert into takes values('88884', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('11855', '482', '1', 'Fall', 2005, 'B-');
	insert into takes values('88417', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('64013', '400', '1', 'Spring', 2007, 'A ');
	insert into takes values('32886', '852', '1', 'Spring', 2008, 'B-');
	insert into takes values('78314', '612', '1', 'Fall', 2007, 'B-');
	insert into takes values('1285', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('22325', '400', '2', 'Fall', 2003, 'A-');
	insert into takes values('81610', '760', '1', 'Spring', 2004, 'B-');
	insert into takes values('92417', '696', '1', 'Spring', 2002, 'B ');
	insert into takes values('57377', '400', '1', 'Spring', 2007, 'A-');
	insert into takes values('3640', '702', '1', 'Spring', 2001, 'B ');
	insert into takes values('72643', '158', '1', 'Fall', 2008, 'C ');
	insert into takes values('11441', '408', '1', 'Spring', 2007, 'A ');
	insert into takes values('57190', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('40080', '959', '1', 'Fall', 2006, 'A ');
	insert into takes values('75299', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('51549', '631', '1', 'Spring', 2007, 'C+');
	insert into takes values('96193', '493', '1', 'Spring', 2010, 'A ');
	insert into takes values('29140', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('43123', '400', '2', 'Fall', 2003, 'B-');
	insert into takes values('36052', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('35', '962', '1', 'Spring', 2008, 'C-');
	insert into takes values('95225', '962', '1', 'Spring', 2008, 'B ');
	insert into takes values('49503', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('52019', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('38668', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('99189', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('65443', '400', '1', 'Spring', 2007, 'C+');
	insert into takes values('46441', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('38121', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('123', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('52291', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('81896', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('19220', '200', '1', 'Spring', 2007, 'C ');
	insert into takes values('16753', '696', '1', 'Spring', 2002, 'B ');
	insert into takes values('25552', '974', '1', 'Fall', 2003, 'A+');
	insert into takes values('63039', '603', '1', 'Fall', 2003, 'B ');
	insert into takes values('87624', '158', '2', 'Spring', 2008, 'C ');
	insert into takes values('70918', '345', '1', 'Spring', 2008, 'A-');
	insert into takes values('96153', '468', '1', 'Fall', 2005, 'A-');
	insert into takes values('51416', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('25468', '169', '1', 'Spring', 2007, 'A-');
	insert into takes values('72528', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('67310', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('95225', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('32886', '843', '1', 'Fall', 2010, 'A-');
	insert into takes values('41091', '927', '1', 'Fall', 2002, 'C-');
	insert into takes values('17086', '258', '1', 'Fall', 2007, 'B+');
	insert into takes values('645', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('62716', '486', '1', 'Fall', 2009, 'B ');
	insert into takes values('61166', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('94620', '400', '2', 'Fall', 2003, 'C+');
	insert into takes values('40992', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('84654', '692', '1', 'Spring', 2010, 'C-');
	insert into takes values('77021', '482', '1', 'Fall', 2005, 'B ');
	insert into takes values('12666', '400', '2', 'Fall', 2003, 'A-');
	insert into takes values('51084', '242', '1', 'Fall', 2009, 'B+');
	insert into takes values('71025', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('22142', '461', '1', 'Fall', 2002, 'B ');
	insert into takes values('32368', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('82083', '482', '1', 'Fall', 2005, 'A-');
	insert into takes values('51084', '345', '1', 'Spring', 2008, 'C+');
	insert into takes values('64196', '105', '2', 'Fall', 2002, 'B-');
	insert into takes values('47677', '962', '1', 'Spring', 2008, 'C+');
	insert into takes values('99399', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('23457', '875', '1', 'Spring', 2005, 'A ');
	insert into takes values('11095', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('19050', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('34542', '604', '1', 'Spring', 2009, 'A-');
	insert into takes values('24865', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('898', '457', '1', 'Spring', 2001, 'A ');
	insert into takes values('84495', '559', '1', 'Fall', 2002, 'C-');
	insert into takes values('50583', '991', '1', 'Spring', 2008, 'C-');
	insert into takes values('69581', '960', '2', 'Fall', 2006, 'C+');
	insert into takes values('44706', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('557', '893', '1', 'Fall', 2007, 'B+');
	insert into takes values('11194', '445', '1', 'Spring', 2001, 'A-');
	insert into takes values('98056', '158', '1', 'Fall', 2008, 'A ');
	insert into takes values('45300', '581', '1', 'Spring', 2005, 'B+');
	insert into takes values('60366', '559', '1', 'Fall', 2002, 'A-');
	insert into takes values('43993', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('25785', '991', '1', 'Spring', 2008, 'A ');
	insert into takes values('35220', '702', '1', 'Spring', 2001, 'A-');
	insert into takes values('59290', '663', '1', 'Spring', 2005, 'C-');
	insert into takes values('51862', '338', '1', 'Spring', 2007, 'C-');
	insert into takes values('11194', '927', '1', 'Fall', 2002, 'C-');
	insert into takes values('67560', '702', '1', 'Spring', 2001, 'C-');
	insert into takes values('48009', '496', '1', 'Fall', 2001, 'C ');
	insert into takes values('3039', '366', '1', 'Fall', 2005, 'C ');
	insert into takes values('282', '581', '1', 'Spring', 2005, 'C-');
	insert into takes values('94766', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('1460', '482', '1', 'Fall', 2005, 'C ');
	insert into takes values('93631', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('85887', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('9408', '313', '1', 'Fall', 2010, 'B ');
	insert into takes values('17924', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('43989', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('39619', '493', '1', 'Spring', 2010, 'C-');
	insert into takes values('79205', '795', '1', 'Spring', 2004, 'B-');
	insert into takes values('20002', '631', '1', 'Spring', 2007, 'A ');
	insert into takes values('83398', '679', '1', 'Spring', 2010, 'B ');
	insert into takes values('50977', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('21774', '843', '1', 'Fall', 2010, 'C ');
	insert into takes values('89246', '105', '2', 'Fall', 2002, 'A ');
	insert into takes values('54605', '959', '1', 'Fall', 2006, 'C+');
	insert into takes values('96117', '603', '1', 'Fall', 2003, 'A ');
	insert into takes values('77130', '468', '1', 'Fall', 2005, 'B+');
	insert into takes values('21086', '304', '1', 'Fall', 2009, 'A ');
	insert into takes values('39892', '735', '1', 'Spring', 2003, 'B-');
	insert into takes values('68330', '949', '1', 'Fall', 2007, 'C-');
	insert into takes values('9605', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('58413', '561', '1', 'Fall', 2006, 'B+');
	insert into takes values('7035', '258', '1', 'Fall', 2007, 'A ');
	insert into takes values('28352', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('6209', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('98984', '468', '2', 'Fall', 2007, 'B ');
	insert into takes values('48850', '200', '1', 'Spring', 2007, 'A-');
	insert into takes values('98388', '747', '1', 'Spring', 2004, 'C-');
	insert into takes values('48678', '408', '2', 'Spring', 2003, 'C ');
	insert into takes values('89106', '461', '1', 'Fall', 2002, 'B-');
	insert into takes values('54460', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('68096', '974', '1', 'Fall', 2003, 'A-');
	insert into takes values('25256', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('59908', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('34236', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('48053', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('33201', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('86127', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('92659', '457', '1', 'Spring', 2001, 'B-');
	insert into takes values('88169', '443', '1', 'Spring', 2010, 'B ');
	insert into takes values('88417', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('21395', '169', '2', 'Fall', 2002, 'A-');
	insert into takes values('63090', '313', '1', 'Fall', 2010, 'A-');
	insert into takes values('27556', '702', '1', 'Spring', 2001, 'B ');
	insert into takes values('90041', '867', '1', 'Fall', 2006, 'A-');
	insert into takes values('78581', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('92864', '338', '1', 'Spring', 2007, 'A-');
	insert into takes values('92703', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('62795', '559', '1', 'Fall', 2002, 'B+');
	insert into takes values('96052', '366', '1', 'Fall', 2005, 'A+');
	insert into takes values('78892', '545', '1', 'Fall', 2001, 'C ');
	insert into takes values('25331', '875', '1', 'Spring', 2005, 'B-');
	insert into takes values('18007', '258', '1', 'Fall', 2007, 'A-');
	insert into takes values('32419', '457', '1', 'Spring', 2001, 'B ');
	insert into takes values('67793', '270', '1', 'Spring', 2010, 'C ');
	insert into takes values('73602', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('34957', '352', '1', 'Spring', 2006, 'C ');
	insert into takes values('13290', '443', '1', 'Spring', 2010, 'A+');
	insert into takes values('48660', '612', '1', 'Fall', 2007, 'B-');
	insert into takes values('51975', '629', '1', 'Spring', 2003, 'A+');
	insert into takes values('32385', '867', '1', 'Fall', 2006, 'A+');
	insert into takes values('16993', '457', '1', 'Spring', 2001, 'A-');
	insert into takes values('75596', '366', '1', 'Fall', 2005, 'B ');
	insert into takes values('31250', '704', '1', 'Spring', 2008, 'B ');
	insert into takes values('57160', '612', '1', 'Fall', 2007, 'B ');
	insert into takes values('32464', '334', '1', 'Fall', 2009, 'A-');
	insert into takes values('86661', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('44304', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('32385', '338', '2', 'Spring', 2006, 'A+');
	insert into takes values('66484', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('78767', '400', '2', 'Fall', 2003, 'A ');
	insert into takes values('95850', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('11966', '893', '1', 'Fall', 2007, 'C ');
	insert into takes values('96968', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('39619', '852', '1', 'Spring', 2008, 'B ');
	insert into takes values('96067', '258', '1', 'Fall', 2007, 'B+');
	insert into takes values('31080', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('43032', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('288', '476', '1', 'Fall', 2010, 'A ');
	insert into takes values('56755', '334', '1', 'Fall', 2009, 'A-');
	insert into takes values('792', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('19638', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('8347', '612', '1', 'Fall', 2007, 'A ');
	insert into takes values('78756', '571', '1', 'Spring', 2004, 'C-');
	insert into takes values('24197', '893', '1', 'Fall', 2007, 'A+');
	insert into takes values('76169', '237', '2', 'Fall', 2009, 'C+');
	insert into takes values('30397', '959', '1', 'Fall', 2006, 'B ');
	insert into takes values('62549', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('23506', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('22086', '408', '2', 'Spring', 2003, 'B ');
	insert into takes values('78434', '376', '1', 'Fall', 2006, 'B-');
	insert into takes values('15074', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('89246', '468', '1', 'Fall', 2005, 'B-');
	insert into takes values('80254', '626', '1', 'Fall', 2006, 'A-');
	insert into takes values('50966', '468', '1', 'Fall', 2005, 'A+');
	insert into takes values('62487', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('57538', '612', '1', 'Fall', 2007, 'A-');
	insert into takes values('46980', '843', '1', 'Fall', 2010, 'A+');
	insert into takes values('30182', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('71426', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('59172', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('54610', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('58300', '642', '1', 'Fall', 2004, 'B+');
	insert into takes values('32245', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('41299', '991', '1', 'Spring', 2008, 'B-');
	insert into takes values('67655', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('31993', '461', '1', 'Fall', 2002, 'B+');
	insert into takes values('63860', '169', '2', 'Fall', 2002, 'B+');
	insert into takes values('61854', '334', '1', 'Fall', 2009, 'B-');
	insert into takes values('98140', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('19917', '972', '1', 'Spring', 2009, 'A+');
	insert into takes values('82083', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('53048', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('88472', '443', '2', 'Spring', 2002, 'A-');
	insert into takes values('11530', '445', '1', 'Spring', 2001, 'B-');
	insert into takes values('96911', '237', '1', 'Spring', 2008, 'A+');
	insert into takes values('47627', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('390', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('18775', '476', '1', 'Fall', 2010, 'C ');
	insert into takes values('71529', '793', '1', 'Spring', 2002, 'B ');
	insert into takes values('31302', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('282', '604', '1', 'Spring', 2009, 'B ');
	insert into takes values('21552', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('52866', '696', '1', 'Spring', 2002, 'B-');
	insert into takes values('27556', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('71768', '476', '1', 'Fall', 2010, 'B ');
	insert into takes values('51416', '852', '1', 'Spring', 2008, 'A-');
	insert into takes values('69521', '581', '1', 'Spring', 2005, 'C ');
	insert into takes values('94815', '696', '1', 'Spring', 2002, 'C-');
	insert into takes values('62152', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('87439', '591', '1', 'Spring', 2005, 'B-');
	insert into takes values('2133', '468', '1', 'Fall', 2005, 'C ');
	insert into takes values('58701', '401', '1', 'Fall', 2003, 'A+');
	insert into takes values('83480', '400', '2', 'Fall', 2003, 'C-');
	insert into takes values('20803', '443', '1', 'Spring', 2010, 'B+');
	insert into takes values('30957', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('13741', '591', '1', 'Spring', 2005, 'B ');
	insert into takes values('52120', '679', '1', 'Spring', 2010, 'B+');
	insert into takes values('43432', '599', '1', 'Spring', 2003, 'A ');
	insert into takes values('15487', '192', '1', 'Fall', 2002, 'A+');
	insert into takes values('5920', '599', '1', 'Spring', 2003, 'B+');
	insert into takes values('33759', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('23500', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('47379', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('27430', '200', '1', 'Spring', 2007, 'B-');
	insert into takes values('85887', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('71631', '352', '1', 'Spring', 2006, 'A+');
	insert into takes values('67051', '105', '2', 'Fall', 2002, 'A-');
	insert into takes values('51553', '581', '1', 'Spring', 2005, 'A ');
	insert into takes values('38895', '493', '1', 'Spring', 2010, 'B+');
	insert into takes values('63645', '561', '1', 'Fall', 2006, 'C ');
	insert into takes values('39394', '959', '1', 'Fall', 2006, 'B ');
	insert into takes values('67660', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('67371', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('26695', '468', '2', 'Fall', 2007, 'B ');
	insert into takes values('68396', '349', '1', 'Spring', 2008, 'A ');
	insert into takes values('94726', '642', '1', 'Fall', 2004, 'B+');
	insert into takes values('44816', '366', '1', 'Fall', 2005, 'A ');
	insert into takes values('13826', '239', '1', 'Fall', 2006, 'B ');
	insert into takes values('23475', '169', '1', 'Spring', 2007, 'C ');
	insert into takes values('34386', '401', '1', 'Fall', 2003, 'A-');
	insert into takes values('90814', '313', '1', 'Fall', 2010, 'C ');
	insert into takes values('25940', '702', '1', 'Spring', 2001, 'B ');
	insert into takes values('92417', '604', '1', 'Spring', 2009, 'A ');
	insert into takes values('69850', '304', '1', 'Fall', 2009, 'C+');
	insert into takes values('55000', '270', '1', 'Spring', 2010, 'A+');
	insert into takes values('60984', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('9408', '421', '1', 'Fall', 2004, 'B-');
	insert into takes values('34542', '334', '1', 'Fall', 2009, 'B-');
	insert into takes values('83136', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('65400', '561', '1', 'Fall', 2006, 'C+');
	insert into takes values('18809', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('89312', '274', '1', 'Fall', 2002, 'C+');
	insert into takes values('76743', '400', '2', 'Fall', 2003, 'A-');
	insert into takes values('53048', '345', '1', 'Spring', 2008, 'C-');
	insert into takes values('51817', '352', '1', 'Spring', 2006, 'C-');
	insert into takes values('20084', '169', '1', 'Spring', 2007, 'A-');
	insert into takes values('37219', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('98140', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('52929', '319', '1', 'Spring', 2003, 'A-');
	insert into takes values('89140', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('58634', '581', '1', 'Spring', 2005, 'A+');
	insert into takes values('99451', '137', '1', 'Spring', 2002, 'A-');
	insert into takes values('8483', '864', '1', 'Spring', 2006, 'A+');
	insert into takes values('86375', '867', '1', 'Fall', 2006, 'C+');
	insert into takes values('7854', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('42556', '793', '1', 'Spring', 2002, 'C-');
	insert into takes values('37350', '352', '1', 'Spring', 2006, 'B+');
	insert into takes values('37809', '468', '1', 'Fall', 2005, 'B ');
	insert into takes values('23449', '808', '1', 'Fall', 2003, 'B-');
	insert into takes values('10834', '443', '2', 'Spring', 2002, 'C+');
	insert into takes values('48776', '468', '2', 'Fall', 2007, 'C+');
	insert into takes values('13741', '612', '1', 'Fall', 2007, 'A+');
	insert into takes values('37350', '612', '1', 'Fall', 2007, 'A ');
	insert into takes values('72768', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('96178', '603', '1', 'Fall', 2003, 'A ');
	insert into takes values('15457', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('93039', '366', '1', 'Fall', 2005, 'C ');
	insert into takes values('97573', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('5298', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('75362', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('67021', '401', '1', 'Fall', 2003, 'B+');
	insert into takes values('65703', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('72055', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('16885', '493', '1', 'Spring', 2010, 'A+');
	insert into takes values('95320', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('34126', '400', '1', 'Spring', 2007, 'B ');
	insert into takes values('36685', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('65681', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('47487', '426', '1', 'Spring', 2006, 'A+');
	insert into takes values('36881', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('96067', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('38899', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('71944', '242', '1', 'Fall', 2009, 'C ');
	insert into takes values('98315', '561', '1', 'Fall', 2006, 'B-');
	insert into takes values('87222', '319', '1', 'Spring', 2003, 'B-');
	insert into takes values('58595', '200', '2', 'Fall', 2002, 'A ');
	insert into takes values('10204', '735', '2', 'Spring', 2010, 'A ');
	insert into takes values('51997', '158', '1', 'Fall', 2008, 'C ');
	insert into takes values('34788', '793', '1', 'Spring', 2002, 'C+');
	insert into takes values('83170', '376', '1', 'Fall', 2006, 'A-');
	insert into takes values('57666', '401', '1', 'Fall', 2003, 'C ');
	insert into takes values('78552', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('38121', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('4435', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('49618', '461', '1', 'Fall', 2002, 'B-');
	insert into takes values('32065', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('97065', '362', '1', 'Fall', 2005, 'B ');
	insert into takes values('5336', '461', '1', 'Fall', 2002, 'B+');
	insert into takes values('76057', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('99463', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('6367', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('99250', '972', '1', 'Spring', 2009, 'A ');
	insert into takes values('36265', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('67657', '400', '2', 'Fall', 2003, 'C-');
	insert into takes values('11055', '612', '1', 'Fall', 2007, 'A ');
	insert into takes values('59553', '795', '1', 'Spring', 2004, 'B-');
	insert into takes values('57334', '603', '1', 'Fall', 2003, 'C-');
	insert into takes values('25187', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('39514', '421', '1', 'Fall', 2004, 'B-');
	insert into takes values('13506', '972', '1', 'Spring', 2009, 'B+');
	insert into takes values('53788', '362', '3', 'Spring', 2008, 'C-');
	insert into takes values('41406', '864', '1', 'Spring', 2006, 'C+');
	insert into takes values('51084', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('21692', '461', '1', 'Fall', 2002, 'A-');
	insert into takes values('96178', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('60224', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('99710', '421', '1', 'Fall', 2004, 'A-');
	insert into takes values('68554', '319', '1', 'Spring', 2003, 'A-');
	insert into takes values('3576', '421', '1', 'Fall', 2004, 'C ');
	insert into takes values('64039', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('85451', '313', '1', 'Fall', 2010, 'A+');
	insert into takes values('93491', '696', '1', 'Spring', 2002, 'B+');
	insert into takes values('46337', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('36263', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('13290', '571', '1', 'Spring', 2004, 'C ');
	insert into takes values('99719', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('17911', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('39619', '400', '2', 'Fall', 2003, 'A+');
	insert into takes values('96153', '489', '1', 'Fall', 2007, 'B+');
	insert into takes values('13365', '599', '1', 'Spring', 2003, 'B-');
	insert into takes values('55940', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('31101', '696', '1', 'Spring', 2002, 'A ');
	insert into takes values('64934', '345', '1', 'Spring', 2008, 'A ');
	insert into takes values('90181', '694', '1', 'Fall', 2002, 'B ');
	insert into takes values('107', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('51008', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('80057', '867', '1', 'Fall', 2006, 'B ');
	insert into takes values('10814', '692', '1', 'Spring', 2010, 'A-');
	insert into takes values('99760', '760', '1', 'Spring', 2004, 'B ');
	insert into takes values('75794', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('28738', '735', '1', 'Spring', 2003, 'C ');
	insert into takes values('53424', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('46066', '748', '1', 'Fall', 2003, 'B ');
	insert into takes values('22254', '237', '2', 'Fall', 2009, 'C+');
	insert into takes values('28299', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('46066', '802', '1', 'Spring', 2003, 'C-');
	insert into takes values('83728', '237', '1', 'Spring', 2008, 'A-');
	insert into takes values('32464', '408', '2', 'Spring', 2003, 'C ');
	insert into takes values('52866', '334', '1', 'Fall', 2009, 'B ');
	insert into takes values('13408', '561', '1', 'Fall', 2006, 'B-');
	insert into takes values('20445', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('61444', '457', '1', 'Spring', 2001, 'A+');
	insert into takes values('18234', '274', '1', 'Fall', 2002, 'C+');
	insert into takes values('86707', '105', '2', 'Fall', 2002, 'C-');
	insert into takes values('40059', '559', '1', 'Fall', 2002, 'A-');
	insert into takes values('17133', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('27687', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('69581', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('888', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('53788', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('33338', '352', '1', 'Spring', 2006, 'A-');
	insert into takes values('59172', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('51723', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('94173', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('84727', '603', '1', 'Fall', 2003, 'A+');
	insert into takes values('59530', '461', '1', 'Fall', 2002, 'B-');
	insert into takes values('56212', '105', '2', 'Fall', 2002, 'A ');
	insert into takes values('70965', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('91343', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('53152', '843', '1', 'Fall', 2010, 'B-');
	insert into takes values('46451', '612', '1', 'Fall', 2007, 'A+');
	insert into takes values('82066', '631', '1', 'Spring', 2007, 'C-');
	insert into takes values('98563', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('28977', '408', '2', 'Spring', 2003, 'A+');
	insert into takes values('97228', '239', '1', 'Fall', 2006, 'B-');
	insert into takes values('65681', '793', '1', 'Spring', 2002, 'A-');
	insert into takes values('50658', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('75791', '274', '1', 'Fall', 2002, 'A+');
	insert into takes values('52669', '239', '1', 'Fall', 2006, 'C+');
	insert into takes values('16297', '604', '1', 'Spring', 2009, 'B ');
	insert into takes values('8457', '793', '1', 'Spring', 2002, 'A+');
	insert into takes values('30289', '692', '1', 'Spring', 2010, 'A ');
	insert into takes values('85575', '338', '1', 'Spring', 2007, 'C+');
	insert into takes values('35685', '200', '1', 'Spring', 2007, 'B-');
	insert into takes values('94178', '200', '2', 'Fall', 2002, 'A ');
	insert into takes values('63288', '527', '1', 'Fall', 2004, 'C+');
	insert into takes values('14874', '237', '1', 'Spring', 2008, 'A-');
	insert into takes values('85910', '242', '1', 'Fall', 2009, 'A-');
	insert into takes values('14284', '702', '1', 'Spring', 2001, 'C+');
	insert into takes values('30341', '421', '1', 'Fall', 2004, 'A-');
	insert into takes values('83136', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('1922', '476', '1', 'Fall', 2010, 'A+');
	insert into takes values('14639', '489', '1', 'Fall', 2007, 'A-');
	insert into takes values('68999', '408', '2', 'Spring', 2003, 'A+');
	insert into takes values('3127', '319', '1', 'Spring', 2003, 'A-');
	insert into takes values('74911', '426', '1', 'Spring', 2006, 'A ');
	insert into takes values('41406', '426', '1', 'Spring', 2006, 'A-');
	insert into takes values('21766', '960', '2', 'Fall', 2006, 'B-');
	insert into takes values('72657', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('61127', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('96085', '457', '1', 'Spring', 2001, 'A+');
	insert into takes values('16528', '200', '1', 'Spring', 2007, 'B-');
	insert into takes values('17769', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('36263', '735', '2', 'Spring', 2010, 'A+');
	insert into takes values('68096', '791', '1', 'Spring', 2006, 'B+');
	insert into takes values('50703', '158', '2', 'Spring', 2008, 'C+');
	insert into takes values('71944', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('48901', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('4508', '270', '1', 'Spring', 2010, 'C-');
	insert into takes values('11419', '527', '1', 'Fall', 2004, 'C-');
	insert into takes values('8426', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('22260', '991', '1', 'Spring', 2008, 'C-');
	insert into takes values('3487', '927', '1', 'Fall', 2002, 'A-');
	insert into takes values('8347', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('85211', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('48053', '694', '1', 'Fall', 2002, 'A ');
	insert into takes values('544', '200', '1', 'Spring', 2007, 'C ');
	insert into takes values('98830', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('90234', '461', '1', 'Fall', 2002, 'C-');
	insert into takes values('37449', '200', '2', 'Fall', 2002, 'A ');
	insert into takes values('87268', '927', '1', 'Fall', 2002, 'A ');
	insert into takes values('21009', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('39394', '352', '1', 'Spring', 2006, 'A-');
	insert into takes values('56078', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('76759', '486', '1', 'Fall', 2009, 'A ');
	insert into takes values('37284', '345', '1', 'Spring', 2008, 'A-');
	insert into takes values('98843', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('24796', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('79210', '105', '2', 'Fall', 2002, 'C-');
	insert into takes values('12711', '200', '1', 'Spring', 2007, 'C ');
	insert into takes values('4682', '408', '2', 'Spring', 2003, 'B-');
	insert into takes values('57474', '493', '1', 'Spring', 2010, 'A-');
	insert into takes values('78314', '760', '1', 'Spring', 2004, 'A ');
	insert into takes values('26473', '626', '1', 'Fall', 2006, 'B-');
	insert into takes values('71944', '591', '1', 'Spring', 2005, 'A ');
	insert into takes values('827', '443', '2', 'Spring', 2002, 'C+');
	insert into takes values('89051', '482', '1', 'Fall', 2005, 'A+');
	insert into takes values('88887', '559', '1', 'Fall', 2002, 'A ');
	insert into takes values('11237', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('30845', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('86375', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('85534', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('64249', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('99189', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('57780', '274', '1', 'Fall', 2002, 'B ');
	insert into takes values('9460', '457', '1', 'Spring', 2001, 'A ');
	insert into takes values('5250', '338', '2', 'Spring', 2006, 'A-');
	insert into takes values('3639', '304', '1', 'Fall', 2009, 'A+');
	insert into takes values('94324', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('64196', '408', '1', 'Spring', 2007, 'A+');
	insert into takes values('80976', '270', '1', 'Spring', 2010, 'C-');
	insert into takes values('76768', '696', '1', 'Spring', 2002, 'C-');
	insert into takes values('52866', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('93571', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('59290', '696', '1', 'Spring', 2002, 'B+');
	insert into takes values('65688', '443', '1', 'Spring', 2010, 'A-');
	insert into takes values('66484', '482', '1', 'Fall', 2005, 'A ');
	insert into takes values('59530', '362', '3', 'Spring', 2008, 'C-');
	insert into takes values('81150', '808', '1', 'Fall', 2003, 'A+');
	insert into takes values('29390', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('17377', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('79534', '591', '1', 'Spring', 2005, 'C-');
	insert into takes values('16453', '313', '1', 'Fall', 2010, 'B-');
	insert into takes values('24932', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('71631', '376', '1', 'Fall', 2006, 'B-');
	insert into takes values('40059', '604', '1', 'Spring', 2009, 'B+');
	insert into takes values('89297', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('35881', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('17057', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('93354', '793', '1', 'Spring', 2002, 'C+');
	insert into takes values('45494', '867', '1', 'Fall', 2006, 'B+');
	insert into takes values('52057', '959', '1', 'Fall', 2006, 'A ');
	insert into takes values('34957', '527', '1', 'Fall', 2004, 'C-');
	insert into takes values('34422', '496', '1', 'Fall', 2001, 'B ');
	insert into takes values('84039', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('10556', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('94371', '795', '1', 'Spring', 2004, 'C+');
	insert into takes values('16075', '795', '1', 'Spring', 2004, 'A-');
	insert into takes values('48776', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('13880', '443', '1', 'Spring', 2010, 'B+');
	insert into takes values('25077', '581', '1', 'Spring', 2005, 'A+');
	insert into takes values('8807', '313', '1', 'Fall', 2010, 'C-');
	insert into takes values('53451', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('58413', '258', '1', 'Fall', 2007, 'C-');
	insert into takes values('68720', '421', '1', 'Fall', 2004, 'A ');
	insert into takes values('39580', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('96153', '237', '1', 'Spring', 2008, 'B+');
	insert into takes values('84845', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('15430', '748', '1', 'Fall', 2003, 'A-');
	insert into takes values('26080', '581', '1', 'Spring', 2005, 'A-');
	insert into takes values('81876', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('77588', '443', '1', 'Spring', 2010, 'C ');
	insert into takes values('70389', '696', '1', 'Spring', 2002, 'B-');
	insert into takes values('39254', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('74530', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('41596', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('20445', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('19048', '581', '1', 'Spring', 2005, 'B+');
	insert into takes values('82918', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('85534', '242', '1', 'Fall', 2009, 'C+');
	insert into takes values('17924', '169', '1', 'Spring', 2007, 'B-');
	insert into takes values('56755', '791', '1', 'Spring', 2006, 'B+');
	insert into takes values('52076', '927', '1', 'Fall', 2002, 'C-');
	insert into takes values('55170', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('7854', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('83747', '603', '1', 'Fall', 2003, 'B-');
	insert into takes values('58594', '972', '1', 'Spring', 2009, 'A ');
	insert into takes values('19362', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('46980', '571', '1', 'Spring', 2004, 'C+');
	insert into takes values('96206', '408', '1', 'Spring', 2007, 'B ');
	insert into takes values('89188', '352', '1', 'Spring', 2006, 'C ');
	insert into takes values('25256', '867', '1', 'Fall', 2006, 'A-');
	insert into takes values('5298', '200', '1', 'Spring', 2007, 'C ');
	insert into takes values('16467', '105', '1', 'Fall', 2009, 'B ');
	insert into takes values('50365', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('80113', '443', '1', 'Spring', 2010, 'C ');
	insert into takes values('18367', '443', '2', 'Spring', 2002, 'A ');
	insert into takes values('97629', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('4682', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('80799', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('48469', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('32369', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('92693', '604', '1', 'Spring', 2009, 'B ');
	insert into takes values('62054', '960', '2', 'Fall', 2006, 'B-');
	insert into takes values('16453', '200', '2', 'Fall', 2002, 'A ');
	insert into takes values('68712', '338', '1', 'Spring', 2007, 'C+');
	insert into takes values('85887', '559', '1', 'Fall', 2002, 'C+');
	insert into takes values('99271', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('82918', '612', '1', 'Fall', 2007, 'B ');
	insert into takes values('77000', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('74672', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('88577', '400', '2', 'Fall', 2003, 'A-');
	insert into takes values('78552', '959', '1', 'Fall', 2006, 'B ');
	insert into takes values('5017', '366', '1', 'Fall', 2005, 'C-');
	insert into takes values('14668', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('95840', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('57962', '962', '1', 'Spring', 2008, 'B ');
	insert into takes values('67017', '242', '1', 'Fall', 2009, 'C-');
	insert into takes values('68779', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('33791', '735', '1', 'Spring', 2003, 'A+');
	insert into takes values('53152', '962', '1', 'Spring', 2008, 'B-');
	insert into takes values('95027', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('61364', '867', '2', 'Fall', 2010, 'A-');
	insert into takes values('29140', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('38271', '692', '1', 'Spring', 2010, 'A-');
	insert into takes values('3039', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('38013', '493', '1', 'Spring', 2010, 'C-');
	insert into takes values('43616', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('71025', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('73213', '581', '1', 'Spring', 2005, 'C ');
	insert into takes values('62636', '735', '1', 'Spring', 2003, 'A+');
	insert into takes values('53699', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('56', '242', '1', 'Fall', 2009, 'C+');
	insert into takes values('83398', '927', '1', 'Fall', 2002, 'A+');
	insert into takes values('95175', '561', '1', 'Fall', 2006, 'A+');
	insert into takes values('48678', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('60867', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('66484', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('4383', '791', '1', 'Spring', 2006, 'B+');
	insert into takes values('12979', '443', '1', 'Spring', 2010, 'A ');
	insert into takes values('88045', '415', '1', 'Fall', 2010, 'A-');
	insert into takes values('75252', '200', '2', 'Fall', 2002, 'B-');
	insert into takes values('8843', '237', '1', 'Spring', 2008, 'C+');
	insert into takes values('37430', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('5243', '242', '1', 'Fall', 2009, 'C+');
	insert into takes values('96193', '629', '1', 'Spring', 2003, 'A ');
	insert into takes values('282', '631', '1', 'Spring', 2007, 'A ');
	insert into takes values('27366', '443', '2', 'Spring', 2002, 'A+');
	insert into takes values('16075', '960', '2', 'Fall', 2006, 'A-');
	insert into takes values('17086', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('20445', '808', '1', 'Fall', 2003, 'C ');
	insert into takes values('28252', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('94836', '591', '1', 'Spring', 2005, 'B ');
	insert into takes values('10834', '443', '1', 'Spring', 2010, 'A-');
	insert into takes values('67655', '334', '1', 'Fall', 2009, 'A-');
	insert into takes values('20084', '974', '1', 'Fall', 2003, 'A-');
	insert into takes values('52076', '200', '2', 'Fall', 2002, 'A-');
	insert into takes values('7973', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('7956', '960', '2', 'Fall', 2006, 'C+');
	insert into takes values('54875', '105', '1', 'Fall', 2009, 'C-');
	insert into takes values('57160', '408', '1', 'Spring', 2007, 'B ');
	insert into takes values('288', '527', '1', 'Fall', 2004, 'B-');
	insert into takes values('98870', '604', '1', 'Spring', 2009, 'B-');
	insert into takes values('21086', '760', '1', 'Spring', 2004, 'B ');
	insert into takes values('55009', '270', '1', 'Spring', 2010, 'B-');
	insert into takes values('99977', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('38602', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('71529', '559', '1', 'Fall', 2002, 'B ');
	insert into takes values('45826', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('50944', '591', '1', 'Spring', 2005, 'A+');
	insert into takes values('73807', '974', '1', 'Fall', 2003, 'A-');
	insert into takes values('94846', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('96193', '591', '1', 'Spring', 2005, 'B-');
	insert into takes values('96911', '612', '1', 'Fall', 2007, 'A ');
	insert into takes values('66356', '158', '2', 'Spring', 2008, 'C ');
	insert into takes values('28409', '482', '1', 'Fall', 2005, 'A ');
	insert into takes values('36102', '795', '1', 'Spring', 2004, 'A-');
	insert into takes values('65433', '158', '2', 'Spring', 2008, 'C ');
	insert into takes values('71628', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('69132', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('90234', '349', '1', 'Spring', 2008, 'A ');
	insert into takes values('29920', '679', '1', 'Spring', 2010, 'A+');
	insert into takes values('90814', '599', '1', 'Spring', 2003, 'B+');
	insert into takes values('30110', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('85226', '545', '1', 'Fall', 2001, 'A ');
	insert into takes values('83557', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('43495', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('73186', '875', '1', 'Spring', 2005, 'B+');
	insert into takes values('3640', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('11101', '338', '1', 'Spring', 2007, 'C-');
	insert into takes values('91132', '735', '1', 'Spring', 2003, 'C-');
	insert into takes values('60406', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('52120', '169', '2', 'Fall', 2002, 'A ');
	insert into takes values('29705', '972', '1', 'Spring', 2009, 'C ');
	insert into takes values('62520', '401', '1', 'Fall', 2003, 'A ');
	insert into takes values('97400', '362', '3', 'Spring', 2008, 'B ');
	insert into takes values('91063', '960', '1', 'Fall', 2009, 'A-');
	insert into takes values('22254', '338', '1', 'Spring', 2007, 'C-');
	insert into takes values('89571', '493', '1', 'Spring', 2010, 'A+');
	insert into takes values('17831', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('45570', '334', '1', 'Fall', 2009, 'C-');
	insert into takes values('72186', '319', '1', 'Spring', 2003, 'B-');
	insert into takes values('69853', '629', '1', 'Spring', 2003, 'B-');
	insert into takes values('59290', '270', '1', 'Spring', 2010, 'C-');
	insert into takes values('78143', '443', '2', 'Spring', 2002, 'B-');
	insert into takes values('72521', '158', '1', 'Fall', 2008, 'B-');
	insert into takes values('38668', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('64550', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('8912', '760', '1', 'Spring', 2004, 'A-');
	insert into takes values('77898', '571', '1', 'Spring', 2004, 'A-');
	insert into takes values('94569', '603', '1', 'Fall', 2003, 'B-');
	insert into takes values('9183', '843', '1', 'Fall', 2010, 'C+');
	insert into takes values('8457', '400', '1', 'Spring', 2007, 'A ');
	insert into takes values('80610', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('98870', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('66229', '242', '1', 'Fall', 2009, 'C+');
	insert into takes values('90194', '334', '1', 'Fall', 2009, 'C ');
	insert into takes values('51997', '791', '1', 'Spring', 2006, 'C+');
	insert into takes values('92464', '972', '1', 'Spring', 2009, 'C-');
	insert into takes values('28994', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('87280', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('32368', '338', '1', 'Spring', 2007, 'C ');
	insert into takes values('41450', '338', '2', 'Spring', 2006, 'B ');
	insert into takes values('16453', '496', '1', 'Fall', 2001, 'B-');
	insert into takes values('60406', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('90381', '421', '1', 'Fall', 2004, 'C+');
	insert into takes values('72485', '581', '1', 'Spring', 2005, 'A-');
	insert into takes values('59517', '445', '1', 'Spring', 2001, 'B+');
	insert into takes values('80976', '192', '1', 'Fall', 2002, 'C ');
	insert into takes values('61998', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('13365', '791', '1', 'Spring', 2006, 'A ');
	insert into takes values('80248', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('35881', '631', '1', 'Spring', 2007, 'B+');
	insert into takes values('7970', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('49450', '400', '2', 'Fall', 2003, 'B+');
	insert into takes values('68070', '239', '1', 'Fall', 2006, 'B-');
	insert into takes values('20445', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('4682', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('30474', '192', '1', 'Fall', 2002, 'A+');
	insert into takes values('62549', '237', '2', 'Fall', 2009, 'A ');
	insert into takes values('89188', '400', '1', 'Spring', 2007, 'C-');
	insert into takes values('7035', '571', '1', 'Spring', 2004, 'B+');
	insert into takes values('90609', '793', '1', 'Spring', 2002, 'C+');
	insert into takes values('82687', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('92965', '591', '1', 'Spring', 2005, 'A ');
	insert into takes values('15883', '843', '1', 'Fall', 2010, 'B+');
	insert into takes values('35523', '927', '1', 'Fall', 2002, 'A-');
	insert into takes values('64164', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('11377', '274', '1', 'Fall', 2002, 'C+');
	insert into takes values('792', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('22057', '493', '1', 'Spring', 2010, 'B ');
	insert into takes values('91799', '760', '1', 'Spring', 2004, 'C-');
	insert into takes values('56598', '362', '2', 'Fall', 2006, 'A ');
	insert into takes values('16885', '408', '2', 'Spring', 2003, 'B ');
	insert into takes values('27662', '663', '1', 'Spring', 2005, 'A ');
	insert into takes values('76049', '489', '1', 'Fall', 2007, 'B ');
	insert into takes values('47001', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('67560', '421', '1', 'Fall', 2004, 'B-');
	insert into takes values('57156', '696', '1', 'Spring', 2002, 'B+');
	insert into takes values('16528', '843', '1', 'Fall', 2010, 'A ');
	insert into takes values('89000', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('84808', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('23475', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('9993', '421', '1', 'Fall', 2004, 'A-');
	insert into takes values('57334', '105', '1', 'Fall', 2009, 'C-');
	insert into takes values('10663', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('80912', '362', '3', 'Spring', 2008, 'C-');
	insert into takes values('85602', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('20099', '158', '2', 'Spring', 2008, 'C-');
	insert into takes values('32954', '169', '2', 'Fall', 2002, 'C ');
	insert into takes values('51923', '338', '2', 'Spring', 2006, 'A+');
	insert into takes values('36995', '959', '1', 'Fall', 2006, 'A ');
	insert into takes values('15144', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('57238', '400', '1', 'Spring', 2007, 'C+');
	insert into takes values('36926', '748', '1', 'Fall', 2003, 'B-');
	insert into takes values('99719', '421', '1', 'Fall', 2004, 'C ');
	insert into takes values('64259', '362', '3', 'Spring', 2008, 'C-');
	insert into takes values('35220', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('72177', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('66293', '489', '1', 'Fall', 2007, 'C+');
	insert into takes values('80799', '545', '1', 'Fall', 2001, 'A-');
	insert into takes values('36052', '735', '2', 'Spring', 2010, 'A-');
	insert into takes values('14628', '571', '1', 'Spring', 2004, 'C-');
	insert into takes values('45494', '629', '1', 'Spring', 2003, 'A ');
	insert into takes values('31137', '338', '1', 'Spring', 2007, 'B ');
	insert into takes values('41818', '105', '2', 'Fall', 2002, 'A+');
	insert into takes values('29091', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('91851', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('63361', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('8843', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('25528', '366', '1', 'Fall', 2005, 'C ');
	insert into takes values('19862', '376', '1', 'Fall', 2006, 'B+');
	insert into takes values('86969', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('72358', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('12563', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('92417', '468', '2', 'Fall', 2007, 'A-');
	insert into takes values('80941', '237', '2', 'Fall', 2009, 'A-');
	insert into takes values('75794', '642', '1', 'Fall', 2004, 'C+');
	insert into takes values('86075', '408', '2', 'Spring', 2003, 'C ');
	insert into takes values('15613', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('73492', '408', '2', 'Spring', 2003, 'A+');
	insert into takes values('56080', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('64593', '242', '1', 'Fall', 2009, 'A ');
	insert into takes values('86344', '962', '1', 'Spring', 2008, 'B ');
	insert into takes values('26147', '457', '1', 'Spring', 2001, 'B ');
	insert into takes values('92839', '864', '1', 'Spring', 2006, 'C+');
	insert into takes values('26473', '200', '1', 'Spring', 2007, 'B+');
	insert into takes values('77580', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('91992', '443', '1', 'Spring', 2010, 'B+');
	insert into takes values('14639', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('5824', '421', '1', 'Fall', 2004, 'B+');
	insert into takes values('18636', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('75938', '864', '1', 'Spring', 2006, 'A ');
	insert into takes values('33791', '237', '2', 'Fall', 2009, 'A ');
	insert into takes values('36019', '376', '1', 'Fall', 2006, 'A-');
	insert into takes values('66259', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('97694', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('66212', '237', '1', 'Spring', 2008, 'A-');
	insert into takes values('68248', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('4034', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('46074', '612', '1', 'Fall', 2007, 'B+');
	insert into takes values('65241', '239', '1', 'Fall', 2006, 'B ');
	insert into takes values('71025', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('66469', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('60762', '793', '1', 'Spring', 2002, 'C+');
	insert into takes values('59117', '559', '1', 'Fall', 2002, 'A-');
	insert into takes values('21395', '338', '1', 'Spring', 2007, 'C+');
	insert into takes values('41973', '852', '1', 'Spring', 2008, 'B ');
	insert into takes values('888', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('78858', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('86674', '366', '1', 'Fall', 2005, 'C ');
	insert into takes values('82697', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('61414', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('72177', '852', '1', 'Spring', 2008, 'B ');
	insert into takes values('37653', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('63560', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('97041', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('37350', '400', '1', 'Spring', 2007, 'B+');
	insert into takes values('83696', '192', '1', 'Fall', 2002, 'A+');
	insert into takes values('69952', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('45359', '663', '1', 'Spring', 2005, 'C ');
	insert into takes values('22057', '461', '1', 'Fall', 2002, 'A-');
	insert into takes values('69732', '137', '1', 'Spring', 2002, 'A ');
	insert into takes values('11422', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('33651', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('1367', '270', '1', 'Spring', 2010, 'C+');
	insert into takes values('70021', '808', '1', 'Fall', 2003, 'A+');
	insert into takes values('97023', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('52929', '496', '1', 'Fall', 2001, 'C-');
	insert into takes values('85910', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('53185', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('65688', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('61065', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('43616', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('72622', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('57787', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('63289', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('8819', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('52076', '603', '1', 'Fall', 2003, 'A ');
	insert into takes values('50537', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('83398', '366', '1', 'Fall', 2005, 'C ');
	insert into takes values('51975', '581', '1', 'Spring', 2005, 'C-');
	insert into takes values('19735', '843', '1', 'Fall', 2010, 'C ');
	insert into takes values('9953', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('2848', '105', '2', 'Fall', 2002, 'A ');
	insert into takes values('45817', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('67725', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('38676', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('50365', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('94990', '527', '1', 'Fall', 2004, 'B+');
	insert into takes values('25380', '791', '1', 'Spring', 2006, 'B+');
	insert into takes values('94535', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('30723', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('14065', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('86127', '408', '2', 'Spring', 2003, 'C-');
	insert into takes values('91343', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('97629', '445', '1', 'Spring', 2001, 'C ');
	insert into takes values('21008', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('32065', '545', '1', 'Fall', 2001, 'B-');
	insert into takes values('41675', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('75082', '960', '2', 'Fall', 2006, 'A-');
	insert into takes values('63361', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('39925', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('26147', '486', '1', 'Fall', 2009, 'A ');
	insert into takes values('92839', '158', '1', 'Fall', 2008, 'A-');
	insert into takes values('1737', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('86375', '200', '2', 'Fall', 2002, 'C+');
	insert into takes values('56882', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('81031', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('20378', '545', '1', 'Fall', 2001, 'A-');
	insert into takes values('58307', '696', '1', 'Spring', 2002, 'B+');
	insert into takes values('65901', '486', '1', 'Fall', 2009, 'C ');
	insert into takes values('62716', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('59539', '274', '1', 'Fall', 2002, 'B-');
	insert into takes values('12214', '345', '1', 'Spring', 2008, 'A+');
	insert into takes values('63243', '793', '1', 'Spring', 2002, 'A-');
	insert into takes values('3127', '401', '1', 'Fall', 2003, 'C ');
	insert into takes values('14628', '338', '1', 'Spring', 2007, 'B ');
	insert into takes values('22345', '493', '1', 'Spring', 2010, 'A+');
	insert into takes values('1827', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('36244', '482', '1', 'Fall', 2005, 'C ');
	insert into takes values('57431', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('93354', '313', '1', 'Fall', 2010, 'C-');
	insert into takes values('62784', '242', '1', 'Fall', 2009, 'C-');
	insert into takes values('95366', '760', '1', 'Spring', 2004, 'C-');
	insert into takes values('24784', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('29031', '237', '2', 'Fall', 2009, 'A-');
	insert into takes values('45817', '362', '2', 'Fall', 2006, 'C-');
	insert into takes values('78454', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('55915', '864', '1', 'Spring', 2006, 'B ');
	insert into takes values('17133', '527', '1', 'Fall', 2004, 'C+');
	insert into takes values('73186', '270', '1', 'Spring', 2010, 'B-');
	insert into takes values('65258', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('15024', '852', '1', 'Spring', 2008, 'B-');
	insert into takes values('43123', '747', '1', 'Spring', 2004, 'B-');
	insert into takes values('5005', '561', '1', 'Fall', 2006, 'C-');
	insert into takes values('70572', '443', '1', 'Spring', 2010, 'A+');
	insert into takes values('71025', '426', '1', 'Spring', 2006, 'B ');
	insert into takes values('9360', '795', '1', 'Spring', 2004, 'B-');
	insert into takes values('30182', '735', '2', 'Spring', 2010, 'B-');
	insert into takes values('28738', '482', '1', 'Fall', 2005, 'A ');
	insert into takes values('10814', '352', '1', 'Spring', 2006, 'A-');
	insert into takes values('98047', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('49205', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('51084', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('77588', '696', '1', 'Spring', 2002, 'B-');
	insert into takes values('87246', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('33107', '974', '1', 'Fall', 2003, 'A-');
	insert into takes values('72055', '559', '1', 'Fall', 2002, 'C+');
	insert into takes values('52741', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('60224', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('30252', '642', '1', 'Fall', 2004, 'C+');
	insert into takes values('40932', '401', '1', 'Fall', 2003, 'C-');
	insert into takes values('32954', '852', '1', 'Spring', 2008, 'B+');
	insert into takes values('63390', '304', '1', 'Fall', 2009, 'B+');
	insert into takes values('88472', '443', '1', 'Spring', 2010, 'B ');
	insert into takes values('29665', '735', '1', 'Spring', 2003, 'C-');
	insert into takes values('30334', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('83728', '631', '1', 'Spring', 2007, 'C-');
	insert into takes values('10705', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('30723', '959', '1', 'Fall', 2006, 'B+');
	insert into takes values('49391', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('88140', '137', '1', 'Spring', 2002, 'C-');
	insert into takes values('62754', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('64155', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('9947', '599', '1', 'Spring', 2003, 'A-');
	insert into takes values('17397', '852', '1', 'Spring', 2008, 'B ');
	insert into takes values('25143', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('23934', '960', '2', 'Fall', 2006, 'C+');
	insert into takes values('30341', '443', '2', 'Spring', 2002, 'B+');
	insert into takes values('3576', '867', '1', 'Fall', 2006, 'A+');
	insert into takes values('94522', '603', '1', 'Fall', 2003, 'A+');
	insert into takes values('49611', '362', '1', 'Fall', 2005, 'C-');
	insert into takes values('68330', '237', '1', 'Spring', 2008, 'C+');
	insert into takes values('39310', '400', '1', 'Spring', 2007, 'A-');
	insert into takes values('21126', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('60762', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('75231', '867', '1', 'Fall', 2006, 'B+');
	insert into takes values('94371', '415', '1', 'Fall', 2010, 'B+');
	insert into takes values('49618', '415', '1', 'Fall', 2010, 'C-');
	insert into takes values('39876', '626', '1', 'Fall', 2006, 'A ');
	insert into takes values('51923', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('56941', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('8819', '867', '1', 'Fall', 2006, 'A-');
	insert into takes values('73165', '747', '1', 'Spring', 2004, 'B+');
	insert into takes values('53451', '158', '2', 'Spring', 2008, 'C ');
	insert into takes values('8426', '747', '1', 'Spring', 2004, 'C ');
	insert into takes values('57185', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('71878', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('22396', '400', '2', 'Fall', 2003, 'A-');
	insert into takes values('52120', '735', '2', 'Spring', 2010, 'C ');
	insert into takes values('78314', '591', '1', 'Spring', 2005, 'B+');
	insert into takes values('83871', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('16405', '362', '1', 'Fall', 2005, 'B ');
	insert into takes values('9360', '319', '1', 'Spring', 2003, 'C-');
	insert into takes values('107', '443', '2', 'Spring', 2002, 'C-');
	insert into takes values('66494', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('90448', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('68150', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('96203', '864', '1', 'Spring', 2006, 'A ');
	insert into takes values('21556', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('58594', '408', '2', 'Spring', 2003, 'A+');
	insert into takes values('51538', '748', '1', 'Fall', 2003, 'B ');
	insert into takes values('71287', '304', '1', 'Fall', 2009, 'B ');
	insert into takes values('30164', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('99226', '959', '1', 'Fall', 2006, 'A+');
	insert into takes values('9495', '482', '1', 'Fall', 2005, 'A+');
	insert into takes values('32744', '747', '1', 'Spring', 2004, 'C-');
	insert into takes values('86573', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('63860', '313', '1', 'Fall', 2010, 'C+');
	insert into takes values('96193', '334', '1', 'Fall', 2009, 'C ');
	insert into takes values('85754', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('43616', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('11682', '867', '2', 'Fall', 2010, 'B-');
	insert into takes values('39876', '581', '1', 'Spring', 2005, 'A-');
	insert into takes values('17339', '692', '1', 'Spring', 2010, 'C+');
	insert into takes values('3487', '843', '1', 'Fall', 2010, 'B-');
	insert into takes values('92442', '457', '1', 'Spring', 2001, 'C ');
	insert into takes values('11076', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('12078', '362', '2', 'Fall', 2006, 'A-');
	insert into takes values('7035', '443', '1', 'Spring', 2010, 'B ');
	insert into takes values('4508', '960', '2', 'Fall', 2006, 'C ');
	insert into takes values('41832', '496', '1', 'Fall', 2001, 'A-');
	insert into takes values('93986', '415', '1', 'Fall', 2010, 'C+');
	insert into takes values('44985', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('91091', '400', '2', 'Fall', 2003, 'B+');
	insert into takes values('92864', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('25942', '137', '1', 'Spring', 2002, 'A-');
	insert into takes values('83398', '791', '1', 'Spring', 2006, 'C-');
	insert into takes values('85602', '867', '1', 'Fall', 2006, 'C+');
	insert into takes values('11057', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('8140', '304', '1', 'Fall', 2009, 'B+');
	insert into takes values('14596', '313', '1', 'Fall', 2010, 'C ');
	insert into takes values('96227', '591', '1', 'Spring', 2005, 'C+');
	insert into takes values('12236', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('44706', '105', '2', 'Fall', 2002, 'A ');
	insert into takes values('55170', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('78454', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('50702', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('28133', '702', '1', 'Spring', 2001, 'C ');
	insert into takes values('70924', '274', '1', 'Fall', 2002, 'C+');
	insert into takes values('40992', '962', '1', 'Spring', 2008, 'C-');
	insert into takes values('68280', '461', '1', 'Fall', 2002, 'C-');
	insert into takes values('11966', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('21009', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('66753', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('83836', '486', '1', 'Fall', 2009, 'C ');
	insert into takes values('55009', '457', '1', 'Spring', 2001, 'A-');
	insert into takes values('67371', '852', '1', 'Spring', 2008, 'C ');
	insert into takes values('80799', '400', '2', 'Fall', 2003, 'A+');
	insert into takes values('78782', '443', '2', 'Spring', 2002, 'B-');
	insert into takes values('32385', '747', '1', 'Spring', 2004, 'C-');
	insert into takes values('52707', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('94178', '415', '1', 'Fall', 2010, 'A-');
	insert into takes values('61920', '696', '1', 'Spring', 2002, 'C-');
	insert into takes values('71287', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('32345', '949', '1', 'Fall', 2007, 'A-');
	insert into takes values('19603', '561', '1', 'Fall', 2006, 'C ');
	insert into takes values('69632', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('10727', '696', '1', 'Spring', 2002, 'B+');
	insert into takes values('18675', '626', '1', 'Fall', 2006, 'A ');
	insert into takes values('44816', '362', '2', 'Fall', 2006, 'A ');
	insert into takes values('27366', '376', '1', 'Fall', 2006, 'A ');
	insert into takes values('98056', '893', '1', 'Fall', 2007, 'A ');
	insert into takes values('25187', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('19917', '735', '1', 'Spring', 2003, 'B-');
	insert into takes values('15980', '694', '1', 'Fall', 2002, 'B ');
	insert into takes values('36881', '443', '2', 'Spring', 2002, 'C+');
	insert into takes values('21337', '793', '1', 'Spring', 2002, 'A+');
	insert into takes values('99268', '949', '1', 'Fall', 2007, 'C+');
	insert into takes values('19048', '867', '2', 'Fall', 2010, 'B-');
	insert into takes values('51008', '561', '1', 'Fall', 2006, 'B+');
	insert into takes values('63538', '603', '1', 'Fall', 2003, 'B+');
	insert into takes values('15430', '313', '1', 'Fall', 2010, 'C+');
	insert into takes values('73387', '949', '1', 'Fall', 2007, 'B ');
	insert into takes values('61166', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('42991', '991', '1', 'Spring', 2008, 'B-');
	insert into takes values('53799', '421', '1', 'Fall', 2004, 'B-');
	insert into takes values('74840', '237', '2', 'Fall', 2009, 'C-');
	insert into takes values('88169', '362', '2', 'Fall', 2006, 'C-');
	insert into takes values('54875', '401', '1', 'Fall', 2003, 'C ');
	insert into takes values('22396', '242', '1', 'Fall', 2009, 'C-');
	insert into takes values('55698', '400', '2', 'Fall', 2003, 'B+');
	insert into takes values('95099', '631', '1', 'Spring', 2007, 'C+');
	insert into takes values('15086', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('60984', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('76173', '137', '1', 'Spring', 2002, 'A-');
	insert into takes values('8378', '599', '1', 'Spring', 2003, 'C ');
	insert into takes values('67017', '852', '1', 'Spring', 2008, 'B+');
	insert into takes values('24746', '158', '1', 'Fall', 2008, 'C ');
	insert into takes values('78758', '493', '1', 'Spring', 2010, 'A-');
	insert into takes values('96067', '571', '1', 'Spring', 2004, 'B+');
	insert into takes values('64039', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('81031', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('52120', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('42298', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('87831', '376', '1', 'Fall', 2006, 'A-');
	insert into takes values('73206', '875', '1', 'Spring', 2005, 'B+');
	insert into takes values('37856', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('84410', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('71768', '571', '1', 'Spring', 2004, 'C+');
	insert into takes values('2201', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('15030', '631', '1', 'Spring', 2007, 'B+');
	insert into takes values('13753', '376', '1', 'Fall', 2006, 'A ');
	insert into takes values('25785', '345', '1', 'Spring', 2008, 'C+');
	insert into takes values('23344', '867', '1', 'Fall', 2006, 'A ');
	insert into takes values('50467', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('37759', '313', '1', 'Fall', 2010, 'A+');
	insert into takes values('24116', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('33645', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('21225', '169', '1', 'Spring', 2007, 'A ');
	insert into takes values('69952', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('79329', '808', '1', 'Fall', 2003, 'C ');
	insert into takes values('33201', '400', '1', 'Spring', 2007, 'A+');
	insert into takes values('10267', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('463', '747', '1', 'Spring', 2004, 'B-');
	insert into takes values('85451', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('44551', '366', '1', 'Fall', 2005, 'A+');
	insert into takes values('98843', '421', '1', 'Fall', 2004, 'C+');
	insert into takes values('21101', '408', '1', 'Spring', 2007, 'C ');
	insert into takes values('47824', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('85226', '468', '1', 'Fall', 2005, 'A+');
	insert into takes values('91978', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('83691', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('27236', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('51084', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('48778', '663', '1', 'Spring', 2005, 'B ');
	insert into takes values('80227', '599', '1', 'Spring', 2003, 'B-');
	insert into takes values('83204', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('8912', '735', '1', 'Spring', 2003, 'A ');
	insert into takes values('1922', '974', '1', 'Fall', 2003, 'C-');
	insert into takes values('17831', '626', '1', 'Fall', 2006, 'C+');
	insert into takes values('67560', '527', '1', 'Fall', 2004, 'B-');
	insert into takes values('25718', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('8860', '158', '1', 'Fall', 2008, 'C ');
	insert into takes values('12078', '443', '1', 'Spring', 2010, 'C ');
	insert into takes values('22258', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('43658', '962', '1', 'Spring', 2008, 'C-');
	insert into takes values('77172', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('47025', '443', '2', 'Spring', 2002, 'B+');
	insert into takes values('32483', '461', '1', 'Fall', 2002, 'B+');
	insert into takes values('68649', '352', '1', 'Spring', 2006, 'A-');
	insert into takes values('80698', '694', '1', 'Fall', 2002, 'C ');
	insert into takes values('43505', '476', '1', 'Fall', 2010, 'B ');
	insert into takes values('64893', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('13217', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('16543', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('94620', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('9933', '239', '1', 'Fall', 2006, 'C+');
	insert into takes values('13028', '489', '1', 'Fall', 2007, 'B+');
	insert into takes values('43032', '581', '1', 'Spring', 2005, 'A-');
	insert into takes values('25077', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('79469', '694', '1', 'Fall', 2002, 'B ');
	insert into takes values('14182', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('65703', '527', '1', 'Fall', 2004, 'A-');
	insert into takes values('7390', '476', '1', 'Fall', 2010, 'C ');
	insert into takes values('14284', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('86529', '960', '2', 'Fall', 2006, 'A-');
	insert into takes values('95697', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('52019', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('71389', '169', '1', 'Spring', 2007, 'C ');
	insert into takes values('54728', '559', '1', 'Fall', 2002, 'C+');
	insert into takes values('31250', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('56003', '604', '1', 'Spring', 2009, 'C ');
	insert into takes values('42114', '735', '1', 'Spring', 2003, 'A ');
	insert into takes values('96895', '482', '1', 'Fall', 2005, 'B-');
	insert into takes values('46441', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('94894', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('84239', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('82687', '158', '2', 'Spring', 2008, 'C ');
	insert into takes values('22226', '304', '1', 'Fall', 2009, 'B+');
	insert into takes values('51817', '679', '1', 'Spring', 2010, 'B+');
	insert into takes values('45359', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('65144', '864', '1', 'Spring', 2006, 'C+');
	insert into takes values('32376', '692', '1', 'Spring', 2010, 'C ');
	insert into takes values('9183', '561', '1', 'Fall', 2006, 'A-');
	insert into takes values('35462', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('5925', '345', '1', 'Spring', 2008, 'A+');
	insert into takes values('61332', '852', '1', 'Spring', 2008, 'A ');
	insert into takes values('71878', '702', '1', 'Spring', 2001, 'C-');
	insert into takes values('19362', '702', '1', 'Spring', 2001, 'A-');
	insert into takes values('68150', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('32369', '200', '2', 'Fall', 2002, 'B+');
	insert into takes values('41965', '338', '2', 'Spring', 2006, 'B+');
	insert into takes values('9495', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('65205', '105', '2', 'Fall', 2002, 'A-');
	insert into takes values('26102', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('91442', '445', '1', 'Spring', 2001, 'B+');
	insert into takes values('24932', '760', '1', 'Spring', 2004, 'C ');
	insert into takes values('28518', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('13880', '603', '1', 'Fall', 2003, 'A ');
	insert into takes values('38668', '313', '1', 'Fall', 2010, 'B ');
	insert into takes values('91799', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('82039', '200', '1', 'Spring', 2007, 'C-');
	insert into takes values('98315', '704', '1', 'Spring', 2008, 'B ');
	insert into takes values('55329', '626', '1', 'Fall', 2006, 'B+');
	insert into takes values('64082', '545', '1', 'Fall', 2001, 'A ');
	insert into takes values('10267', '362', '2', 'Fall', 2006, 'B-');
	insert into takes values('9947', '735', '1', 'Spring', 2003, 'C ');
	insert into takes values('69132', '200', '2', 'Fall', 2002, 'A+');
	insert into takes values('33645', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('29091', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('95366', '545', '1', 'Fall', 2001, 'B-');
	insert into takes values('16849', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('28738', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('18709', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('65681', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('68096', '747', '1', 'Spring', 2004, 'C-');
	insert into takes values('62636', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('435', '642', '1', 'Fall', 2004, 'B-');
	insert into takes values('79170', '237', '1', 'Spring', 2008, 'A-');
	insert into takes values('35935', '443', '2', 'Spring', 2002, 'A-');
	insert into takes values('96772', '795', '1', 'Spring', 2004, 'B-');
	insert into takes values('24325', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('75878', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('81150', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('92839', '696', '1', 'Spring', 2002, 'C-');
	insert into takes values('26473', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('28994', '169', '2', 'Fall', 2002, 'A ');
	insert into takes values('77130', '808', '1', 'Fall', 2003, 'A+');
	insert into takes values('18740', '482', '1', 'Fall', 2005, 'A+');
	insert into takes values('16467', '793', '1', 'Spring', 2002, 'C ');
	insert into takes values('17339', '313', '1', 'Fall', 2010, 'C ');
	insert into takes values('75510', '158', '2', 'Spring', 2008, 'C-');
	insert into takes values('57985', '443', '1', 'Spring', 2010, 'C ');
	insert into takes values('67018', '401', '1', 'Fall', 2003, 'A+');
	insert into takes values('63645', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('55170', '735', '1', 'Spring', 2003, 'C-');
	insert into takes values('72165', '599', '1', 'Spring', 2003, 'A ');
	insert into takes values('57135', '864', '1', 'Spring', 2006, 'A+');
	insert into takes values('28252', '457', '1', 'Spring', 2001, 'B+');
	insert into takes values('80799', '468', '1', 'Fall', 2005, 'C+');
	insert into takes values('93366', '426', '1', 'Spring', 2006, 'B ');
	insert into takes values('28133', '158', '1', 'Fall', 2008, 'C-');
	insert into takes values('56299', '972', '1', 'Spring', 2009, 'A ');
	insert into takes values('27804', '747', '1', 'Spring', 2004, 'B-');
	insert into takes values('59172', '489', '1', 'Fall', 2007, 'B+');
	insert into takes values('16075', '242', '1', 'Fall', 2009, 'A+');
	insert into takes values('27804', '376', '1', 'Fall', 2006, 'B-');
	insert into takes values('1726', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('69285', '972', '1', 'Spring', 2009, 'C-');
	insert into takes values('50702', '200', '1', 'Spring', 2007, 'C ');
	insert into takes values('48850', '735', '1', 'Spring', 2003, 'A+');
	insert into takes values('37586', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('77234', '468', '1', 'Fall', 2005, 'B+');
	insert into takes values('11510', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('50039', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('22620', '443', '2', 'Spring', 2002, 'B ');
	insert into takes values('978', '158', '2', 'Spring', 2008, 'C+');
	insert into takes values('32376', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('3487', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('79329', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('64121', '345', '1', 'Spring', 2008, 'B ');
	insert into takes values('75513', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('22417', '319', '1', 'Spring', 2003, 'C+');
	insert into takes values('94697', '401', '1', 'Fall', 2003, 'B+');
	insert into takes values('36881', '352', '1', 'Spring', 2006, 'A-');
	insert into takes values('65205', '962', '1', 'Spring', 2008, 'B-');
	insert into takes values('76911', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('71631', '105', '1', 'Fall', 2009, 'C+');
	insert into takes values('9256', '304', '1', 'Fall', 2009, 'C-');
	insert into takes values('26494', '875', '1', 'Spring', 2005, 'B-');
	insert into takes values('54622', '304', '1', 'Fall', 2009, 'C-');
	insert into takes values('50013', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('25187', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('70362', '313', '1', 'Fall', 2010, 'C-');
	insert into takes values('57107', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('40558', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('34542', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('1285', '561', '1', 'Fall', 2006, 'A-');
	insert into takes values('11195', '972', '1', 'Spring', 2009, 'C ');
	insert into takes values('89132', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('53077', '960', '1', 'Fall', 2009, 'A+');
	insert into takes values('53048', '748', '1', 'Fall', 2003, 'B-');
	insert into takes values('57985', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('73072', '169', '1', 'Spring', 2007, 'B+');
	insert into takes values('75878', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('435', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('48165', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('9495', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('48247', '345', '1', 'Spring', 2008, 'B-');
	insert into takes values('25362', '702', '1', 'Spring', 2001, 'C-');
	insert into takes values('77000', '105', '1', 'Fall', 2009, 'B ');
	insert into takes values('51817', '468', '1', 'Fall', 2005, 'C ');
	insert into takes values('99451', '274', '1', 'Fall', 2002, 'B ');
	insert into takes values('28133', '559', '1', 'Fall', 2002, 'C+');
	insert into takes values('507', '960', '2', 'Fall', 2006, 'C-');
	insert into takes values('78116', '559', '1', 'Fall', 2002, 'C+');
	insert into takes values('32954', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('5703', '867', '2', 'Fall', 2010, 'C ');
	insert into takes values('57941', '270', '1', 'Spring', 2010, 'A-');
	insert into takes values('52494', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('11262', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('1533', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('22086', '875', '1', 'Spring', 2005, 'A ');
	insert into takes values('30289', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('3335', '893', '1', 'Fall', 2007, 'C ');
	insert into takes values('77130', '242', '1', 'Fall', 2009, 'B ');
	insert into takes values('41450', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('41965', '489', '1', 'Fall', 2007, 'C ');
	insert into takes values('31266', '748', '1', 'Fall', 2003, 'B-');
	insert into takes values('7514', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('94620', '270', '1', 'Spring', 2010, 'B+');
	insert into takes values('1726', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('54508', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('76173', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('87280', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('1737', '408', '2', 'Spring', 2003, 'C-');
	insert into takes values('38476', '489', '1', 'Fall', 2007, 'C ');
	insert into takes values('5144', '642', '1', 'Fall', 2004, 'B+');
	insert into takes values('30896', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('23311', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('96052', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('95029', '334', '1', 'Fall', 2009, 'A ');
	insert into takes values('98619', '663', '1', 'Spring', 2005, 'A-');
	insert into takes values('20244', '735', '2', 'Spring', 2010, 'A ');
	insert into takes values('88302', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('90609', '629', '1', 'Spring', 2003, 'B-');
	insert into takes values('96324', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('82918', '599', '1', 'Spring', 2003, 'A ');
	insert into takes values('19536', '200', '1', 'Spring', 2007, 'A+');
	insert into takes values('93631', '200', '2', 'Fall', 2002, 'B+');
	insert into takes values('84727', '489', '1', 'Fall', 2007, 'A-');
	insert into takes values('63645', '313', '1', 'Fall', 2010, 'A-');
	insert into takes values('7498', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('75928', '603', '1', 'Fall', 2003, 'B-');
	insert into takes values('38013', '704', '1', 'Spring', 2008, 'B ');
	insert into takes values('94766', '949', '1', 'Fall', 2007, 'C+');
	insert into takes values('15340', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('59455', '258', '1', 'Fall', 2007, 'A ');
	insert into takes values('21337', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('27950', '527', '1', 'Fall', 2004, 'B+');
	insert into takes values('83691', '468', '2', 'Fall', 2007, 'C-');
	insert into takes values('48776', '696', '1', 'Spring', 2002, 'A+');
	insert into takes values('68396', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('99949', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('8483', '760', '1', 'Spring', 2004, 'B+');
	insert into takes values('27952', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('85063', '748', '1', 'Fall', 2003, 'C ');
	insert into takes values('70299', '270', '1', 'Spring', 2010, 'C ');
	insert into takes values('72485', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('44551', '527', '1', 'Fall', 2004, 'C-');
	insert into takes values('36303', '349', '1', 'Spring', 2008, 'C-');
	insert into takes values('15144', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('64164', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('11578', '974', '1', 'Fall', 2003, 'C ');
	insert into takes values('52471', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('89759', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('3127', '702', '1', 'Spring', 2001, 'C+');
	insert into takes values('59848', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('64155', '338', '2', 'Spring', 2006, 'A ');
	insert into takes values('24784', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('94142', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('70061', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('39238', '802', '1', 'Spring', 2003, 'B+');
	insert into takes values('89551', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('7732', '735', '2', 'Spring', 2010, 'B ');
	insert into takes values('77130', '445', '1', 'Spring', 2001, 'B+');
	insert into takes values('10838', '927', '1', 'Fall', 2002, 'A-');
	insert into takes values('16035', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('3127', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('50664', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('5208', '852', '1', 'Spring', 2008, 'A-');
	insert into takes values('47379', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('73387', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('28994', '561', '1', 'Fall', 2006, 'B+');
	insert into takes values('99760', '362', '3', 'Spring', 2008, 'C-');
	insert into takes values('66281', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('4508', '400', '1', 'Spring', 2007, 'B ');
	insert into takes values('32369', '867', '1', 'Fall', 2006, 'B+');
	insert into takes values('8251', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('71287', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('66269', '486', '1', 'Fall', 2009, 'B-');
	insert into takes values('4582', '242', '1', 'Fall', 2009, 'A-');
	insert into takes values('86375', '169', '2', 'Fall', 2002, 'B ');
	insert into takes values('90220', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('5925', '468', '2', 'Fall', 2007, 'C+');
	insert into takes values('21692', '408', '1', 'Spring', 2007, 'C+');
	insert into takes values('37219', '457', '1', 'Spring', 2001, 'C+');
	insert into takes values('88553', '400', '1', 'Spring', 2007, 'B ');
	insert into takes values('66494', '270', '1', 'Spring', 2010, 'C ');
	insert into takes values('62705', '461', '1', 'Fall', 2002, 'A-');
	insert into takes values('65101', '400', '1', 'Spring', 2007, 'C+');
	insert into takes values('65676', '443', '2', 'Spring', 2002, 'C ');
	insert into takes values('19321', '400', '2', 'Fall', 2003, 'A+');
	insert into takes values('70965', '169', '2', 'Fall', 2002, 'B-');
	insert into takes values('79534', '258', '1', 'Fall', 2007, 'C-');
	insert into takes values('30957', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('45494', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('74796', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('41091', '893', '1', 'Fall', 2007, 'C+');
	insert into takes values('63860', '200', '2', 'Fall', 2002, 'C+');
	insert into takes values('60249', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('48009', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('2201', '345', '1', 'Spring', 2008, 'B-');
	insert into takes values('52291', '692', '1', 'Spring', 2010, 'C ');
	insert into takes values('31080', '663', '1', 'Spring', 2005, 'C-');
	insert into takes values('41406', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('35175', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('55531', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('39612', '105', '1', 'Fall', 2009, 'C+');
	insert into takes values('65979', '972', '1', 'Spring', 2009, 'C ');
	insert into takes values('5414', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('858', '169', '1', 'Spring', 2007, 'A ');
	insert into takes values('33645', '334', '1', 'Fall', 2009, 'B ');
	insert into takes values('5843', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('59397', '489', '1', 'Fall', 2007, 'B+');
	insert into takes values('31554', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('67407', '468', '2', 'Fall', 2007, 'A+');
	insert into takes values('18709', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('13028', '696', '1', 'Spring', 2002, 'C+');
	insert into takes values('13753', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('25331', '735', '1', 'Spring', 2003, 'C+');
	insert into takes values('98940', '169', '2', 'Fall', 2002, 'A+');
	insert into takes values('43032', '258', '1', 'Fall', 2007, 'C ');
	insert into takes values('14869', '760', '1', 'Spring', 2004, 'A-');
	insert into takes values('35721', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('52872', '457', '1', 'Spring', 2001, 'C-');
	insert into takes values('89051', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('88389', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('39552', '338', '1', 'Spring', 2007, 'C+');
	insert into takes values('81538', '735', '1', 'Spring', 2003, 'C-');
	insert into takes values('96895', '867', '1', 'Fall', 2006, 'A-');
	insert into takes values('84845', '200', '1', 'Spring', 2007, 'A+');
	insert into takes values('25718', '362', '2', 'Fall', 2006, 'A ');
	insert into takes values('41674', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('11510', '362', '1', 'Fall', 2005, 'B ');
	insert into takes values('37350', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('78454', '486', '1', 'Fall', 2009, 'A ');
	insert into takes values('17207', '200', '2', 'Fall', 2002, 'C+');
	insert into takes values('51084', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('52057', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('49982', '867', '2', 'Fall', 2010, 'A+');
	insert into takes values('49792', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('53048', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('21395', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('6895', '258', '1', 'Fall', 2007, 'B+');
	insert into takes values('8807', '345', '1', 'Spring', 2008, 'B-');
	insert into takes values('71529', '591', '1', 'Spring', 2005, 'B-');
	insert into takes values('41671', '949', '1', 'Fall', 2007, 'B ');
	insert into takes values('41280', '345', '1', 'Spring', 2008, 'B-');
	insert into takes values('15074', '489', '1', 'Fall', 2007, 'B ');
	insert into takes values('21008', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('336', '496', '1', 'Fall', 2001, 'B ');
	insert into takes values('99754', '559', '1', 'Fall', 2002, 'B+');
	insert into takes values('99949', '962', '1', 'Spring', 2008, 'A ');
	insert into takes values('32385', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('72768', '338', '2', 'Spring', 2006, 'A-');
	insert into takes values('71543', '559', '1', 'Fall', 2002, 'A-');
	insert into takes values('77218', '802', '1', 'Spring', 2003, 'A+');
	insert into takes values('66054', '105', '2', 'Fall', 2002, 'B-');
	insert into takes values('11237', '972', '1', 'Spring', 2009, 'B+');
	insert into takes values('14032', '443', '2', 'Spring', 2002, 'B-');
	insert into takes values('15517', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('9495', '362', '1', 'Fall', 2005, 'B ');
	insert into takes values('3833', '304', '1', 'Fall', 2009, 'A+');
	insert into takes values('2423', '200', '1', 'Spring', 2007, 'A+');
	insert into takes values('68330', '704', '1', 'Spring', 2008, 'C ');
	insert into takes values('13506', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('62124', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('11055', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('99711', '400', '1', 'Spring', 2007, 'A+');
	insert into takes values('60267', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('5144', '313', '1', 'Fall', 2010, 'C+');
	insert into takes values('78481', '338', '2', 'Spring', 2006, 'B ');
	insert into takes values('71287', '559', '1', 'Fall', 2002, 'B ');
	insert into takes values('75938', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('11262', '493', '1', 'Spring', 2010, 'A+');
	insert into takes values('46260', '626', '1', 'Fall', 2006, 'B+');
	insert into takes values('33338', '843', '1', 'Fall', 2010, 'B-');
	insert into takes values('17924', '747', '1', 'Spring', 2004, 'C ');
	insert into takes values('1968', '694', '1', 'Fall', 2002, 'A ');
	insert into takes values('86552', '334', '1', 'Fall', 2009, 'A ');
	insert into takes values('95852', '747', '1', 'Spring', 2004, 'C-');
	insert into takes values('52471', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('88045', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('98315', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('507', '415', '1', 'Fall', 2010, 'C+');
	insert into takes values('25362', '559', '1', 'Fall', 2002, 'C+');
	insert into takes values('15487', '545', '1', 'Fall', 2001, 'A+');
	insert into takes values('20099', '105', '1', 'Fall', 2009, 'C+');
	insert into takes values('30182', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('54622', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('92464', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('65144', '349', '1', 'Spring', 2008, 'A ');
	insert into takes values('41671', '959', '1', 'Fall', 2006, 'B ');
	insert into takes values('49214', '702', '1', 'Spring', 2001, 'C-');
	insert into takes values('6400', '612', '1', 'Fall', 2007, 'A+');
	insert into takes values('19824', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('70918', '991', '1', 'Spring', 2008, 'A ');
	insert into takes values('24784', '735', '1', 'Spring', 2003, 'C ');
	insert into takes values('69758', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('49339', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('99348', '352', '1', 'Spring', 2006, 'A+');
	insert into takes values('17397', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('61364', '735', '1', 'Spring', 2003, 'A ');
	insert into takes values('50583', '735', '2', 'Spring', 2010, 'B-');
	insert into takes values('18740', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('80821', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('87965', '169', '1', 'Spring', 2007, 'C+');
	insert into takes values('50013', '158', '1', 'Fall', 2008, 'A ');
	insert into takes values('28977', '362', '3', 'Spring', 2008, 'B ');
	insert into takes values('60249', '581', '1', 'Spring', 2005, 'A ');
	insert into takes values('57787', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('95201', '626', '1', 'Fall', 2006, 'A ');
	insert into takes values('5208', '426', '1', 'Spring', 2006, 'A-');
	insert into takes values('61354', '603', '1', 'Fall', 2003, 'A+');
	insert into takes values('931', '626', '1', 'Fall', 2006, 'A-');
	insert into takes values('73213', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('63390', '415', '1', 'Fall', 2010, 'C+');
	insert into takes values('63288', '158', '2', 'Spring', 2008, 'A-');
	insert into takes values('5925', '443', '1', 'Spring', 2010, 'B-');
	insert into takes values('15328', '158', '1', 'Fall', 2008, 'C-');
	insert into takes values('28361', '793', '1', 'Spring', 2002, 'A-');
	insert into takes values('13211', '445', '1', 'Spring', 2001, 'C ');
	insert into takes values('53225', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('95046', '747', '1', 'Spring', 2004, 'B+');
	insert into takes values('23934', '591', '1', 'Spring', 2005, 'C+');
	insert into takes values('94535', '696', '1', 'Spring', 2002, 'B ');
	insert into takes values('93171', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('40937', '603', '1', 'Fall', 2003, 'B+');
	insert into takes values('2501', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('70235', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('78756', '313', '1', 'Fall', 2010, 'A-');
	insert into takes values('43854', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('1285', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('59553', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('13408', '242', '1', 'Fall', 2009, 'C+');
	insert into takes values('57123', '604', '1', 'Spring', 2009, 'B ');
	insert into takes values('978', '270', '1', 'Spring', 2010, 'C+');
	insert into takes values('73492', '527', '1', 'Fall', 2004, 'C ');
	insert into takes values('16250', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('88169', '875', '1', 'Spring', 2005, 'B-');
	insert into takes values('88302', '694', '1', 'Fall', 2002, 'B-');
	insert into takes values('29399', '561', '1', 'Fall', 2006, 'C ');
	insert into takes values('64039', '158', '1', 'Fall', 2008, 'A-');
	insert into takes values('85910', '927', '1', 'Fall', 2002, 'C+');
	insert into takes values('52876', '334', '1', 'Fall', 2009, 'A ');
	insert into takes values('88358', '443', '2', 'Spring', 2002, 'A-');
	insert into takes values('38691', '443', '2', 'Spring', 2002, 'C-');
	insert into takes values('34422', '313', '1', 'Fall', 2010, 'B+');
	insert into takes values('54622', '561', '1', 'Fall', 2006, 'B-');
	insert into takes values('49244', '927', '1', 'Fall', 2002, 'A ');
	insert into takes values('43981', '791', '1', 'Spring', 2006, 'A ');
	insert into takes values('96203', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('23934', '237', '1', 'Spring', 2008, 'B-');
	insert into takes values('792', '527', '1', 'Fall', 2004, 'A-');
	insert into takes values('22258', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('83039', '461', '1', 'Fall', 2002, 'A-');
	insert into takes values('46769', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('98984', '158', '2', 'Spring', 2008, 'B-');
	insert into takes values('8853', '748', '1', 'Fall', 2003, 'C ');
	insert into takes values('86934', '376', '1', 'Fall', 2006, 'B+');
	insert into takes values('74464', '362', '1', 'Fall', 2005, 'B ');
	insert into takes values('67657', '561', '1', 'Fall', 2006, 'C ');
	insert into takes values('33460', '747', '1', 'Spring', 2004, 'C ');
	insert into takes values('50703', '591', '1', 'Spring', 2005, 'B+');
	insert into takes values('29462', '482', '1', 'Fall', 2005, 'B ');
	insert into takes values('80047', '158', '1', 'Fall', 2008, 'C-');
	insert into takes values('69952', '852', '1', 'Spring', 2008, 'C ');
	insert into takes values('19541', '571', '1', 'Spring', 2004, 'A+');
	insert into takes values('24002', '105', '2', 'Fall', 2002, 'C-');
	insert into takes values('72485', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('82646', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('52157', '158', '2', 'Spring', 2008, 'C-');
	insert into takes values('25331', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('65056', '604', '1', 'Spring', 2009, 'B-');
	insert into takes values('91799', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('18821', '376', '1', 'Fall', 2006, 'C ');
	insert into takes values('1922', '793', '1', 'Spring', 2002, 'A ');
	insert into takes values('46074', '559', '1', 'Fall', 2002, 'A ');
	insert into takes values('41491', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('21100', '748', '1', 'Fall', 2003, 'C-');
	insert into takes values('78858', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('73908', '972', '1', 'Spring', 2009, 'B ');
	insert into takes values('53799', '927', '1', 'Fall', 2002, 'C-');
	insert into takes values('53469', '875', '1', 'Spring', 2005, 'A-');
	insert into takes values('79205', '476', '1', 'Fall', 2010, 'B ');
	insert into takes values('14484', '362', '2', 'Fall', 2006, 'A-');
	insert into takes values('93508', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('87280', '959', '1', 'Fall', 2006, 'B+');
	insert into takes values('26881', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('41406', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('27727', '692', '1', 'Spring', 2010, 'A ');
	insert into takes values('33546', '843', '1', 'Fall', 2010, 'B-');
	insert into takes values('58413', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('63645', '875', '1', 'Spring', 2005, 'B+');
	insert into takes values('16885', '604', '1', 'Spring', 2009, 'C ');
	insert into takes values('92864', '960', '1', 'Fall', 2009, 'B+');
	insert into takes values('44038', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('66753', '843', '1', 'Fall', 2010, 'A+');
	insert into takes values('20195', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('19917', '960', '1', 'Fall', 2009, 'A-');
	insert into takes values('7970', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('83002', '949', '1', 'Fall', 2007, 'A-');
	insert into takes values('34404', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('55857', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('91915', '852', '1', 'Spring', 2008, 'C+');
	insert into takes values('94697', '864', '1', 'Spring', 2006, 'B ');
	insert into takes values('85226', '626', '1', 'Fall', 2006, 'A ');
	insert into takes values('41832', '376', '1', 'Fall', 2006, 'C+');
	insert into takes values('13504', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('10481', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('69747', '304', '1', 'Fall', 2009, 'C+');
	insert into takes values('50969', '461', '1', 'Fall', 2002, 'B+');
	insert into takes values('36402', '345', '1', 'Spring', 2008, 'A ');
	insert into takes values('94620', '338', '2', 'Spring', 2006, 'A ');
	insert into takes values('58634', '679', '1', 'Spring', 2010, 'B-');
	insert into takes values('72501', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('24746', '445', '1', 'Spring', 2001, 'A-');
	insert into takes values('68649', '599', '1', 'Spring', 2003, 'A+');
	insert into takes values('72014', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('97551', '559', '1', 'Fall', 2002, 'C+');
	insert into takes values('29959', '867', '1', 'Fall', 2006, 'A+');
	insert into takes values('15726', '376', '1', 'Fall', 2006, 'B ');
	insert into takes values('67340', '679', '1', 'Spring', 2010, 'A+');
	insert into takes values('15698', '468', '2', 'Fall', 2007, 'C+');
	insert into takes values('93653', '808', '1', 'Fall', 2003, 'A-');
	insert into takes values('87268', '242', '1', 'Fall', 2009, 'A-');
	insert into takes values('49701', '338', '2', 'Spring', 2006, 'C ');
	insert into takes values('55009', '959', '1', 'Fall', 2006, 'A+');
	insert into takes values('12941', '443', '1', 'Spring', 2010, 'B+');
	insert into takes values('2419', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('21009', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('888', '401', '1', 'Fall', 2003, 'C ');
	insert into takes values('24630', '408', '2', 'Spring', 2003, 'A ');
	insert into takes values('16133', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('20195', '867', '1', 'Fall', 2006, 'B ');
	insert into takes values('41894', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('31341', '960', '2', 'Fall', 2006, 'B-');
	insert into takes values('54672', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('77580', '362', '1', 'Fall', 2005, 'B ');
	insert into takes values('85226', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('66259', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('31250', '239', '1', 'Fall', 2006, 'A-');
	insert into takes values('68554', '959', '1', 'Fall', 2006, 'A ');
	insert into takes values('6895', '443', '2', 'Spring', 2002, 'C-');
	insert into takes values('70572', '445', '1', 'Spring', 2001, 'C ');
	insert into takes values('40932', '496', '1', 'Fall', 2001, 'B-');
	insert into takes values('31624', '426', '1', 'Spring', 2006, 'A+');
	insert into takes values('36791', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('69850', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('55940', '747', '1', 'Spring', 2004, 'A ');
	insert into takes values('11262', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('91915', '631', '1', 'Spring', 2007, 'A ');
	insert into takes values('82591', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('34392', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('6523', '200', '2', 'Fall', 2002, 'C-');
	insert into takes values('99949', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('68248', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('79911', '793', '1', 'Spring', 2002, 'B ');
	insert into takes values('89297', '362', '3', 'Spring', 2008, 'A+');
	insert into takes values('80113', '612', '1', 'Fall', 2007, 'A-');
	insert into takes values('16631', '991', '1', 'Spring', 2008, 'C-');
	insert into takes values('32245', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('95284', '158', '2', 'Spring', 2008, 'C-');
	insert into takes values('31554', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('66484', '696', '1', 'Spring', 2002, 'C-');
	insert into takes values('31086', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('46970', '748', '1', 'Fall', 2003, 'C-');
	insert into takes values('54672', '974', '1', 'Fall', 2003, 'A+');
	insert into takes values('60366', '735', '1', 'Spring', 2003, 'C ');
	insert into takes values('88358', '793', '1', 'Spring', 2002, 'A-');
	insert into takes values('96085', '352', '1', 'Spring', 2006, 'A-');
	insert into takes values('65396', '561', '1', 'Fall', 2006, 'B+');
	insert into takes values('50414', '760', '1', 'Spring', 2004, 'C+');
	insert into takes values('84845', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('48471', '612', '1', 'Fall', 2007, 'B-');
	insert into takes values('4034', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('46928', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('8347', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('85680', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('16311', '376', '1', 'Fall', 2006, 'B+');
	insert into takes values('89571', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('56080', '242', '1', 'Fall', 2009, 'B ');
	insert into takes values('33206', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('49813', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('45770', '581', '1', 'Spring', 2005, 'C ');
	insert into takes values('96178', '443', '2', 'Spring', 2002, 'C+');
	insert into takes values('25380', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('16593', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('63289', '959', '1', 'Fall', 2006, 'B ');
	insert into takes values('74639', '169', '2', 'Fall', 2002, 'A ');
	insert into takes values('66293', '527', '1', 'Fall', 2004, 'C ');
	insert into takes values('20244', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('62520', '612', '1', 'Fall', 2007, 'B-');
	insert into takes values('91132', '258', '1', 'Fall', 2007, 'C+');
	insert into takes values('29803', '408', '1', 'Spring', 2007, 'A+');
	insert into takes values('13511', '468', '1', 'Fall', 2005, 'B+');
	insert into takes values('90381', '972', '1', 'Spring', 2009, 'B+');
	insert into takes values('41345', '631', '1', 'Spring', 2007, 'C-');
	insert into takes values('95201', '629', '1', 'Spring', 2003, 'B-');
	insert into takes values('78116', '445', '1', 'Spring', 2001, 'B+');
	insert into takes values('32886', '200', '1', 'Spring', 2007, 'A-');
	insert into takes values('73072', '791', '1', 'Spring', 2006, 'B+');
	insert into takes values('75791', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('70362', '991', '1', 'Spring', 2008, 'B ');
	insert into takes values('87246', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('64138', '599', '1', 'Spring', 2003, 'C+');
	insert into takes values('39115', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('27044', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('53451', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('85234', '274', '1', 'Fall', 2002, 'C+');
	insert into takes values('40116', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('74464', '496', '1', 'Fall', 2001, 'A-');
	insert into takes values('56089', '200', '1', 'Spring', 2007, 'B-');
	insert into takes values('51678', '735', '1', 'Spring', 2003, 'B-');
	insert into takes values('62795', '496', '1', 'Fall', 2001, 'B+');
	insert into takes values('6895', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('33645', '629', '1', 'Spring', 2003, 'B+');
	insert into takes values('57538', '735', '1', 'Spring', 2003, 'B-');
	insert into takes values('96741', '461', '1', 'Fall', 2002, 'B+');
	insert into takes values('82082', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('46725', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('75252', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('15457', '927', '1', 'Fall', 2002, 'A-');
	insert into takes values('4940', '612', '1', 'Fall', 2007, 'B-');
	insert into takes values('80990', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('82697', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('68453', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('99780', '239', '1', 'Fall', 2006, 'A-');
	insert into takes values('32245', '875', '1', 'Spring', 2005, 'A-');
	insert into takes values('34195', '959', '1', 'Fall', 2006, 'B ');
	insert into takes values('69628', '867', '2', 'Fall', 2010, 'C ');
	insert into takes values('68070', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('58595', '237', '2', 'Fall', 2009, 'A ');
	insert into takes values('95626', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('41671', '105', '1', 'Fall', 2009, 'C+');
	insert into takes values('3163', '338', '2', 'Spring', 2006, 'A ');
	insert into takes values('99451', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('35498', '867', '2', 'Fall', 2010, 'C-');
	insert into takes values('60406', '468', '1', 'Fall', 2005, 'C ');
	insert into takes values('81258', '426', '1', 'Spring', 2006, 'A+');
	insert into takes values('41299', '852', '1', 'Spring', 2008, 'C+');
	insert into takes values('9953', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('1018', '349', '1', 'Spring', 2008, 'A-');
	insert into takes values('64140', '461', '1', 'Fall', 2002, 'B+');
	insert into takes values('49759', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('78922', '972', '1', 'Spring', 2009, 'A-');
	insert into takes values('41599', '604', '1', 'Spring', 2009, 'A-');
	insert into takes values('64550', '692', '1', 'Spring', 2010, 'A-');
	insert into takes values('10838', '760', '1', 'Spring', 2004, 'C+');
	insert into takes values('91616', '270', '1', 'Spring', 2010, 'C ');
	insert into takes values('96968', '258', '1', 'Fall', 2007, 'A ');
	insert into takes values('25780', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('90181', '696', '1', 'Spring', 2002, 'B-');
	insert into takes values('2177', '400', '2', 'Fall', 2003, 'A ');
	insert into takes values('62549', '362', '1', 'Fall', 2005, 'C ');
	insert into takes values('21556', '242', '1', 'Fall', 2009, 'B ');
	insert into takes values('45720', '401', '1', 'Fall', 2003, 'C ');
	insert into takes values('61403', '867', '1', 'Fall', 2006, 'B+');
	insert into takes values('75510', '692', '1', 'Spring', 2010, 'C ');
	insert into takes values('66008', '443', '2', 'Spring', 2002, 'A-');
	insert into takes values('1726', '443', '2', 'Spring', 2002, 'A-');
	insert into takes values('89551', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('40116', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('75794', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('24442', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('99268', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('7149', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('9460', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('41675', '421', '1', 'Fall', 2004, 'A ');
	insert into takes values('75791', '237', '1', 'Spring', 2008, 'C+');
	insert into takes values('8022', '704', '1', 'Spring', 2008, 'C ');
	insert into takes values('70688', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('8860', '258', '1', 'Fall', 2007, 'C+');
	insert into takes values('29140', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('25068', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('38602', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('57456', '400', '1', 'Spring', 2007, 'C-');
	insert into takes values('76759', '527', '1', 'Fall', 2004, 'C ');
	insert into takes values('2970', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('41599', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('99073', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('15070', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('82868', '612', '1', 'Fall', 2007, 'A+');
	insert into takes values('38555', '694', '1', 'Fall', 2002, 'A+');
	insert into takes values('93004', '421', '1', 'Fall', 2004, 'A ');
	insert into takes values('35293', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('91197', '663', '1', 'Spring', 2005, 'C ');
	insert into takes values('16528', '362', '3', 'Spring', 2008, 'A+');
	insert into takes values('58846', '962', '1', 'Spring', 2008, 'B ');
	insert into takes values('99422', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('27366', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('22532', '559', '1', 'Fall', 2002, 'A ');
	insert into takes values('19203', '735', '2', 'Spring', 2010, 'B ');
	insert into takes values('4940', '960', '1', 'Fall', 2009, 'B-');
	insert into takes values('28004', '258', '1', 'Fall', 2007, 'C+');
	insert into takes values('46762', '663', '1', 'Spring', 2005, 'B-');
	insert into takes values('23373', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('82083', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('86661', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('78332', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('14668', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('61998', '561', '1', 'Fall', 2006, 'A-');
	insert into takes values('49618', '960', '2', 'Fall', 2006, 'B+');
	insert into takes values('30772', '960', '2', 'Fall', 2006, 'B-');
	insert into takes values('10454', '561', '1', 'Fall', 2006, 'B-');
	insert into takes values('63361', '401', '1', 'Fall', 2003, 'C+');
	insert into takes values('75273', '867', '1', 'Fall', 2006, 'A ');
	insert into takes values('97629', '692', '1', 'Spring', 2010, 'C+');
	insert into takes values('70522', '461', '1', 'Fall', 2002, 'C+');
	insert into takes values('77148', '793', '1', 'Spring', 2002, 'A-');
	insert into takes values('96772', '852', '1', 'Spring', 2008, 'C ');
	insert into takes values('71529', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('85754', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('64550', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('41965', '972', '1', 'Spring', 2009, 'C ');
	insert into takes values('40303', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('67514', '679', '1', 'Spring', 2010, 'B ');
	insert into takes values('94257', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('27687', '443', '2', 'Spring', 2002, 'C-');
	insert into takes values('15144', '443', '1', 'Spring', 2010, 'C+');
	insert into takes values('44584', '962', '1', 'Spring', 2008, 'C-');
	insert into takes values('83747', '591', '1', 'Spring', 2005, 'A-');
	insert into takes values('40189', '270', '1', 'Spring', 2010, 'B+');
	insert into takes values('43032', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('19048', '642', '1', 'Fall', 2004, 'A-');
	insert into takes values('82646', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('10917', '338', '2', 'Spring', 2006, 'B ');
	insert into takes values('6400', '345', '1', 'Spring', 2008, 'C ');
	insert into takes values('86375', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('37581', '875', '1', 'Spring', 2005, 'A-');
	insert into takes values('41751', '486', '1', 'Fall', 2009, 'C+');
	insert into takes values('5399', '692', '1', 'Spring', 2010, 'B-');
	insert into takes values('65190', '200', '1', 'Spring', 2007, 'B+');
	insert into takes values('70098', '747', '1', 'Spring', 2004, 'C-');
	insert into takes values('56499', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('70564', '629', '1', 'Spring', 2003, 'B+');
	insert into takes values('30021', '927', '1', 'Fall', 2002, 'A+');
	insert into takes values('89246', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('21102', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('83480', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('48640', '679', '1', 'Spring', 2010, 'C+');
	insert into takes values('1285', '304', '1', 'Fall', 2009, 'C-');
	insert into takes values('63582', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('11055', '629', '1', 'Spring', 2003, 'A ');
	insert into takes values('40677', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('69732', '366', '1', 'Fall', 2005, 'A ');
	insert into takes values('30110', '313', '1', 'Fall', 2010, 'B ');
	insert into takes values('10814', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('68720', '642', '1', 'Fall', 2004, 'B-');
	insert into takes values('88884', '105', '2', 'Fall', 2002, 'A-');
	insert into takes values('23506', '408', '2', 'Spring', 2003, 'B ');
	insert into takes values('11076', '258', '1', 'Fall', 2007, 'A+');
	insert into takes values('15698', '612', '1', 'Fall', 2007, 'A+');
	insert into takes values('46928', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('84845', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('35721', '468', '1', 'Fall', 2005, 'A+');
	insert into takes values('94371', '352', '1', 'Spring', 2006, 'C+');
	insert into takes values('75273', '626', '1', 'Fall', 2006, 'B-');
	insert into takes values('97551', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('68453', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('64155', '200', '2', 'Fall', 2002, 'C-');
	insert into takes values('98359', '571', '1', 'Spring', 2004, 'C-');
	insert into takes values('22179', '338', '2', 'Spring', 2006, 'C+');
	insert into takes values('29871', '735', '1', 'Spring', 2003, 'B-');
	insert into takes values('13921', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('29871', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('65688', '105', '1', 'Fall', 2009, 'C ');
	insert into takes values('90009', '105', '1', 'Fall', 2009, 'C-');
	insert into takes values('9993', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('42688', '461', '1', 'Fall', 2002, 'B-');
	insert into takes values('24116', '400', '2', 'Fall', 2003, 'B+');
	insert into takes values('48469', '443', '2', 'Spring', 2002, 'B+');
	insert into takes values('59553', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('79892', '949', '1', 'Fall', 2007, 'B ');
	insert into takes values('435', '496', '1', 'Fall', 2001, 'C ');
	insert into takes values('63289', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('32464', '415', '1', 'Fall', 2010, 'C ');
	insert into takes values('6195', '366', '1', 'Fall', 2005, 'A+');
	insert into takes values('53089', '493', '1', 'Spring', 2010, 'B+');
	insert into takes values('73268', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('21395', '313', '1', 'Fall', 2010, 'B-');
	insert into takes values('7854', '270', '1', 'Spring', 2010, 'B-');
	insert into takes values('76799', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('95029', '338', '1', 'Spring', 2007, 'A-');
	insert into takes values('96003', '313', '1', 'Fall', 2010, 'B-');
	insert into takes values('29849', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('99611', '468', '1', 'Fall', 2005, 'A+');
	insert into takes values('4383', '349', '1', 'Spring', 2008, 'A ');
	insert into takes values('99754', '421', '1', 'Fall', 2004, 'A ');
	insert into takes values('74672', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('84239', '270', '1', 'Spring', 2010, 'A+');
	insert into takes values('46035', '482', '1', 'Fall', 2005, 'B ');
	insert into takes values('69471', '270', '1', 'Spring', 2010, 'B+');
	insert into takes values('50583', '169', '2', 'Fall', 2002, 'A-');
	insert into takes values('98047', '362', '2', 'Fall', 2006, 'A ');
	insert into takes values('76759', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('50658', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('80742', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('85680', '793', '1', 'Spring', 2002, 'B+');
	insert into takes values('58874', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('45083', '169', '1', 'Spring', 2007, 'B ');
	insert into takes values('65208', '486', '1', 'Fall', 2009, 'A-');
	insert into takes values('53799', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('40116', '338', '1', 'Spring', 2007, 'A ');
	insert into takes values('24746', '169', '1', 'Spring', 2007, 'B ');
	insert into takes values('98984', '949', '1', 'Fall', 2007, 'C ');
	insert into takes values('67051', '795', '1', 'Spring', 2004, 'B ');
	insert into takes values('85445', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('81896', '169', '1', 'Spring', 2007, 'B ');
	insert into takes values('97065', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('64401', '559', '1', 'Fall', 2002, 'A ');
	insert into takes values('51678', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('33401', '258', '1', 'Fall', 2007, 'A-');
	insert into takes values('94620', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('7602', '137', '1', 'Spring', 2002, 'B+');
	insert into takes values('22050', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('88169', '242', '1', 'Fall', 2009, 'C ');
	insert into takes values('20540', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('29435', '313', '1', 'Fall', 2010, 'A ');
	insert into takes values('23224', '366', '1', 'Fall', 2005, 'C ');
	insert into takes values('64934', '319', '1', 'Spring', 2003, 'C+');
	insert into takes values('16849', '974', '1', 'Fall', 2003, 'A-');
	insert into takes values('73542', '137', '1', 'Spring', 2002, 'A-');
	insert into takes values('20002', '704', '1', 'Spring', 2008, 'C-');
	insert into takes values('14182', '852', '1', 'Spring', 2008, 'C+');
	insert into takes values('13081', '443', '2', 'Spring', 2002, 'B+');
	insert into takes values('92965', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('39157', '735', '1', 'Spring', 2003, 'A-');
	insert into takes values('5243', '313', '1', 'Fall', 2010, 'C-');
	insert into takes values('90914', '137', '1', 'Spring', 2002, 'C-');
	insert into takes values('858', '200', '1', 'Spring', 2007, 'A ');
	insert into takes values('58606', '158', '2', 'Spring', 2008, 'C+');
	insert into takes values('15249', '468', '2', 'Fall', 2007, 'C-');
	insert into takes values('48778', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('72657', '105', '1', 'Fall', 2009, 'B+');
	insert into takes values('10454', '468', '1', 'Fall', 2005, 'A ');
	insert into takes values('32881', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('55940', '345', '1', 'Spring', 2008, 'C+');
	insert into takes values('98359', '401', '1', 'Fall', 2003, 'A+');
	insert into takes values('12216', '694', '1', 'Fall', 2002, 'A ');
	insert into takes values('36791', '793', '1', 'Spring', 2002, 'B+');
	insert into takes values('62749', '408', '2', 'Spring', 2003, 'A+');
	insert into takes values('80990', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('21692', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('89132', '376', '1', 'Fall', 2006, 'A-');
	insert into takes values('9114', '960', '2', 'Fall', 2006, 'A ');
	insert into takes values('71768', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('69581', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('11195', '258', '1', 'Fall', 2007, 'B+');
	insert into takes values('36845', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('35498', '105', '2', 'Fall', 2002, 'C+');
	insert into takes values('73072', '476', '1', 'Fall', 2010, 'C-');
	insert into takes values('35042', '571', '1', 'Spring', 2004, 'C-');
	insert into takes values('45359', '401', '1', 'Fall', 2003, 'C-');
	insert into takes values('29849', '561', '1', 'Fall', 2006, 'C+');
	insert into takes values('84704', '735', '1', 'Spring', 2003, 'C+');
	insert into takes values('41832', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('92464', '443', '2', 'Spring', 2002, 'B+');
	insert into takes values('95029', '612', '1', 'Fall', 2007, 'A+');
	insert into takes values('11578', '642', '1', 'Fall', 2004, 'C+');
	insert into takes values('10269', '352', '1', 'Spring', 2006, 'C-');
	insert into takes values('83136', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('22170', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('54610', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('17996', '735', '1', 'Spring', 2003, 'A+');
	insert into takes values('91992', '468', '1', 'Fall', 2005, 'A+');
	insert into takes values('61354', '626', '1', 'Fall', 2006, 'B ');
	insert into takes values('81884', '663', '1', 'Spring', 2005, 'B ');
	insert into takes values('93508', '445', '1', 'Spring', 2001, 'A-');
	insert into takes values('3005', '808', '1', 'Fall', 2003, 'C ');
	insert into takes values('51579', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('34322', '679', '1', 'Spring', 2010, 'C+');
	insert into takes values('57666', '867', '2', 'Fall', 2010, 'B-');
	insert into takes values('10814', '105', '1', 'Fall', 2009, 'C-');
	insert into takes values('86661', '242', '1', 'Fall', 2009, 'C-');
	insert into takes values('3651', '949', '1', 'Fall', 2007, 'B ');
	insert into takes values('31560', '408', '1', 'Spring', 2007, 'C ');
	insert into takes values('73072', '802', '1', 'Spring', 2003, 'B+');
	insert into takes values('20099', '545', '1', 'Fall', 2001, 'B-');
	insert into takes values('82580', '561', '1', 'Fall', 2006, 'C ');
	insert into takes values('25525', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('59530', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('1922', '237', '1', 'Spring', 2008, 'B-');
	insert into takes values('51678', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('37038', '867', '2', 'Fall', 2010, 'C-');
	insert into takes values('8251', '426', '1', 'Spring', 2006, 'A-');
	insert into takes values('45570', '852', '1', 'Spring', 2008, 'B ');
	insert into takes values('93571', '559', '1', 'Fall', 2002, 'B ');
	insert into takes values('40116', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('70235', '960', '2', 'Fall', 2006, 'C+');
	insert into takes values('6523', '426', '1', 'Spring', 2006, 'A-');
	insert into takes values('58595', '702', '1', 'Spring', 2001, 'B-');
	insert into takes values('5399', '679', '1', 'Spring', 2010, 'C-');
	insert into takes values('11966', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('79772', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('35138', '239', '1', 'Fall', 2006, 'B-');
	insert into takes values('13495', '338', '2', 'Spring', 2006, 'C ');
	insert into takes values('58701', '376', '1', 'Fall', 2006, 'B-');
	insert into takes values('88887', '760', '1', 'Spring', 2004, 'C ');
	insert into takes values('52494', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('31250', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('53803', '457', '1', 'Spring', 2001, 'A ');
	insert into takes values('91063', '696', '1', 'Spring', 2002, 'C ');
	insert into takes values('32119', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('94801', '457', '1', 'Spring', 2001, 'C+');
	insert into takes values('73606', '200', '2', 'Fall', 2002, 'A-');
	insert into takes values('34158', '421', '1', 'Fall', 2004, 'B+');
	insert into takes values('12214', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('64259', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('75273', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('14563', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('20084', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('39241', '852', '1', 'Spring', 2008, 'A ');
	insert into takes values('65676', '482', '1', 'Fall', 2005, 'A+');
	insert into takes values('31080', '345', '1', 'Spring', 2008, 'B-');
	insert into takes values('1018', '599', '1', 'Spring', 2003, 'A+');
	insert into takes values('56139', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('99775', '604', '1', 'Spring', 2009, 'B+');
	insert into takes values('23794', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('33201', '795', '1', 'Spring', 2004, 'A-');
	insert into takes values('39881', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('62716', '663', '1', 'Spring', 2005, 'A-');
	insert into takes values('49759', '237', '1', 'Spring', 2008, 'B ');
	insert into takes values('24197', '362', '2', 'Fall', 2006, 'A ');
	insert into takes values('33651', '642', '1', 'Fall', 2004, 'A+');
	insert into takes values('82580', '864', '1', 'Spring', 2006, 'C+');
	insert into takes values('16133', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('3487', '527', '1', 'Fall', 2004, 'B+');
	insert into takes values('94801', '400', '1', 'Spring', 2007, 'C ');
	insert into takes values('10269', '631', '1', 'Spring', 2007, 'B+');
	insert into takes values('23525', '791', '1', 'Spring', 2006, 'A-');
	insert into takes values('32345', '793', '1', 'Spring', 2002, 'A-');
	insert into takes values('52866', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('53185', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('34322', '169', '1', 'Spring', 2007, 'A-');
	insert into takes values('16907', '421', '1', 'Fall', 2004, 'C+');
	insert into takes values('8807', '962', '1', 'Spring', 2008, 'A+');
	insert into takes values('17676', '401', '1', 'Fall', 2003, 'A-');
	insert into takes values('56499', '949', '1', 'Fall', 2007, 'A-');
	insert into takes values('92385', '400', '1', 'Spring', 2007, 'C ');
	insert into takes values('66090', '362', '3', 'Spring', 2008, 'A+');
	insert into takes values('78858', '237', '2', 'Fall', 2009, 'C ');
	insert into takes values('69581', '802', '1', 'Spring', 2003, 'A+');
	insert into takes values('85234', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('14065', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('58846', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('51768', '843', '1', 'Fall', 2010, 'C ');
	insert into takes values('58326', '581', '1', 'Spring', 2005, 'B+');
	insert into takes values('26730', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('77244', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('64222', '561', '1', 'Fall', 2006, 'A+');
	insert into takes values('42688', '200', '1', 'Spring', 2007, 'A ');
	insert into takes values('17607', '489', '1', 'Fall', 2007, 'B-');
	insert into takes values('21102', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('75395', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('49280', '704', '1', 'Spring', 2008, 'B ');
	insert into takes values('43432', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('83444', '270', '1', 'Spring', 2010, 'B-');
	insert into takes values('92776', '192', '1', 'Fall', 2002, 'A+');
	insert into takes values('33837', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('33206', '338', '1', 'Spring', 2007, 'C ');
	insert into takes values('47126', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('58465', '561', '1', 'Fall', 2006, 'C+');
	insert into takes values('77218', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('51579', '158', '1', 'Fall', 2008, 'C-');
	insert into takes values('18675', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('79205', '694', '1', 'Fall', 2002, 'C ');
	insert into takes values('74530', '735', '1', 'Spring', 2003, 'C-');
	insert into takes values('1367', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('71944', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('56212', '334', '1', 'Fall', 2009, 'B+');
	insert into takes values('85981', '629', '1', 'Spring', 2003, 'A ');
	insert into takes values('24387', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('10204', '692', '1', 'Spring', 2010, 'B-');
	insert into takes values('98140', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('60249', '663', '1', 'Spring', 2005, 'A ');
	insert into takes values('58935', '496', '1', 'Fall', 2001, 'B ');
	insert into takes values('95953', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('23994', '808', '1', 'Fall', 2003, 'B ');
	insert into takes values('3127', '949', '1', 'Fall', 2007, 'C-');
	insert into takes values('34170', '401', '1', 'Fall', 2003, 'C-');
	insert into takes values('55000', '974', '1', 'Fall', 2003, 'B-');
	insert into takes values('64140', '545', '1', 'Fall', 2001, 'A+');
	insert into takes values('11453', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('5920', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('12563', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('51238', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('81258', '843', '1', 'Fall', 2010, 'A-');
	insert into takes values('54610', '559', '1', 'Fall', 2002, 'C-');
	insert into takes values('56499', '571', '1', 'Spring', 2004, 'C ');
	insert into takes values('107', '735', '2', 'Spring', 2010, 'A ');
	insert into takes values('87624', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('93004', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('1000', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('37521', '468', '2', 'Fall', 2007, 'B ');
	insert into takes values('18234', '158', '2', 'Spring', 2008, 'C ');
	insert into takes values('24932', '105', '2', 'Fall', 2002, 'A+');
	insert into takes values('41751', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('43226', '875', '1', 'Spring', 2005, 'C ');
	insert into takes values('75252', '626', '1', 'Fall', 2006, 'B-');
	insert into takes values('75116', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('25362', '415', '1', 'Fall', 2010, 'C-');
	insert into takes values('61232', '400', '1', 'Spring', 2007, 'A+');
	insert into takes values('85063', '692', '1', 'Spring', 2010, 'C+');
	insert into takes values('76768', '258', '1', 'Fall', 2007, 'C ');
	insert into takes values('16250', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('84727', '366', '1', 'Fall', 2005, 'A ');
	insert into takes values('35198', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('43016', '571', '1', 'Spring', 2004, 'C+');
	insert into takes values('1954', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('20002', '893', '1', 'Fall', 2007, 'C+');
	insert into takes values('83170', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('22268', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('50743', '421', '1', 'Fall', 2004, 'A-');
	insert into takes values('92867', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('70235', '604', '1', 'Spring', 2009, 'B ');
	insert into takes values('44584', '105', '2', 'Fall', 2002, 'B-');
	insert into takes values('67146', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('75513', '747', '1', 'Spring', 2004, 'C-');
	insert into takes values('85505', '843', '1', 'Fall', 2010, 'C ');
	insert into takes values('9953', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('978', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('32954', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('59920', '200', '1', 'Spring', 2007, 'A-');
	insert into takes values('34055', '679', '1', 'Spring', 2010, 'A+');
	insert into takes values('99348', '696', '1', 'Spring', 2002, 'A ');
	insert into takes values('98120', '604', '1', 'Spring', 2009, 'B ');
	insert into takes values('95850', '962', '1', 'Spring', 2008, 'C+');
	insert into takes values('27430', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('34502', '692', '1', 'Spring', 2010, 'C+');
	insert into takes values('38336', '476', '1', 'Fall', 2010, 'C ');
	insert into takes values('48471', '493', '1', 'Spring', 2010, 'C-');
	insert into takes values('8192', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('25362', '237', '1', 'Spring', 2008, 'C-');
	insert into takes values('64642', '991', '1', 'Spring', 2008, 'A ');
	insert into takes values('57334', '137', '1', 'Spring', 2002, 'B+');
	insert into takes values('29871', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('59046', '493', '1', 'Spring', 2010, 'C ');
	insert into takes values('6712', '401', '1', 'Fall', 2003, 'B+');
	insert into takes values('26494', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('28252', '702', '1', 'Spring', 2001, 'A-');
	insert into takes values('49205', '461', '1', 'Fall', 2002, 'B-');
	insert into takes values('30124', '200', '2', 'Fall', 2002, 'A+');
	insert into takes values('69752', '304', '1', 'Fall', 2009, 'C-');
	insert into takes values('48471', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('61783', '493', '1', 'Spring', 2010, 'B+');
	insert into takes values('11455', '468', '1', 'Fall', 2005, 'B-');
	insert into takes values('47824', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('83573', '408', '1', 'Spring', 2007, 'C ');
	insert into takes values('35881', '242', '1', 'Fall', 2009, 'C ');
	insert into takes values('68720', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('85356', '105', '2', 'Fall', 2002, 'B-');
	insert into takes values('45359', '338', '2', 'Spring', 2006, 'A ');
	insert into takes values('52057', '974', '1', 'Fall', 2003, 'A-');
	insert into takes values('71631', '362', '2', 'Fall', 2006, 'C-');
	insert into takes values('39978', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('79352', '875', '1', 'Spring', 2005, 'A ');
	insert into takes values('28518', '867', '2', 'Fall', 2010, 'B-');
	insert into takes values('84845', '545', '1', 'Fall', 2001, 'A ');
	insert into takes values('14668', '338', '1', 'Spring', 2007, 'C-');
	insert into takes values('30896', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('75560', '793', '1', 'Spring', 2002, 'A-');
	insert into takes values('17397', '629', '1', 'Spring', 2003, 'B-');
	insert into takes values('65299', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('82646', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('67024', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('1826', '200', '1', 'Spring', 2007, 'B+');
	insert into takes values('26695', '476', '1', 'Fall', 2010, 'C-');
	insert into takes values('17133', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('38545', '694', '1', 'Fall', 2002, 'B ');
	insert into takes values('53048', '105', '1', 'Fall', 2009, 'C-');
	insert into takes values('68395', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('68150', '239', '1', 'Fall', 2006, 'B-');
	insert into takes values('36052', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('64945', '960', '1', 'Fall', 2009, 'C-');
	insert into takes values('80742', '349', '1', 'Spring', 2008, 'C-');
	insert into takes values('72959', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('78581', '345', '1', 'Spring', 2008, 'C ');
	insert into takes values('15980', '421', '1', 'Fall', 2004, 'B+');
	insert into takes values('58172', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('50013', '960', '1', 'Fall', 2009, 'B+');
	insert into takes values('27898', '927', '1', 'Fall', 2002, 'B-');
	insert into takes values('61854', '443', '1', 'Spring', 2010, 'C+');
	insert into takes values('10269', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('16057', '875', '1', 'Spring', 2005, 'A-');
	insert into takes values('18234', '366', '1', 'Fall', 2005, 'C-');
	insert into takes values('9183', '692', '1', 'Spring', 2010, 'C-');
	insert into takes values('99754', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('96246', '802', '1', 'Spring', 2003, 'C-');
	insert into takes values('18554', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('57213', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('842', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('3739', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('32217', '408', '1', 'Spring', 2007, 'B ');
	insert into takes values('9114', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('80941', '468', '1', 'Fall', 2005, 'C ');
	insert into takes values('28316', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('69081', '239', '1', 'Fall', 2006, 'A-');
	insert into takes values('35362', '972', '1', 'Spring', 2009, 'C ');
	insert into takes values('62429', '461', '1', 'Fall', 2002, 'B ');
	insert into takes values('14432', '400', '2', 'Fall', 2003, 'C-');
	insert into takes values('74911', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('88418', '345', '1', 'Spring', 2008, 'B ');
	insert into takes values('39925', '991', '1', 'Spring', 2008, 'A ');
	insert into takes values('68999', '349', '1', 'Spring', 2008, 'C-');
	insert into takes values('8853', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('97435', '443', '2', 'Spring', 2002, 'B ');
	insert into takes values('65688', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('73411', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('96052', '200', '1', 'Spring', 2007, 'C ');
	insert into takes values('74974', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('94894', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('10663', '604', '1', 'Spring', 2009, 'A ');
	insert into takes values('46436', '893', '1', 'Fall', 2007, 'C ');
	insert into takes values('60249', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('58355', '927', '1', 'Fall', 2002, 'B-');
	insert into takes values('86641', '239', '1', 'Fall', 2006, 'B ');
	insert into takes values('81876', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('19536', '791', '1', 'Spring', 2006, 'C+');
	insert into takes values('38548', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('5843', '694', '1', 'Fall', 2002, 'C+');
	insert into takes values('29665', '169', '1', 'Spring', 2007, 'B ');
	insert into takes values('90132', '258', '1', 'Fall', 2007, 'B+');
	insert into takes values('73606', '461', '1', 'Fall', 2002, 'C+');
	insert into takes values('31820', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('87965', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('57925', '702', '1', 'Spring', 2001, 'C+');
	insert into takes values('10736', '489', '1', 'Fall', 2007, 'C+');
	insert into takes values('75116', '599', '1', 'Spring', 2003, 'C ');
	insert into takes values('83573', '338', '1', 'Spring', 2007, 'C-');
	insert into takes values('77289', '338', '1', 'Spring', 2007, 'C+');
	insert into takes values('30845', '338', '1', 'Spring', 2007, 'A+');
	insert into takes values('26473', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('16405', '158', '1', 'Fall', 2008, 'A+');
	insert into takes values('17665', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('91343', '603', '1', 'Fall', 2003, 'A+');
	insert into takes values('30252', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('85234', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('58413', '105', '1', 'Fall', 2009, 'C-');
	insert into takes values('7514', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('61920', '105', '2', 'Fall', 2002, 'C+');
	insert into takes values('5898', '960', '1', 'Fall', 2009, 'C-');
	insert into takes values('87015', '338', '1', 'Spring', 2007, 'C-');
	insert into takes values('78792', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('77548', '793', '1', 'Spring', 2002, 'A-');
	insert into takes values('90124', '974', '1', 'Fall', 2003, 'C ');
	insert into takes values('43912', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('59397', '493', '1', 'Spring', 2010, 'A-');
	insert into takes values('15883', '461', '1', 'Fall', 2002, 'B-');
	insert into takes values('30858', '802', '1', 'Spring', 2003, 'C+');
	insert into takes values('87651', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('94311', '864', '1', 'Spring', 2006, 'B+');
	insert into takes values('95574', '169', '1', 'Spring', 2007, 'C+');
	insert into takes values('49339', '408', '2', 'Spring', 2003, 'B-');
	insert into takes values('62487', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('31993', '802', '1', 'Spring', 2003, 'C-');
	insert into takes values('90234', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('25256', '408', '2', 'Spring', 2003, 'C ');
	insert into takes values('97694', '493', '1', 'Spring', 2010, 'A ');
	insert into takes values('18809', '692', '1', 'Spring', 2010, 'A-');
	insert into takes values('1367', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('5463', '603', '1', 'Fall', 2003, 'A+');
	insert into takes values('85366', '663', '1', 'Spring', 2005, 'C-');
	insert into takes values('57666', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('44816', '169', '1', 'Spring', 2007, 'C+');
	insert into takes values('76049', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('75362', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('91370', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('91132', '200', '1', 'Spring', 2007, 'B+');
	insert into takes values('81984', '561', '1', 'Fall', 2006, 'A+');
	insert into takes values('4449', '960', '2', 'Fall', 2006, 'C-');
	insert into takes values('76173', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('8378', '631', '1', 'Spring', 2007, 'A ');
	insert into takes values('41827', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('99694', '304', '1', 'Fall', 2009, 'C-');
	insert into takes values('70299', '793', '1', 'Spring', 2002, 'B+');
	insert into takes values('79205', '581', '1', 'Spring', 2005, 'C-');
	insert into takes values('95574', '421', '1', 'Fall', 2004, 'C+');
	insert into takes values('1018', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('22417', '893', '1', 'Fall', 2007, 'B ');
	insert into takes values('69081', '974', '1', 'Fall', 2003, 'A+');
	insert into takes values('92839', '875', '1', 'Spring', 2005, 'A-');
	insert into takes values('99694', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('93986', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('67436', '468', '1', 'Fall', 2005, 'A-');
	insert into takes values('93571', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('36494', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('77003', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('81396', '338', '1', 'Spring', 2007, 'A ');
	insert into takes values('19638', '927', '1', 'Fall', 2002, 'B-');
	insert into takes values('91370', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('507', '852', '1', 'Spring', 2008, 'A ');
	insert into takes values('39892', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('82066', '893', '1', 'Fall', 2007, 'B ');
	insert into takes values('51553', '426', '1', 'Spring', 2006, 'A+');
	insert into takes values('29390', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('66212', '493', '1', 'Spring', 2010, 'B ');
	insert into takes values('74672', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('68999', '489', '1', 'Fall', 2007, 'B+');
	insert into takes values('49813', '571', '1', 'Spring', 2004, 'C-');
	insert into takes values('58606', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('14563', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('51955', '415', '1', 'Fall', 2010, 'B+');
	insert into takes values('15430', '169', '1', 'Spring', 2007, 'C+');
	insert into takes values('9947', '482', '1', 'Fall', 2005, 'B-');
	insert into takes values('15283', '242', '1', 'Fall', 2009, 'B ');
	insert into takes values('67657', '486', '1', 'Fall', 2009, 'C+');
	insert into takes values('47677', '366', '1', 'Fall', 2005, 'A ');
	insert into takes values('83480', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('29399', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('17057', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('40371', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('86661', '274', '1', 'Fall', 2002, 'B ');
	insert into takes values('38555', '376', '1', 'Fall', 2006, 'B ');
	insert into takes values('61403', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('41890', '362', '3', 'Spring', 2008, 'A+');
	insert into takes values('48778', '338', '2', 'Spring', 2006, 'C ');
	insert into takes values('58595', '972', '1', 'Spring', 2009, 'C ');
	insert into takes values('49759', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('8022', '962', '1', 'Spring', 2008, 'A+');
	insert into takes values('73165', '867', '1', 'Fall', 2006, 'A-');
	insert into takes values('19050', '604', '1', 'Spring', 2009, 'B+');
	insert into takes values('56299', '415', '1', 'Fall', 2010, 'A+');
	insert into takes values('57787', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('67018', '571', '1', 'Spring', 2004, 'B+');
	insert into takes values('6712', '631', '1', 'Spring', 2007, 'B ');
	insert into takes values('14023', '461', '1', 'Fall', 2002, 'B+');
	insert into takes values('82083', '679', '1', 'Spring', 2010, 'B ');
	insert into takes values('70688', '852', '1', 'Spring', 2008, 'B-');
	insert into takes values('72669', '760', '1', 'Spring', 2004, 'A ');
	insert into takes values('30957', '696', '1', 'Spring', 2002, 'B ');
	insert into takes values('92867', '496', '1', 'Fall', 2001, 'B-');
	insert into takes values('1827', '747', '1', 'Spring', 2004, 'A ');
	insert into takes values('67340', '867', '1', 'Fall', 2006, 'B+');
	insert into takes values('15283', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('96117', '443', '2', 'Spring', 2002, 'C-');
	insert into takes values('70924', '735', '2', 'Spring', 2010, 'B ');
	insert into takes values('42991', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('77218', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('86674', '158', '2', 'Spring', 2008, 'C ');
	insert into takes values('71631', '461', '1', 'Fall', 2002, 'C-');
	insert into takes values('32369', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('22618', '631', '1', 'Spring', 2007, 'B+');
	insert into takes values('10556', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('79502', '864', '1', 'Spring', 2006, 'B+');
	insert into takes values('931', '760', '1', 'Spring', 2004, 'A ');
	insert into takes values('52187', '927', '1', 'Fall', 2002, 'C ');
	insert into takes values('49813', '270', '1', 'Spring', 2010, 'C ');
	insert into takes values('2629', '457', '1', 'Spring', 2001, 'B-');
	insert into takes values('30299', '604', '1', 'Spring', 2009, 'C ');
	insert into takes values('12979', '242', '1', 'Fall', 2009, 'C ');
	insert into takes values('37759', '747', '1', 'Spring', 2004, 'C ');
	insert into takes values('94142', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('5243', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('28989', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('57780', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('59848', '852', '1', 'Spring', 2008, 'B-');
	insert into takes values('45083', '200', '1', 'Spring', 2007, 'B-');
	insert into takes values('29239', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('91616', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('67293', '604', '1', 'Spring', 2009, 'C ');
	insert into takes values('38271', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('123', '496', '1', 'Fall', 2001, 'C-');
	insert into takes values('25256', '893', '1', 'Fall', 2007, 'B ');
	insert into takes values('57083', '468', '1', 'Fall', 2005, 'A ');
	insert into takes values('82301', '400', '1', 'Spring', 2007, 'B ');
	insert into takes values('56212', '852', '1', 'Spring', 2008, 'A ');
	insert into takes values('51975', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('75794', '545', '1', 'Fall', 2001, 'A ');
	insert into takes values('49873', '581', '1', 'Spring', 2005, 'A+');
	insert into takes values('11530', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('57107', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('78552', '242', '1', 'Fall', 2009, 'B ');
	insert into takes values('89571', '793', '1', 'Spring', 2002, 'B ');
	insert into takes values('47265', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('54605', '319', '1', 'Spring', 2003, 'B-');
	insert into takes values('39657', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('18234', '571', '1', 'Spring', 2004, 'C+');
	insert into takes values('65121', '457', '1', 'Spring', 2001, 'B+');
	insert into takes values('53077', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('17057', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('4015', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('48778', '400', '2', 'Fall', 2003, 'A ');
	insert into takes values('88417', '972', '1', 'Spring', 2009, 'B-');
	insert into takes values('29959', '561', '1', 'Fall', 2006, 'A ');
	insert into takes values('65208', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('89734', '169', '1', 'Spring', 2007, 'B+');
	insert into takes values('69850', '974', '1', 'Fall', 2003, 'C ');
	insert into takes values('39901', '401', '1', 'Fall', 2003, 'A ');
	insert into takes values('10727', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('14628', '493', '1', 'Spring', 2010, 'B+');
	insert into takes values('50969', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('69081', '338', '2', 'Spring', 2006, 'A ');
	insert into takes values('11855', '571', '1', 'Spring', 2004, 'A-');
	insert into takes values('41091', '408', '1', 'Spring', 2007, 'A ');
	insert into takes values('72643', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('19450', '962', '1', 'Spring', 2008, 'B-');
	insert into takes values('90194', '760', '1', 'Spring', 2004, 'B ');
	insert into takes values('51678', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('95089', '468', '1', 'Fall', 2005, 'B ');
	insert into takes values('62795', '158', '1', 'Fall', 2008, 'C ');
	insert into takes values('8912', '489', '1', 'Fall', 2007, 'B+');
	insert into takes values('79502', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('95697', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('94801', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('24002', '843', '1', 'Fall', 2010, 'A-');
	insert into takes values('70061', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('10834', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('9256', '169', '2', 'Fall', 2002, 'A+');
	insert into takes values('28133', '443', '1', 'Spring', 2010, 'B+');
	insert into takes values('55009', '239', '1', 'Fall', 2006, 'A-');
	insert into takes values('36995', '591', '1', 'Spring', 2005, 'A+');
	insert into takes values('83314', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('95366', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('1220', '631', '1', 'Spring', 2007, 'A ');
	insert into takes values('49073', '893', '1', 'Fall', 2007, 'C+');
	insert into takes values('66293', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('41091', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('33791', '362', '2', 'Fall', 2006, 'C-');
	insert into takes values('15726', '274', '1', 'Fall', 2002, 'B-');
	insert into takes values('88045', '793', '1', 'Spring', 2002, 'B+');
	insert into takes values('39394', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('62832', '694', '1', 'Fall', 2002, 'C+');
	insert into takes values('72768', '468', '1', 'Fall', 2005, 'A-');
	insert into takes values('30182', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('69679', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('34018', '457', '1', 'Spring', 2001, 'B+');
	insert into takes values('12362', '795', '1', 'Spring', 2004, 'B-');
	insert into takes values('99775', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('93571', '200', '1', 'Spring', 2007, 'C ');
	insert into takes values('21102', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('69081', '527', '1', 'Fall', 2004, 'A ');
	insert into takes values('85981', '735', '2', 'Spring', 2010, 'B-');
	insert into takes values('72501', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('25380', '362', '3', 'Spring', 2008, 'A+');
	insert into takes values('7123', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('38555', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('40738', '239', '1', 'Fall', 2006, 'C+');
	insert into takes values('52157', '401', '1', 'Fall', 2003, 'B+');
	insert into takes values('24865', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('21692', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('65715', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('99730', '747', '1', 'Spring', 2004, 'C ');
	insert into takes values('61403', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('4383', '200', '1', 'Spring', 2007, 'B+');
	insert into takes values('57083', '105', '2', 'Fall', 2002, 'B+');
	insert into takes values('15726', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('95046', '591', '1', 'Spring', 2005, 'A-');
	insert into takes values('49611', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('98830', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('61364', '692', '1', 'Spring', 2010, 'C-');
	insert into takes values('44206', '545', '1', 'Fall', 2001, 'B-');
	insert into takes values('64934', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('99660', '960', '2', 'Fall', 2006, 'A ');
	insert into takes values('53118', '960', '1', 'Fall', 2009, 'B-');
	insert into takes values('99775', '793', '1', 'Spring', 2002, 'C+');
	insert into takes values('57780', '864', '1', 'Spring', 2006, 'A+');
	insert into takes values('13365', '304', '1', 'Fall', 2009, 'C-');
	insert into takes values('61402', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('29002', '793', '1', 'Spring', 2002, 'B+');
	insert into takes values('56143', '867', '2', 'Fall', 2010, 'A+');
	insert into takes values('64259', '242', '1', 'Fall', 2009, 'C+');
	insert into takes values('26619', '169', '1', 'Spring', 2007, 'A-');
	insert into takes values('2133', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('45826', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('1080', '468', '2', 'Fall', 2007, 'A-');
	insert into takes values('56124', '169', '2', 'Fall', 2002, 'B ');
	insert into takes values('3640', '962', '1', 'Spring', 2008, 'B-');
	insert into takes values('40303', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('35588', '489', '1', 'Fall', 2007, 'A-');
	insert into takes values('51955', '461', '1', 'Fall', 2002, 'C+');
	insert into takes values('39876', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('81566', '571', '1', 'Spring', 2004, 'C+');
	insert into takes values('89297', '735', '2', 'Spring', 2010, 'A+');
	insert into takes values('6990', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('23457', '461', '1', 'Fall', 2002, 'B-');
	insert into takes values('11152', '631', '1', 'Spring', 2007, 'B+');
	insert into takes values('37038', '137', '1', 'Spring', 2002, 'A-');
	insert into takes values('47379', '457', '1', 'Spring', 2001, 'A ');
	insert into takes values('84845', '692', '1', 'Spring', 2010, 'B-');
	insert into takes values('20084', '972', '1', 'Spring', 2009, 'C ');
	insert into takes values('17944', '443', '1', 'Spring', 2010, 'B+');
	insert into takes values('23392', '200', '2', 'Fall', 2002, 'B+');
	insert into takes values('89297', '408', '2', 'Spring', 2003, 'A ');
	insert into takes values('13506', '304', '1', 'Fall', 2009, 'C+');
	insert into takes values('30650', '200', '1', 'Spring', 2007, 'B-');
	insert into takes values('62429', '415', '1', 'Fall', 2010, 'B ');
	insert into takes values('64222', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('987', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('70359', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('43130', '962', '1', 'Spring', 2008, 'B ');
	insert into takes values('48471', '679', '1', 'Spring', 2010, 'B-');
	insert into takes values('7123', '612', '1', 'Fall', 2007, 'A-');
	insert into takes values('88418', '313', '1', 'Fall', 2010, 'B+');
	insert into takes values('67583', '105', '2', 'Fall', 2002, 'A ');
	insert into takes values('4682', '443', '2', 'Spring', 2002, 'A ');
	insert into takes values('11152', '313', '1', 'Fall', 2010, 'C-');
	insert into takes values('85451', '158', '1', 'Fall', 2008, 'B+');
	insert into takes values('55859', '482', '1', 'Fall', 2005, 'C ');
	insert into takes values('86641', '237', '1', 'Spring', 2008, 'C-');
	insert into takes values('34542', '496', '1', 'Fall', 2001, 'B+');
	insert into takes values('85849', '496', '1', 'Fall', 2001, 'C ');
	insert into takes values('74840', '457', '1', 'Spring', 2001, 'C-');
	insert into takes values('12683', '561', '1', 'Fall', 2006, 'A-');
	insert into takes values('84727', '313', '1', 'Fall', 2010, 'C+');
	insert into takes values('42092', '962', '1', 'Spring', 2008, 'B ');
	insert into takes values('31302', '482', '1', 'Fall', 2005, 'C ');
	insert into takes values('24197', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('41596', '959', '1', 'Fall', 2006, 'B ');
	insert into takes values('66090', '748', '1', 'Fall', 2003, 'B ');
	insert into takes values('68070', '105', '1', 'Fall', 2009, 'C ');
	insert into takes values('66008', '696', '1', 'Spring', 2002, 'C+');
	insert into takes values('65208', '802', '1', 'Spring', 2003, 'C-');
	insert into takes values('83462', '200', '1', 'Spring', 2007, 'B+');
	insert into takes values('32368', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('79589', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('50467', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('72959', '599', '1', 'Spring', 2003, 'B ');
	insert into takes values('82126', '258', '1', 'Fall', 2007, 'B-');
	insert into takes values('14182', '400', '2', 'Fall', 2003, 'C-');
	insert into takes values('24809', '415', '1', 'Fall', 2010, 'A+');
	insert into takes values('36263', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('12216', '349', '1', 'Spring', 2008, 'B+');
	insert into takes values('63090', '603', '1', 'Fall', 2003, 'B+');
	insert into takes values('12216', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('29192', '489', '1', 'Fall', 2007, 'B ');
	insert into takes values('90234', '793', '1', 'Spring', 2002, 'B+');
	insert into takes values('76270', '334', '1', 'Fall', 2009, 'B ');
	insert into takes values('85849', '242', '1', 'Fall', 2009, 'C-');
	insert into takes values('89196', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('85356', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('40303', '270', '1', 'Spring', 2010, 'B+');
	insert into takes values('31554', '692', '1', 'Spring', 2010, 'C-');
	insert into takes values('14499', '366', '1', 'Fall', 2005, 'B ');
	insert into takes values('10527', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('72959', '169', '1', 'Spring', 2007, 'B+');
	insert into takes values('41671', '545', '1', 'Fall', 2001, 'A+');
	insert into takes values('12078', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('38902', '274', '1', 'Fall', 2002, 'B-');
	insert into takes values('13023', '561', '1', 'Fall', 2006, 'C ');
	insert into takes values('48469', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('94371', '376', '1', 'Fall', 2006, 'A-');
	insert into takes values('10814', '313', '1', 'Fall', 2010, 'B ');
	insert into takes values('32376', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('64155', '169', '2', 'Fall', 2002, 'C ');
	insert into takes values('62549', '496', '1', 'Fall', 2001, 'B+');
	insert into takes values('64945', '304', '1', 'Fall', 2009, 'C-');
	insert into takes values('1827', '421', '1', 'Fall', 2004, 'C-');
	insert into takes values('28361', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('99660', '760', '1', 'Spring', 2004, 'C-');
	insert into takes values('67146', '962', '1', 'Spring', 2008, 'B ');
	insert into takes values('59517', '561', '1', 'Fall', 2006, 'A-');
	insert into takes values('43123', '642', '1', 'Fall', 2004, 'A+');
	insert into takes values('94766', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('74016', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('99226', '626', '1', 'Fall', 2006, 'B ');
	insert into takes values('123', '192', '1', 'Fall', 2002, 'A+');
	insert into takes values('96193', '852', '1', 'Spring', 2008, 'A-');
	insert into takes values('32744', '692', '1', 'Spring', 2010, 'C+');
	insert into takes values('34404', '735', '1', 'Spring', 2003, 'A+');
	insert into takes values('46260', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('5336', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('69521', '927', '1', 'Fall', 2002, 'A-');
	insert into takes values('29390', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('69581', '679', '1', 'Spring', 2010, 'C+');
	insert into takes values('11966', '612', '1', 'Fall', 2007, 'B-');
	insert into takes values('37715', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('45300', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('81207', '679', '1', 'Spring', 2010, 'A+');
	insert into takes values('21009', '169', '1', 'Spring', 2007, 'C ');
	insert into takes values('97658', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('61332', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('8957', '735', '1', 'Spring', 2003, 'B-');
	insert into takes values('51549', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('96052', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('667', '426', '1', 'Spring', 2006, 'C ');
	insert into takes values('28252', '626', '1', 'Fall', 2006, 'B-');
	insert into takes values('89000', '702', '1', 'Spring', 2001, 'B-');
	insert into takes values('67725', '426', '1', 'Spring', 2006, 'A ');
	insert into takes values('31993', '581', '1', 'Spring', 2005, 'C ');
	insert into takes values('58889', '443', '2', 'Spring', 2002, 'A ');
	insert into takes values('70564', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('96003', '603', '1', 'Fall', 2003, 'B+');
	insert into takes values('10834', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('96067', '408', '1', 'Spring', 2007, 'B ');
	insert into takes values('44551', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('86833', '960', '1', 'Fall', 2009, 'B+');
	insert into takes values('68150', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('76291', '808', '1', 'Fall', 2003, 'A+');
	insert into takes values('792', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('88389', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('16405', '581', '1', 'Spring', 2005, 'C ');
	insert into takes values('59172', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('78143', '561', '1', 'Fall', 2006, 'C-');
	insert into takes values('13217', '867', '1', 'Fall', 2006, 'A ');
	insert into takes values('87280', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('9993', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('11076', '702', '1', 'Spring', 2001, 'B ');
	insert into takes values('73387', '631', '1', 'Spring', 2007, 'B ');
	insert into takes values('68396', '362', '3', 'Spring', 2008, 'C+');
	insert into takes values('89000', '949', '1', 'Fall', 2007, 'C-');
	insert into takes values('49214', '482', '1', 'Fall', 2005, 'C ');
	insert into takes values('92464', '400', '2', 'Fall', 2003, 'B-');
	insert into takes values('7956', '493', '1', 'Spring', 2010, 'C ');
	insert into takes values('28299', '158', '1', 'Fall', 2008, 'C-');
	insert into takes values('21401', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('87044', '696', '1', 'Spring', 2002, 'C+');
	insert into takes values('14869', '345', '1', 'Spring', 2008, 'C ');
	insert into takes values('46980', '443', '1', 'Spring', 2010, 'A ');
	insert into takes values('89106', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('97101', '468', '2', 'Fall', 2007, 'A-');
	insert into takes values('25046', '748', '1', 'Fall', 2003, 'B-');
	insert into takes values('29002', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('336', '338', '2', 'Spring', 2006, 'A+');
	insert into takes values('86802', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('30252', '352', '1', 'Spring', 2006, 'B+');
	insert into takes values('51975', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('56089', '692', '1', 'Spring', 2010, 'A+');
	insert into takes values('64934', '735', '2', 'Spring', 2010, 'B ');
	insert into takes values('4508', '972', '1', 'Spring', 2009, 'C-');
	insert into takes values('28019', '158', '1', 'Fall', 2008, 'B-');
	insert into takes values('44836', '401', '1', 'Fall', 2003, 'C+');
	insert into takes values('31250', '561', '1', 'Fall', 2006, 'A-');
	insert into takes values('37284', '631', '1', 'Spring', 2007, 'B+');
	insert into takes values('41973', '692', '1', 'Spring', 2010, 'C ');
	insert into takes values('93631', '493', '1', 'Spring', 2010, 'A ');
	insert into takes values('22254', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('30021', '603', '1', 'Fall', 2003, 'B ');
	insert into takes values('31137', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('85211', '864', '1', 'Spring', 2006, 'B+');
	insert into takes values('22260', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('22004', '704', '1', 'Spring', 2008, 'C-');
	insert into takes values('29390', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('19342', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('46442', '468', '1', 'Fall', 2005, 'A ');
	insert into takes values('75241', '581', '1', 'Spring', 2005, 'A-');
	insert into takes values('68395', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('22142', '105', '2', 'Fall', 2002, 'C+');
	insert into takes values('55238', '349', '1', 'Spring', 2008, 'A ');
	insert into takes values('32368', '793', '1', 'Spring', 2002, 'C ');
	insert into takes values('43993', '960', '2', 'Fall', 2006, 'C+');
	insert into takes values('23110', '401', '1', 'Fall', 2003, 'C+');
	insert into takes values('22086', '663', '1', 'Spring', 2005, 'A ');
	insert into takes values('7956', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('67033', '237', '2', 'Fall', 2009, 'B+');
	insert into takes values('80248', '612', '1', 'Fall', 2007, 'A ');
	insert into takes values('11076', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('31035', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('38121', '319', '1', 'Spring', 2003, 'C+');
	insert into takes values('40992', '599', '1', 'Spring', 2003, 'A ');
	insert into takes values('49701', '702', '1', 'Spring', 2001, 'B-');
	insert into takes values('78637', '237', '1', 'Spring', 2008, 'A-');
	insert into takes values('2629', '366', '1', 'Fall', 2005, 'C-');
	insert into takes values('44038', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('66259', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('50598', '338', '2', 'Spring', 2006, 'C+');
	insert into takes values('90194', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('61127', '591', '1', 'Spring', 2005, 'A-');
	insert into takes values('39310', '319', '1', 'Spring', 2003, 'C+');
	insert into takes values('96052', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('18821', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('10527', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('13511', '867', '1', 'Fall', 2006, 'A+');
	insert into takes values('83462', '468', '1', 'Fall', 2005, 'B-');
	insert into takes values('13028', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('82083', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('25256', '362', '2', 'Fall', 2006, 'A-');
	insert into takes values('77130', '702', '1', 'Spring', 2001, 'C+');
	insert into takes values('29705', '421', '1', 'Fall', 2004, 'C ');
	insert into takes values('29665', '959', '1', 'Fall', 2006, 'B ');
	insert into takes values('9460', '626', '1', 'Fall', 2006, 'A-');
	insert into takes values('68010', '158', '2', 'Spring', 2008, 'C+');
	insert into takes values('10705', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('11604', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('99399', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('90132', '972', '1', 'Spring', 2009, 'A-');
	insert into takes values('34126', '604', '1', 'Spring', 2009, 'B+');
	insert into takes values('14628', '476', '1', 'Fall', 2010, 'A+');
	insert into takes values('18808', '192', '1', 'Fall', 2002, 'C-');
	insert into takes values('16405', '629', '1', 'Spring', 2003, 'B-');
	insert into takes values('61920', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('69521', '960', '2', 'Fall', 2006, 'C ');
	insert into takes values('58606', '468', '1', 'Fall', 2005, 'A ');
	insert into takes values('23270', '237', '2', 'Fall', 2009, 'C+');
	insert into takes values('5017', '476', '1', 'Fall', 2010, 'A+');
	insert into takes values('14554', '571', '1', 'Spring', 2004, 'C ');
	insert into takes values('32217', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('26619', '105', '2', 'Fall', 2002, 'A+');
	insert into takes values('5005', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('71631', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('435', '313', '1', 'Fall', 2010, 'C ');
	insert into takes values('35362', '867', '2', 'Fall', 2010, 'B-');
	insert into takes values('4582', '949', '1', 'Fall', 2007, 'C+');
	insert into takes values('14094', '421', '1', 'Fall', 2004, 'A ');
	insert into takes values('58634', '527', '1', 'Fall', 2004, 'B-');
	insert into takes values('23992', '338', '2', 'Spring', 2006, 'A ');
	insert into takes values('21789', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('11510', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('69960', '457', '1', 'Spring', 2001, 'A+');
	insert into takes values('69628', '457', '1', 'Spring', 2001, 'C ');
	insert into takes values('68453', '864', '1', 'Spring', 2006, 'C-');
	insert into takes values('18775', '338', '1', 'Spring', 2007, 'C+');
	insert into takes values('45817', '642', '1', 'Fall', 2004, 'B-');
	insert into takes values('71389', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('44584', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('99764', '421', '1', 'Fall', 2004, 'A-');
	insert into takes values('24010', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('9953', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('64121', '735', '1', 'Spring', 2003, 'C+');
	insert into takes values('57962', '692', '1', 'Spring', 2010, 'C-');
	insert into takes values('39521', '408', '1', 'Spring', 2007, 'A-');
	insert into takes values('56143', '105', '2', 'Fall', 2002, 'A-');
	insert into takes values('29863', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('75116', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('92703', '527', '1', 'Fall', 2004, 'C-');
	insert into takes values('74070', '629', '1', 'Spring', 2003, 'A+');
	insert into takes values('83003', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('75791', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('48640', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('34331', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('66753', '137', '1', 'Spring', 2002, 'A-');
	insert into takes values('34331', '352', '1', 'Spring', 2006, 'C+');
	insert into takes values('39115', '239', '1', 'Fall', 2006, 'B ');
	insert into takes values('11262', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('33546', '169', '1', 'Spring', 2007, 'B-');
	insert into takes values('14554', '468', '2', 'Fall', 2007, 'A-');
	insert into takes values('5005', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('52371', '239', '1', 'Fall', 2006, 'C-');
	insert into takes values('52669', '258', '1', 'Fall', 2007, 'C+');
	insert into takes values('25380', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('12362', '626', '1', 'Fall', 2006, 'B ');
	insert into takes values('29514', '426', '1', 'Spring', 2006, 'A+');
	insert into takes values('28989', '747', '1', 'Spring', 2004, 'A ');
	insert into takes values('93708', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('69752', '461', '1', 'Fall', 2002, 'A-');
	insert into takes values('35687', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('65400', '581', '1', 'Spring', 2005, 'C+');
	insert into takes values('16057', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('99694', '702', '1', 'Spring', 2001, 'A-');
	insert into takes values('40897', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('78552', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('18709', '927', '1', 'Fall', 2002, 'C-');
	insert into takes values('94178', '604', '1', 'Spring', 2009, 'A-');
	insert into takes values('62728', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('17507', '468', '2', 'Fall', 2007, 'C+');
	insert into takes values('52872', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('57026', '400', '2', 'Fall', 2003, 'C+');
	insert into takes values('86344', '663', '1', 'Spring', 2005, 'A ');
	insert into takes values('14484', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('7490', '974', '1', 'Fall', 2003, 'C ');
	insert into takes values('11855', '408', '1', 'Spring', 2007, 'A-');
	insert into takes values('97573', '457', '1', 'Spring', 2001, 'A-');
	insert into takes values('56089', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('14432', '349', '1', 'Spring', 2008, 'C-');
	insert into takes values('1232', '571', '1', 'Spring', 2004, 'A-');
	insert into takes values('81294', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('51553', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('67542', '258', '1', 'Fall', 2007, 'C ');
	insert into takes values('49611', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('30397', '496', '1', 'Fall', 2001, 'A-');
	insert into takes values('92442', '612', '1', 'Fall', 2007, 'B+');
	insert into takes values('77664', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('95260', '258', '1', 'Fall', 2007, 'B+');
	insert into takes values('77364', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('14596', '962', '1', 'Spring', 2008, 'A ');
	insert into takes values('25187', '352', '1', 'Spring', 2006, 'B+');
	insert into takes values('6895', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('68010', '258', '1', 'Fall', 2007, 'C-');
	insert into takes values('23344', '702', '1', 'Spring', 2001, 'C ');
	insert into takes values('45083', '338', '1', 'Spring', 2007, 'A-');
	insert into takes values('888', '581', '1', 'Spring', 2005, 'C-');
	insert into takes values('67407', '679', '1', 'Spring', 2010, 'B+');
	insert into takes values('99451', '352', '1', 'Spring', 2006, 'A-');
	insert into takes values('97042', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('44836', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('74460', '696', '1', 'Spring', 2002, 'C-');
	insert into takes values('73492', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('9993', '561', '1', 'Fall', 2006, 'A+');
	insert into takes values('50966', '239', '1', 'Fall', 2006, 'A-');
	insert into takes values('31486', '808', '1', 'Fall', 2003, 'B ');
	insert into takes values('3651', '760', '1', 'Spring', 2004, 'C ');
	insert into takes values('78481', '457', '1', 'Spring', 2001, 'A+');
	insert into takes values('74672', '604', '1', 'Spring', 2009, 'A ');
	insert into takes values('43032', '270', '1', 'Spring', 2010, 'A-');
	insert into takes values('65144', '599', '1', 'Spring', 2003, 'C ');
	insert into takes values('50365', '415', '1', 'Fall', 2010, 'C ');
	insert into takes values('83691', '545', '1', 'Fall', 2001, 'C ');
	insert into takes values('97590', '561', '1', 'Fall', 2006, 'B+');
	insert into takes values('27430', '457', '1', 'Spring', 2001, 'C+');
	insert into takes values('39157', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('11262', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('43993', '274', '1', 'Fall', 2002, 'C+');
	insert into takes values('58355', '960', '2', 'Fall', 2006, 'C+');
	insert into takes values('65241', '603', '1', 'Fall', 2003, 'B-');
	insert into takes values('7861', '960', '1', 'Fall', 2009, 'A-');
	insert into takes values('84845', '401', '1', 'Fall', 2003, 'A ');
	insert into takes values('76224', '793', '1', 'Spring', 2002, 'C+');
	insert into takes values('760', '527', '1', 'Fall', 2004, 'C-');
	insert into takes values('61354', '376', '1', 'Fall', 2006, 'B+');
	insert into takes values('16297', '352', '1', 'Spring', 2006, 'C ');
	insert into takes values('59530', '960', '1', 'Fall', 2009, 'A+');
	insert into takes values('76250', '843', '1', 'Fall', 2010, 'A-');
	insert into takes values('17769', '242', '1', 'Fall', 2009, 'C+');
	insert into takes values('50966', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('59553', '274', '1', 'Fall', 2002, 'C+');
	insert into takes values('36265', '468', '1', 'Fall', 2005, 'B-');
	insert into takes values('83836', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('15883', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('914', '808', '1', 'Fall', 2003, 'B ');
	insert into takes values('827', '974', '1', 'Fall', 2003, 'B-');
	insert into takes values('11057', '559', '1', 'Fall', 2002, 'B+');
	insert into takes values('60224', '791', '1', 'Spring', 2006, 'B+');
	insert into takes values('31993', '735', '1', 'Spring', 2003, 'C ');
	insert into takes values('82687', '867', '1', 'Fall', 2006, 'B ');
	insert into takes values('5871', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('72177', '443', '1', 'Spring', 2010, 'A-');
	insert into takes values('29863', '604', '1', 'Spring', 2009, 'A-');
	insert into takes values('11055', '702', '1', 'Spring', 2001, 'C+');
	insert into takes values('39241', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('8140', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('48640', '493', '1', 'Spring', 2010, 'C ');
	insert into takes values('39580', '445', '1', 'Spring', 2001, 'C ');
	insert into takes values('51997', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('77148', '349', '1', 'Spring', 2008, 'B+');
	insert into takes values('14554', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('42560', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('57474', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('18108', '421', '1', 'Fall', 2004, 'A-');
	insert into takes values('39254', '561', '1', 'Fall', 2006, 'B-');
	insert into takes values('22417', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('67436', '408', '1', 'Spring', 2007, 'A ');
	insert into takes values('65681', '270', '1', 'Spring', 2010, 'B-');
	insert into takes values('10663', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('39521', '612', '1', 'Fall', 2007, 'A+');
	insert into takes values('66356', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('44584', '591', '1', 'Spring', 2005, 'B+');
	insert into takes values('58469', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('27952', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('87624', '443', '1', 'Spring', 2010, 'A ');
	insert into takes values('83022', '527', '1', 'Fall', 2004, 'C+');
	insert into takes values('88887', '443', '1', 'Spring', 2010, 'A-');
	insert into takes values('35138', '200', '2', 'Fall', 2002, 'C-');
	insert into takes values('96193', '571', '1', 'Spring', 2004, 'A-');
	insert into takes values('18675', '400', '1', 'Spring', 2007, 'A-');
	insert into takes values('87268', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('75560', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('74840', '852', '1', 'Spring', 2008, 'A-');
	insert into takes values('14032', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('41280', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('76291', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('9360', '258', '1', 'Fall', 2007, 'C+');
	insert into takes values('43854', '696', '1', 'Spring', 2002, 'A-');
	insert into takes values('85680', '875', '1', 'Spring', 2005, 'B+');
	insert into takes values('64082', '561', '1', 'Fall', 2006, 'A+');
	insert into takes values('36845', '352', '1', 'Spring', 2006, 'C-');
	insert into takes values('10834', '169', '1', 'Spring', 2007, 'C+');
	insert into takes values('52187', '158', '1', 'Fall', 2008, 'A ');
	insert into takes values('57185', '200', '2', 'Fall', 2002, 'B-');
	insert into takes values('19862', '694', '1', 'Fall', 2002, 'A ');
	insert into takes values('7973', '735', '1', 'Spring', 2003, 'C-');
	insert into takes values('48423', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('68248', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('94522', '421', '1', 'Fall', 2004, 'C+');
	insert into takes values('77244', '105', '2', 'Fall', 2002, 'C+');
	insert into takes values('50267', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('54672', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('99647', '137', '1', 'Spring', 2002, 'B ');
	insert into takes values('16543', '445', '1', 'Spring', 2001, 'A-');
	insert into takes values('87193', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('51553', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('34770', '561', '1', 'Fall', 2006, 'B-');
	insert into takes values('99399', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('14499', '626', '1', 'Fall', 2006, 'B-');
	insert into takes values('44551', '603', '1', 'Fall', 2003, 'A ');
	insert into takes values('1220', '476', '1', 'Fall', 2010, 'C ');
	insert into takes values('99348', '959', '1', 'Fall', 2006, 'A-');
	insert into takes values('16753', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('82707', '415', '1', 'Fall', 2010, 'A-');
	insert into takes values('37339', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('17911', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('97355', '489', '1', 'Fall', 2007, 'B-');
	insert into takes values('32419', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('91569', '169', '1', 'Spring', 2007, 'B-');
	insert into takes values('3163', '237', '2', 'Fall', 2009, 'C+');
	insert into takes values('5208', '612', '1', 'Fall', 2007, 'A+');
	insert into takes values('99451', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('66269', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('6523', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('42096', '468', '1', 'Fall', 2005, 'A ');
	insert into takes values('81294', '893', '1', 'Fall', 2007, 'B+');
	insert into takes values('49244', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('48165', '696', '1', 'Spring', 2002, 'A-');
	insert into takes values('22467', '496', '1', 'Fall', 2001, 'B+');
	insert into takes values('15517', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('18808', '400', '1', 'Spring', 2007, 'B ');
	insert into takes values('68248', '334', '1', 'Fall', 2009, 'B-');
	insert into takes values('18775', '561', '1', 'Fall', 2006, 'A+');
	insert into takes values('52750', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('91799', '927', '1', 'Fall', 2002, 'C ');
	insert into takes values('4435', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('45002', '461', '1', 'Fall', 2002, 'B ');
	insert into takes values('8807', '457', '1', 'Spring', 2001, 'B ');
	insert into takes values('38602', '158', '2', 'Spring', 2008, 'B+');
	insert into takes values('33651', '169', '2', 'Fall', 2002, 'A+');
	insert into takes values('41832', '408', '1', 'Spring', 2007, 'A+');
	insert into takes values('30177', '345', '1', 'Spring', 2008, 'C-');
	insert into takes values('76291', '591', '1', 'Spring', 2005, 'B-');
	insert into takes values('20489', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('14554', '443', '1', 'Spring', 2010, 'A ');
	insert into takes values('50039', '704', '1', 'Spring', 2008, 'C ');
	insert into takes values('44816', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('23224', '443', '1', 'Spring', 2010, 'A+');
	insert into takes values('78637', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('59397', '468', '1', 'Fall', 2005, 'B ');
	insert into takes values('65438', '366', '1', 'Fall', 2005, 'C ');
	insert into takes values('64121', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('19541', '581', '1', 'Spring', 2005, 'C+');
	insert into takes values('81396', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('69850', '702', '1', 'Spring', 2001, 'B-');
	insert into takes values('49391', '959', '1', 'Fall', 2006, 'C+');
	insert into takes values('29920', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('76743', '493', '1', 'Spring', 2010, 'B ');
	insert into takes values('29863', '200', '2', 'Fall', 2002, 'A+');
	insert into takes values('27236', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('24796', '274', '1', 'Fall', 2002, 'B ');
	insert into takes values('56849', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('26080', '679', '1', 'Spring', 2010, 'B ');
	insert into takes values('86344', '200', '1', 'Spring', 2007, 'C ');
	insert into takes values('77548', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('66494', '735', '2', 'Spring', 2010, 'B-');
	insert into takes values('23934', '489', '1', 'Fall', 2007, 'A ');
	insert into takes values('37856', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('30289', '270', '1', 'Spring', 2010, 'B-');
	insert into takes values('67293', '748', '1', 'Fall', 2003, 'C-');
	insert into takes values('54610', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('23224', '486', '1', 'Fall', 2009, 'A-');
	insert into takes values('21789', '760', '1', 'Spring', 2004, 'B ');
	insert into takes values('8022', '443', '2', 'Spring', 2002, 'C ');
	insert into takes values('91569', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('59117', '591', '1', 'Spring', 2005, 'C-');
	insert into takes values('4182', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('29390', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('57238', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('45359', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('19293', '362', '1', 'Fall', 2005, 'C-');
	insert into takes values('61783', '237', '1', 'Spring', 2008, 'B+');
	insert into takes values('66753', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('93508', '875', '1', 'Spring', 2005, 'C ');
	insert into takes values('23224', '426', '1', 'Spring', 2006, 'B ');
	insert into takes values('46260', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('83592', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('15980', '793', '1', 'Spring', 2002, 'B ');
	insert into takes values('49792', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('847', '599', '1', 'Spring', 2003, 'A+');
	insert into takes values('89059', '960', '1', 'Fall', 2009, 'B-');
	insert into takes values('67425', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('18709', '631', '1', 'Spring', 2007, 'A-');
	insert into takes values('90353', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('82970', '559', '1', 'Fall', 2002, 'A ');
	insert into takes values('66763', '362', '1', 'Fall', 2005, 'C ');
	insert into takes values('45680', '476', '1', 'Fall', 2010, 'B+');
	insert into takes values('14668', '663', '1', 'Spring', 2005, 'A ');
	insert into takes values('31690', '443', '1', 'Spring', 2010, 'A-');
	insert into takes values('5399', '461', '1', 'Fall', 2002, 'C-');
	insert into takes values('18821', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('57334', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('89188', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('90814', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('81896', '237', '1', 'Spring', 2008, 'A+');
	insert into takes values('3545', '864', '1', 'Spring', 2006, 'C-');
	insert into takes values('64192', '793', '1', 'Spring', 2002, 'B ');
	insert into takes values('52523', '843', '1', 'Fall', 2010, 'C ');
	insert into takes values('85746', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('2133', '852', '1', 'Spring', 2008, 'B+');
	insert into takes values('24630', '445', '1', 'Spring', 2001, 'B-');
	insert into takes values('67018', '443', '1', 'Spring', 2010, 'B ');
	insert into takes values('14639', '561', '1', 'Fall', 2006, 'A ');
	insert into takes values('70452', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('16849', '991', '1', 'Spring', 2008, 'B-');
	insert into takes values('10705', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('76911', '443', '1', 'Spring', 2010, 'C+');
	insert into takes values('74016', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('87651', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('61081', '426', '1', 'Spring', 2006, 'C ');
	insert into takes values('41671', '493', '1', 'Spring', 2010, 'A ');
	insert into takes values('92703', '692', '1', 'Spring', 2010, 'A+');
	insert into takes values('41345', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('22260', '679', '1', 'Spring', 2010, 'B+');
	insert into takes values('32483', '400', '2', 'Fall', 2003, 'A ');
	insert into takes values('64121', '702', '1', 'Spring', 2001, 'C ');
	insert into takes values('10838', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('76224', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('39881', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('6523', '486', '1', 'Fall', 2009, 'B ');
	insert into takes values('90448', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('21766', '239', '1', 'Fall', 2006, 'C-');
	insert into takes values('88045', '408', '2', 'Spring', 2003, 'A ');
	insert into takes values('41751', '158', '2', 'Spring', 2008, 'A ');
	insert into takes values('53424', '581', '1', 'Spring', 2005, 'A ');
	insert into takes values('21789', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('22254', '626', '1', 'Fall', 2006, 'C ');
	insert into takes values('76173', '747', '1', 'Spring', 2004, 'C ');
	insert into takes values('31302', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('9114', '319', '1', 'Spring', 2003, 'C-');
	insert into takes values('51203', '457', '1', 'Spring', 2001, 'B-');
	insert into takes values('53451', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('50702', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('64067', '571', '1', 'Spring', 2004, 'C-');
	insert into takes values('32772', '338', '2', 'Spring', 2006, 'A ');
	insert into takes values('68248', '426', '1', 'Spring', 2006, 'A+');
	insert into takes values('79911', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('4582', '400', '1', 'Spring', 2007, 'C+');
	insert into takes values('20814', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('55329', '476', '1', 'Fall', 2010, 'B ');
	insert into takes values('57666', '927', '1', 'Fall', 2002, 'A ');
	insert into takes values('56089', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('75082', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('46928', '489', '1', 'Fall', 2007, 'B-');
	insert into takes values('76224', '612', '1', 'Fall', 2007, 'A-');
	insert into takes values('15430', '493', '1', 'Spring', 2010, 'A ');
	insert into takes values('34569', '242', '1', 'Fall', 2009, 'C ');
	insert into takes values('6710', '493', '1', 'Spring', 2010, 'C+');
	insert into takes values('1367', '591', '1', 'Spring', 2005, 'A+');
	insert into takes values('82974', '696', '1', 'Spring', 2002, 'A-');
	insert into takes values('11530', '338', '2', 'Spring', 2006, 'A+');
	insert into takes values('61403', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('16347', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('11966', '679', '1', 'Spring', 2010, 'C-');
	insert into takes values('30474', '345', '1', 'Spring', 2008, 'B ');
	insert into takes values('86753', '366', '1', 'Fall', 2005, 'A+');
	insert into takes values('80651', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('65038', '237', '1', 'Spring', 2008, 'C+');
	insert into takes values('89297', '972', '1', 'Spring', 2009, 'C-');
	insert into takes values('29665', '791', '1', 'Spring', 2006, 'A-');
	insert into takes values('74911', '571', '1', 'Spring', 2004, 'B+');
	insert into takes values('79469', '493', '1', 'Spring', 2010, 'C+');
	insert into takes values('56003', '694', '1', 'Fall', 2002, 'A ');
	insert into takes values('88525', '843', '1', 'Fall', 2010, 'A ');
	insert into takes values('87784', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('80285', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('2561', '158', '2', 'Spring', 2008, 'B+');
	insert into takes values('1460', '960', '2', 'Fall', 2006, 'A-');
	insert into takes values('6287', '603', '1', 'Fall', 2003, 'B ');
	insert into takes values('1460', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('84515', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('64642', '443', '1', 'Spring', 2010, 'C+');
	insert into takes values('13495', '200', '2', 'Fall', 2002, 'B-');
	insert into takes values('87048', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('49611', '457', '1', 'Spring', 2001, 'B-');
	insert into takes values('94814', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('90567', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('39927', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('35198', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('84432', '591', '1', 'Spring', 2005, 'B-');
	insert into takes values('45720', '496', '1', 'Fall', 2001, 'A-');
	insert into takes values('96968', '200', '1', 'Spring', 2007, 'A ');
	insert into takes values('39580', '192', '1', 'Fall', 2002, 'A+');
	insert into takes values('88085', '338', '1', 'Spring', 2007, 'B-');
	insert into takes values('53496', '959', '1', 'Fall', 2006, 'A-');
	insert into takes values('44258', '415', '1', 'Fall', 2010, 'B ');
	insert into takes values('99719', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('58469', '626', '1', 'Fall', 2006, 'B ');
	insert into takes values('90234', '443', '1', 'Spring', 2010, 'B-');
	insert into takes values('70021', '631', '1', 'Spring', 2007, 'A+');
	insert into takes values('77231', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('17911', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('89759', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('82646', '875', '1', 'Spring', 2005, 'B-');
	insert into takes values('13880', '748', '1', 'Fall', 2003, 'B ');
	insert into takes values('89104', '960', '1', 'Fall', 2009, 'B ');
	insert into takes values('32217', '482', '1', 'Fall', 2005, 'B-');
	insert into takes values('88418', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('16075', '366', '1', 'Fall', 2005, 'A ');
	insert into takes values('76057', '237', '2', 'Fall', 2009, 'A-');
	insert into takes values('81876', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('68395', '192', '1', 'Fall', 2002, 'C ');
	insert into takes values('79170', '561', '1', 'Fall', 2006, 'B+');
	insert into takes values('53469', '352', '1', 'Spring', 2006, 'A-');
	insert into takes values('53152', '401', '1', 'Fall', 2003, 'A-');
	insert into takes values('86707', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('70021', '242', '1', 'Fall', 2009, 'C ');
	insert into takes values('38899', '408', '2', 'Spring', 2003, 'B-');
	insert into takes values('77364', '747', '1', 'Spring', 2004, 'B-');
	insert into takes values('86001', '476', '1', 'Fall', 2010, 'A ');
	insert into takes values('90041', '545', '1', 'Fall', 2001, 'C ');
	insert into takes values('35881', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('15283', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('30474', '604', '1', 'Spring', 2009, 'B ');
	insert into takes values('61737', '867', '2', 'Fall', 2010, 'A+');
	insert into takes values('40044', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('70572', '591', '1', 'Spring', 2005, 'B+');
	insert into takes values('78858', '338', '1', 'Spring', 2007, 'A ');
	insert into takes values('38336', '400', '1', 'Spring', 2007, 'A-');
	insert into takes values('31761', '972', '1', 'Spring', 2009, 'A-');
	insert into takes values('1836', '960', '2', 'Fall', 2006, 'A ');
	insert into takes values('10814', '972', '1', 'Spring', 2009, 'B+');
	insert into takes values('21552', '991', '1', 'Spring', 2008, 'B ');
	insert into takes values('58465', '408', '2', 'Spring', 2003, 'C ');
	insert into takes values('34386', '808', '1', 'Fall', 2003, 'A+');
	insert into takes values('75791', '352', '1', 'Spring', 2006, 'B+');
	insert into takes values('26695', '270', '1', 'Spring', 2010, 'C ');
	insert into takes values('25718', '443', '2', 'Spring', 2002, 'B-');
	insert into takes values('80247', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('10267', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('46436', '158', '1', 'Fall', 2008, 'B-');
	insert into takes values('5336', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('8912', '802', '1', 'Spring', 2003, 'A+');
	insert into takes values('12173', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('31560', '137', '1', 'Spring', 2002, 'C-');
	insert into takes values('98120', '169', '1', 'Spring', 2007, 'C+');
	insert into takes values('54620', '545', '1', 'Fall', 2001, 'A ');
	insert into takes values('7123', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('75241', '158', '2', 'Spring', 2008, 'B-');
	insert into takes values('74460', '200', '2', 'Fall', 2002, 'B-');
	insert into takes values('50966', '679', '1', 'Spring', 2010, 'B ');
	insert into takes values('65241', '258', '1', 'Fall', 2007, 'A-');
	insert into takes values('81789', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('20002', '376', '1', 'Fall', 2006, 'A-');
	insert into takes values('64893', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('20974', '338', '2', 'Spring', 2006, 'A+');
	insert into takes values('51975', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('78552', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('89140', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('87015', '169', '2', 'Fall', 2002, 'A ');
	insert into takes values('7020', '875', '1', 'Spring', 2005, 'C-');
	insert into takes values('84702', '612', '1', 'Fall', 2007, 'B+');
	insert into takes values('41965', '468', '2', 'Fall', 2007, 'C-');
	insert into takes values('49684', '760', '1', 'Spring', 2004, 'B+');
	insert into takes values('42092', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('72768', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('96206', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('89414', '571', '1', 'Spring', 2004, 'C ');
	insert into takes values('19735', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('30164', '200', '2', 'Fall', 2002, 'C-');
	insert into takes values('22004', '482', '1', 'Fall', 2005, 'C ');
	insert into takes values('17076', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('54153', '158', '2', 'Spring', 2008, 'A ');
	insert into takes values('67051', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('29399', '702', '1', 'Spring', 2001, 'C-');
	insert into takes values('63361', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('68554', '603', '1', 'Fall', 2003, 'A+');
	insert into takes values('15144', '376', '1', 'Fall', 2006, 'B-');
	insert into takes values('75534', '603', '1', 'Fall', 2003, 'C-');
	insert into takes values('64155', '692', '1', 'Spring', 2010, 'A-');
	insert into takes values('17507', '603', '1', 'Fall', 2003, 'B-');
	insert into takes values('36685', '599', '1', 'Spring', 2003, 'A-');
	insert into takes values('94522', '237', '1', 'Spring', 2008, 'B ');
	insert into takes values('43130', '604', '1', 'Spring', 2009, 'B+');
	insert into takes values('86707', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('89414', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('83747', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('82697', '362', '3', 'Spring', 2008, 'B ');
	insert into takes values('35462', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('41299', '362', '2', 'Fall', 2006, 'B-');
	insert into takes values('20084', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('27043', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('57377', '696', '1', 'Spring', 2002, 'B-');
	insert into takes values('69853', '489', '1', 'Fall', 2007, 'B+');
	insert into takes values('16885', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('45826', '631', '1', 'Spring', 2007, 'C+');
	insert into takes values('67725', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('37734', '169', '2', 'Fall', 2002, 'B ');
	insert into takes values('23506', '362', '1', 'Fall', 2005, 'C+');
	insert into takes values('91978', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('9408', '949', '1', 'Fall', 2007, 'C ');
	insert into takes values('56143', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('33759', '461', '1', 'Fall', 2002, 'A-');
	insert into takes values('43130', '258', '1', 'Fall', 2007, 'A+');
	insert into takes values('44352', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('65438', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('50331', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('30017', '457', '1', 'Spring', 2001, 'C+');
	insert into takes values('75560', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('39204', '443', '2', 'Spring', 2002, 'B+');
	insert into takes values('5243', '415', '1', 'Fall', 2010, 'C-');
	insert into takes values('3163', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('3651', '629', '1', 'Spring', 2003, 'A ');
	insert into takes values('9953', '864', '1', 'Spring', 2006, 'B ');
	insert into takes values('45359', '445', '1', 'Spring', 2001, 'B+');
	insert into takes values('17207', '760', '1', 'Spring', 2004, 'C ');
	insert into takes values('59517', '612', '1', 'Fall', 2007, 'A ');
	insert into takes values('93631', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('66229', '400', '1', 'Spring', 2007, 'B ');
	insert into takes values('92464', '864', '1', 'Spring', 2006, 'C-');
	insert into takes values('52741', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('544', '239', '1', 'Fall', 2006, 'C+');
	insert into takes values('31079', '735', '1', 'Spring', 2003, 'C-');
	insert into takes values('6729', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('49244', '793', '1', 'Spring', 2002, 'A-');
	insert into takes values('94726', '927', '1', 'Fall', 2002, 'A ');
	insert into takes values('83691', '476', '1', 'Fall', 2010, 'C ');
	insert into takes values('64401', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('41345', '366', '1', 'Fall', 2005, 'B ');
	insert into takes values('18675', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('4182', '735', '2', 'Spring', 2010, 'C ');
	insert into takes values('74016', '959', '1', 'Fall', 2006, 'A+');
	insert into takes values('46106', '408', '2', 'Spring', 2003, 'C-');
	insert into takes values('46769', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('75522', '137', '1', 'Spring', 2002, 'B+');
	insert into takes values('14596', '242', '1', 'Fall', 2009, 'C+');
	insert into takes values('64013', '702', '1', 'Spring', 2001, 'A-');
	insert into takes values('50969', '559', '1', 'Fall', 2002, 'A-');
	insert into takes values('35721', '604', '1', 'Spring', 2009, 'B ');
	insert into takes values('39157', '400', '2', 'Fall', 2003, 'A ');
	insert into takes values('51553', '401', '1', 'Fall', 2003, 'A ');
	insert into takes values('41671', '893', '1', 'Fall', 2007, 'A+');
	insert into takes values('63612', '304', '1', 'Fall', 2009, 'C-');
	insert into takes values('97658', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('37653', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('92965', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('88085', '960', '1', 'Fall', 2009, 'A-');
	insert into takes values('85602', '105', '1', 'Fall', 2009, 'C+');
	insert into takes values('18809', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('23224', '400', '2', 'Fall', 2003, 'A ');
	insert into takes values('5243', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('84865', '482', '1', 'Fall', 2005, 'A ');
	insert into takes values('60688', '105', '1', 'Fall', 2009, 'C ');
	insert into takes values('45826', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('8860', '591', '1', 'Spring', 2005, 'A+');
	insert into takes values('79697', '313', '1', 'Fall', 2010, 'C ');
	insert into takes values('10204', '237', '2', 'Fall', 2009, 'A-');
	insert into takes values('38668', '808', '1', 'Fall', 2003, 'C ');
	insert into takes values('51416', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('17676', '400', '1', 'Spring', 2007, 'A ');
	insert into takes values('51678', '748', '1', 'Fall', 2003, 'C ');
	insert into takes values('792', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('43912', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('27727', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('19220', '313', '1', 'Fall', 2010, 'C+');
	insert into takes values('19766', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('46981', '604', '1', 'Spring', 2009, 'A-');
	insert into takes values('55859', '400', '1', 'Spring', 2007, 'B+');
	insert into takes values('28019', '486', '1', 'Fall', 2009, 'B ');
	insert into takes values('64192', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('17769', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('25940', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('25256', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('96911', '795', '1', 'Spring', 2004, 'B+');
	insert into takes values('35588', '591', '1', 'Spring', 2005, 'A-');
	insert into takes values('20084', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('16969', '808', '1', 'Fall', 2003, 'A+');
	insert into takes values('23449', '972', '1', 'Spring', 2009, 'C ');
	insert into takes values('57431', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('16311', '445', '1', 'Spring', 2001, 'A-');
	insert into takes values('44038', '200', '1', 'Spring', 2007, 'A-');
	insert into takes values('64593', '493', '1', 'Spring', 2010, 'A+');
	insert into takes values('31250', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('23373', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('55009', '408', '1', 'Spring', 2007, 'A ');
	insert into takes values('66008', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('31101', '972', '1', 'Spring', 2009, 'C-');
	insert into takes values('16035', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('1018', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('26147', '545', '1', 'Fall', 2001, 'A+');
	insert into takes values('51923', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('25528', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('81876', '493', '1', 'Spring', 2010, 'B+');
	insert into takes values('48423', '867', '1', 'Fall', 2006, 'A ');
	insert into takes values('64938', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('24010', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('61783', '242', '1', 'Fall', 2009, 'A+');
	insert into takes values('847', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('107', '408', '2', 'Spring', 2003, 'A ');
	insert into takes values('77234', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('35', '493', '1', 'Spring', 2010, 'A-');
	insert into takes values('16543', '735', '2', 'Spring', 2010, 'A+');
	insert into takes values('68554', '927', '1', 'Fall', 2002, 'B-');
	insert into takes values('99760', '421', '1', 'Fall', 2004, 'A-');
	insert into takes values('79205', '875', '1', 'Spring', 2005, 'A-');
	insert into takes values('27430', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('1285', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('24784', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('77729', '200', '2', 'Fall', 2002, 'C-');
	insert into takes values('68720', '169', '2', 'Fall', 2002, 'A ');
	insert into takes values('27366', '795', '1', 'Spring', 2004, 'B ');
	insert into takes values('15328', '843', '1', 'Fall', 2010, 'A-');
	insert into takes values('89393', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('39704', '443', '2', 'Spring', 2002, 'B+');
	insert into takes values('82591', '258', '1', 'Fall', 2007, 'A+');
	insert into takes values('1367', '875', '1', 'Spring', 2005, 'C-');
	insert into takes values('35175', '457', '1', 'Spring', 2001, 'A+');
	insert into takes values('29707', '545', '1', 'Fall', 2001, 'A+');
	insert into takes values('88577', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('61354', '304', '1', 'Fall', 2009, 'C-');
	insert into takes values('6400', '991', '1', 'Spring', 2008, 'B-');
	insert into takes values('69122', '702', '1', 'Spring', 2001, 'C-');
	insert into takes values('52929', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('79772', '334', '1', 'Fall', 2009, 'C-');
	insert into takes values('23525', '702', '1', 'Spring', 2001, 'B ');
	insert into takes values('6673', '169', '2', 'Fall', 2002, 'B ');
	insert into takes values('49280', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('7287', '242', '1', 'Fall', 2009, 'B ');
	insert into takes values('50664', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('1954', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('88308', '345', '1', 'Spring', 2008, 'B-');
	insert into takes values('51084', '274', '1', 'Fall', 2002, 'B ');
	insert into takes values('53490', '748', '1', 'Fall', 2003, 'B-');
	insert into takes values('90089', '702', '1', 'Spring', 2001, 'C-');
	insert into takes values('48247', '631', '1', 'Spring', 2007, 'A ');
	insert into takes values('81258', '642', '1', 'Fall', 2004, 'A-');
	insert into takes values('52120', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('1533', '852', '1', 'Spring', 2008, 'B+');
	insert into takes values('68395', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('17207', '445', '1', 'Spring', 2001, 'B-');
	insert into takes values('66269', '489', '1', 'Fall', 2007, 'B-');
	insert into takes values('4449', '137', '1', 'Spring', 2002, 'A ');
	insert into takes values('87222', '258', '1', 'Fall', 2007, 'C-');
	insert into takes values('99719', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('6673', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('49391', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('22086', '457', '1', 'Spring', 2001, 'C+');
	insert into takes values('94846', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('42298', '400', '2', 'Fall', 2003, 'B-');
	insert into takes values('31302', '694', '1', 'Fall', 2002, 'A+');
	insert into takes values('69241', '791', '1', 'Spring', 2006, 'A-');
	insert into takes values('86001', '867', '2', 'Fall', 2010, 'C-');
	insert into takes values('62716', '875', '1', 'Spring', 2005, 'B-');
	insert into takes values('79210', '270', '1', 'Spring', 2010, 'A+');
	insert into takes values('54672', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('31516', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('8022', '626', '1', 'Fall', 2006, 'C ');
	insert into takes values('27017', '875', '1', 'Spring', 2005, 'B-');
	insert into takes values('42688', '612', '1', 'Fall', 2007, 'A-');
	insert into takes values('34236', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('65101', '893', '1', 'Fall', 2007, 'A ');
	insert into takes values('9993', '445', '1', 'Spring', 2001, 'C+');
	insert into takes values('557', '629', '1', 'Spring', 2003, 'B ');
	insert into takes values('87015', '443', '2', 'Spring', 2002, 'B+');
	insert into takes values('34957', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('51868', '679', '1', 'Spring', 2010, 'A ');
	insert into takes values('6895', '735', '2', 'Spring', 2010, 'B ');
	insert into takes values('70828', '401', '1', 'Fall', 2003, 'C-');
	insert into takes values('36685', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('39254', '482', '1', 'Fall', 2005, 'A ');
	insert into takes values('82591', '629', '1', 'Spring', 2003, 'B ');
	insert into takes values('77361', '476', '1', 'Fall', 2010, 'A ');
	insert into takes values('10269', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('78454', '401', '1', 'Fall', 2003, 'A+');
	insert into takes values('68554', '843', '1', 'Fall', 2010, 'C+');
	insert into takes values('86001', '702', '1', 'Spring', 2001, 'A-');
	insert into takes values('35905', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('78782', '313', '1', 'Fall', 2010, 'C-');
	insert into takes values('57941', '802', '1', 'Spring', 2003, 'C+');
	insert into takes values('30858', '702', '1', 'Spring', 2001, 'B-');
	insert into takes values('61232', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('64731', '626', '1', 'Fall', 2006, 'B-');
	insert into takes values('68150', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('36995', '679', '1', 'Spring', 2010, 'C+');
	insert into takes values('30021', '200', '1', 'Spring', 2007, 'C ');
	insert into takes values('18234', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('81789', '400', '2', 'Fall', 2003, 'A+');
	insert into takes values('78922', '561', '1', 'Fall', 2006, 'C ');
	insert into takes values('11455', '476', '1', 'Fall', 2010, 'A+');
	insert into takes values('45494', '791', '1', 'Spring', 2006, 'A-');
	insert into takes values('10693', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('17057', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('18821', '527', '1', 'Fall', 2004, 'C-');
	insert into takes values('95631', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('19536', '319', '1', 'Spring', 2003, 'C-');
	insert into takes values('6474', '352', '1', 'Spring', 2006, 'C ');
	insert into takes values('978', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('8807', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('48471', '760', '1', 'Spring', 2004, 'C ');
	insert into takes values('28989', '545', '1', 'Fall', 2001, 'B-');
	insert into takes values('70688', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('36402', '626', '1', 'Fall', 2006, 'B ');
	insert into takes values('50969', '604', '1', 'Spring', 2009, 'C ');
	insert into takes values('25331', '345', '1', 'Spring', 2008, 'C+');
	insert into takes values('98984', '457', '1', 'Spring', 2001, 'B-');
	insert into takes values('69471', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('12078', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('29707', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('50206', '991', '1', 'Spring', 2008, 'B-');
	insert into takes values('67371', '604', '1', 'Spring', 2009, 'B-');
	insert into takes values('67407', '991', '1', 'Spring', 2008, 'C-');
	insert into takes values('95175', '972', '1', 'Spring', 2009, 'A-');
	insert into takes values('1367', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('25718', '808', '1', 'Fall', 2003, 'B-');
	insert into takes values('7861', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('77148', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('76291', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('39238', '334', '1', 'Fall', 2009, 'C-');
	insert into takes values('25725', '237', '1', 'Spring', 2008, 'C-');
	insert into takes values('98388', '401', '1', 'Fall', 2003, 'C ');
	insert into takes values('20378', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('64192', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('67793', '345', '1', 'Spring', 2008, 'A-');
	insert into takes values('14032', '200', '2', 'Fall', 2002, 'C+');
	insert into takes values('21102', '200', '1', 'Spring', 2007, 'B+');
	insert into takes values('14284', '313', '1', 'Fall', 2010, 'B-');
	insert into takes values('78116', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('74639', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('61527', '626', '1', 'Fall', 2006, 'A ');
	insert into takes values('93986', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('87246', '642', '1', 'Fall', 2004, 'B+');
	insert into takes values('62373', '158', '1', 'Fall', 2008, 'C ');
	insert into takes values('41751', '401', '1', 'Fall', 2003, 'A ');
	insert into takes values('39157', '345', '1', 'Spring', 2008, 'C ');
	insert into takes values('37454', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('25077', '192', '1', 'Fall', 2002, 'A+');
	insert into takes values('35935', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('55354', '468', '1', 'Fall', 2005, 'B+');
	insert into takes values('75046', '692', '1', 'Spring', 2010, 'C ');
	insert into takes values('15083', '400', '1', 'Spring', 2007, 'B ');
	insert into takes values('6209', '415', '1', 'Fall', 2010, 'C-');
	insert into takes values('59517', '603', '1', 'Fall', 2003, 'A+');
	insert into takes values('77580', '237', '1', 'Spring', 2008, 'B-');
	insert into takes values('14668', '489', '1', 'Fall', 2007, 'B+');
	insert into takes values('19638', '200', '2', 'Fall', 2002, 'C+');
	insert into takes values('51549', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('36019', '545', '1', 'Fall', 2001, 'A-');
	insert into takes values('21100', '169', '1', 'Spring', 2007, 'A ');
	insert into takes values('90089', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('10033', '603', '1', 'Fall', 2003, 'B ');
	insert into takes values('71426', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('70452', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('42388', '192', '1', 'Fall', 2002, 'C-');
	insert into takes values('3739', '415', '1', 'Fall', 2010, 'B ');
	insert into takes values('69960', '748', '1', 'Fall', 2003, 'B-');
	insert into takes values('82918', '443', '1', 'Spring', 2010, 'B ');
	insert into takes values('26147', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('3163', '443', '1', 'Spring', 2010, 'A ');
	insert into takes values('64724', '694', '1', 'Fall', 2002, 'B-');
	insert into takes values('61003', '631', '1', 'Spring', 2007, 'B+');
	insert into takes values('65056', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('18740', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('4034', '760', '1', 'Spring', 2004, 'C ');
	insert into takes values('18859', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('62749', '852', '1', 'Spring', 2008, 'B+');
	insert into takes values('31086', '960', '1', 'Fall', 2009, 'A-');
	insert into takes values('65715', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('21008', '408', '2', 'Spring', 2003, 'B ');
	insert into takes values('56598', '105', '1', 'Fall', 2009, 'B ');
	insert into takes values('9659', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('86674', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('67436', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('62487', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('36791', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('65396', '468', '1', 'Fall', 2005, 'B+');
	insert into takes values('9183', '486', '1', 'Fall', 2009, 'B ');
	insert into takes values('69628', '338', '2', 'Spring', 2006, 'C ');
	insert into takes values('54296', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('68999', '105', '1', 'Fall', 2009, 'C-');
	insert into takes values('66469', '258', '1', 'Fall', 2007, 'A+');
	insert into takes values('61402', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('72669', '476', '1', 'Fall', 2010, 'A ');
	insert into takes values('40937', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('42556', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('74639', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('29002', '468', '1', 'Fall', 2005, 'B+');
	insert into takes values('45359', '704', '1', 'Spring', 2008, 'C ');
	insert into takes values('5961', '408', '2', 'Spring', 2003, 'B ');
	insert into takes values('39978', '270', '1', 'Spring', 2010, 'C ');
	insert into takes values('56003', '735', '2', 'Spring', 2010, 'A-');
	insert into takes values('10269', '489', '1', 'Fall', 2007, 'A-');
	insert into takes values('19735', '581', '1', 'Spring', 2005, 'A ');
	insert into takes values('68070', '571', '1', 'Spring', 2004, 'A+');
	insert into takes values('41832', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('81896', '972', '1', 'Spring', 2009, 'C ');
	insert into takes values('15578', '545', '1', 'Fall', 2001, 'C ');
	insert into takes values('18554', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('63502', '962', '1', 'Spring', 2008, 'B ');
	insert into takes values('29849', '867', '1', 'Fall', 2006, 'B ');
	insert into takes values('83039', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('18809', '603', '1', 'Fall', 2003, 'B ');
	insert into takes values('17769', '571', '1', 'Spring', 2004, 'C-');
	insert into takes values('71904', '959', '1', 'Fall', 2006, 'A+');
	insert into takes values('35685', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('35685', '242', '1', 'Fall', 2009, 'C+');
	insert into takes values('36685', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('63288', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('7287', '319', '1', 'Spring', 2003, 'C-');
	insert into takes values('89196', '561', '1', 'Fall', 2006, 'B-');
	insert into takes values('46725', '270', '1', 'Spring', 2010, 'A+');
	insert into takes values('18809', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('72186', '493', '1', 'Spring', 2010, 'B+');
	insert into takes values('16297', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('52385', '704', '1', 'Spring', 2008, 'C ');
	insert into takes values('48660', '158', '2', 'Spring', 2008, 'C-');
	insert into takes values('74911', '735', '2', 'Spring', 2010, 'B-');
	insert into takes values('99977', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('19321', '105', '2', 'Fall', 2002, 'A ');
	insert into takes values('7970', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('44706', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('80912', '313', '1', 'Fall', 2010, 'B-');
	insert into takes values('57780', '443', '2', 'Spring', 2002, 'A+');
	insert into takes values('36513', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('39927', '612', '1', 'Fall', 2007, 'B+');
	insert into takes values('54296', '962', '1', 'Spring', 2008, 'C+');
	insert into takes values('25525', '304', '1', 'Fall', 2009, 'A ');
	insert into takes values('16311', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('7020', '270', '1', 'Spring', 2010, 'B-');
	insert into takes values('45083', '408', '2', 'Spring', 2003, 'C-');
	insert into takes values('20378', '270', '1', 'Spring', 2010, 'B-');
	insert into takes values('15030', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('46980', '313', '1', 'Fall', 2010, 'A-');
	insert into takes values('87044', '561', '1', 'Fall', 2006, 'C+');
	insert into takes values('22467', '376', '1', 'Fall', 2006, 'C ');
	insert into takes values('90448', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('94894', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('23457', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('21100', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('58172', '867', '2', 'Fall', 2010, 'B-');
	insert into takes values('53469', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('92332', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('75173', '258', '1', 'Fall', 2007, 'A ');
	insert into takes values('82688', '169', '1', 'Spring', 2007, 'B-');
	insert into takes values('36263', '489', '1', 'Fall', 2007, 'B+');
	insert into takes values('77244', '274', '1', 'Fall', 2002, 'A+');
	insert into takes values('42019', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('53077', '376', '1', 'Fall', 2006, 'B-');
	insert into takes values('61081', '408', '1', 'Spring', 2007, 'A+');
	insert into takes values('63361', '663', '1', 'Spring', 2005, 'A-');
	insert into takes values('26619', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('30164', '482', '1', 'Fall', 2005, 'A+');
	insert into takes values('34392', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('23392', '338', '2', 'Spring', 2006, 'A-');
	insert into takes values('31476', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('2286', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('70021', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('22004', '313', '1', 'Fall', 2010, 'B ');
	insert into takes values('41211', '867', '1', 'Fall', 2006, 'A+');
	insert into takes values('91851', '631', '1', 'Spring', 2007, 'C+');
	insert into takes values('11194', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('13504', '338', '2', 'Spring', 2006, 'B+');
	insert into takes values('30397', '349', '1', 'Spring', 2008, 'A-');
	insert into takes values('12362', '760', '1', 'Spring', 2004, 'B+');
	insert into takes values('74796', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('2139', '545', '1', 'Fall', 2001, 'A+');
	insert into takes values('47677', '421', '1', 'Fall', 2004, 'C+');
	insert into takes values('34236', '258', '1', 'Fall', 2007, 'C+');
	insert into takes values('41973', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('56598', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('82066', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('53185', '200', '2', 'Fall', 2002, 'B-');
	insert into takes values('98019', '158', '2', 'Spring', 2008, 'C-');
	insert into takes values('37586', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('7498', '760', '1', 'Spring', 2004, 'C+');
	insert into takes values('53803', '545', '1', 'Fall', 2001, 'B-');
	insert into takes values('59172', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('87784', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('19541', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('22050', '274', '1', 'Fall', 2002, 'B ');
	insert into takes values('24116', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('18941', '959', '1', 'Fall', 2006, 'A ');
	insert into takes values('98423', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('15457', '443', '2', 'Spring', 2002, 'C ');
	insert into takes values('48660', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('73213', '338', '2', 'Spring', 2006, 'B+');
	insert into takes values('75522', '959', '1', 'Fall', 2006, 'A-');
	insert into takes values('5920', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('77003', '679', '1', 'Spring', 2010, 'B ');
	insert into takes values('60748', '169', '2', 'Fall', 2002, 'C ');
	insert into takes values('65205', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('4438', '927', '1', 'Fall', 2002, 'C+');
	insert into takes values('39046', '443', '2', 'Spring', 2002, 'C+');
	insert into takes values('47265', '527', '1', 'Fall', 2004, 'B-');
	insert into takes values('38121', '927', '1', 'Fall', 2002, 'A-');
	insert into takes values('92417', '242', '1', 'Fall', 2009, 'A ');
	insert into takes values('1000', '802', '1', 'Spring', 2003, 'C+');
	insert into takes values('47126', '591', '1', 'Spring', 2005, 'A-');
	insert into takes values('98940', '401', '1', 'Fall', 2003, 'C+');
	insert into takes values('81538', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('93354', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('4383', '408', '2', 'Spring', 2003, 'B-');
	insert into takes values('64642', '527', '1', 'Fall', 2004, 'A ');
	insert into takes values('43989', '867', '1', 'Fall', 2006, 'C+');
	insert into takes values('3576', '408', '2', 'Spring', 2003, 'A+');
	insert into takes values('92274', '545', '1', 'Fall', 2001, 'C ');
	insert into takes values('65676', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('74530', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('21556', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('14032', '313', '1', 'Fall', 2010, 'A+');
	insert into takes values('31341', '527', '1', 'Fall', 2004, 'B+');
	insert into takes values('62054', '631', '1', 'Spring', 2007, 'A ');
	insert into takes values('3639', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('32056', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('4034', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('27236', '843', '1', 'Fall', 2010, 'B+');
	insert into takes values('10917', '960', '1', 'Fall', 2009, 'B+');
	insert into takes values('22325', '476', '1', 'Fall', 2010, 'B+');
	insert into takes values('19050', '349', '1', 'Spring', 2008, 'B+');
	insert into takes values('37809', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('18740', '735', '2', 'Spring', 2010, 'B-');
	insert into takes values('49205', '313', '1', 'Fall', 2010, 'B ');
	insert into takes values('16405', '493', '1', 'Spring', 2010, 'C ');
	insert into takes values('83314', '960', '2', 'Fall', 2006, 'B+');
	insert into takes values('4940', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('17397', '237', '2', 'Fall', 2009, 'C+');
	insert into takes values('14668', '631', '1', 'Spring', 2007, 'B ');
	insert into takes values('17424', '629', '1', 'Spring', 2003, 'B+');
	insert into takes values('69752', '559', '1', 'Fall', 2002, 'B ');
	insert into takes values('34197', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('8603', '893', '1', 'Fall', 2007, 'B ');
	insert into takes values('90124', '735', '1', 'Spring', 2003, 'C+');
	insert into takes values('96615', '893', '1', 'Fall', 2007, 'B-');
	insert into takes values('77548', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('26427', '626', '1', 'Fall', 2006, 'C+');
	insert into takes values('62754', '559', '1', 'Fall', 2002, 'B ');
	insert into takes values('99268', '376', '1', 'Fall', 2006, 'C+');
	insert into takes values('17997', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('17128', '200', '1', 'Spring', 2007, 'B-');
	insert into takes values('1367', '169', '2', 'Fall', 2002, 'A+');
	insert into takes values('12941', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('5243', '747', '1', 'Spring', 2004, 'C-');
	insert into takes values('288', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('98870', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('95175', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('89414', '421', '1', 'Fall', 2004, 'A ');
	insert into takes values('19245', '362', '2', 'Fall', 2006, 'C-');
	insert into takes values('29920', '400', '2', 'Fall', 2003, 'A ');
	insert into takes values('70098', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('14484', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('25068', '468', '2', 'Fall', 2007, 'B ');
	insert into takes values('32506', '408', '2', 'Spring', 2003, 'B-');
	insert into takes values('61065', '795', '1', 'Spring', 2004, 'C+');
	insert into takes values('75794', '362', '3', 'Spring', 2008, 'C+');
	insert into takes values('55238', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('48901', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('82688', '313', '1', 'Fall', 2010, 'B-');
	insert into takes values('26427', '591', '1', 'Spring', 2005, 'C+');
	insert into takes values('41774', '408', '1', 'Spring', 2007, 'C ');
	insert into takes values('12683', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('13408', '864', '1', 'Spring', 2006, 'C-');
	insert into takes values('29959', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('17996', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('94535', '105', '1', 'Fall', 2009, 'A+');
	insert into takes values('7287', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('77172', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('63860', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('46260', '443', '1', 'Spring', 2010, 'C+');
	insert into takes values('56212', '445', '1', 'Spring', 2001, 'A-');
	insert into takes values('19220', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('89312', '408', '1', 'Spring', 2007, 'B ');
	insert into takes values('1087', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('51084', '642', '1', 'Fall', 2004, 'C+');
	insert into takes values('23994', '702', '1', 'Spring', 2001, 'C ');
	insert into takes values('33107', '867', '2', 'Fall', 2010, 'C ');
	insert into takes values('62152', '482', '1', 'Fall', 2005, 'A-');
	insert into takes values('40682', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('58606', '400', '1', 'Spring', 2007, 'B ');
	insert into takes values('28409', '401', '1', 'Fall', 2003, 'C-');
	insert into takes values('52385', '169', '1', 'Spring', 2007, 'C+');
	insert into takes values('34392', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('27366', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('75794', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('93171', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('28538', '927', '1', 'Fall', 2002, 'B-');
	insert into takes values('50598', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('3487', '991', '1', 'Spring', 2008, 'B ');
	insert into takes values('17086', '626', '1', 'Fall', 2006, 'C ');
	insert into takes values('43016', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('81207', '400', '2', 'Fall', 2003, 'A+');
	insert into takes values('19536', '415', '1', 'Fall', 2010, 'B+');
	insert into takes values('34502', '169', '1', 'Spring', 2007, 'C+');
	insert into takes values('37454', '415', '1', 'Fall', 2010, 'C+');
	insert into takes values('15578', '599', '1', 'Spring', 2003, 'B+');
	insert into takes values('84495', '137', '1', 'Spring', 2002, 'A ');
	insert into takes values('74530', '237', '2', 'Fall', 2009, 'C ');
	insert into takes values('57238', '338', '1', 'Spring', 2007, 'A+');
	insert into takes values('57377', '352', '1', 'Spring', 2006, 'A-');
	insert into takes values('17507', '893', '1', 'Fall', 2007, 'C+');
	insert into takes values('26427', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('97658', '169', '1', 'Spring', 2007, 'C ');
	insert into takes values('39114', '421', '1', 'Fall', 2004, 'A-');
	insert into takes values('37759', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('29390', '376', '1', 'Fall', 2006, 'C ');
	insert into takes values('45680', '581', '1', 'Spring', 2005, 'A-');
	insert into takes values('77003', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('17997', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('93354', '376', '1', 'Fall', 2006, 'C ');
	insert into takes values('18752', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('34569', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('55009', '735', '1', 'Spring', 2003, 'A ');
	insert into takes values('6712', '694', '1', 'Fall', 2002, 'B-');
	insert into takes values('46981', '791', '1', 'Spring', 2006, 'C+');
	insert into takes values('69225', '972', '1', 'Spring', 2009, 'A-');
	insert into takes values('66269', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('37038', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('65056', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('39472', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('18941', '258', '1', 'Fall', 2007, 'C ');
	insert into takes values('56003', '400', '2', 'Fall', 2003, 'C+');
	insert into takes values('63860', '663', '1', 'Spring', 2005, 'C ');
	insert into takes values('14621', '571', '1', 'Spring', 2004, 'C+');
	insert into takes values('75772', '893', '1', 'Fall', 2007, 'A+');
	insert into takes values('16075', '258', '1', 'Fall', 2007, 'B+');
	insert into takes values('76246', '663', '1', 'Spring', 2005, 'C-');
	insert into takes values('13081', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('28299', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('63612', '408', '1', 'Spring', 2007, 'C+');
	insert into takes values('56849', '489', '1', 'Fall', 2007, 'C ');
	insert into takes values('29462', '581', '1', 'Spring', 2005, 'C ');
	insert into takes values('20445', '702', '1', 'Spring', 2001, 'B ');
	insert into takes values('39520', '408', '1', 'Spring', 2007, 'A ');
	insert into takes values('27727', '735', '2', 'Spring', 2010, 'C ');
	insert into takes values('41774', '795', '1', 'Spring', 2004, 'B-');
	insert into takes values('17424', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('98359', '443', '1', 'Spring', 2010, 'A+');
	insert into takes values('83696', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('54296', '561', '1', 'Fall', 2006, 'B-');
	insert into takes values('45817', '362', '3', 'Spring', 2008, 'C-');
	insert into takes values('4645', '486', '1', 'Fall', 2009, 'C ');
	insert into takes values('65241', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('74974', '696', '1', 'Spring', 2002, 'A-');
	insert into takes values('59673', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('48611', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('14581', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('41491', '972', '1', 'Spring', 2009, 'A+');
	insert into takes values('66494', '338', '2', 'Spring', 2006, 'A+');
	insert into takes values('34788', '561', '1', 'Fall', 2006, 'C ');
	insert into takes values('36379', '158', '2', 'Spring', 2008, 'C+');
	insert into takes values('30021', '376', '1', 'Fall', 2006, 'C ');
	insert into takes values('11083', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('34770', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('31080', '237', '1', 'Spring', 2008, 'B ');
	insert into takes values('21337', '408', '1', 'Spring', 2007, 'A-');
	insert into takes values('8603', '274', '1', 'Fall', 2002, 'B ');
	insert into takes values('79911', '748', '1', 'Fall', 2003, 'C ');
	insert into takes values('282', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('81984', '972', '1', 'Spring', 2009, 'A-');
	insert into takes values('52876', '960', '1', 'Fall', 2009, 'B ');
	insert into takes values('56276', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('66090', '735', '1', 'Spring', 2003, 'C+');
	insert into takes values('31486', '612', '1', 'Fall', 2007, 'A+');
	insert into takes values('53165', '158', '1', 'Fall', 2008, 'B+');
	insert into takes values('39514', '362', '1', 'Fall', 2005, 'C-');
	insert into takes values('97629', '468', '1', 'Fall', 2005, 'B+');
	insert into takes values('92274', '581', '1', 'Spring', 2005, 'A+');
	insert into takes values('90089', '760', '1', 'Spring', 2004, 'C+');
	insert into takes values('76270', '642', '1', 'Fall', 2004, 'A-');
	insert into takes values('67560', '591', '1', 'Spring', 2005, 'B ');
	insert into takes values('107', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('23270', '274', '1', 'Fall', 2002, 'A+');
	insert into takes values('69230', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('37818', '105', '2', 'Fall', 2002, 'A+');
	insert into takes values('56057', '864', '1', 'Spring', 2006, 'B+');
	insert into takes values('64164', '362', '1', 'Fall', 2005, 'C ');
	insert into takes values('63039', '748', '1', 'Fall', 2003, 'C ');
	insert into takes values('36265', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('5898', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('69521', '338', '1', 'Spring', 2007, 'A ');
	insert into takes values('74460', '376', '1', 'Fall', 2006, 'C ');
	insert into takes values('56058', '875', '1', 'Spring', 2005, 'B+');
	insert into takes values('94846', '591', '1', 'Spring', 2005, 'B+');
	insert into takes values('65703', '493', '1', 'Spring', 2010, 'C+');
	insert into takes values('77664', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('40558', '694', '1', 'Fall', 2002, 'B ');
	insert into takes values('40178', '493', '1', 'Spring', 2010, 'A-');
	insert into takes values('85887', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('25725', '875', '1', 'Spring', 2005, 'A+');
	insert into takes values('76049', '626', '1', 'Fall', 2006, 'B+');
	insert into takes values('88140', '169', '1', 'Spring', 2007, 'B+');
	insert into takes values('22258', '105', '2', 'Fall', 2002, 'A ');
	insert into takes values('21401', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('48901', '338', '2', 'Spring', 2006, 'C+');
	insert into takes values('93039', '960', '2', 'Fall', 2006, 'A ');
	insert into takes values('41973', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('30858', '486', '1', 'Fall', 2009, 'B ');
	insert into takes values('63449', '376', '1', 'Fall', 2006, 'B+');
	insert into takes values('66106', '927', '1', 'Fall', 2002, 'C-');
	insert into takes values('73328', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('61003', '959', '1', 'Fall', 2006, 'A+');
	insert into takes values('80254', '704', '1', 'Spring', 2008, 'B ');
	insert into takes values('95320', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('53424', '158', '2', 'Spring', 2008, 'B+');
	insert into takes values('32772', '457', '1', 'Spring', 2001, 'B-');
	insert into takes values('96117', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('52371', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('56212', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('12214', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('69679', '960', '2', 'Fall', 2006, 'A-');
	insert into takes values('11055', '443', '2', 'Spring', 2002, 'A+');
	insert into takes values('22198', '352', '1', 'Spring', 2006, 'C ');
	insert into takes values('91132', '192', '1', 'Fall', 2002, 'C-');
	insert into takes values('4449', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('85887', '493', '1', 'Spring', 2010, 'A-');
	insert into takes values('69628', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('87439', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('97065', '158', '1', 'Fall', 2008, 'A-');
	insert into takes values('63361', '808', '1', 'Fall', 2003, 'A+');
	insert into takes values('93354', '696', '1', 'Spring', 2002, 'A-');
	insert into takes values('27687', '443', '1', 'Spring', 2010, 'B ');
	insert into takes values('90814', '366', '1', 'Fall', 2005, 'C-');
	insert into takes values('42688', '962', '1', 'Spring', 2008, 'C-');
	insert into takes values('57666', '974', '1', 'Fall', 2003, 'C ');
	insert into takes values('84432', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('36019', '663', '1', 'Spring', 2005, 'A ');
	insert into takes values('54610', '496', '1', 'Fall', 2001, 'B-');
	insert into takes values('58465', '486', '1', 'Fall', 2009, 'A-');
	insert into takes values('6287', '694', '1', 'Fall', 2002, 'A+');
	insert into takes values('14432', '237', '2', 'Fall', 2009, 'C+');
	insert into takes values('99451', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('13495', '496', '1', 'Fall', 2001, 'C-');
	insert into takes values('22086', '408', '1', 'Spring', 2007, 'C ');
	insert into takes values('54622', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('95320', '962', '1', 'Spring', 2008, 'A ');
	insert into takes values('58081', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('92949', '408', '2', 'Spring', 2003, 'A+');
	insert into takes values('91978', '200', '2', 'Fall', 2002, 'B-');
	insert into takes values('10834', '445', '1', 'Spring', 2001, 'B+');
	insert into takes values('3739', '493', '1', 'Spring', 2010, 'B+');
	insert into takes values('89188', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('21102', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('4355', '457', '1', 'Spring', 2001, 'A-');
	insert into takes values('40457', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('71387', '304', '1', 'Fall', 2009, 'B ');
	insert into takes values('35687', '893', '1', 'Fall', 2007, 'C+');
	insert into takes values('18809', '408', '2', 'Spring', 2003, 'B-');
	insert into takes values('15883', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('83136', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('8252', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('69081', '496', '1', 'Fall', 2001, 'A+');
	insert into takes values('57055', '376', '1', 'Fall', 2006, 'C ');
	insert into takes values('91063', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('75534', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('96193', '461', '1', 'Fall', 2002, 'C-');
	insert into takes values('45300', '105', '2', 'Fall', 2002, 'C+');
	insert into takes values('90234', '415', '1', 'Fall', 2010, 'A+');
	insert into takes values('88993', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('20985', '493', '1', 'Spring', 2010, 'A+');
	insert into takes values('16753', '169', '2', 'Fall', 2002, 'A ');
	insert into takes values('57456', '748', '1', 'Fall', 2003, 'B ');
	insert into takes values('2177', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('60366', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('75878', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('27919', '482', '1', 'Fall', 2005, 'B-');
	insert into takes values('79446', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('17911', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('99348', '571', '1', 'Spring', 2004, 'C+');
	insert into takes values('21225', '559', '1', 'Fall', 2002, 'C-');
	insert into takes values('58172', '376', '1', 'Fall', 2006, 'C+');
	insert into takes values('14639', '692', '1', 'Spring', 2010, 'C+');
	insert into takes values('43130', '496', '1', 'Fall', 2001, 'C-');
	insert into takes values('71543', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('62429', '169', '2', 'Fall', 2002, 'A+');
	insert into takes values('9993', '735', '1', 'Spring', 2003, 'B-');
	insert into takes values('79892', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('2629', '349', '1', 'Spring', 2008, 'C-');
	insert into takes values('9953', '571', '1', 'Spring', 2004, 'C+');
	insert into takes values('33107', '258', '1', 'Fall', 2007, 'B+');
	insert into takes values('79502', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('107', '972', '1', 'Spring', 2009, 'C-');
	insert into takes values('76246', '603', '1', 'Fall', 2003, 'B+');
	insert into takes values('25725', '200', '1', 'Spring', 2007, 'A-');
	insert into takes values('52076', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('55286', '972', '1', 'Spring', 2009, 'A-');
	insert into takes values('14639', '893', '1', 'Fall', 2007, 'C+');
	insert into takes values('29803', '443', '2', 'Spring', 2002, 'B ');
	insert into takes values('66469', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('51203', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('71768', '581', '1', 'Spring', 2005, 'C-');
	insert into takes values('85063', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('69747', '927', '1', 'Fall', 2002, 'A ');
	insert into takes values('98359', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('13403', '192', '1', 'Fall', 2002, 'C-');
	insert into takes values('15083', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('38902', '242', '1', 'Fall', 2009, 'A-');
	insert into takes values('6710', '496', '1', 'Fall', 2001, 'B ');
	insert into takes values('23475', '960', '2', 'Fall', 2006, 'A-');
	insert into takes values('47677', '468', '1', 'Fall', 2005, 'A+');
	insert into takes values('81294', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('28299', '867', '2', 'Fall', 2010, 'A-');
	insert into takes values('68554', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('29192', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('65205', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('83002', '400', '2', 'Fall', 2003, 'A+');
	insert into takes values('53077', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('68278', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('48678', '893', '1', 'Fall', 2007, 'B ');
	insert into takes values('62716', '748', '1', 'Fall', 2003, 'C-');
	insert into takes values('74016', '694', '1', 'Fall', 2002, 'C+');
	insert into takes values('53728', '169', '1', 'Spring', 2007, 'B-');
	insert into takes values('68516', '591', '1', 'Spring', 2005, 'A+');
	insert into takes values('1110', '599', '1', 'Spring', 2003, 'C+');
	insert into takes values('29192', '559', '1', 'Fall', 2002, 'B+');
	insert into takes values('63645', '338', '2', 'Spring', 2006, 'C ');
	insert into takes values('99226', '949', '1', 'Fall', 2007, 'B ');
	insert into takes values('46337', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('73492', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('26473', '747', '1', 'Spring', 2004, 'B-');
	insert into takes values('94569', '875', '1', 'Spring', 2005, 'A ');
	insert into takes values('27094', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('61920', '137', '1', 'Spring', 2002, 'A-');
	insert into takes values('49813', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('39204', '169', '1', 'Spring', 2007, 'B-');
	insert into takes values('8343', '137', '1', 'Spring', 2002, 'A-');
	insert into takes values('34422', '626', '1', 'Fall', 2006, 'B-');
	insert into takes values('53089', '793', '1', 'Spring', 2002, 'C ');
	insert into takes values('32119', '158', '1', 'Fall', 2008, 'B+');
	insert into takes values('5017', '867', '1', 'Fall', 2006, 'A-');
	insert into takes values('95260', '415', '1', 'Fall', 2010, 'C-');
	insert into takes values('29849', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('94726', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('49873', '421', '1', 'Fall', 2004, 'B+');
	insert into takes values('54153', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('26802', '604', '1', 'Spring', 2009, 'B ');
	insert into takes values('30334', '960', '1', 'Fall', 2009, 'B+');
	insert into takes values('35935', '482', '1', 'Fall', 2005, 'A-');
	insert into takes values('74672', '679', '1', 'Spring', 2010, 'C+');
	insert into takes values('11194', '591', '1', 'Spring', 2005, 'B+');
	insert into takes values('30252', '158', '2', 'Spring', 2008, 'C+');
	insert into takes values('544', '415', '1', 'Fall', 2010, 'B-');
	insert into takes values('70688', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('39978', '959', '1', 'Fall', 2006, 'A+');
	insert into takes values('96911', '169', '1', 'Spring', 2007, 'A ');
	insert into takes values('20803', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('82066', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('52157', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('52669', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('99250', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('87044', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('73206', '200', '2', 'Fall', 2002, 'A+');
	insert into takes values('9408', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('74464', '962', '1', 'Spring', 2008, 'C+');
	insert into takes values('62549', '735', '1', 'Spring', 2003, 'C-');
	insert into takes values('98870', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('77130', '105', '1', 'Fall', 2009, 'C ');
	insert into takes values('53451', '626', '1', 'Fall', 2006, 'B ');
	insert into takes values('60984', '599', '1', 'Spring', 2003, 'A-');
	insert into takes values('95850', '696', '1', 'Spring', 2002, 'A ');
	insert into takes values('26028', '362', '3', 'Spring', 2008, 'C+');
	insert into takes values('10904', '401', '1', 'Fall', 2003, 'B+');
	insert into takes values('62373', '489', '1', 'Fall', 2007, 'A-');
	insert into takes values('27528', '631', '1', 'Spring', 2007, 'A+');
	insert into takes values('37430', '974', '1', 'Fall', 2003, 'A+');
	insert into takes values('53469', '105', '2', 'Fall', 2002, 'B+');
	insert into takes values('64297', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('27430', '376', '1', 'Fall', 2006, 'C+');
	insert into takes values('78332', '793', '1', 'Spring', 2002, 'A+');
	insert into takes values('64938', '237', '2', 'Fall', 2009, 'A-');
	insert into takes values('37521', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('23475', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('64222', '313', '1', 'Fall', 2010, 'B ');
	insert into takes values('4355', '400', '1', 'Spring', 2007, 'B ');
	insert into takes values('66008', '704', '1', 'Spring', 2008, 'C ');
	insert into takes values('1968', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('75273', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('3639', '867', '1', 'Fall', 2006, 'A ');
	insert into takes values('37454', '893', '1', 'Fall', 2007, 'C+');
	insert into takes values('94697', '735', '1', 'Spring', 2003, 'A ');
	insert into takes values('61232', '270', '1', 'Spring', 2010, 'C-');
	insert into takes values('7490', '702', '1', 'Spring', 2001, 'C ');
	insert into takes values('76953', '959', '1', 'Fall', 2006, 'A ');
	insert into takes values('17086', '735', '2', 'Spring', 2010, 'A+');
	insert into takes values('62487', '443', '2', 'Spring', 2002, 'A+');
	insert into takes values('16480', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('46260', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('65258', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('54508', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('73394', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('48165', '702', '1', 'Spring', 2001, 'C-');
	insert into takes values('89188', '319', '1', 'Spring', 2003, 'A-');
	insert into takes values('66763', '426', '1', 'Spring', 2006, 'C ');
	insert into takes values('57213', '694', '1', 'Fall', 2002, 'A+');
	insert into takes values('31442', '457', '1', 'Spring', 2001, 'C ');
	insert into takes values('11966', '242', '1', 'Fall', 2009, 'B ');
	insert into takes values('66279', '338', '2', 'Spring', 2006, 'A+');
	insert into takes values('72528', '843', '1', 'Fall', 2010, 'A-');
	insert into takes values('11083', '400', '2', 'Fall', 2003, 'A-');
	insert into takes values('98870', '445', '1', 'Spring', 2001, 'C+');
	insert into takes values('53805', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('44584', '559', '1', 'Fall', 2002, 'A ');
	insert into takes values('1080', '591', '1', 'Spring', 2005, 'A-');
	insert into takes values('6729', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('41894', '400', '2', 'Fall', 2003, 'C+');
	insert into takes values('75928', '137', '1', 'Spring', 2002, 'B ');
	insert into takes values('20814', '415', '1', 'Fall', 2010, 'A+');
	insert into takes values('68720', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('86375', '960', '2', 'Fall', 2006, 'B+');
	insert into takes values('7861', '461', '1', 'Fall', 2002, 'A-');
	insert into takes values('27687', '313', '1', 'Fall', 2010, 'A-');
	insert into takes values('76895', '334', '1', 'Fall', 2009, 'A ');
	insert into takes values('82970', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('85746', '927', '1', 'Fall', 2002, 'C ');
	insert into takes values('22396', '200', '1', 'Spring', 2007, 'A-');
	insert into takes values('4438', '362', '1', 'Fall', 2005, 'B ');
	insert into takes values('31364', '237', '2', 'Fall', 2009, 'C-');
	insert into takes values('17192', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('67340', '962', '1', 'Spring', 2008, 'A ');
	insert into takes values('95175', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('99977', '493', '1', 'Spring', 2010, 'A+');
	insert into takes values('21086', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('49611', '960', '2', 'Fall', 2006, 'B+');
	insert into takes values('56882', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('86641', '631', '1', 'Spring', 2007, 'A-');
	insert into takes values('19582', '561', '1', 'Fall', 2006, 'A ');
	insert into takes values('29192', '376', '1', 'Fall', 2006, 'A-');
	insert into takes values('85234', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('53047', '158', '1', 'Fall', 2008, 'A-');
	insert into takes values('13211', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('33837', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('83214', '345', '1', 'Spring', 2008, 'C ');
	insert into takes values('83557', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('99226', '629', '1', 'Spring', 2003, 'B ');
	insert into takes values('65299', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('60762', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('92464', '319', '1', 'Spring', 2003, 'B ');
	insert into takes values('66753', '192', '1', 'Fall', 2002, 'C ');
	insert into takes values('23506', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('64013', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('75395', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('63502', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('59117', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('56299', '476', '1', 'Fall', 2010, 'A+');
	insert into takes values('94142', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('2848', '927', '1', 'Fall', 2002, 'A ');
	insert into takes values('63288', '468', '1', 'Fall', 2005, 'B ');
	insert into takes values('65563', '893', '1', 'Fall', 2007, 'A+');
	insert into takes values('21008', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('91063', '482', '1', 'Fall', 2005, 'B ');
	insert into takes values('81396', '237', '1', 'Spring', 2008, 'C-');
	insert into takes values('82707', '468', '2', 'Fall', 2007, 'A-');
	insert into takes values('5393', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('38696', '408', '1', 'Spring', 2007, 'A+');
	insert into takes values('43981', '426', '1', 'Spring', 2006, 'A+');
	insert into takes values('96003', '169', '1', 'Spring', 2007, 'B+');
	insert into takes values('52872', '843', '1', 'Fall', 2010, 'B+');
	insert into takes values('5703', '696', '1', 'Spring', 2002, 'B ');
	insert into takes values('53485', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('42843', '258', '1', 'Fall', 2007, 'C ');
	insert into takes values('22396', '486', '1', 'Fall', 2009, 'A-');
	insert into takes values('6895', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('98359', '581', '1', 'Spring', 2005, 'A+');
	insert into takes values('44836', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('23449', '559', '1', 'Fall', 2002, 'B ');
	insert into takes values('68070', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('54610', '808', '1', 'Fall', 2003, 'A+');
	insert into takes values('24784', '105', '2', 'Fall', 2002, 'C+');
	insert into takes values('4508', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('96324', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('63090', '642', '1', 'Fall', 2004, 'C+');
	insert into takes values('99271', '927', '1', 'Fall', 2002, 'A-');
	insert into takes values('81876', '561', '1', 'Fall', 2006, 'B+');
	insert into takes values('24442', '334', '1', 'Fall', 2009, 'A ');
	insert into takes values('54605', '571', '1', 'Spring', 2004, 'B+');
	insert into takes values('18941', '415', '1', 'Fall', 2010, 'B-');
	insert into takes values('32483', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('48009', '362', '2', 'Fall', 2006, 'B-');
	insert into takes values('11202', '612', '1', 'Fall', 2007, 'A-');
	insert into takes values('88993', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('16480', '486', '1', 'Fall', 2009, 'A ');
	insert into takes values('75772', '626', '1', 'Fall', 2006, 'B ');
	insert into takes values('5393', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('17996', '612', '1', 'Fall', 2007, 'B-');
	insert into takes values('22467', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('32419', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('81258', '493', '1', 'Spring', 2010, 'C+');
	insert into takes values('85211', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('19450', '169', '1', 'Spring', 2007, 'C ');
	insert into takes values('71426', '527', '1', 'Fall', 2004, 'C-');
	insert into takes values('40059', '696', '1', 'Spring', 2002, 'A ');
	insert into takes values('11101', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('28994', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('83871', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('2501', '338', '1', 'Spring', 2007, 'A+');
	insert into takes values('74473', '974', '1', 'Fall', 2003, 'A-');
	insert into takes values('94998', '527', '1', 'Fall', 2004, 'A ');
	insert into takes values('1087', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('25718', '927', '1', 'Fall', 2002, 'A ');
	insert into takes values('61402', '445', '1', 'Spring', 2001, 'A-');
	insert into takes values('9360', '362', '3', 'Spring', 2008, 'C+');
	insert into takes values('6195', '843', '1', 'Fall', 2010, 'B-');
	insert into takes values('29849', '443', '1', 'Spring', 2010, 'A ');
	insert into takes values('25525', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('36265', '496', '1', 'Fall', 2001, 'C-');
	insert into takes values('35138', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('99719', '875', '1', 'Spring', 2005, 'B-');
	insert into takes values('68712', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('99949', '401', '1', 'Fall', 2003, 'B+');
	insert into takes values('84654', '489', '1', 'Fall', 2007, 'C+');
	insert into takes values('83686', '461', '1', 'Fall', 2002, 'B+');
	insert into takes values('53547', '200', '1', 'Spring', 2007, 'B-');
	insert into takes values('842', '663', '1', 'Spring', 2005, 'A-');
	insert into takes values('34542', '242', '1', 'Fall', 2009, 'C+');
	insert into takes values('48165', '626', '1', 'Fall', 2006, 'A ');
	insert into takes values('42019', '864', '1', 'Spring', 2006, 'C+');
	insert into takes values('97629', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('51768', '200', '2', 'Fall', 2002, 'A+');
	insert into takes values('34770', '105', '1', 'Fall', 2009, 'C+');
	insert into takes values('47487', '581', '1', 'Spring', 2005, 'C ');
	insert into takes values('11419', '486', '1', 'Fall', 2009, 'C+');
	insert into takes values('32506', '352', '1', 'Spring', 2006, 'A-');
	insert into takes values('90194', '604', '1', 'Spring', 2009, 'A-');
	insert into takes values('80420', '496', '1', 'Fall', 2001, 'A+');
	insert into takes values('11441', '696', '1', 'Spring', 2002, 'A ');
	insert into takes values('79170', '237', '2', 'Fall', 2009, 'B+');
	insert into takes values('39927', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('39704', '158', '1', 'Fall', 2008, 'B+');
	insert into takes values('87785', '949', '1', 'Fall', 2007, 'C+');
	insert into takes values('11441', '571', '1', 'Spring', 2004, 'B+');
	insert into takes values('42843', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('50039', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('79446', '527', '1', 'Fall', 2004, 'C+');
	insert into takes values('898', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('81258', '631', '1', 'Spring', 2007, 'B ');
	insert into takes values('40677', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('90567', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('42960', '795', '1', 'Spring', 2004, 'B-');
	insert into takes values('78116', '663', '1', 'Spring', 2005, 'C ');
	insert into takes values('11152', '443', '2', 'Spring', 2002, 'C ');
	insert into takes values('81031', '319', '1', 'Spring', 2003, 'C-');
	insert into takes values('88801', '864', '1', 'Spring', 2006, 'B ');
	insert into takes values('2501', '158', '2', 'Spring', 2008, 'C+');
	insert into takes values('84727', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('86707', '445', '1', 'Spring', 2001, 'A-');
	insert into takes values('44258', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('18469', '927', '1', 'Fall', 2002, 'B-');
	insert into takes values('12069', '376', '1', 'Fall', 2006, 'C+');
	insert into takes values('15457', '793', '1', 'Spring', 2002, 'B ');
	insert into takes values('19917', '137', '1', 'Spring', 2002, 'A ');
	insert into takes values('85754', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('81396', '345', '1', 'Spring', 2008, 'B-');
	insert into takes values('86661', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('45826', '496', '1', 'Fall', 2001, 'A+');
	insert into takes values('16133', '696', '1', 'Spring', 2002, 'C ');
	insert into takes values('52494', '679', '1', 'Spring', 2010, 'B+');
	insert into takes values('28994', '338', '1', 'Spring', 2007, 'C+');
	insert into takes values('22325', '696', '1', 'Spring', 2002, 'C ');
	insert into takes values('52741', '304', '1', 'Fall', 2009, 'C-');
	insert into takes values('89571', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('19862', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('41832', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('80976', '400', '1', 'Spring', 2007, 'A-');
	insert into takes values('5208', '760', '1', 'Spring', 2004, 'B-');
	insert into takes values('16631', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('66259', '457', '1', 'Spring', 2001, 'A ');
	insert into takes values('36379', '258', '1', 'Fall', 2007, 'C ');
	insert into takes values('52471', '802', '1', 'Spring', 2003, 'C-');
	insert into takes values('17207', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('83462', '461', '1', 'Fall', 2002, 'B+');
	insert into takes values('35042', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('7854', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('50944', '893', '1', 'Fall', 2007, 'A ');
	insert into takes values('92040', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('39925', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('9605', '893', '1', 'Fall', 2007, 'C ');
	insert into takes values('28361', '747', '1', 'Spring', 2004, 'C-');
	insert into takes values('53165', '468', '2', 'Fall', 2007, 'A-');
	insert into takes values('76743', '468', '1', 'Fall', 2005, 'C+');
	insert into takes values('18808', '415', '1', 'Fall', 2010, 'B+');
	insert into takes values('25362', '376', '1', 'Fall', 2006, 'A ');
	insert into takes values('978', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('78454', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('39046', '793', '1', 'Spring', 2002, 'B ');
	insert into takes values('22003', '239', '1', 'Fall', 2006, 'C+');
	insert into takes values('24746', '802', '1', 'Spring', 2003, 'A+');
	insert into takes values('43912', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('81785', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('24809', '802', '1', 'Spring', 2003, 'C-');
	insert into takes values('69758', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('25256', '158', '1', 'Fall', 2008, 'B+');
	insert into takes values('86075', '400', '2', 'Fall', 2003, 'A-');
	insert into takes values('24932', '443', '1', 'Spring', 2010, 'C+');
	insert into takes values('31035', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('70924', '612', '1', 'Fall', 2007, 'A+');
	insert into takes values('4438', '362', '2', 'Fall', 2006, 'B-');
	insert into takes values('39472', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('17192', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('76173', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('22620', '237', '1', 'Spring', 2008, 'B ');
	insert into takes values('62832', '258', '1', 'Fall', 2007, 'B-');
	insert into takes values('64013', '468', '1', 'Fall', 2005, 'B-');
	insert into takes values('18941', '400', '1', 'Spring', 2007, 'B ');
	insert into takes values('58465', '696', '1', 'Spring', 2002, 'B-');
	insert into takes values('82039', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('34386', '581', '1', 'Spring', 2005, 'B+');
	insert into takes values('89734', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('76743', '893', '1', 'Fall', 2007, 'A+');
	insert into takes values('81883', '864', '1', 'Spring', 2006, 'C-');
	insert into takes values('46970', '313', '1', 'Fall', 2010, 'A-');
	insert into takes values('41832', '599', '1', 'Spring', 2003, 'C+');
	insert into takes values('88801', '349', '1', 'Spring', 2008, 'A ');
	insert into takes values('75116', '795', '1', 'Spring', 2004, 'B ');
	insert into takes values('95029', '793', '1', 'Spring', 2002, 'B ');
	insert into takes values('63310', '864', '1', 'Spring', 2006, 'C-');
	insert into takes values('32368', '591', '1', 'Spring', 2005, 'B ');
	insert into takes values('41671', '426', '1', 'Spring', 2006, 'B ');
	insert into takes values('44703', '561', '1', 'Fall', 2006, 'A+');
	insert into takes values('51416', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('41938', '408', '1', 'Spring', 2007, 'A-');
	insert into takes values('47001', '591', '1', 'Spring', 2005, 'B+');
	insert into takes values('74672', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('37430', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('88389', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('83691', '237', '2', 'Fall', 2009, 'B+');
	insert into takes values('37581', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('80248', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('46074', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('30341', '960', '2', 'Fall', 2006, 'B+');
	insert into takes values('88884', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('65241', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('77130', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('4508', '927', '1', 'Fall', 2002, 'A+');
	insert into takes values('62716', '626', '1', 'Fall', 2006, 'A-');
	insert into takes values('69241', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('51093', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('31993', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('18583', '457', '1', 'Spring', 2001, 'A+');
	insert into takes values('82918', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('8192', '169', '2', 'Fall', 2002, 'B-');
	insert into takes values('52856', '105', '1', 'Fall', 2009, 'C-');
	insert into takes values('93653', '400', '1', 'Spring', 2007, 'A-');
	insert into takes values('13365', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('33338', '959', '1', 'Fall', 2006, 'B+');
	insert into takes values('74016', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('84727', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('72768', '795', '1', 'Spring', 2004, 'B-');
	insert into takes values('51678', '663', '1', 'Spring', 2005, 'A ');
	insert into takes values('77172', '927', '1', 'Fall', 2002, 'A+');
	insert into takes values('32376', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('95099', '864', '1', 'Spring', 2006, 'C-');
	insert into takes values('46260', '486', '1', 'Fall', 2009, 'A ');
	insert into takes values('88287', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('88308', '974', '1', 'Fall', 2003, 'C-');
	insert into takes values('68330', '319', '1', 'Spring', 2003, 'B ');
	insert into takes values('82697', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('24387', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('92659', '747', '1', 'Spring', 2004, 'B+');
	insert into takes values('73186', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('47677', '445', '1', 'Spring', 2001, 'A-');
	insert into takes values('25780', '362', '1', 'Fall', 2005, 'C ');
	insert into takes values('91992', '400', '1', 'Spring', 2007, 'C+');
	insert into takes values('75522', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('7287', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('25380', '304', '1', 'Fall', 2009, 'B+');
	insert into takes values('96153', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('68999', '559', '1', 'Fall', 2002, 'B+');
	insert into takes values('99694', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('24442', '735', '1', 'Spring', 2003, 'A+');
	insert into takes values('17057', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('65443', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('87246', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('13741', '694', '1', 'Fall', 2002, 'C ');
	insert into takes values('95626', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('69521', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('57055', '972', '1', 'Spring', 2009, 'C ');
	insert into takes values('26473', '443', '1', 'Spring', 2010, 'A+');
	insert into takes values('92776', '352', '1', 'Spring', 2006, 'A-');
	insert into takes values('92776', '696', '1', 'Spring', 2002, 'A+');
	insert into takes values('93039', '270', '1', 'Spring', 2010, 'C ');
	insert into takes values('33651', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('30161', '105', '1', 'Fall', 2009, 'A+');
	insert into takes values('50664', '867', '2', 'Fall', 2010, 'A+');
	insert into takes values('44584', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('61332', '748', '1', 'Fall', 2003, 'B-');
	insert into takes values('96203', '927', '1', 'Fall', 2002, 'A+');
	insert into takes values('20002', '679', '1', 'Spring', 2010, 'C+');
	insert into takes values('58701', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('82066', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('88389', '843', '1', 'Fall', 2010, 'A+');
	insert into takes values('24374', '366', '1', 'Fall', 2005, 'A+');
	insert into takes values('8819', '338', '1', 'Spring', 2007, 'B-');
	insert into takes values('86075', '237', '2', 'Fall', 2009, 'C+');
	insert into takes values('92442', '313', '1', 'Fall', 2010, 'B ');
	insert into takes values('89734', '852', '1', 'Spring', 2008, 'B-');
	insert into takes values('65753', '679', '1', 'Spring', 2010, 'B ');
	insert into takes values('90220', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('56276', '169', '2', 'Fall', 2002, 'B+');
	insert into takes values('14563', '692', '1', 'Spring', 2010, 'B-');
	insert into takes values('68712', '591', '1', 'Spring', 2005, 'B ');
	insert into takes values('58170', '443', '2', 'Spring', 2002, 'B-');
	insert into takes values('22325', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('73542', '408', '2', 'Spring', 2003, 'A ');
	insert into takes values('50414', '468', '2', 'Fall', 2007, 'C+');
	insert into takes values('87785', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('42843', '169', '2', 'Fall', 2002, 'B-');
	insert into takes values('80990', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('88417', '867', '1', 'Fall', 2006, 'B+');
	insert into takes values('23344', '362', '1', 'Fall', 2005, 'B ');
	insert into takes values('34197', '603', '1', 'Fall', 2003, 'A ');
	insert into takes values('38371', '867', '1', 'Fall', 2006, 'C+');
	insert into takes values('19450', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('20985', '400', '2', 'Fall', 2003, 'B-');
	insert into takes values('94998', '105', '1', 'Fall', 2009, 'C+');
	insert into takes values('7490', '345', '1', 'Spring', 2008, 'A ');
	insert into takes values('35357', '362', '3', 'Spring', 2008, 'C-');
	insert into takes values('15430', '468', '2', 'Fall', 2007, 'A+');
	insert into takes values('99760', '313', '1', 'Fall', 2010, 'B ');
	insert into takes values('89551', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('13506', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('28994', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('54622', '338', '1', 'Spring', 2007, 'B ');
	insert into takes values('36265', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('71389', '702', '1', 'Spring', 2001, 'B-');
	insert into takes values('20244', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('38973', '843', '1', 'Fall', 2010, 'A-');
	insert into takes values('45680', '735', '1', 'Spring', 2003, 'A-');
	insert into takes values('74509', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('42298', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('30772', '603', '1', 'Fall', 2003, 'A+');
	insert into takes values('17831', '486', '1', 'Fall', 2009, 'C ');
	insert into takes values('27094', '400', '1', 'Spring', 2007, 'C+');
	insert into takes values('62728', '137', '1', 'Spring', 2002, 'A ');
	insert into takes values('69730', '802', '1', 'Spring', 2003, 'C+');
	insert into takes values('65433', '237', '2', 'Fall', 2009, 'B+');
	insert into takes values('49611', '158', '2', 'Spring', 2008, 'B+');
	insert into takes values('82646', '960', '1', 'Fall', 2009, 'C-');
	insert into takes values('62487', '793', '1', 'Spring', 2002, 'A-');
	insert into takes values('90220', '200', '1', 'Spring', 2007, 'B+');
	insert into takes values('17924', '400', '2', 'Fall', 2003, 'C-');
	insert into takes values('50365', '960', '2', 'Fall', 2006, 'C+');
	insert into takes values('52134', '747', '1', 'Spring', 2004, 'A ');
	insert into takes values('86404', '581', '1', 'Spring', 2005, 'A ');
	insert into takes values('20489', '468', '2', 'Fall', 2007, 'A+');
	insert into takes values('16528', '468', '1', 'Fall', 2005, 'B-');
	insert into takes values('75878', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('81876', '338', '1', 'Spring', 2007, 'C ');
	insert into takes values('88472', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('99399', '258', '1', 'Fall', 2007, 'C-');
	insert into takes values('54620', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('72622', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('73206', '949', '1', 'Fall', 2007, 'A-');
	insert into takes values('38013', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('99226', '489', '1', 'Fall', 2007, 'A ');
	insert into takes values('23449', '362', '3', 'Spring', 2008, 'B ');
	insert into takes values('56276', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('95284', '612', '1', 'Fall', 2007, 'B+');
	insert into takes values('463', '626', '1', 'Fall', 2006, 'B ');
	insert into takes values('51093', '793', '1', 'Spring', 2002, 'B ');
	insert into takes values('14182', '401', '1', 'Fall', 2003, 'C-');
	insert into takes values('16523', '559', '1', 'Fall', 2002, 'B ');
	insert into takes values('16057', '408', '2', 'Spring', 2003, 'C ');
	insert into takes values('90082', '445', '1', 'Spring', 2001, 'C ');
	insert into takes values('59539', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('19203', '200', '2', 'Fall', 2002, 'B-');
	insert into takes values('60984', '704', '1', 'Spring', 2008, 'C ');
	insert into takes values('24197', '366', '1', 'Fall', 2005, 'C-');
	insert into takes values('56078', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('12069', '401', '1', 'Fall', 2003, 'A+');
	insert into takes values('72622', '748', '1', 'Fall', 2003, 'B ');
	insert into takes values('22268', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('69732', '527', '1', 'Fall', 2004, 'C+');
	insert into takes values('26802', '867', '1', 'Fall', 2006, 'A-');
	insert into takes values('55009', '445', '1', 'Spring', 2001, 'B-');
	insert into takes values('39881', '443', '2', 'Spring', 2002, 'A+');
	insert into takes values('24002', '258', '1', 'Fall', 2007, 'A+');
	insert into takes values('68779', '735', '2', 'Spring', 2010, 'A+');
	insert into takes values('78552', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('62549', '237', '1', 'Spring', 2008, 'B ');
	insert into takes values('19766', '443', '2', 'Spring', 2002, 'A ');
	insert into takes values('11455', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('38973', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('65038', '843', '1', 'Fall', 2010, 'C ');
	insert into takes values('57185', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('66281', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('49611', '237', '1', 'Spring', 2008, 'C+');
	insert into takes values('43981', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('65056', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('21008', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('28518', '760', '1', 'Spring', 2004, 'C ');
	insert into takes values('97101', '545', '1', 'Fall', 2001, 'B ');
	insert into takes values('16405', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('45002', '239', '1', 'Fall', 2006, 'C-');
	insert into takes values('26102', '457', '1', 'Spring', 2001, 'A-');
	insert into takes values('50331', '527', '1', 'Fall', 2004, 'C ');
	insert into takes values('97355', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('97953', '852', '1', 'Spring', 2008, 'B ');
	insert into takes values('13023', '237', '2', 'Fall', 2009, 'A ');
	insert into takes values('30110', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('34569', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('5393', '696', '1', 'Spring', 2002, 'B+');
	insert into takes values('27017', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('76270', '192', '1', 'Fall', 2002, 'C ');
	insert into takes values('23525', '349', '1', 'Spring', 2008, 'A-');
	insert into takes values('33645', '612', '1', 'Fall', 2007, 'B+');
	insert into takes values('57026', '443', '1', 'Spring', 2010, 'B ');
	insert into takes values('98843', '468', '2', 'Fall', 2007, 'C-');
	insert into takes values('48660', '400', '2', 'Fall', 2003, 'A-');
	insert into takes values('73602', '852', '1', 'Spring', 2008, 'B ');
	insert into takes values('52385', '476', '1', 'Fall', 2010, 'B+');
	insert into takes values('31080', '527', '1', 'Fall', 2004, 'A ');
	insert into takes values('10834', '334', '1', 'Fall', 2009, 'A ');
	insert into takes values('79697', '421', '1', 'Fall', 2004, 'C-');
	insert into takes values('91370', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('92659', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('69850', '408', '1', 'Spring', 2007, 'C+');
	insert into takes values('11419', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('54296', '304', '1', 'Fall', 2009, 'A+');
	insert into takes values('41091', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('57083', '694', '1', 'Fall', 2002, 'C ');
	insert into takes values('83511', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('37818', '376', '1', 'Fall', 2006, 'A-');
	insert into takes values('11202', '200', '2', 'Fall', 2002, 'A ');
	insert into takes values('56080', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('25468', '631', '1', 'Spring', 2007, 'A ');
	insert into takes values('30124', '663', '1', 'Spring', 2005, 'A ');
	insert into takes values('80285', '561', '1', 'Fall', 2006, 'B-');
	insert into takes values('73394', '362', '1', 'Fall', 2005, 'C-');
	insert into takes values('10033', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('29803', '591', '1', 'Spring', 2005, 'A-');
	insert into takes values('90567', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('65144', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('27898', '545', '1', 'Fall', 2001, 'B-');
	insert into takes values('19050', '991', '1', 'Spring', 2008, 'A ');
	insert into takes values('72521', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('29959', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('22198', '362', '3', 'Spring', 2008, 'A+');
	insert into takes values('83214', '875', '1', 'Spring', 2005, 'C-');
	insert into takes values('85614', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('76953', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('56139', '875', '1', 'Spring', 2005, 'A+');
	insert into takes values('41599', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('48469', '401', '1', 'Fall', 2003, 'A ');
	insert into takes values('22057', '476', '1', 'Fall', 2010, 'A ');
	insert into takes values('38973', '852', '1', 'Spring', 2008, 'A ');
	insert into takes values('1827', '334', '1', 'Fall', 2009, 'B+');
	insert into takes values('76173', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('46074', '486', '1', 'Fall', 2009, 'B ');
	insert into takes values('25942', '258', '1', 'Fall', 2007, 'A ');
	insert into takes values('23344', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('24784', '493', '1', 'Spring', 2010, 'A+');
	insert into takes values('73492', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('57185', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('10917', '972', '1', 'Spring', 2009, 'C-');
	insert into takes values('29435', '843', '1', 'Fall', 2010, 'B+');
	insert into takes values('5298', '760', '1', 'Spring', 2004, 'C+');
	insert into takes values('43616', '468', '1', 'Fall', 2005, 'C ');
	insert into takes values('4015', '991', '1', 'Spring', 2008, 'A ');
	insert into takes values('2629', '747', '1', 'Spring', 2004, 'C ');
	insert into takes values('90448', '400', '1', 'Spring', 2007, 'B+');
	insert into takes values('33791', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('22396', '867', '2', 'Fall', 2010, 'C ');
	insert into takes values('52876', '991', '1', 'Spring', 2008, 'B ');
	insert into takes values('68453', '663', '1', 'Spring', 2005, 'B ');
	insert into takes values('7514', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('73908', '408', '1', 'Spring', 2007, 'B ');
	insert into takes values('51817', '443', '1', 'Spring', 2010, 'C+');
	insert into takes values('77548', '158', '2', 'Spring', 2008, 'B-');
	insert into takes values('41683', '242', '1', 'Fall', 2009, 'A-');
	insert into takes values('34018', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('84189', '631', '1', 'Spring', 2007, 'A ');
	insert into takes values('72521', '274', '1', 'Fall', 2002, 'C+');
	insert into takes values('92949', '476', '1', 'Fall', 2010, 'B+');
	insert into takes values('90234', '426', '1', 'Spring', 2006, 'A-');
	insert into takes values('10076', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('34392', '591', '1', 'Spring', 2005, 'B+');
	insert into takes values('89196', '626', '1', 'Fall', 2006, 'C ');
	insert into takes values('77580', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('86806', '599', '1', 'Spring', 2003, 'C ');
	insert into takes values('32490', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('51817', '338', '1', 'Spring', 2007, 'B-');
	insert into takes values('19536', '461', '1', 'Fall', 2002, 'C+');
	insert into takes values('90448', '137', '1', 'Spring', 2002, 'B ');
	insert into takes values('9993', '443', '2', 'Spring', 2002, 'C-');
	insert into takes values('87831', '304', '1', 'Fall', 2009, 'A ');
	insert into takes values('90181', '603', '1', 'Fall', 2003, 'B ');
	insert into takes values('59172', '663', '1', 'Spring', 2005, 'B ');
	insert into takes values('25077', '612', '1', 'Fall', 2007, 'B+');
	insert into takes values('85809', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('71944', '972', '1', 'Spring', 2009, 'B-');
	insert into takes values('4015', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('25362', '760', '1', 'Spring', 2004, 'B-');
	insert into takes values('48009', '401', '1', 'Fall', 2003, 'C+');
	insert into takes values('44206', '242', '1', 'Fall', 2009, 'C+');
	insert into takes values('48778', '338', '1', 'Spring', 2007, 'A ');
	insert into takes values('57135', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('86806', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('1232', '313', '1', 'Fall', 2010, 'B-');
	insert into takes values('94801', '496', '1', 'Fall', 2001, 'C-');
	insert into takes values('53799', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('52057', '603', '1', 'Fall', 2003, 'A ');
	insert into takes values('18808', '486', '1', 'Fall', 2009, 'B-');
	insert into takes values('19791', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('336', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('15083', '696', '1', 'Spring', 2002, 'C ');
	insert into takes values('54296', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('37449', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('97228', '349', '1', 'Spring', 2008, 'B+');
	insert into takes values('35881', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('25528', '493', '1', 'Spring', 2010, 'B+');
	insert into takes values('16849', '169', '1', 'Spring', 2007, 'B+');
	insert into takes values('69752', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('78758', '692', '1', 'Spring', 2010, 'A+');
	insert into takes values('53165', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('1018', '482', '1', 'Fall', 2005, 'A+');
	insert into takes values('73411', '493', '1', 'Spring', 2010, 'A ');
	insert into takes values('30161', '486', '1', 'Fall', 2009, 'B-');
	insert into takes values('9360', '345', '1', 'Spring', 2008, 'A ');
	insert into takes values('18108', '735', '2', 'Spring', 2010, 'A+');
	insert into takes values('78454', '493', '1', 'Spring', 2010, 'C ');
	insert into takes values('10727', '443', '1', 'Spring', 2010, 'B-');
	insert into takes values('18554', '105', '1', 'Fall', 2009, 'B+');
	insert into takes values('89312', '200', '2', 'Fall', 2002, 'B-');
	insert into takes values('90082', '760', '1', 'Spring', 2004, 'C-');
	insert into takes values('760', '400', '2', 'Fall', 2003, 'C+');
	insert into takes values('97042', '105', '2', 'Fall', 2002, 'A ');
	insert into takes values('16528', '445', '1', 'Spring', 2001, 'C+');
	insert into takes values('24932', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('14829', '867', '2', 'Fall', 2010, 'A+');
	insert into takes values('89059', '591', '1', 'Spring', 2005, 'B+');
	insert into takes values('61065', '366', '1', 'Fall', 2005, 'A+');
	insert into takes values('48678', '400', '2', 'Fall', 2003, 'A ');
	insert into takes values('91197', '864', '1', 'Spring', 2006, 'B ');
	insert into takes values('77172', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('52656', '476', '1', 'Fall', 2010, 'C ');
	insert into takes values('15328', '974', '1', 'Fall', 2003, 'C ');
	insert into takes values('94311', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('85887', '362', '2', 'Fall', 2006, 'A-');
	insert into takes values('15086', '927', '1', 'Fall', 2002, 'C-');
	insert into takes values('57190', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('53490', '599', '1', 'Spring', 2003, 'B ');
	insert into takes values('92385', '802', '1', 'Spring', 2003, 'C-');
	insert into takes values('79469', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('64593', '704', '1', 'Spring', 2008, 'C ');
	insert into takes values('36265', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('78572', '237', '2', 'Fall', 2009, 'C+');
	insert into takes values('67033', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('42298', '748', '1', 'Fall', 2003, 'C-');
	insert into takes values('98726', '852', '1', 'Spring', 2008, 'B-');
	insert into takes values('94814', '591', '1', 'Spring', 2005, 'A-');
	insert into takes values('97355', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('49618', '408', '1', 'Spring', 2007, 'B ');
	insert into takes values('35', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('32464', '927', '1', 'Fall', 2002, 'C ');
	insert into takes values('91370', '496', '1', 'Fall', 2001, 'A+');
	insert into takes values('53728', '527', '1', 'Fall', 2004, 'A-');
	insert into takes values('53089', '960', '2', 'Fall', 2006, 'A ');
	insert into takes values('1827', '270', '1', 'Spring', 2010, 'C-');
	insert into takes values('1922', '415', '1', 'Fall', 2010, 'A+');
	insert into takes values('86802', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('3143', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('72643', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('17377', '959', '1', 'Fall', 2006, 'B ');
	insert into takes values('978', '893', '1', 'Fall', 2007, 'B+');
	insert into takes values('45720', '604', '1', 'Spring', 2009, 'A ');
	insert into takes values('11578', '192', '1', 'Fall', 2002, 'A+');
	insert into takes values('2177', '319', '1', 'Spring', 2003, 'B-');
	insert into takes values('30397', '626', '1', 'Fall', 2006, 'C+');
	insert into takes values('1884', '867', '2', 'Fall', 2010, 'B-');
	insert into takes values('85614', '612', '1', 'Fall', 2007, 'A-');
	insert into takes values('35220', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('64934', '457', '1', 'Spring', 2001, 'C ');
	insert into takes values('84792', '959', '1', 'Fall', 2006, 'A+');
	insert into takes values('52120', '893', '1', 'Fall', 2007, 'B+');
	insert into takes values('46436', '239', '1', 'Fall', 2006, 'B ');
	insert into takes values('72643', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('16075', '631', '1', 'Spring', 2007, 'A ');
	insert into takes values('48660', '366', '1', 'Fall', 2005, 'A+');
	insert into takes values('85366', '960', '2', 'Fall', 2006, 'A ');
	insert into takes values('69752', '704', '1', 'Spring', 2008, 'B ');
	insert into takes values('32345', '867', '1', 'Fall', 2006, 'A+');
	insert into takes values('51678', '852', '1', 'Spring', 2008, 'C+');
	insert into takes values('56078', '663', '1', 'Spring', 2005, 'B ');
	insert into takes values('33791', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('87831', '415', '1', 'Fall', 2010, 'C ');
	insert into takes values('15538', '571', '1', 'Spring', 2004, 'B+');
	insert into takes values('15070', '960', '1', 'Fall', 2009, 'A-');
	insert into takes values('61444', '581', '1', 'Spring', 2005, 'C+');
	insert into takes values('47824', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('84432', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('12563', '352', '1', 'Spring', 2006, 'A-');
	insert into takes values('17944', '802', '1', 'Spring', 2003, 'C+');
	insert into takes values('73206', '663', '1', 'Spring', 2005, 'A ');
	insert into takes values('17397', '704', '1', 'Spring', 2008, 'B ');
	insert into takes values('61414', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('58935', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('71389', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('81638', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('99711', '631', '1', 'Spring', 2007, 'C-');
	insert into takes values('79170', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('97042', '663', '1', 'Spring', 2005, 'B-');
	insert into takes values('80285', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('72979', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('99348', '893', '1', 'Fall', 2007, 'A+');
	insert into takes values('46956', '362', '1', 'Fall', 2005, 'C+');
	insert into takes values('27952', '527', '1', 'Fall', 2004, 'A-');
	insert into takes values('73268', '692', '1', 'Spring', 2010, 'C ');
	insert into takes values('69132', '603', '1', 'Fall', 2003, 'B-');
	insert into takes values('99271', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('70828', '974', '1', 'Fall', 2003, 'A+');
	insert into takes values('86001', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('27430', '802', '1', 'Spring', 2003, 'A+');
	insert into takes values('83573', '843', '1', 'Fall', 2010, 'A-');
	insert into takes values('56299', '158', '1', 'Fall', 2008, 'A+');
	insert into takes values('8378', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('288', '791', '1', 'Spring', 2006, 'A ');
	insert into takes values('80976', '461', '1', 'Fall', 2002, 'C+');
	insert into takes values('7602', '735', '1', 'Spring', 2003, 'C+');
	insert into takes values('57083', '313', '1', 'Fall', 2010, 'C+');
	insert into takes values('37284', '476', '1', 'Fall', 2010, 'B ');
	insert into takes values('64121', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('44836', '242', '1', 'Fall', 2009, 'B ');
	insert into takes values('81294', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('7973', '893', '1', 'Fall', 2007, 'B ');
	insert into takes values('75596', '663', '1', 'Spring', 2005, 'A ');
	insert into takes values('98315', '793', '1', 'Spring', 2002, 'B+');
	insert into takes values('53699', '352', '1', 'Spring', 2006, 'C-');
	insert into takes values('38288', '843', '1', 'Fall', 2010, 'A+');
	insert into takes values('35881', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('89312', '960', '2', 'Fall', 2006, 'C-');
	insert into takes values('82974', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('61920', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('51768', '559', '1', 'Fall', 2002, 'C-');
	insert into takes values('99422', '476', '1', 'Fall', 2010, 'A ');
	insert into takes values('38676', '604', '1', 'Spring', 2009, 'B+');
	insert into takes values('85680', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('42388', '642', '1', 'Fall', 2004, 'C+');
	insert into takes values('8483', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('39310', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('67793', '603', '1', 'Fall', 2003, 'A ');
	insert into takes values('96911', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('50414', '489', '1', 'Fall', 2007, 'B-');
	insert into takes values('49813', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('34170', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('38288', '696', '1', 'Spring', 2002, 'C+');
	insert into takes values('56078', '313', '1', 'Fall', 2010, 'B+');
	insert into takes values('92703', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('48009', '581', '1', 'Spring', 2005, 'C+');
	insert into takes values('61444', '599', '1', 'Spring', 2003, 'A+');
	insert into takes values('89734', '200', '2', 'Fall', 2002, 'C-');
	insert into takes values('70918', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('25331', '401', '1', 'Fall', 2003, 'C+');
	insert into takes values('61920', '158', '1', 'Fall', 2008, 'C-');
	insert into takes values('48660', '875', '1', 'Spring', 2005, 'C ');
	insert into takes values('6895', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('41988', '631', '1', 'Spring', 2007, 'B ');
	insert into takes values('14581', '702', '1', 'Spring', 2001, 'B-');
	insert into takes values('30341', '408', '2', 'Spring', 2003, 'B-');
	insert into takes values('36384', '735', '1', 'Spring', 2003, 'A+');
	insert into takes values('898', '867', '1', 'Fall', 2006, 'A-');
	insert into takes values('97400', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('43495', '258', '1', 'Fall', 2007, 'C ');
	insert into takes values('19450', '468', '1', 'Fall', 2005, 'A-');
	insert into takes values('12971', '867', '1', 'Fall', 2006, 'A-');
	insert into takes values('24442', '612', '1', 'Fall', 2007, 'A+');
	insert into takes values('27366', '457', '1', 'Spring', 2001, 'A-');
	insert into takes values('62549', '808', '1', 'Fall', 2003, 'A-');
	insert into takes values('56058', '960', '2', 'Fall', 2006, 'A ');
	insert into takes values('57026', '313', '1', 'Fall', 2010, 'A+');
	insert into takes values('14284', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('10834', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('83314', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('33759', '808', '1', 'Fall', 2003, 'C ');
	insert into takes values('85614', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('24796', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('40189', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('82063', '319', '1', 'Spring', 2003, 'A-');
	insert into takes values('79469', '105', '2', 'Fall', 2002, 'B-');
	insert into takes values('48053', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('667', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('56882', '893', '1', 'Fall', 2007, 'B-');
	insert into takes values('12979', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('16405', '875', '1', 'Spring', 2005, 'A ');
	insert into takes values('93631', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('84792', '457', '1', 'Spring', 2001, 'B ');
	insert into takes values('89759', '169', '1', 'Spring', 2007, 'B-');
	insert into takes values('98843', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('76759', '426', '1', 'Spring', 2006, 'C ');
	insert into takes values('76895', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('68396', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('13495', '875', '1', 'Spring', 2005, 'C-');
	insert into takes values('40932', '468', '2', 'Fall', 2007, 'B ');
	insert into takes values('83170', '629', '1', 'Spring', 2003, 'B-');
	insert into takes values('93366', '319', '1', 'Spring', 2003, 'C-');
	insert into takes values('8378', '603', '1', 'Fall', 2003, 'B ');
	insert into takes values('34197', '867', '2', 'Fall', 2010, 'A+');
	insert into takes values('79911', '237', '2', 'Fall', 2009, 'C-');
	insert into takes values('60867', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('38691', '338', '2', 'Spring', 2006, 'A-');
	insert into takes values('34502', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('35462', '843', '1', 'Fall', 2010, 'C+');
	insert into takes values('40303', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('87439', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('6474', '962', '1', 'Spring', 2008, 'C-');
	insert into takes values('57055', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('29705', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('27727', '443', '2', 'Spring', 2002, 'A ');
	insert into takes values('4015', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('4435', '960', '2', 'Fall', 2006, 'C+');
	insert into takes values('69853', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('68516', '105', '2', 'Fall', 2002, 'A ');
	insert into takes values('13365', '400', '1', 'Spring', 2007, 'C+');
	insert into takes values('97573', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('36379', '489', '1', 'Fall', 2007, 'B ');
	insert into takes values('70021', '867', '1', 'Fall', 2006, 'B+');
	insert into takes values('9440', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('57925', '338', '1', 'Spring', 2007, 'C+');
	insert into takes values('6895', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('96178', '679', '1', 'Spring', 2010, 'B ');
	insert into takes values('72528', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('69732', '362', '2', 'Fall', 2006, 'B-');
	insert into takes values('55698', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('435', '559', '1', 'Fall', 2002, 'C-');
	insert into takes values('83444', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('80254', '962', '1', 'Spring', 2008, 'A ');
	insert into takes values('41674', '338', '1', 'Spring', 2007, 'A ');
	insert into takes values('81245', '626', '1', 'Fall', 2006, 'B ');
	insert into takes values('39472', '760', '1', 'Spring', 2004, 'C+');
	insert into takes values('93354', '629', '1', 'Spring', 2003, 'B-');
	insert into takes values('87015', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('52656', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('36126', '445', '1', 'Spring', 2001, 'C+');
	insert into takes values('28538', '493', '1', 'Spring', 2010, 'A+');
	insert into takes values('37809', '334', '1', 'Fall', 2009, 'B+');
	insert into takes values('25362', '338', '2', 'Spring', 2006, 'B+');
	insert into takes values('59530', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('62749', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('21126', '137', '1', 'Spring', 2002, 'A-');
	insert into takes values('56598', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('86344', '239', '1', 'Fall', 2006, 'C-');
	insert into takes values('30943', '748', '1', 'Fall', 2003, 'C ');
	insert into takes values('63390', '893', '1', 'Fall', 2007, 'B ');
	insert into takes values('48471', '352', '1', 'Spring', 2006, 'C ');
	insert into takes values('97023', '875', '1', 'Spring', 2005, 'C-');
	insert into takes values('20814', '489', '1', 'Fall', 2007, 'C ');
	insert into takes values('39241', '867', '2', 'Fall', 2010, 'C-');
	insert into takes values('31364', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('43211', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('68649', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('10269', '237', '2', 'Fall', 2009, 'A-');
	insert into takes values('51768', '200', '1', 'Spring', 2007, 'A ');
	insert into takes values('3576', '561', '1', 'Fall', 2006, 'A ');
	insert into takes values('76246', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('24387', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('80047', '468', '2', 'Fall', 2007, 'C-');
	insert into takes values('93508', '476', '1', 'Fall', 2010, 'C ');
	insert into takes values('79329', '345', '1', 'Spring', 2008, 'C-');
	insert into takes values('39927', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('11510', '239', '1', 'Fall', 2006, 'B-');
	insert into takes values('85211', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('557', '581', '1', 'Spring', 2005, 'A ');
	insert into takes values('827', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('47627', '960', '2', 'Fall', 2006, 'C ');
	insert into takes values('96968', '400', '2', 'Fall', 2003, 'A-');
	insert into takes values('80698', '960', '2', 'Fall', 2006, 'A ');
	insert into takes values('61737', '415', '1', 'Fall', 2010, 'A-');
	insert into takes values('69783', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('78552', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('81883', '237', '1', 'Spring', 2008, 'B+');
	insert into takes values('51997', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('98843', '972', '1', 'Spring', 2009, 'A ');
	insert into takes values('38895', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('64550', '631', '1', 'Spring', 2007, 'A+');
	insert into takes values('45650', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('16849', '400', '2', 'Fall', 2003, 'C-');
	insert into takes values('5898', '362', '2', 'Fall', 2006, 'C-');
	insert into takes values('59538', '599', '1', 'Spring', 2003, 'B ');
	insert into takes values('14621', '366', '1', 'Fall', 2005, 'A ');
	insert into takes values('26102', '468', '1', 'Fall', 2005, 'B+');
	insert into takes values('78581', '158', '2', 'Spring', 2008, 'A ');
	insert into takes values('67660', '927', '1', 'Fall', 2002, 'B-');
	insert into takes values('259', '313', '1', 'Fall', 2010, 'A+');
	insert into takes values('38895', '612', '1', 'Fall', 2007, 'A-');
	insert into takes values('93814', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('63361', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('96741', '702', '1', 'Spring', 2001, 'B-');
	insert into takes values('37653', '242', '1', 'Fall', 2009, 'B ');
	insert into takes values('64082', '591', '1', 'Spring', 2005, 'B+');
	insert into takes values('5843', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('75252', '702', '1', 'Spring', 2001, 'C+');
	insert into takes values('15144', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('99711', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('37430', '735', '1', 'Spring', 2003, 'A-');
	insert into takes values('80047', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('20985', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('41938', '415', '1', 'Fall', 2010, 'C+');
	insert into takes values('79469', '334', '1', 'Fall', 2009, 'C ');
	insert into takes values('93004', '852', '1', 'Spring', 2008, 'B ');
	insert into takes values('79763', '445', '1', 'Spring', 2001, 'B+');
	insert into takes values('62520', '960', '1', 'Fall', 2009, 'B-');
	insert into takes values('53699', '867', '2', 'Fall', 2010, 'C ');
	insert into takes values('68278', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('91132', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('67657', '591', '1', 'Spring', 2005, 'A+');
	insert into takes values('37715', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('32130', '105', '2', 'Fall', 2002, 'A ');
	insert into takes values('35687', '599', '1', 'Spring', 2003, 'B-');
	insert into takes values('57431', '626', '1', 'Fall', 2006, 'B ');
	insert into takes values('55329', '362', '3', 'Spring', 2008, 'C-');
	insert into takes values('39580', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('51698', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('48660', '599', '1', 'Spring', 2003, 'B-');
	insert into takes values('66090', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('46106', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('42565', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('68720', '237', '1', 'Spring', 2008, 'C-');
	insert into takes values('28004', '793', '1', 'Spring', 2002, 'A+');
	insert into takes values('29920', '852', '1', 'Spring', 2008, 'C+');
	insert into takes values('15086', '237', '1', 'Spring', 2008, 'B+');
	insert into takes values('83686', '457', '1', 'Spring', 2001, 'C ');
	insert into takes values('54672', '258', '1', 'Fall', 2007, 'A-');
	insert into takes values('61737', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('46725', '352', '1', 'Spring', 2006, 'C+');
	insert into takes values('50206', '313', '1', 'Fall', 2010, 'B-');
	insert into takes values('68395', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('74672', '237', '1', 'Spring', 2008, 'B-');
	insert into takes values('17192', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('83214', '493', '1', 'Spring', 2010, 'A+');
	insert into takes values('97590', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('35293', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('14214', '169', '1', 'Spring', 2007, 'C ');
	insert into takes values('71631', '631', '1', 'Spring', 2007, 'B+');
	insert into takes values('58634', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('898', '445', '1', 'Spring', 2001, 'C+');
	insert into takes values('15980', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('79170', '408', '2', 'Spring', 2003, 'A+');
	insert into takes values('59673', '237', '1', 'Spring', 2008, 'A+');
	insert into takes values('67051', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('36494', '591', '1', 'Spring', 2005, 'C-');
	insert into takes values('13408', '927', '1', 'Fall', 2002, 'C ');
	insert into takes values('91915', '158', '2', 'Spring', 2008, 'C ');
	insert into takes values('26494', '561', '1', 'Fall', 2006, 'A+');
	insert into takes values('32954', '319', '1', 'Spring', 2003, 'B ');
	insert into takes values('41211', '626', '1', 'Fall', 2006, 'A ');
	insert into takes values('82970', '581', '1', 'Spring', 2005, 'A+');
	insert into takes values('56057', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('8252', '349', '1', 'Spring', 2008, 'A ');
	insert into takes values('50977', '793', '1', 'Spring', 2002, 'A-');
	insert into takes values('56', '852', '1', 'Spring', 2008, 'A ');
	insert into takes values('57160', '345', '1', 'Spring', 2008, 'B ');
	insert into takes values('53089', '626', '1', 'Fall', 2006, 'B ');
	insert into takes values('5824', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('63390', '852', '1', 'Spring', 2008, 'B+');
	insert into takes values('81876', '960', '1', 'Fall', 2009, 'A-');
	insert into takes values('36263', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('53805', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('86552', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('75116', '802', '1', 'Spring', 2003, 'A+');
	insert into takes values('87054', '972', '1', 'Spring', 2009, 'A+');
	insert into takes values('2970', '352', '1', 'Spring', 2006, 'B ');
	insert into takes values('37653', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('85534', '559', '1', 'Fall', 2002, 'A-');
	insert into takes values('11095', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('65433', '960', '2', 'Fall', 2006, 'C-');
	insert into takes values('97679', '603', '1', 'Fall', 2003, 'B+');
	insert into takes values('89734', '571', '1', 'Spring', 2004, 'B+');
	insert into takes values('88577', '591', '1', 'Spring', 2005, 'A+');
	insert into takes values('75560', '893', '1', 'Fall', 2007, 'C ');
	insert into takes values('4182', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('59539', '972', '1', 'Spring', 2009, 'C ');
	insert into takes values('33651', '486', '1', 'Fall', 2009, 'A ');
	insert into takes values('99710', '795', '1', 'Spring', 2004, 'A-');
	insert into takes values('10481', '612', '1', 'Fall', 2007, 'B ');
	insert into takes values('48165', '237', '2', 'Fall', 2009, 'C+');
	insert into takes values('17377', '334', '1', 'Fall', 2009, 'B ');
	insert into takes values('37586', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('72741', '545', '1', 'Fall', 2001, 'A-');
	insert into takes values('50664', '864', '1', 'Spring', 2006, 'C-');
	insert into takes values('31442', '158', '2', 'Spring', 2008, 'B-');
	insert into takes values('68999', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('79210', '927', '1', 'Fall', 2002, 'C-');
	insert into takes values('41671', '694', '1', 'Fall', 2002, 'C+');
	insert into takes values('67310', '843', '1', 'Fall', 2010, 'C ');
	insert into takes values('26730', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('46956', '319', '1', 'Spring', 2003, 'B ');
	insert into takes values('7020', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('36494', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('59117', '927', '1', 'Fall', 2002, 'A-');
	insert into takes values('16133', '527', '1', 'Fall', 2004, 'C-');
	insert into takes values('50664', '319', '1', 'Spring', 2003, 'C+');
	insert into takes values('38676', '476', '1', 'Fall', 2010, 'A ');
	insert into takes values('71085', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('85451', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('22004', '200', '2', 'Fall', 2002, 'A-');
	insert into takes values('8483', '496', '1', 'Fall', 2001, 'C-');
	insert into takes values('99660', '443', '1', 'Spring', 2010, 'A-');
	insert into takes values('43993', '408', '2', 'Spring', 2003, 'A+');
	insert into takes values('28133', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('37734', '408', '2', 'Spring', 2003, 'A+');
	insert into takes values('63538', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('41741', '696', '1', 'Spring', 2002, 'B-');
	insert into takes values('25785', '304', '1', 'Fall', 2009, 'C+');
	insert into takes values('78314', '237', '2', 'Fall', 2009, 'A ');
	insert into takes values('14432', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('25611', '468', '2', 'Fall', 2007, 'A-');
	insert into takes values('16311', '313', '1', 'Fall', 2010, 'C+');
	insert into takes values('49759', '345', '1', 'Spring', 2008, 'A-');
	insert into takes values('12078', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('41406', '704', '1', 'Spring', 2008, 'A+');
	insert into takes values('92703', '496', '1', 'Fall', 2001, 'B-');
	insert into takes values('65396', '237', '1', 'Spring', 2008, 'C+');
	insert into takes values('48462', '421', '1', 'Fall', 2004, 'B+');
	insert into takes values('58465', '313', '1', 'Fall', 2010, 'B+');
	insert into takes values('83696', '313', '1', 'Fall', 2010, 'B ');
	insert into takes values('71768', '270', '1', 'Spring', 2010, 'B-');
	insert into takes values('36926', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('5393', '443', '2', 'Spring', 2002, 'C ');
	insert into takes values('85366', '349', '1', 'Spring', 2008, 'A-');
	insert into takes values('57055', '242', '1', 'Fall', 2009, 'C-');
	insert into takes values('63502', '158', '2', 'Spring', 2008, 'A-');
	insert into takes values('90124', '352', '1', 'Spring', 2006, 'B+');
	insert into takes values('25077', '169', '1', 'Spring', 2007, 'B-');
	insert into takes values('2139', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('2201', '338', '2', 'Spring', 2006, 'A+');
	insert into takes values('29705', '137', '1', 'Spring', 2002, 'A ');
	insert into takes values('69241', '496', '1', 'Fall', 2001, 'B+');
	insert into takes values('34770', '192', '1', 'Fall', 2002, 'C ');
	insert into takes values('94990', '893', '1', 'Fall', 2007, 'A ');
	insert into takes values('28738', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('16075', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('16969', '663', '1', 'Spring', 2005, 'B ');
	insert into takes values('44703', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('95697', '875', '1', 'Spring', 2005, 'B-');
	insert into takes values('50703', '604', '1', 'Spring', 2009, 'C ');
	insert into takes values('26427', '795', '1', 'Spring', 2004, 'A-');
	insert into takes values('1826', '401', '1', 'Fall', 2003, 'A-');
	insert into takes values('89246', '158', '2', 'Spring', 2008, 'A ');
	insert into takes values('16543', '702', '1', 'Spring', 2001, 'C-');
	insert into takes values('2133', '949', '1', 'Fall', 2007, 'C-');
	insert into takes values('99647', '270', '1', 'Spring', 2010, 'C+');
	insert into takes values('25331', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('23994', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('76895', '237', '1', 'Spring', 2008, 'B ');
	insert into takes values('92659', '875', '1', 'Spring', 2005, 'A ');
	insert into takes values('14874', '561', '1', 'Fall', 2006, 'C-');
	insert into takes values('43981', '612', '1', 'Fall', 2007, 'B-');
	insert into takes values('37284', '793', '1', 'Spring', 2002, 'A ');
	insert into takes values('46450', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('32056', '852', '1', 'Spring', 2008, 'C+');
	insert into takes values('31690', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('11262', '304', '1', 'Fall', 2009, 'C-');
	insert into takes values('87965', '468', '1', 'Fall', 2005, 'A ');
	insert into takes values('61920', '258', '1', 'Fall', 2007, 'A-');
	insert into takes values('80248', '105', '1', 'Fall', 2009, 'A+');
	insert into takes values('56124', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('31690', '949', '1', 'Fall', 2007, 'C+');
	insert into takes values('97400', '158', '1', 'Fall', 2008, 'A+');
	insert into takes values('49982', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('9947', '158', '2', 'Spring', 2008, 'B-');
	insert into takes values('49611', '793', '1', 'Spring', 2002, 'B ');
	insert into takes values('89734', '158', '1', 'Fall', 2008, 'C ');
	insert into takes values('22258', '875', '1', 'Spring', 2005, 'B+');
	insert into takes values('35257', '158', '1', 'Fall', 2008, 'A-');
	insert into takes values('11441', '486', '1', 'Fall', 2009, 'C+');
	insert into takes values('18636', '400', '2', 'Fall', 2003, 'C+');
	insert into takes values('993', '692', '1', 'Spring', 2010, 'B-');
	insert into takes values('50013', '702', '1', 'Spring', 2001, 'C+');
	insert into takes values('66969', '476', '1', 'Fall', 2010, 'B+');
	insert into takes values('1968', '200', '1', 'Spring', 2007, 'A-');
	insert into takes values('30397', '468', '1', 'Fall', 2005, 'C+');
	insert into takes values('59673', '599', '1', 'Spring', 2003, 'B+');
	insert into takes values('93653', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('5005', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('70918', '362', '1', 'Fall', 2005, 'C ');
	insert into takes values('6895', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('14563', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('72165', '137', '1', 'Spring', 2002, 'B ');
	insert into takes values('60249', '169', '2', 'Fall', 2002, 'B ');
	insert into takes values('5925', '421', '1', 'Fall', 2004, 'C ');
	insert into takes values('67542', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('57985', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('78332', '461', '1', 'Fall', 2002, 'C+');
	insert into takes values('76799', '875', '1', 'Spring', 2005, 'A ');
	insert into takes values('97435', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('85614', '468', '2', 'Fall', 2007, 'A+');
	insert into takes values('37715', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('72959', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('48861', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('49982', '313', '1', 'Fall', 2010, 'A+');
	insert into takes values('51093', '258', '1', 'Fall', 2007, 'A ');
	insert into takes values('28409', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('14869', '237', '1', 'Spring', 2008, 'A-');
	insert into takes values('21009', '735', '2', 'Spring', 2010, 'B ');
	insert into takes values('28738', '867', '1', 'Fall', 2006, 'A+');
	insert into takes values('16885', '445', '1', 'Spring', 2001, 'B-');
	insert into takes values('29803', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('24387', '362', '2', 'Fall', 2006, 'C-');
	insert into takes values('17397', '105', '1', 'Fall', 2009, 'A+');
	insert into takes values('40189', '793', '1', 'Spring', 2002, 'C ');
	insert into takes values('38336', '468', '1', 'Fall', 2005, 'A+');
	insert into takes values('84727', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('41832', '735', '2', 'Spring', 2010, 'A+');
	insert into takes values('96067', '867', '2', 'Fall', 2010, 'B-');
	insert into takes values('52157', '258', '1', 'Fall', 2007, 'A ');
	insert into takes values('22268', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('85308', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('57185', '457', '1', 'Spring', 2001, 'B+');
	insert into takes values('26494', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('61737', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('98047', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('75928', '791', '1', 'Spring', 2006, 'C+');
	insert into takes values('68330', '867', '1', 'Fall', 2006, 'B ');
	insert into takes values('12214', '169', '1', 'Spring', 2007, 'A-');
	insert into takes values('22142', '962', '1', 'Spring', 2008, 'C+');
	insert into takes values('51093', '735', '2', 'Spring', 2010, 'A ');
	insert into takes values('90234', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('19848', '496', '1', 'Fall', 2001, 'C ');
	insert into takes values('64945', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('90814', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('15070', '445', '1', 'Spring', 2001, 'B-');
	insert into takes values('12563', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('21774', '486', '1', 'Fall', 2009, 'C+');
	insert into takes values('12236', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('1080', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('83622', '352', '1', 'Spring', 2006, 'C ');
	insert into takes values('57787', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('96003', '875', '1', 'Spring', 2005, 'B+');
	insert into takes values('66356', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('88472', '192', '1', 'Fall', 2002, 'C-');
	insert into takes values('57456', '702', '1', 'Spring', 2001, 'C ');
	insert into takes values('73165', '991', '1', 'Spring', 2008, 'A ');
	insert into takes values('84792', '527', '1', 'Fall', 2004, 'C+');
	insert into takes values('31080', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('70828', '591', '1', 'Spring', 2005, 'A ');
	insert into takes values('88884', '493', '1', 'Spring', 2010, 'C ');
	insert into takes values('81538', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('28829', '599', '1', 'Spring', 2003, 'A ');
	insert into takes values('96227', '376', '1', 'Fall', 2006, 'A ');
	insert into takes values('30299', '843', '1', 'Fall', 2010, 'A ');
	insert into takes values('57107', '960', '2', 'Fall', 2006, 'A-');
	insert into takes values('62373', '421', '1', 'Fall', 2004, 'C ');
	insert into takes values('50658', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('95201', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('69747', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('74070', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('82039', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('81550', '591', '1', 'Spring', 2005, 'B ');
	insert into takes values('93571', '476', '1', 'Fall', 2010, 'C-');
	insert into takes values('49073', '468', '2', 'Fall', 2007, 'A+');
	insert into takes values('1727', '696', '1', 'Spring', 2002, 'C+');
	insert into takes values('52523', '692', '1', 'Spring', 2010, 'B-');
	insert into takes values('27528', '679', '1', 'Spring', 2010, 'B+');
	insert into takes values('57538', '270', '1', 'Spring', 2010, 'C-');
	insert into takes values('88302', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('78922', '793', '1', 'Spring', 2002, 'A ');
	insert into takes values('74840', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('9659', '270', '1', 'Spring', 2010, 'C+');
	insert into takes values('42298', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('31137', '192', '1', 'Fall', 2002, 'C ');
	insert into takes values('66494', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('56', '974', '1', 'Fall', 2003, 'C-');
	insert into takes values('847', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('9360', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('11510', '496', '1', 'Fall', 2001, 'A-');
	insert into takes values('23344', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('77361', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('53496', '795', '1', 'Spring', 2004, 'B ');
	insert into takes values('67657', '443', '2', 'Spring', 2002, 'C+');
	insert into takes values('21086', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('53451', '603', '1', 'Fall', 2003, 'B ');
	insert into takes values('77000', '352', '1', 'Spring', 2006, 'A+');
	insert into takes values('9605', '362', '2', 'Fall', 2006, 'A ');
	insert into takes values('94846', '561', '1', 'Fall', 2006, 'B-');
	insert into takes values('27366', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('84495', '200', '2', 'Fall', 2002, 'A+');
	insert into takes values('74639', '274', '1', 'Fall', 2002, 'B ');
	insert into takes values('93986', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('10727', '642', '1', 'Fall', 2004, 'A+');
	insert into takes values('57123', '735', '1', 'Spring', 2003, 'C ');
	insert into takes values('19050', '401', '1', 'Fall', 2003, 'B+');
	insert into takes values('4182', '237', '2', 'Fall', 2009, 'C-');
	insert into takes values('52291', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('22467', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('1884', '408', '1', 'Spring', 2007, 'C+');
	insert into takes values('81031', '482', '1', 'Fall', 2005, 'A ');
	insert into takes values('86327', '808', '1', 'Fall', 2003, 'B ');
	insert into takes values('463', '105', '1', 'Fall', 2009, 'C+');
	insert into takes values('20002', '604', '1', 'Spring', 2009, 'C ');
	insert into takes values('30188', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('5824', '612', '1', 'Fall', 2007, 'C ');
	insert into takes values('2133', '679', '1', 'Spring', 2010, 'B+');
	insert into takes values('55286', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('94522', '200', '2', 'Fall', 2002, 'C-');
	insert into takes values('57026', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('90448', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('80698', '496', '1', 'Fall', 2001, 'C-');
	insert into takes values('55009', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('4435', '496', '1', 'Fall', 2001, 'A-');
	insert into takes values('95046', '603', '1', 'Fall', 2003, 'B+');
	insert into takes values('54622', '482', '1', 'Fall', 2005, 'C ');
	insert into takes values('89196', '852', '1', 'Spring', 2008, 'A-');
	insert into takes values('99348', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('69853', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('69241', '376', '1', 'Fall', 2006, 'C ');
	insert into takes values('8517', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('50365', '793', '1', 'Spring', 2002, 'C ');
	insert into takes values('34569', '747', '1', 'Spring', 2004, 'B-');
	insert into takes values('99348', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('24796', '345', '1', 'Spring', 2008, 'A ');
	insert into takes values('73394', '591', '1', 'Spring', 2005, 'B-');
	insert into takes values('4345', '631', '1', 'Spring', 2007, 'A ');
	insert into takes values('5298', '852', '1', 'Spring', 2008, 'B-');
	insert into takes values('17944', '349', '1', 'Spring', 2008, 'A ');
	insert into takes values('91616', '545', '1', 'Fall', 2001, 'A ');
	insert into takes values('62705', '105', '1', 'Fall', 2009, 'B ');
	insert into takes values('62373', '496', '1', 'Fall', 2001, 'B+');
	insert into takes values('94846', '274', '1', 'Fall', 2002, 'B-');
	insert into takes values('45083', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('9933', '527', '1', 'Fall', 2004, 'A ');
	insert into takes values('9360', '875', '1', 'Spring', 2005, 'C ');
	insert into takes values('10033', '408', '1', 'Spring', 2007, 'C-');
	insert into takes values('55170', '200', '1', 'Spring', 2007, 'A ');
	insert into takes values('32245', '105', '1', 'Fall', 2009, 'C+');
	insert into takes values('36384', '692', '1', 'Spring', 2010, 'A ');
	insert into takes values('12326', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('75252', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('16250', '486', '1', 'Fall', 2009, 'A ');
	insert into takes values('92849', '421', '1', 'Fall', 2004, 'A ');
	insert into takes values('71878', '274', '1', 'Fall', 2002, 'A+');
	insert into takes values('71287', '443', '1', 'Spring', 2010, 'A+');
	insert into takes values('40080', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('51008', '400', '2', 'Fall', 2003, 'B+');
	insert into takes values('15144', '362', '3', 'Spring', 2008, 'B ');
	insert into takes values('25468', '242', '1', 'Fall', 2009, 'A-');
	insert into takes values('26427', '631', '1', 'Spring', 2007, 'A+');
	insert into takes values('53225', '258', '1', 'Fall', 2007, 'B-');
	insert into takes values('57780', '421', '1', 'Fall', 2004, 'A ');
	insert into takes values('62124', '843', '1', 'Fall', 2010, 'C ');
	insert into takes values('99719', '927', '1', 'Fall', 2002, 'A ');
	insert into takes values('30110', '242', '1', 'Fall', 2009, 'C-');
	insert into takes values('8378', '867', '2', 'Fall', 2010, 'A+');
	insert into takes values('58634', '401', '1', 'Fall', 2003, 'C ');
	insert into takes values('55170', '629', '1', 'Spring', 2003, 'B ');
	insert into takes values('19321', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('86404', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('30124', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('99760', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('32772', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('6287', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('36303', '843', '1', 'Fall', 2010, 'B+');
	insert into takes values('70807', '468', '2', 'Fall', 2007, 'A-');
	insert into takes values('21102', '457', '1', 'Spring', 2001, 'B ');
	insert into takes values('83838', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('94371', '362', '2', 'Fall', 2006, 'C-');
	insert into takes values('38899', '679', '1', 'Spring', 2010, 'A+');
	insert into takes values('70098', '468', '1', 'Fall', 2005, 'C ');
	insert into takes values('15340', '169', '1', 'Spring', 2007, 'B-');
	insert into takes values('81207', '258', '1', 'Fall', 2007, 'C ');
	insert into takes values('82066', '400', '1', 'Spring', 2007, 'A ');
	insert into takes values('2970', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('87054', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('39472', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('259', '795', '1', 'Spring', 2004, 'B+');
	insert into takes values('83622', '338', '1', 'Spring', 2007, 'C-');
	insert into takes values('68278', '496', '1', 'Fall', 2001, 'B ');
	insert into takes values('77000', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('92703', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('17507', '927', '1', 'Fall', 2002, 'C+');
	insert into takes values('9408', '692', '1', 'Spring', 2010, 'A+');
	insert into takes values('73328', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('16969', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('69783', '408', '2', 'Spring', 2003, 'C ');
	insert into takes values('80698', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('11578', '864', '1', 'Spring', 2006, 'B ');
	insert into takes values('35881', '362', '3', 'Spring', 2008, 'B ');
	insert into takes values('49792', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('10269', '704', '1', 'Spring', 2008, 'C-');
	insert into takes values('17397', '493', '1', 'Spring', 2010, 'B ');
	insert into takes values('93631', '843', '1', 'Fall', 2010, 'C+');
	insert into takes values('78758', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('72643', '258', '1', 'Fall', 2007, 'C ');
	insert into takes values('50365', '105', '2', 'Fall', 2002, 'A-');
	insert into takes values('78637', '270', '1', 'Spring', 2010, 'A+');
	insert into takes values('78782', '581', '1', 'Spring', 2005, 'C ');
	insert into takes values('3739', '612', '1', 'Fall', 2007, 'B-');
	insert into takes values('37454', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('858', '237', '1', 'Spring', 2008, 'B ');
	insert into takes values('94324', '867', '2', 'Fall', 2010, 'A-');
	insert into takes values('22198', '867', '1', 'Fall', 2006, 'B ');
	insert into takes values('8912', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('18007', '313', '1', 'Fall', 2010, 'C ');
	insert into takes values('107', '867', '1', 'Fall', 2006, 'A+');
	insert into takes values('30723', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('46074', '258', '1', 'Fall', 2007, 'C-');
	insert into takes values('5250', '629', '1', 'Spring', 2003, 'A+');
	insert into takes values('75534', '352', '1', 'Spring', 2006, 'C-');
	insert into takes values('88169', '468', '1', 'Fall', 2005, 'B+');
	insert into takes values('57026', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('8022', '304', '1', 'Fall', 2009, 'A+');
	insert into takes values('29514', '991', '1', 'Spring', 2008, 'B-');
	insert into takes values('67514', '603', '1', 'Fall', 2003, 'A ');
	insert into takes values('16057', '313', '1', 'Fall', 2010, 'C ');
	insert into takes values('41091', '445', '1', 'Spring', 2001, 'C ');
	insert into takes values('71944', '642', '1', 'Fall', 2004, 'A-');
	insert into takes values('98423', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('74974', '663', '1', 'Spring', 2005, 'A-');
	insert into takes values('98870', '461', '1', 'Fall', 2002, 'B+');
	insert into takes values('96324', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('86969', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('65987', '704', '1', 'Spring', 2008, 'C ');
	insert into takes values('27094', '793', '1', 'Spring', 2002, 'C-');
	insert into takes values('6712', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('39612', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('17128', '735', '1', 'Spring', 2003, 'A+');
	insert into takes values('24932', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('85445', '468', '1', 'Fall', 2005, 'A-');
	insert into takes values('5381', '852', '1', 'Spring', 2008, 'A-');
	insert into takes values('80742', '338', '2', 'Spring', 2006, 'C ');
	insert into takes values('11419', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('89759', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('96193', '445', '1', 'Spring', 2001, 'A-');
	insert into takes values('55531', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('64938', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('95046', '105', '2', 'Fall', 2002, 'A+');
	insert into takes values('35257', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('21401', '461', '1', 'Fall', 2002, 'B+');
	insert into takes values('27017', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('58874', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('74796', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('49792', '443', '2', 'Spring', 2002, 'C ');
	insert into takes values('21401', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('66054', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('98726', '461', '1', 'Fall', 2002, 'C-');
	insert into takes values('49611', '169', '1', 'Spring', 2007, 'B-');
	insert into takes values('48462', '949', '1', 'Fall', 2007, 'C-');
	insert into takes values('85211', '626', '1', 'Fall', 2006, 'C+');
	insert into takes values('49205', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('7204', '852', '1', 'Spring', 2008, 'C-');
	insert into takes values('25552', '581', '1', 'Spring', 2005, 'C+');
	insert into takes values('35935', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('99271', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('41751', '461', '1', 'Fall', 2002, 'C+');
	insert into takes values('93491', '852', '1', 'Spring', 2008, 'B-');
	insert into takes values('78581', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('89059', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('80248', '443', '1', 'Spring', 2010, 'A-');
	insert into takes values('82974', '421', '1', 'Fall', 2004, 'B+');
	insert into takes values('63243', '482', '1', 'Fall', 2005, 'C ');
	insert into takes values('67425', '702', '1', 'Spring', 2001, 'C ');
	insert into takes values('62795', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('4173', '561', '1', 'Fall', 2006, 'A ');
	insert into takes values('73411', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('29239', '808', '1', 'Fall', 2003, 'B ');
	insert into takes values('76270', '561', '1', 'Fall', 2006, 'A+');
	insert into takes values('72979', '274', '1', 'Fall', 2002, 'B-');
	insert into takes values('18234', '631', '1', 'Spring', 2007, 'B ');
	insert into takes values('7973', '338', '2', 'Spring', 2006, 'C+');
	insert into takes values('79205', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('92703', '445', '1', 'Spring', 2001, 'C+');
	insert into takes values('23270', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('97435', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('78552', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('58874', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('52385', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('69752', '893', '1', 'Fall', 2007, 'B-');
	insert into takes values('72006', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('24442', '239', '1', 'Fall', 2006, 'C-');
	insert into takes values('87706', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('259', '791', '1', 'Spring', 2006, 'A-');
	insert into takes values('31337', '338', '1', 'Spring', 2007, 'B-');
	insert into takes values('45083', '793', '1', 'Spring', 2002, 'C+');
	insert into takes values('34569', '408', '1', 'Spring', 2007, 'A+');
	insert into takes values('44703', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('95850', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('88884', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('84702', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('47627', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('60406', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('8343', '169', '2', 'Fall', 2002, 'C ');
	insert into takes values('45720', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('32130', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('52866', '443', '2', 'Spring', 2002, 'B-');
	insert into takes values('64914', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('53699', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('35881', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('84515', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('57160', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('98056', '642', '1', 'Fall', 2004, 'A-');
	insert into takes values('58634', '867', '2', 'Fall', 2010, 'A-');
	insert into takes values('36126', '105', '1', 'Fall', 2009, 'B ');
	insert into takes values('53118', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('65329', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('83838', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('74672', '702', '1', 'Spring', 2001, 'A-');
	insert into takes values('82707', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('39925', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('70572', '864', '1', 'Spring', 2006, 'C+');
	insert into takes values('6729', '352', '1', 'Spring', 2006, 'A+');
	insert into takes values('32130', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('53047', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('72768', '545', '1', 'Fall', 2001, 'A ');
	insert into takes values('7035', '158', '1', 'Fall', 2008, 'B-');
	insert into takes values('36926', '137', '1', 'Spring', 2002, 'C-');
	insert into takes values('32490', '362', '2', 'Fall', 2006, 'A-');
	insert into takes values('50966', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('43616', '867', '1', 'Fall', 2006, 'C+');
	insert into takes values('30021', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('24325', '443', '2', 'Spring', 2002, 'C+');
	insert into takes values('65688', '603', '1', 'Fall', 2003, 'C-');
	insert into takes values('93043', '400', '2', 'Fall', 2003, 'A-');
	insert into takes values('97023', '313', '1', 'Fall', 2010, 'C-');
	insert into takes values('43989', '468', '1', 'Fall', 2005, 'C+');
	insert into takes values('99463', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('34392', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('60406', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('65205', '169', '2', 'Fall', 2002, 'B+');
	insert into takes values('31035', '960', '1', 'Fall', 2009, 'B ');
	insert into takes values('8517', '561', '1', 'Fall', 2006, 'B-');
	insert into takes values('63860', '352', '1', 'Spring', 2006, 'C-');
	insert into takes values('64724', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('87651', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('36845', '489', '1', 'Fall', 2007, 'B-');
	insert into takes values('67146', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('61332', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('5843', '571', '1', 'Spring', 2004, 'A+');
	insert into takes values('18583', '274', '1', 'Fall', 2002, 'C+');
	insert into takes values('93366', '200', '2', 'Fall', 2002, 'B-');
	insert into takes values('94998', '581', '1', 'Spring', 2005, 'A+');
	insert into takes values('88287', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('27919', '237', '1', 'Spring', 2008, 'A-');
	insert into takes values('11419', '802', '1', 'Spring', 2003, 'C-');
	insert into takes values('82301', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('62124', '313', '1', 'Fall', 2010, 'A ');
	insert into takes values('81245', '237', '1', 'Spring', 2008, 'A-');
	insert into takes values('10838', '415', '1', 'Fall', 2010, 'B+');
	insert into takes values('55329', '875', '1', 'Spring', 2005, 'C-');
	insert into takes values('53788', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('55000', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('56849', '158', '1', 'Fall', 2008, 'B+');
	insert into takes values('95859', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('76743', '629', '1', 'Spring', 2003, 'B ');
	insert into takes values('82918', '313', '1', 'Fall', 2010, 'B+');
	insert into takes values('28352', '376', '1', 'Fall', 2006, 'B+');
	insert into takes values('87015', '169', '1', 'Spring', 2007, 'C ');
	insert into takes values('72055', '334', '1', 'Fall', 2009, 'C ');
	insert into takes values('58307', '362', '2', 'Fall', 2006, 'B-');
	insert into takes values('35881', '169', '1', 'Spring', 2007, 'C ');
	insert into takes values('32483', '793', '1', 'Spring', 2002, 'B ');
	insert into takes values('64724', '696', '1', 'Spring', 2002, 'B-');
	insert into takes values('5414', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('39881', '457', '1', 'Spring', 2001, 'B+');
	insert into takes values('28004', '626', '1', 'Fall', 2006, 'C+');
	insert into takes values('95320', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('25725', '400', '1', 'Spring', 2007, 'A ');
	insert into takes values('88793', '486', '1', 'Fall', 2009, 'A ');
	insert into takes values('71628', '400', '2', 'Fall', 2003, 'C+');
	insert into takes values('83557', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('64169', '362', '1', 'Fall', 2005, 'C-');
	insert into takes values('44584', '875', '1', 'Spring', 2005, 'A+');
	insert into takes values('64297', '105', '1', 'Fall', 2009, 'B ');
	insert into takes values('68649', '486', '1', 'Fall', 2009, 'B-');
	insert into takes values('67310', '692', '1', 'Spring', 2010, 'C+');
	insert into takes values('99764', '192', '1', 'Fall', 2002, 'C-');
	insert into takes values('71287', '338', '1', 'Spring', 2007, 'C+');
	insert into takes values('99422', '972', '1', 'Spring', 2009, 'A-');
	insert into takes values('84865', '760', '1', 'Spring', 2004, 'B ');
	insert into takes values('42843', '843', '1', 'Fall', 2010, 'C ');
	insert into takes values('28352', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('95840', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('56232', '408', '1', 'Spring', 2007, 'A-');
	insert into takes values('14065', '599', '1', 'Spring', 2003, 'B-');
	insert into takes values('91851', '468', '1', 'Fall', 2005, 'C ');
	insert into takes values('62728', '366', '1', 'Fall', 2005, 'C ');
	insert into takes values('48009', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('60748', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('66293', '366', '1', 'Fall', 2005, 'C-');
	insert into takes values('48778', '735', '1', 'Spring', 2003, 'A-');
	insert into takes values('28128', '893', '1', 'Fall', 2007, 'C+');
	insert into takes values('5920', '527', '1', 'Fall', 2004, 'A ');
	insert into takes values('41596', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('36379', '304', '1', 'Fall', 2009, 'A ');
	insert into takes values('898', '400', '1', 'Spring', 2007, 'B ');
	insert into takes values('27727', '735', '1', 'Spring', 2003, 'B-');
	insert into takes values('46450', '408', '1', 'Spring', 2007, 'A+');
	insert into takes values('75299', '748', '1', 'Fall', 2003, 'C-');
	insert into takes values('26028', '169', '2', 'Fall', 2002, 'A+');
	insert into takes values('74796', '760', '1', 'Spring', 2004, 'C ');
	insert into takes values('978', '696', '1', 'Spring', 2002, 'A+');
	insert into takes values('25077', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('28361', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('20974', '443', '2', 'Spring', 2002, 'C-');
	insert into takes values('28518', '270', '1', 'Spring', 2010, 'A-');
	insert into takes values('69132', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('37818', '258', '1', 'Fall', 2007, 'B-');
	insert into takes values('86404', '949', '1', 'Fall', 2007, 'C+');
	insert into takes values('9084', '270', '1', 'Spring', 2010, 'C ');
	insert into takes values('90220', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('5005', '200', '1', 'Spring', 2007, 'A ');
	insert into takes values('14023', '692', '1', 'Spring', 2010, 'A-');
	insert into takes values('67725', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('24630', '489', '1', 'Fall', 2007, 'C+');
	insert into takes values('78892', '192', '1', 'Fall', 2002, 'C ');
	insert into takes values('38712', '694', '1', 'Fall', 2002, 'A ');
	insert into takes values('16631', '748', '1', 'Fall', 2003, 'A-');
	insert into takes values('26473', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('81610', '457', '1', 'Spring', 2001, 'B ');
	insert into takes values('56003', '338', '1', 'Spring', 2007, 'C-');
	insert into takes values('76743', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('74840', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('38899', '735', '2', 'Spring', 2010, 'B ');
	insert into takes values('90009', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('13408', '599', '1', 'Spring', 2003, 'C ');
	insert into takes values('57431', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('93653', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('92417', '362', '2', 'Fall', 2006, 'A-');
	insert into takes values('52750', '137', '1', 'Spring', 2002, 'C-');
	insert into takes values('3039', '421', '1', 'Fall', 2004, 'B-');
	insert into takes values('36019', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('45680', '692', '1', 'Spring', 2010, 'C-');
	insert into takes values('39241', '366', '1', 'Fall', 2005, 'C-');
	insert into takes values('90041', '401', '1', 'Fall', 2003, 'C-');
	insert into takes values('67371', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('12078', '362', '3', 'Spring', 2008, 'B ');
	insert into takes values('19536', '192', '1', 'Fall', 2002, 'A+');
	insert into takes values('83462', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('9460', '169', '1', 'Spring', 2007, 'B+');
	insert into takes values('34018', '313', '1', 'Fall', 2010, 'A ');
	insert into takes values('86344', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('45680', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('53805', '237', '1', 'Spring', 2008, 'B+');
	insert into takes values('96988', '401', '1', 'Fall', 2003, 'A-');
	insert into takes values('15328', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('94990', '603', '1', 'Fall', 2003, 'A ');
	insert into takes values('14432', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('37581', '692', '1', 'Spring', 2010, 'C-');
	insert into takes values('57334', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('21552', '457', '1', 'Spring', 2001, 'B+');
	insert into takes values('93708', '313', '1', 'Fall', 2010, 'B-');
	insert into takes values('77289', '604', '1', 'Spring', 2009, 'A ');
	insert into takes values('40897', '679', '1', 'Spring', 2010, 'B-');
	insert into takes values('45002', '486', '1', 'Fall', 2009, 'C ');
	insert into takes values('43993', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('4438', '893', '1', 'Fall', 2007, 'B ');
	insert into takes values('51868', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('37759', '258', '1', 'Fall', 2007, 'B-');
	insert into takes values('63390', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('90082', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('49813', '274', '1', 'Fall', 2002, 'A+');
	insert into takes values('79352', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('72669', '445', '1', 'Spring', 2001, 'B-');
	insert into takes values('27043', '696', '1', 'Spring', 2002, 'B ');
	insert into takes values('77361', '581', '1', 'Spring', 2005, 'C-');
	insert into takes values('56598', '663', '1', 'Spring', 2005, 'A ');
	insert into takes values('97868', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('66494', '169', '2', 'Fall', 2002, 'A-');
	insert into takes values('81258', '791', '1', 'Spring', 2006, 'A ');
	insert into takes values('94726', '408', '1', 'Spring', 2007, 'C-');
	insert into takes values('8426', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('90181', '747', '1', 'Spring', 2004, 'B+');
	insert into takes values('33107', '400', '1', 'Spring', 2007, 'C+');
	insert into takes values('47670', '795', '1', 'Spring', 2004, 'B ');
	insert into takes values('75173', '663', '1', 'Spring', 2005, 'B-');
	insert into takes values('99730', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('87222', '169', '1', 'Spring', 2007, 'A ');
	insert into takes values('22179', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('1727', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('98388', '972', '1', 'Spring', 2009, 'A+');
	insert into takes values('91091', '366', '1', 'Fall', 2005, 'A ');
	insert into takes values('11441', '443', '1', 'Spring', 2010, 'B+');
	insert into takes values('84515', '631', '1', 'Spring', 2007, 'B+');
	insert into takes values('52134', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('44038', '200', '2', 'Fall', 2002, 'A+');
	insert into takes values('67371', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('67725', '561', '1', 'Fall', 2006, 'A+');
	insert into takes values('51203', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('99780', '445', '1', 'Spring', 2001, 'A-');
	insert into takes values('21086', '400', '1', 'Spring', 2007, 'A ');
	insert into takes values('37038', '808', '1', 'Fall', 2003, 'A-');
	insert into takes values('30222', '959', '1', 'Fall', 2006, 'A-');
	insert into takes values('5298', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('11202', '599', '1', 'Spring', 2003, 'B-');
	insert into takes values('49339', '793', '1', 'Spring', 2002, 'A ');
	insert into takes values('50386', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('46442', '696', '1', 'Spring', 2002, 'B-');
	insert into takes values('64222', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('33651', '169', '1', 'Spring', 2007, 'A-');
	insert into takes values('61065', '445', '1', 'Spring', 2001, 'A-');
	insert into takes values('16515', '679', '1', 'Spring', 2010, 'A ');
	insert into takes values('55238', '338', '1', 'Spring', 2007, 'C-');
	insert into takes values('83836', '962', '1', 'Spring', 2008, 'A+');
	insert into takes values('89234', '972', '1', 'Spring', 2009, 'A ');
	insert into takes values('49873', '349', '1', 'Spring', 2008, 'A ');
	insert into takes values('27528', '864', '1', 'Spring', 2006, 'B+');
	insert into takes values('41683', '426', '1', 'Spring', 2006, 'A ');
	insert into takes values('98315', '457', '1', 'Spring', 2001, 'B+');
	insert into takes values('29462', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('37586', '591', '1', 'Spring', 2005, 'A ');
	insert into takes values('94766', '400', '2', 'Fall', 2003, 'B+');
	insert into takes values('77218', '692', '1', 'Spring', 2010, 'A+');
	insert into takes values('93043', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('26028', '270', '1', 'Spring', 2010, 'B+');
	insert into takes values('20489', '461', '1', 'Fall', 2002, 'B+');
	insert into takes values('24630', '443', '2', 'Spring', 2002, 'B-');
	insert into takes values('10838', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('15578', '489', '1', 'Fall', 2007, 'A-');
	insert into takes values('81876', '237', '2', 'Fall', 2009, 'C-');
	insert into takes values('13753', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('19450', '400', '1', 'Spring', 2007, 'C+');
	insert into takes values('45200', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('68720', '735', '1', 'Spring', 2003, 'C ');
	insert into takes values('57083', '237', '2', 'Fall', 2009, 'B+');
	insert into takes values('54728', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('32464', '735', '2', 'Spring', 2010, 'A ');
	insert into takes values('25256', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('95284', '461', '1', 'Fall', 2002, 'C-');
	insert into takes values('81028', '694', '1', 'Fall', 2002, 'C ');
	insert into takes values('60224', '345', '1', 'Spring', 2008, 'A-');
	insert into takes values('56755', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('72622', '421', '1', 'Fall', 2004, 'C ');
	insert into takes values('86833', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('50039', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('667', '927', '1', 'Fall', 2002, 'C+');
	insert into takes values('10838', '852', '1', 'Spring', 2008, 'A ');
	insert into takes values('85981', '679', '1', 'Spring', 2010, 'B-');
	insert into takes values('52291', '421', '1', 'Fall', 2004, 'C+');
	insert into takes values('91091', '338', '2', 'Spring', 2006, 'B+');
	insert into takes values('48165', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('18709', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('23392', '493', '1', 'Spring', 2010, 'C+');
	insert into takes values('56057', '959', '1', 'Fall', 2006, 'B ');
	insert into takes values('19342', '445', '1', 'Spring', 2001, 'B+');
	insert into takes values('61127', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('59046', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('43989', '304', '1', 'Fall', 2009, 'C-');
	insert into takes values('96227', '692', '1', 'Spring', 2010, 'C ');
	insert into takes values('40080', '663', '1', 'Spring', 2005, 'A ');
	insert into takes values('18775', '239', '1', 'Fall', 2006, 'C-');
	insert into takes values('79892', '959', '1', 'Fall', 2006, 'A-');
	insert into takes values('51862', '105', '2', 'Fall', 2002, 'B+');
	insert into takes values('22345', '631', '1', 'Spring', 2007, 'A ');
	insert into takes values('57213', '349', '1', 'Spring', 2008, 'A-');
	insert into takes values('81028', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('50013', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('8853', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('24201', '443', '2', 'Spring', 2002, 'B+');
	insert into takes values('73606', '802', '1', 'Spring', 2003, 'C-');
	insert into takes values('72528', '105', '2', 'Fall', 2002, 'B+');
	insert into takes values('31476', '468', '2', 'Fall', 2007, 'C-');
	insert into takes values('92839', '867', '2', 'Fall', 2010, 'B-');
	insert into takes values('83444', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('41832', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('52187', '960', '1', 'Fall', 2009, 'A-');
	insert into takes values('827', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('74840', '408', '1', 'Spring', 2007, 'C-');
	insert into takes values('46655', '959', '1', 'Fall', 2006, 'B ');
	insert into takes values('52523', '960', '2', 'Fall', 2006, 'C-');
	insert into takes values('83622', '962', '1', 'Spring', 2008, 'B-');
	insert into takes values('97629', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('95029', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('14182', '927', '1', 'Fall', 2002, 'B-');
	insert into takes values('41832', '972', '1', 'Spring', 2009, 'C ');
	insert into takes values('51008', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('75794', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('84495', '960', '2', 'Fall', 2006, 'C-');
	insert into takes values('20803', '663', '1', 'Spring', 2005, 'B-');
	insert into takes values('37869', '493', '1', 'Spring', 2010, 'B+');
	insert into takes values('42019', '169', '1', 'Spring', 2007, 'B ');
	insert into takes values('39114', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('78314', '408', '2', 'Spring', 2003, 'A+');
	insert into takes values('41211', '408', '2', 'Spring', 2003, 'B ');
	insert into takes values('17133', '927', '1', 'Fall', 2002, 'A+');
	insert into takes values('94766', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('11453', '581', '1', 'Spring', 2005, 'C+');
	insert into takes values('93653', '237', '1', 'Spring', 2008, 'C+');
	insert into takes values('60249', '927', '1', 'Fall', 2002, 'A-');
	insert into takes values('499', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('52945', '352', '1', 'Spring', 2006, 'B ');
	insert into takes values('16849', '338', '1', 'Spring', 2007, 'C ');
	insert into takes values('69081', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('4438', '694', '1', 'Fall', 2002, 'C+');
	insert into takes values('59290', '760', '1', 'Spring', 2004, 'A-');
	insert into takes values('1367', '401', '1', 'Fall', 2003, 'A-');
	insert into takes values('8378', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('90372', '696', '1', 'Spring', 2002, 'A ');
	insert into takes values('65703', '642', '1', 'Fall', 2004, 'C+');
	insert into takes values('16969', '959', '1', 'Fall', 2006, 'B+');
	insert into takes values('89051', '486', '1', 'Fall', 2009, 'B ');
	insert into takes values('99764', '545', '1', 'Fall', 2001, 'A+');
	insert into takes values('36102', '169', '2', 'Fall', 2002, 'A-');
	insert into takes values('35523', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('78332', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('50966', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('90220', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('12683', '274', '1', 'Fall', 2002, 'B-');
	insert into takes values('44881', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('108', '457', '1', 'Spring', 2001, 'C ');
	insert into takes values('46655', '352', '1', 'Spring', 2006, 'A+');
	insert into takes values('31086', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('8603', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('14639', '338', '1', 'Spring', 2007, 'C-');
	insert into takes values('36685', '426', '1', 'Spring', 2006, 'A ');
	insert into takes values('36881', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('18636', '972', '1', 'Spring', 2009, 'C-');
	insert into takes values('45002', '527', '1', 'Fall', 2004, 'A ');
	insert into takes values('64724', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('22086', '482', '1', 'Fall', 2005, 'B ');
	insert into takes values('67310', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('71630', '338', '2', 'Spring', 2006, 'A ');
	insert into takes values('25525', '591', '1', 'Spring', 2005, 'C-');
	insert into takes values('84808', '400', '1', 'Spring', 2007, 'A-');
	insert into takes values('62487', '443', '1', 'Spring', 2010, 'C ');
	insert into takes values('52057', '270', '1', 'Spring', 2010, 'B+');
	insert into takes values('87246', '200', '2', 'Fall', 2002, 'A-');
	insert into takes values('76768', '426', '1', 'Spring', 2006, 'A-');
	insert into takes values('98140', '401', '1', 'Fall', 2003, 'B+');
	insert into takes values('88993', '604', '1', 'Spring', 2009, 'C ');
	insert into takes values('40932', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('63040', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('55915', '137', '1', 'Spring', 2002, 'B ');
	insert into takes values('1922', '192', '1', 'Fall', 2002, 'C ');
	insert into takes values('86736', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('94697', '192', '1', 'Fall', 2002, 'C-');
	insert into takes values('98423', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('64169', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('33107', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('68712', '376', '1', 'Fall', 2006, 'C ');
	insert into takes values('53728', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('1812', '258', '1', 'Fall', 2007, 'A ');
	insert into takes values('82580', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('39394', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('6474', '959', '1', 'Fall', 2006, 'A-');
	insert into takes values('27898', '704', '1', 'Spring', 2008, 'C-');
	insert into takes values('65144', '603', '1', 'Fall', 2003, 'B ');
	insert into takes values('44038', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('92839', '445', '1', 'Spring', 2001, 'C+');
	insert into takes values('71287', '274', '1', 'Fall', 2002, 'B-');
	insert into takes values('76799', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('14874', '496', '1', 'Fall', 2001, 'B+');
	insert into takes values('71387', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('59530', '747', '1', 'Spring', 2004, 'B+');
	insert into takes values('86753', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('49982', '852', '1', 'Spring', 2008, 'A ');
	insert into takes values('57238', '401', '1', 'Fall', 2003, 'B+');
	insert into takes values('32954', '791', '1', 'Spring', 2006, 'C-');
	insert into takes values('43226', '352', '1', 'Spring', 2006, 'C-');
	insert into takes values('87054', '791', '1', 'Spring', 2006, 'C+');
	insert into takes values('65753', '527', '1', 'Fall', 2004, 'C+');
	insert into takes values('11237', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('34770', '747', '1', 'Spring', 2004, 'A ');
	insert into takes values('39876', '735', '1', 'Spring', 2003, 'C ');
	insert into takes values('72622', '559', '1', 'Fall', 2002, 'A ');
	insert into takes values('78469', '489', '1', 'Fall', 2007, 'B-');
	insert into takes values('83314', '489', '1', 'Fall', 2007, 'A-');
	insert into takes values('41988', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('61003', '702', '1', 'Spring', 2001, 'C-');
	insert into takes values('84039', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('21009', '561', '1', 'Fall', 2006, 'A-');
	insert into takes values('81207', '158', '1', 'Fall', 2008, 'B-');
	insert into takes values('54672', '169', '1', 'Spring', 2007, 'A-');
	insert into takes values('58326', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('63090', '493', '1', 'Spring', 2010, 'C-');
	insert into takes values('64934', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('51093', '867', '2', 'Fall', 2010, 'C ');
	insert into takes values('282', '735', '2', 'Spring', 2010, 'A-');
	insert into takes values('8853', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('65438', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('70564', '795', '1', 'Spring', 2004, 'B+');
	insert into takes values('78332', '137', '1', 'Spring', 2002, 'A-');
	insert into takes values('37339', '561', '1', 'Fall', 2006, 'A ');
	insert into takes values('21100', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('20803', '493', '1', 'Spring', 2010, 'B ');
	insert into takes values('4345', '258', '1', 'Fall', 2007, 'C ');
	insert into takes values('29707', '867', '2', 'Fall', 2010, 'C-');
	insert into takes values('98388', '408', '2', 'Spring', 2003, 'B-');
	insert into takes values('72186', '852', '1', 'Spring', 2008, 'B ');
	insert into takes values('49214', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('98870', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('19917', '376', '1', 'Fall', 2006, 'C+');
	insert into takes values('31337', '468', '1', 'Fall', 2005, 'A-');
	insert into takes values('1884', '545', '1', 'Fall', 2001, 'B-');
	insert into takes values('84189', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('37284', '137', '1', 'Spring', 2002, 'C-');
	insert into takes values('31560', '334', '1', 'Fall', 2009, 'C ');
	insert into takes values('84702', '604', '1', 'Spring', 2009, 'A-');
	insert into takes values('56212', '791', '1', 'Spring', 2006, 'C+');
	insert into takes values('23994', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('2970', '270', '1', 'Spring', 2010, 'B+');
	insert into takes values('80990', '352', '1', 'Spring', 2006, 'C+');
	insert into takes values('71529', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('87785', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('31476', '867', '2', 'Fall', 2010, 'A+');
	insert into takes values('49280', '421', '1', 'Fall', 2004, 'C+');
	insert into takes values('86404', '972', '1', 'Spring', 2009, 'C ');
	insert into takes values('63039', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('23994', '338', '2', 'Spring', 2006, 'B ');
	insert into takes values('32419', '696', '1', 'Spring', 2002, 'B+');
	insert into takes values('45300', '443', '2', 'Spring', 2002, 'B+');
	insert into takes values('48901', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('36379', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('83838', '105', '2', 'Fall', 2002, 'C+');
	insert into takes values('22170', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('57135', '401', '1', 'Fall', 2003, 'C-');
	insert into takes values('50386', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('61354', '972', '1', 'Spring', 2009, 'A-');
	insert into takes values('58606', '105', '1', 'Fall', 2009, 'B+');
	insert into takes values('4015', '793', '1', 'Spring', 2002, 'B ');
	insert into takes values('5943', '376', '1', 'Fall', 2006, 'C+');
	insert into takes values('9993', '696', '1', 'Spring', 2002, 'C ');
	insert into takes values('49391', '527', '1', 'Fall', 2004, 'C+');
	insert into takes values('62054', '949', '1', 'Fall', 2007, 'A-');
	insert into takes values('86127', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('33759', '489', '1', 'Fall', 2007, 'A ');
	insert into takes values('4645', '696', '1', 'Spring', 2002, 'A ');
	insert into takes values('29192', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('69632', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('97868', '274', '1', 'Fall', 2002, 'B ');
	insert into takes values('40044', '421', '1', 'Fall', 2004, 'A ');
	insert into takes values('29002', '274', '1', 'Fall', 2002, 'C+');
	insert into takes values('7043', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('95175', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('69307', '864', '1', 'Spring', 2006, 'A ');
	insert into takes values('67657', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('51678', '612', '1', 'Fall', 2007, 'B ');
	insert into takes values('41211', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('2848', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('81396', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('84432', '795', '1', 'Spring', 2004, 'A-');
	insert into takes values('23506', '349', '1', 'Spring', 2008, 'A-');
	insert into takes values('51955', '137', '1', 'Spring', 2002, 'C-');
	insert into takes values('15578', '735', '1', 'Spring', 2003, 'C-');
	insert into takes values('95225', '400', '1', 'Spring', 2007, 'B ');
	insert into takes values('38602', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('71529', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('79763', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('81566', '867', '2', 'Fall', 2010, 'A-');
	insert into takes values('53118', '304', '1', 'Fall', 2009, 'A ');
	insert into takes values('3833', '581', '1', 'Spring', 2005, 'A-');
	insert into takes values('16543', '270', '1', 'Spring', 2010, 'C-');
	insert into takes values('67222', '867', '1', 'Fall', 2006, 'A ');
	insert into takes values('46155', '893', '1', 'Fall', 2007, 'C ');
	insert into takes values('89246', '791', '1', 'Spring', 2006, 'A-');
	insert into takes values('96895', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('55531', '559', '1', 'Fall', 2002, 'A ');
	insert into takes values('83871', '345', '1', 'Spring', 2008, 'C ');
	insert into takes values('48850', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('62728', '599', '1', 'Spring', 2003, 'B+');
	insert into takes values('43495', '949', '1', 'Fall', 2007, 'A-');
	insert into takes values('19791', '200', '1', 'Spring', 2007, 'C ');
	insert into takes values('58300', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('38555', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('48165', '629', '1', 'Spring', 2003, 'B+');
	insert into takes values('31137', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('77548', '468', '1', 'Fall', 2005, 'A-');
	insert into takes values('28316', '476', '1', 'Fall', 2010, 'C ');
	insert into takes values('32385', '962', '1', 'Spring', 2008, 'B-');
	insert into takes values('18709', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('36379', '760', '1', 'Spring', 2004, 'B-');
	insert into takes values('40481', '304', '1', 'Fall', 2009, 'C-');
	insert into takes values('64820', '274', '1', 'Fall', 2002, 'B-');
	insert into takes values('64013', '338', '1', 'Spring', 2007, 'A+');
	insert into takes values('29140', '457', '1', 'Spring', 2001, 'A ');
	insert into takes values('19791', '527', '1', 'Fall', 2004, 'C ');
	insert into takes values('67436', '795', '1', 'Spring', 2004, 'B-');
	insert into takes values('31266', '559', '1', 'Fall', 2002, 'B ');
	insert into takes values('33791', '791', '1', 'Spring', 2006, 'C+');
	insert into takes values('97042', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('88525', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('71630', '200', '2', 'Fall', 2002, 'A ');
	insert into takes values('75395', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('41211', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('25611', '735', '1', 'Spring', 2003, 'A-');
	insert into takes values('38121', '313', '1', 'Fall', 2010, 'B-');
	insert into takes values('86981', '169', '2', 'Fall', 2002, 'B+');
	insert into takes values('20195', '401', '1', 'Fall', 2003, 'A ');
	insert into takes values('30164', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('17600', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('22417', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('28252', '169', '2', 'Fall', 2002, 'B-');
	insert into takes values('36995', '468', '1', 'Fall', 2005, 'B-');
	insert into takes values('6673', '735', '1', 'Spring', 2003, 'C-');
	insert into takes values('25256', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('13403', '489', '1', 'Fall', 2007, 'B ');
	insert into takes values('93171', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('96052', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('39521', '735', '1', 'Spring', 2003, 'A-');
	insert into takes values('3651', '802', '1', 'Spring', 2003, 'C+');
	insert into takes values('34569', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('21246', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('11453', '443', '1', 'Spring', 2010, 'C ');
	insert into takes values('23475', '927', '1', 'Fall', 2002, 'B-');
	insert into takes values('71630', '591', '1', 'Spring', 2005, 'A-');
	insert into takes values('259', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('70688', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('30188', '679', '1', 'Spring', 2010, 'C-');
	insert into takes values('71389', '867', '2', 'Fall', 2010, 'C-');
	insert into takes values('23439', '843', '1', 'Fall', 2010, 'A-');
	insert into takes values('27556', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('32130', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('30299', '352', '1', 'Spring', 2006, 'B+');
	insert into takes values('58935', '482', '1', 'Fall', 2005, 'A+');
	insert into takes values('49391', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('89759', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('93061', '457', '1', 'Spring', 2001, 'C ');
	insert into takes values('78469', '559', '1', 'Fall', 2002, 'A ');
	insert into takes values('50206', '692', '1', 'Spring', 2010, 'C ');
	insert into takes values('67560', '696', '1', 'Spring', 2002, 'A+');
	insert into takes values('16057', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('35138', '105', '1', 'Fall', 2009, 'B+');
	insert into takes values('91580', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('33201', '493', '1', 'Spring', 2010, 'B+');
	insert into takes values('64169', '457', '1', 'Spring', 2001, 'C+');
	insert into takes values('63310', '105', '2', 'Fall', 2002, 'A+');
	insert into takes values('68516', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('79772', '489', '1', 'Fall', 2007, 'B-');
	insert into takes values('77364', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('33546', '443', '2', 'Spring', 2002, 'B+');
	insert into takes values('57941', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('41091', '692', '1', 'Spring', 2010, 'A ');
	insert into takes values('17600', '349', '1', 'Spring', 2008, 'A ');
	insert into takes values('29705', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('43348', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('74974', '626', '1', 'Fall', 2006, 'B-');
	insert into takes values('26619', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('29031', '338', '1', 'Spring', 2007, 'A-');
	insert into takes values('55531', '319', '1', 'Spring', 2003, 'C-');
	insert into takes values('66494', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('37521', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('14284', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('43016', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('52876', '158', '1', 'Fall', 2008, 'B-');
	insert into takes values('48850', '760', '1', 'Spring', 2004, 'A ');
	insert into takes values('42388', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('38548', '400', '1', 'Spring', 2007, 'A+');
	insert into takes values('82082', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('64039', '867', '1', 'Fall', 2006, 'A ');
	insert into takes values('44998', '864', '1', 'Spring', 2006, 'A+');
	insert into takes values('57160', '626', '1', 'Fall', 2006, 'B+');
	insert into takes values('39514', '443', '1', 'Spring', 2010, 'B+');
	insert into takes values('89414', '692', '1', 'Spring', 2010, 'A-');
	insert into takes values('23344', '237', '1', 'Spring', 2008, 'C-');
	insert into takes values('85614', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('75241', '415', '1', 'Fall', 2010, 'B-');
	insert into takes values('65396', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('65438', '696', '1', 'Spring', 2002, 'C+');
	insert into takes values('32954', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('39204', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('64121', '421', '1', 'Fall', 2004, 'C-');
	insert into takes values('28409', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('46066', '338', '2', 'Spring', 2006, 'A+');
	insert into takes values('34197', '527', '1', 'Fall', 2004, 'A ');
	insert into takes values('64593', '603', '1', 'Fall', 2003, 'B-');
	insert into takes values('54620', '962', '1', 'Spring', 2008, 'C-');
	insert into takes values('10693', '486', '1', 'Fall', 2009, 'C+');
	insert into takes values('32368', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('13290', '808', '1', 'Fall', 2003, 'B-');
	insert into takes values('65681', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('14639', '793', '1', 'Spring', 2002, 'C ');
	insert into takes values('40044', '561', '1', 'Fall', 2006, 'A+');
	insert into takes values('26730', '843', '1', 'Fall', 2010, 'A ');
	insert into takes values('50206', '852', '1', 'Spring', 2008, 'C-');
	insert into takes values('99463', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('44551', '864', '1', 'Spring', 2006, 'C+');
	insert into takes values('34126', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('75241', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('61232', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('38371', '338', '1', 'Spring', 2007, 'B ');
	insert into takes values('18808', '258', '1', 'Fall', 2007, 'C-');
	insert into takes values('22004', '242', '1', 'Fall', 2009, 'A-');
	insert into takes values('41599', '400', '1', 'Spring', 2007, 'A-');
	insert into takes values('1884', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('87965', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('28352', '401', '1', 'Fall', 2003, 'B+');
	insert into takes values('94801', '258', '1', 'Fall', 2007, 'A ');
	insert into takes values('29871', '408', '1', 'Spring', 2007, 'C+');
	insert into takes values('76759', '545', '1', 'Fall', 2001, 'A ');
	insert into takes values('3493', '960', '2', 'Fall', 2006, 'B-');
	insert into takes values('10454', '169', '2', 'Fall', 2002, 'A+');
	insert into takes values('64140', '793', '1', 'Spring', 2002, 'B ');
	insert into takes values('12362', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('85754', '408', '2', 'Spring', 2003, 'C-');
	insert into takes values('39881', '345', '1', 'Spring', 2008, 'C-');
	insert into takes values('5208', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('85445', '334', '1', 'Fall', 2009, 'B+');
	insert into takes values('43348', '408', '1', 'Spring', 2007, 'A-');
	insert into takes values('94814', '304', '1', 'Fall', 2009, 'B+');
	insert into takes values('64945', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('35462', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('12078', '239', '1', 'Fall', 2006, 'C-');
	insert into takes values('77244', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('33338', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('35462', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('40558', '591', '1', 'Spring', 2005, 'B-');
	insert into takes values('56124', '421', '1', 'Fall', 2004, 'B+');
	insert into takes values('84808', '843', '1', 'Fall', 2010, 'B-');
	insert into takes values('60867', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('90041', '692', '1', 'Spring', 2010, 'A+');
	insert into takes values('44551', '362', '2', 'Fall', 2006, 'A-');
	insert into takes values('39552', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('70395', '747', '1', 'Spring', 2004, 'B+');
	insert into takes values('67146', '760', '1', 'Spring', 2004, 'C+');
	insert into takes values('36402', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('11095', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('57511', '468', '1', 'Fall', 2005, 'B-');
	insert into takes values('3005', '843', '1', 'Fall', 2010, 'C ');
	insert into takes values('48469', '468', '1', 'Fall', 2005, 'C+');
	insert into takes values('23500', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('82688', '242', '1', 'Fall', 2009, 'B ');
	insert into takes values('43016', '200', '1', 'Spring', 2007, 'B-');
	insert into takes values('80248', '362', '2', 'Fall', 2006, 'A ');
	insert into takes values('24442', '694', '1', 'Fall', 2002, 'A ');
	insert into takes values('72165', '702', '1', 'Spring', 2001, 'B-');
	insert into takes values('69521', '496', '1', 'Fall', 2001, 'B-');
	insert into takes values('66469', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('52057', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('70828', '376', '1', 'Fall', 2006, 'B+');
	insert into takes values('21126', '169', '1', 'Spring', 2007, 'C ');
	insert into takes values('50467', '352', '1', 'Spring', 2006, 'C ');
	insert into takes values('47379', '239', '1', 'Fall', 2006, 'B ');
	insert into takes values('46694', '237', '1', 'Spring', 2008, 'C+');
	insert into takes values('70965', '242', '1', 'Fall', 2009, 'A+');
	insert into takes values('5824', '345', '1', 'Spring', 2008, 'C+');
	insert into takes values('24630', '791', '1', 'Spring', 2006, 'B+');
	insert into takes values('54622', '443', '2', 'Spring', 2002, 'C-');
	insert into takes values('87222', '692', '1', 'Spring', 2010, 'C-');
	insert into takes values('77664', '443', '1', 'Spring', 2010, 'C ');
	insert into takes values('99760', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('86981', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('31101', '408', '1', 'Spring', 2007, 'C+');
	insert into takes values('64893', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('15883', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('7020', '426', '1', 'Spring', 2006, 'B ');
	insert into takes values('85981', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('73206', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('25611', '338', '1', 'Spring', 2007, 'A ');
	insert into takes values('78922', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('842', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('914', '748', '1', 'Fall', 2003, 'B-');
	insert into takes values('97953', '105', '1', 'Fall', 2009, 'C-');
	insert into takes values('14639', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('82707', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('55000', '415', '1', 'Fall', 2010, 'B+');
	insert into takes values('34126', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('57962', '545', '1', 'Fall', 2001, 'C ');
	insert into takes values('90041', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('30289', '747', '1', 'Spring', 2004, 'C-');
	insert into takes values('97435', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('55857', '482', '1', 'Fall', 2005, 'B-');
	insert into takes values('40116', '960', '2', 'Fall', 2006, 'B-');
	insert into takes values('85356', '362', '2', 'Fall', 2006, 'A-');
	insert into takes values('69307', '270', '1', 'Spring', 2010, 'A-');
	insert into takes values('23311', '704', '1', 'Spring', 2008, 'A+');
	insert into takes values('90132', '400', '2', 'Fall', 2003, 'B+');
	insert into takes values('33107', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('53185', '867', '2', 'Fall', 2010, 'C-');
	insert into takes values('31560', '864', '1', 'Spring', 2006, 'C+');
	insert into takes values('7861', '376', '1', 'Fall', 2006, 'B-');
	insert into takes values('36881', '843', '1', 'Fall', 2010, 'C+');
	insert into takes values('13495', '242', '1', 'Fall', 2009, 'B+');
	insert into takes values('88085', '408', '2', 'Spring', 2003, 'C ');
	insert into takes values('88045', '694', '1', 'Fall', 2002, 'A+');
	insert into takes values('94697', '158', '2', 'Spring', 2008, 'A-');
	insert into takes values('75046', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('72006', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('64169', '486', '1', 'Fall', 2009, 'C+');
	insert into takes values('14484', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('70688', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('13504', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('12236', '591', '1', 'Spring', 2005, 'B-');
	insert into takes values('41988', '105', '2', 'Fall', 2002, 'C+');
	insert into takes values('11083', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('34197', '679', '1', 'Spring', 2010, 'B-');
	insert into takes values('32490', '319', '1', 'Spring', 2003, 'B-');
	insert into takes values('28518', '169', '1', 'Spring', 2007, 'B ');
	insert into takes values('19245', '313', '1', 'Fall', 2010, 'A-');
	insert into takes values('18859', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('83022', '747', '1', 'Spring', 2004, 'B+');
	insert into takes values('24197', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('41827', '843', '1', 'Fall', 2010, 'B-');
	insert into takes values('14668', '242', '1', 'Fall', 2009, 'A+');
	insert into takes values('8517', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('3576', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('67340', '748', '1', 'Fall', 2003, 'C ');
	insert into takes values('73411', '696', '1', 'Spring', 2002, 'C ');
	insert into takes values('98870', '631', '1', 'Spring', 2007, 'A+');
	insert into takes values('17339', '679', '1', 'Spring', 2010, 'C-');
	insert into takes values('85754', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('72014', '843', '1', 'Fall', 2010, 'C ');
	insert into takes values('65208', '105', '2', 'Fall', 2002, 'A-');
	insert into takes values('7956', '795', '1', 'Spring', 2004, 'B-');
	insert into takes values('89297', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('58355', '169', '1', 'Spring', 2007, 'C+');
	insert into takes values('26881', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('4438', '704', '1', 'Spring', 2008, 'C ');
	insert into takes values('15074', '791', '1', 'Spring', 2006, 'C+');
	insert into takes values('37101', '169', '2', 'Fall', 2002, 'B ');
	insert into takes values('12979', '927', '1', 'Fall', 2002, 'C-');
	insert into takes values('40937', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('29002', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('23224', '561', '1', 'Fall', 2006, 'A-');
	insert into takes values('53089', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('98140', '169', '2', 'Fall', 2002, 'A+');
	insert into takes values('39520', '105', '1', 'Fall', 2009, 'B ');
	insert into takes values('51093', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('79170', '603', '1', 'Fall', 2003, 'A+');
	insert into takes values('57107', '489', '1', 'Fall', 2007, 'C+');
	insert into takes values('24325', '626', '1', 'Fall', 2006, 'C+');
	insert into takes values('42843', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('14499', '242', '1', 'Fall', 2009, 'C ');
	insert into takes values('97868', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('19603', '875', '1', 'Spring', 2005, 'C-');
	insert into takes values('81550', '237', '1', 'Spring', 2008, 'C-');
	insert into takes values('31080', '137', '1', 'Spring', 2002, 'C-');
	insert into takes values('79487', '366', '1', 'Fall', 2005, 'A+');
	insert into takes values('76799', '559', '1', 'Fall', 2002, 'C-');
	insert into takes values('33107', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('70099', '304', '1', 'Fall', 2009, 'B ');
	insert into takes values('34502', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('98940', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('81538', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('3335', '345', '1', 'Spring', 2008, 'C ');
	insert into takes values('21766', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('76895', '270', '1', 'Spring', 2010, 'A+');
	insert into takes values('544', '679', '1', 'Spring', 2010, 'B ');
	insert into takes values('95284', '421', '1', 'Fall', 2004, 'C-');
	insert into takes values('96968', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('28538', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('64121', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('34322', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('19450', '401', '1', 'Fall', 2003, 'C+');
	insert into takes values('64039', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('38545', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('87246', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('38895', '893', '1', 'Fall', 2007, 'A+');
	insert into takes values('57474', '795', '1', 'Spring', 2004, 'B-');
	insert into takes values('58300', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('64140', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('57666', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('64401', '366', '1', 'Fall', 2005, 'A+');
	insert into takes values('51817', '242', '1', 'Fall', 2009, 'A+');
	insert into takes values('78116', '735', '1', 'Spring', 2003, 'C-');
	insert into takes values('90124', '642', '1', 'Fall', 2004, 'A+');
	insert into takes values('66212', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('41751', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('46035', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('77289', '867', '2', 'Fall', 2010, 'B-');
	insert into takes values('61403', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('24865', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('4034', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('86806', '468', '1', 'Fall', 2005, 'B ');
	insert into takes values('12683', '200', '1', 'Spring', 2007, 'A-');
	insert into takes values('34542', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('65241', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('5920', '476', '1', 'Fall', 2010, 'A ');
	insert into takes values('1460', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('28977', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('96772', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('82301', '345', '1', 'Spring', 2008, 'C ');
	insert into takes values('38676', '334', '1', 'Fall', 2009, 'B+');
	insert into takes values('65038', '852', '1', 'Spring', 2008, 'A-');
	insert into takes values('31690', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('81883', '949', '1', 'Fall', 2007, 'C+');
	insert into takes values('98830', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('80698', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('45436', '338', '1', 'Spring', 2007, 'A ');
	insert into takes values('82083', '603', '1', 'Fall', 2003, 'A+');
	insert into takes values('96085', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('89106', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('19848', '735', '1', 'Spring', 2003, 'C-');
	insert into takes values('6367', '612', '1', 'Fall', 2007, 'B ');
	insert into takes values('11095', '457', '1', 'Spring', 2001, 'A ');
	insert into takes values('95089', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('78911', '604', '1', 'Spring', 2009, 'C ');
	insert into takes values('72014', '426', '1', 'Spring', 2006, 'A-');
	insert into takes values('24201', '493', '1', 'Spring', 2010, 'A+');
	insert into takes values('97101', '599', '1', 'Spring', 2003, 'C+');
	insert into takes values('29390', '400', '1', 'Spring', 2007, 'A ');
	insert into takes values('36303', '962', '1', 'Spring', 2008, 'C-');
	insert into takes values('56882', '959', '1', 'Fall', 2006, 'C+');
	insert into takes values('64550', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('69132', '591', '1', 'Spring', 2005, 'C-');
	insert into takes values('7020', '366', '1', 'Fall', 2005, 'A ');
	insert into takes values('79352', '972', '1', 'Spring', 2009, 'B-');
	insert into takes values('72959', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('80248', '629', '1', 'Spring', 2003, 'B-');
	insert into takes values('46970', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('55286', '561', '1', 'Fall', 2006, 'C-');
	insert into takes values('62429', '959', '1', 'Fall', 2006, 'B+');
	insert into takes values('89551', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('6304', '852', '1', 'Spring', 2008, 'B-');
	insert into takes values('83747', '735', '2', 'Spring', 2010, 'C ');
	insert into takes values('25611', '461', '1', 'Fall', 2002, 'C-');
	insert into takes values('65987', '748', '1', 'Fall', 2003, 'C-');
	insert into takes values('41450', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('6895', '334', '1', 'Fall', 2009, 'A-');
	insert into takes values('5414', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('53699', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('64593', '426', '1', 'Spring', 2006, 'A ');
	insert into takes values('25187', '482', '1', 'Fall', 2005, 'B ');
	insert into takes values('32886', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('13511', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('98047', '408', '1', 'Spring', 2007, 'C-');
	insert into takes values('93354', '468', '1', 'Fall', 2005, 'C+');
	insert into takes values('76057', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('79210', '158', '1', 'Fall', 2008, 'B+');
	insert into takes values('42092', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('98984', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('7861', '457', '1', 'Spring', 2001, 'C+');
	insert into takes values('107', '274', '1', 'Fall', 2002, 'A+');
	insert into takes values('1954', '304', '1', 'Fall', 2009, 'C-');
	insert into takes values('77000', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('58701', '793', '1', 'Spring', 2002, 'B ');
	insert into takes values('47001', '334', '1', 'Fall', 2009, 'B+');
	insert into takes values('88801', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('86651', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('64642', '972', '1', 'Spring', 2009, 'A+');
	insert into takes values('80651', '696', '1', 'Spring', 2002, 'A-');
	insert into takes values('35588', '603', '1', 'Fall', 2003, 'B+');
	insert into takes values('10838', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('21774', '991', '1', 'Spring', 2008, 'B ');
	insert into takes values('27017', '559', '1', 'Fall', 2002, 'B ');
	insert into takes values('66008', '571', '1', 'Spring', 2004, 'A+');
	insert into takes values('63040', '408', '1', 'Spring', 2007, 'A+');
	insert into takes values('80990', '237', '2', 'Fall', 2009, 'A-');
	insert into takes values('90181', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('40992', '345', '1', 'Spring', 2008, 'A-');
	insert into takes values('95099', '867', '1', 'Fall', 2006, 'B+');
	insert into takes values('35721', '629', '1', 'Spring', 2003, 'A ');
	insert into takes values('66495', '561', '1', 'Fall', 2006, 'C+');
	insert into takes values('59908', '345', '1', 'Spring', 2008, 'C-');
	insert into takes values('80976', '864', '1', 'Spring', 2006, 'A+');
	insert into takes values('28952', '258', '1', 'Fall', 2007, 'A-');
	insert into takes values('34788', '461', '1', 'Fall', 2002, 'B+');
	insert into takes values('17207', '313', '1', 'Fall', 2010, 'B+');
	insert into takes values('81785', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('60748', '692', '1', 'Spring', 2010, 'C-');
	insert into takes values('64820', '338', '2', 'Spring', 2006, 'A+');
	insert into takes values('75534', '366', '1', 'Fall', 2005, 'C ');
	insert into takes values('12971', '313', '1', 'Fall', 2010, 'C-');
	insert into takes values('45680', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('94730', '603', '1', 'Fall', 2003, 'B ');
	insert into takes values('42114', '561', '1', 'Fall', 2006, 'C+');
	insert into takes values('33401', '158', '2', 'Spring', 2008, 'C-');
	insert into takes values('24630', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('52494', '421', '1', 'Fall', 2004, 'A-');
	insert into takes values('61081', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('8378', '527', '1', 'Fall', 2004, 'A ');
	insert into takes values('16515', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('5617', '559', '1', 'Fall', 2002, 'A-');
	insert into takes values('65438', '642', '1', 'Fall', 2004, 'A+');
	insert into takes values('72177', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('25046', '793', '1', 'Spring', 2002, 'A+');
	insert into takes values('76246', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('86404', '400', '2', 'Fall', 2003, 'A-');
	insert into takes values('66279', '559', '1', 'Fall', 2002, 'B ');
	insert into takes values('16250', '702', '1', 'Spring', 2001, 'A-');
	insert into takes values('8517', '237', '2', 'Fall', 2009, 'C ');
	insert into takes values('40937', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('33817', '270', '1', 'Spring', 2010, 'C+');
	insert into takes values('77003', '959', '1', 'Fall', 2006, 'A-');
	insert into takes values('50267', '443', '1', 'Spring', 2010, 'C+');
	insert into takes values('50702', '345', '1', 'Spring', 2008, 'A+');
	insert into takes values('99764', '631', '1', 'Spring', 2007, 'C-');
	insert into takes values('18338', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('80651', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('45002', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('12711', '795', '1', 'Spring', 2004, 'A-');
	insert into takes values('32419', '867', '2', 'Fall', 2010, 'A-');
	insert into takes values('77000', '408', '1', 'Spring', 2007, 'A-');
	insert into takes values('99611', '802', '1', 'Spring', 2003, 'A+');
	insert into takes values('38476', '468', '2', 'Fall', 2007, 'C+');
	insert into takes values('65299', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('18636', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('57213', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('41674', '400', '1', 'Spring', 2007, 'C+');
	insert into takes values('70965', '304', '1', 'Fall', 2009, 'A+');
	insert into takes values('71529', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('83204', '401', '1', 'Fall', 2003, 'C+');
	insert into takes values('978', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('92332', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('10527', '105', '2', 'Fall', 2002, 'C-');
	insert into takes values('29192', '476', '1', 'Fall', 2010, 'B+');
	insert into takes values('16311', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('22258', '612', '1', 'Fall', 2007, 'A ');
	insert into takes values('760', '457', '1', 'Spring', 2001, 'B+');
	insert into takes values('85366', '105', '1', 'Fall', 2009, 'B+');
	insert into takes values('42625', '334', '1', 'Fall', 2009, 'B-');
	insert into takes values('98423', '345', '1', 'Spring', 2008, 'B ');
	insert into takes values('90041', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('61402', '400', '2', 'Fall', 2003, 'C-');
	insert into takes values('73394', '735', '1', 'Spring', 2003, 'C ');
	insert into takes values('63040', '795', '1', 'Spring', 2004, 'C+');
	insert into takes values('61527', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('77000', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('77361', '559', '1', 'Fall', 2002, 'A-');
	insert into takes values('7620', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('13028', '679', '1', 'Spring', 2010, 'C-');
	insert into takes values('75534', '679', '1', 'Spring', 2010, 'B+');
	insert into takes values('5920', '875', '1', 'Spring', 2005, 'A-');
	insert into takes values('90353', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('74070', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('73606', '338', '2', 'Spring', 2006, 'A-');
	insert into takes values('11237', '852', '1', 'Spring', 2008, 'A ');
	insert into takes values('40682', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('46260', '760', '1', 'Spring', 2004, 'B+');
	insert into takes values('11422', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('10705', '489', '1', 'Fall', 2007, 'B ');
	insert into takes values('5943', '702', '1', 'Spring', 2001, 'C-');
	insert into takes values('65443', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('36244', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('58874', '486', '1', 'Fall', 2009, 'A ');
	insert into takes values('66484', '960', '2', 'Fall', 2006, 'B+');
	insert into takes values('50386', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('61920', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('50598', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('70828', '631', '1', 'Spring', 2007, 'A-');
	insert into takes values('67560', '200', '1', 'Spring', 2007, 'B-');
	insert into takes values('23994', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('82063', '461', '1', 'Fall', 2002, 'C+');
	insert into takes values('30182', '169', '2', 'Fall', 2002, 'B-');
	insert into takes values('90567', '486', '1', 'Fall', 2009, 'A ');
	insert into takes values('80976', '692', '1', 'Spring', 2010, 'C-');
	insert into takes values('91992', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('53185', '735', '2', 'Spring', 2010, 'A-');
	insert into takes values('6523', '735', '2', 'Spring', 2010, 'C ');
	insert into takes values('93571', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('12069', '105', '2', 'Fall', 2002, 'B+');
	insert into takes values('43432', '486', '1', 'Fall', 2009, 'C ');
	insert into takes values('50365', '304', '1', 'Fall', 2009, 'C+');
	insert into takes values('35198', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('65299', '702', '1', 'Spring', 2001, 'C+');
	insert into takes values('36657', '445', '1', 'Spring', 2001, 'B+');
	insert into takes values('98830', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('69732', '338', '2', 'Spring', 2006, 'A+');
	insert into takes values('1884', '443', '2', 'Spring', 2002, 'B ');
	insert into takes values('88417', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('76743', '200', '1', 'Spring', 2007, 'B-');
	insert into takes values('67033', '352', '1', 'Spring', 2006, 'B+');
	insert into takes values('48776', '867', '1', 'Fall', 2006, 'B+');
	insert into takes values('75560', '486', '1', 'Fall', 2009, 'A ');
	insert into takes values('76798', '304', '1', 'Fall', 2009, 'C-');
	insert into takes values('79170', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('931', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('44271', '200', '1', 'Spring', 2007, 'C-');
	insert into takes values('85534', '694', '1', 'Fall', 2002, 'C+');
	insert into takes values('66293', '476', '1', 'Fall', 2010, 'B+');
	insert into takes values('12078', '795', '1', 'Spring', 2004, 'B ');
	insert into takes values('18007', '696', '1', 'Spring', 2002, 'B-');
	insert into takes values('1367', '599', '1', 'Spring', 2003, 'A ');
	insert into takes values('55915', '791', '1', 'Spring', 2006, 'C+');
	insert into takes values('29002', '802', '1', 'Spring', 2003, 'A+');
	insert into takes values('64164', '426', '1', 'Spring', 2006, 'A+');
	insert into takes values('41299', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('52371', '169', '1', 'Spring', 2007, 'B+');
	insert into takes values('21225', '313', '1', 'Fall', 2010, 'C-');
	insert into takes values('7854', '692', '1', 'Spring', 2010, 'A ');
	insert into takes values('30182', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('46655', '875', '1', 'Spring', 2005, 'B+');
	insert into takes values('30222', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('39881', '258', '1', 'Fall', 2007, 'B+');
	insert into takes values('75116', '400', '1', 'Spring', 2007, 'B ');
	insert into takes values('69222', '366', '1', 'Fall', 2005, 'B ');
	insert into takes values('2139', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('10736', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('44271', '401', '1', 'Fall', 2003, 'B+');
	insert into takes values('60366', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('52929', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('28829', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('44038', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('48009', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('48423', '313', '1', 'Fall', 2010, 'A ');
	insert into takes values('26802', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('80247', '468', '1', 'Fall', 2005, 'A ');
	insert into takes values('12563', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('7656', '457', '1', 'Spring', 2001, 'B-');
	insert into takes values('16133', '169', '2', 'Fall', 2002, 'B-');
	insert into takes values('80420', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('52750', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('76246', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('22268', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('30650', '591', '1', 'Spring', 2005, 'C+');
	insert into takes values('89106', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('2201', '791', '1', 'Spring', 2006, 'A ');
	insert into takes values('83557', '443', '2', 'Spring', 2002, 'C-');
	insert into takes values('28994', '270', '1', 'Spring', 2010, 'C-');
	insert into takes values('34386', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('75928', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('82083', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('85887', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('73268', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('1826', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('31302', '612', '1', 'Fall', 2007, 'A+');
	insert into takes values('40457', '338', '1', 'Spring', 2007, 'C-');
	insert into takes values('72669', '626', '1', 'Fall', 2006, 'A ');
	insert into takes values('27044', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('16993', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('1232', '960', '2', 'Fall', 2006, 'B-');
	insert into takes values('17086', '169', '1', 'Spring', 2007, 'B ');
	insert into takes values('22170', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('3639', '426', '1', 'Spring', 2006, 'A+');
	insert into takes values('96193', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('80976', '158', '2', 'Spring', 2008, 'A ');
	insert into takes values('98843', '105', '2', 'Fall', 2002, 'B-');
	insert into takes values('84704', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('29959', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('34331', '258', '1', 'Fall', 2007, 'B-');
	insert into takes values('79210', '408', '1', 'Spring', 2007, 'A ');
	insert into takes values('76224', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('65443', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('32772', '319', '1', 'Spring', 2003, 'C+');
	insert into takes values('14023', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('1018', '468', '1', 'Fall', 2005, 'B ');
	insert into takes values('99369', '960', '1', 'Fall', 2009, 'C-');
	insert into takes values('13028', '366', '1', 'Fall', 2005, 'A+');
	insert into takes values('49214', '461', '1', 'Fall', 2002, 'B-');
	insert into takes values('23794', '852', '1', 'Spring', 2008, 'C+');
	insert into takes values('81638', '338', '2', 'Spring', 2006, 'B+');
	insert into takes values('96153', '893', '1', 'Fall', 2007, 'B-');
	insert into takes values('57107', '696', '1', 'Spring', 2002, 'C-');
	insert into takes values('19293', '802', '1', 'Spring', 2003, 'C+');
	insert into takes values('63489', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('99694', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('16035', '445', '1', 'Spring', 2001, 'A-');
	insert into takes values('14628', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('11604', '545', '1', 'Fall', 2001, 'A+');
	insert into takes values('94620', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('65056', '702', '1', 'Spring', 2001, 'A-');
	insert into takes values('96324', '304', '1', 'Fall', 2009, 'B ');
	insert into takes values('16907', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('6523', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('83136', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('37219', '791', '1', 'Spring', 2006, 'A ');
	insert into takes values('55238', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('60406', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('51955', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('67542', '875', '1', 'Spring', 2005, 'C ');
	insert into takes values('20540', '237', '2', 'Fall', 2009, 'B+');
	insert into takes values('15030', '571', '1', 'Spring', 2004, 'A+');
	insert into takes values('82083', '893', '1', 'Fall', 2007, 'B+');
	insert into takes values('7602', '962', '1', 'Spring', 2008, 'B ');
	insert into takes values('45300', '242', '1', 'Fall', 2009, 'A ');
	insert into takes values('26494', '581', '1', 'Spring', 2005, 'A+');
	insert into takes values('91132', '791', '1', 'Spring', 2006, 'A ');
	insert into takes values('50206', '843', '1', 'Fall', 2010, 'B-');
	insert into takes values('85754', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('95089', '482', '1', 'Fall', 2005, 'A+');
	insert into takes values('94697', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('32483', '631', '1', 'Spring', 2007, 'A-');
	insert into takes values('41973', '591', '1', 'Spring', 2005, 'A-');
	insert into takes values('86806', '793', '1', 'Spring', 2002, 'A ');
	insert into takes values('50013', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('75082', '258', '1', 'Fall', 2007, 'C ');
	insert into takes values('91799', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('13365', '457', '1', 'Spring', 2001, 'C+');
	insert into takes values('23344', '629', '1', 'Spring', 2003, 'A+');
	insert into takes values('14563', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('36995', '852', '1', 'Spring', 2008, 'B ');
	insert into takes values('33107', '959', '1', 'Fall', 2006, 'B ');
	insert into takes values('10267', '242', '1', 'Fall', 2009, 'B ');
	insert into takes values('83003', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('33201', '581', '1', 'Spring', 2005, 'C ');
	insert into takes values('59455', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('98047', '486', '1', 'Fall', 2009, 'C ');
	insert into takes values('72643', '338', '2', 'Spring', 2006, 'B+');
	insert into takes values('71387', '445', '1', 'Spring', 2001, 'C ');
	insert into takes values('20195', '239', '1', 'Fall', 2006, 'B-');
	insert into takes values('23934', '486', '1', 'Fall', 2009, 'A-');
	insert into takes values('52876', '270', '1', 'Spring', 2010, 'C ');
	insert into takes values('68720', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('7498', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('26147', '192', '1', 'Fall', 2002, 'C ');
	insert into takes values('66212', '949', '1', 'Fall', 2007, 'C-');
	insert into takes values('31035', '559', '1', 'Fall', 2002, 'C-');
	insert into takes values('75395', '760', '1', 'Spring', 2004, 'C ');
	insert into takes values('6474', '468', '1', 'Fall', 2005, 'A ');
	insert into takes values('24201', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('89234', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('72643', '443', '2', 'Spring', 2002, 'A ');
	insert into takes values('29390', '893', '1', 'Fall', 2007, 'A-');
	insert into takes values('16523', '415', '1', 'Fall', 2010, 'C ');
	insert into takes values('44271', '642', '1', 'Fall', 2004, 'B-');
	insert into takes values('85910', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('88287', '852', '1', 'Spring', 2008, 'B-');
	insert into takes values('931', '489', '1', 'Fall', 2007, 'B-');
	insert into takes values('21337', '561', '1', 'Fall', 2006, 'C+');
	insert into takes values('163', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('66090', '696', '1', 'Spring', 2002, 'C ');
	insert into takes values('36244', '875', '1', 'Spring', 2005, 'A ');
	insert into takes values('49813', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('84239', '443', '1', 'Spring', 2010, 'B+');
	insert into takes values('36126', '242', '1', 'Fall', 2009, 'A+');
	insert into takes values('75510', '864', '1', 'Spring', 2006, 'C+');
	insert into takes values('19791', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('45002', '735', '1', 'Spring', 2003, 'C ');
	insert into takes values('37869', '457', '1', 'Spring', 2001, 'C-');
	insert into takes values('65563', '867', '1', 'Fall', 2006, 'B+');
	insert into takes values('69952', '704', '1', 'Spring', 2008, 'A+');
	insert into takes values('34158', '748', '1', 'Fall', 2003, 'A-');
	insert into takes values('41211', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('8819', '960', '2', 'Fall', 2006, 'A-');
	insert into takes values('53788', '486', '1', 'Fall', 2009, 'A ');
	insert into takes values('21556', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('28538', '200', '1', 'Spring', 2007, 'C-');
	insert into takes values('46451', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('1954', '493', '1', 'Spring', 2010, 'B+');
	insert into takes values('97590', '200', '2', 'Fall', 2002, 'A+');
	insert into takes values('21102', '864', '1', 'Spring', 2006, 'C-');
	insert into takes values('11152', '843', '1', 'Fall', 2010, 'B-');
	insert into takes values('70572', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('61920', '376', '1', 'Fall', 2006, 'B ');
	insert into takes values('11855', '270', '1', 'Spring', 2010, 'C-');
	insert into takes values('82039', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('2419', '581', '1', 'Spring', 2005, 'A ');
	insert into takes values('63886', '603', '1', 'Fall', 2003, 'C-');
	insert into takes values('69285', '237', '1', 'Spring', 2008, 'B ');
	insert into takes values('69285', '791', '1', 'Spring', 2006, 'C-');
	insert into takes values('47677', '893', '1', 'Fall', 2007, 'B+');
	insert into takes values('25611', '581', '1', 'Spring', 2005, 'C ');
	insert into takes values('92693', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('51549', '561', '1', 'Fall', 2006, 'B-');
	insert into takes values('51997', '867', '1', 'Fall', 2006, 'B+');
	insert into takes values('50038', '867', '2', 'Fall', 2010, 'A-');
	insert into takes values('67051', '991', '1', 'Spring', 2008, 'B ');
	insert into takes values('29140', '237', '2', 'Fall', 2009, 'B+');
	insert into takes values('29390', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('47677', '991', '1', 'Spring', 2008, 'B-');
	insert into takes values('76768', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('34542', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('10033', '493', '1', 'Spring', 2010, 'C-');
	insert into takes values('14874', '445', '1', 'Spring', 2001, 'C ');
	insert into takes values('47001', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('7490', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('79911', '631', '1', 'Spring', 2007, 'A ');
	insert into takes values('78922', '476', '1', 'Fall', 2010, 'C-');
	insert into takes values('77415', '496', '1', 'Fall', 2001, 'C ');
	insert into takes values('21692', '663', '1', 'Spring', 2005, 'C-');
	insert into takes values('6400', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('63860', '991', '1', 'Spring', 2008, 'B ');
	insert into takes values('52750', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('77003', '362', '3', 'Spring', 2008, 'C+');
	insert into takes values('22258', '400', '2', 'Fall', 2003, 'A ');
	insert into takes values('30161', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('37521', '200', '2', 'Fall', 2002, 'A ');
	insert into takes values('21556', '158', '2', 'Spring', 2008, 'B+');
	insert into takes values('1836', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('27366', '960', '1', 'Fall', 2009, 'B+');
	insert into takes values('97694', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('57377', '694', '1', 'Fall', 2002, 'C+');
	insert into takes values('78469', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('85366', '527', '1', 'Fall', 2004, 'B-');
	insert into takes values('22254', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('64196', '626', '1', 'Fall', 2006, 'A-');
	insert into takes values('57107', '626', '1', 'Fall', 2006, 'A-');
	insert into takes values('8457', '791', '1', 'Spring', 2006, 'B+');
	insert into takes values('53424', '239', '1', 'Fall', 2006, 'B ');
	insert into takes values('49244', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('8517', '696', '1', 'Spring', 2002, 'B ');
	insert into takes values('76895', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('51955', '747', '1', 'Spring', 2004, 'C ');
	insert into takes values('29140', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('78911', '270', '1', 'Spring', 2010, 'C ');
	insert into takes values('23110', '561', '1', 'Fall', 2006, 'A-');
	insert into takes values('21126', '200', '2', 'Fall', 2002, 'A+');
	insert into takes values('107', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('64039', '415', '1', 'Fall', 2010, 'B ');
	insert into takes values('54672', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('34770', '694', '1', 'Fall', 2002, 'C+');
	insert into takes values('53048', '581', '1', 'Spring', 2005, 'A-');
	insert into takes values('68720', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('5144', '604', '1', 'Spring', 2009, 'B+');
	insert into takes values('39580', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('39238', '445', '1', 'Spring', 2001, 'B-');
	insert into takes values('66484', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('80227', '591', '1', 'Spring', 2005, 'A+');
	insert into takes values('67583', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('75273', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('83592', '581', '1', 'Spring', 2005, 'B+');
	insert into takes values('39114', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('63560', '493', '1', 'Spring', 2010, 'A-');
	insert into takes values('96117', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('17607', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('52741', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('15144', '867', '1', 'Fall', 2006, 'A-');
	insert into takes values('22620', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('32119', '239', '1', 'Fall', 2006, 'C+');
	insert into takes values('81550', '313', '1', 'Fall', 2010, 'C+');
	insert into takes values('72741', '960', '1', 'Fall', 2009, 'C-');
	insert into takes values('48850', '843', '1', 'Fall', 2010, 'A+');
	insert into takes values('1232', '760', '1', 'Spring', 2004, 'C-');
	insert into takes values('14499', '493', '1', 'Spring', 2010, 'A ');
	insert into takes values('83622', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('67222', '408', '2', 'Spring', 2003, 'C ');
	insert into takes values('67340', '345', '1', 'Spring', 2008, 'B-');
	insert into takes values('53118', '421', '1', 'Fall', 2004, 'C ');
	insert into takes values('66469', '158', '1', 'Fall', 2008, 'A+');
	insert into takes values('86552', '137', '1', 'Spring', 2002, 'A-');
	insert into takes values('78782', '702', '1', 'Spring', 2001, 'B ');
	insert into takes values('80285', '581', '1', 'Spring', 2005, 'A+');
	insert into takes values('75082', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('27950', '793', '1', 'Spring', 2002, 'B+');
	insert into takes values('64249', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('61332', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('51868', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('18338', '748', '1', 'Fall', 2003, 'A-');
	insert into takes values('79469', '496', '1', 'Fall', 2001, 'B-');
	insert into takes values('14484', '408', '2', 'Spring', 2003, 'B ');
	insert into takes values('57185', '694', '1', 'Fall', 2002, 'A+');
	insert into takes values('9114', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('20814', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('26147', '476', '1', 'Fall', 2010, 'A ');
	insert into takes values('58634', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('47379', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('61783', '642', '1', 'Fall', 2004, 'A-');
	insert into takes values('51238', '591', '1', 'Spring', 2005, 'A+');
	insert into takes values('53699', '735', '1', 'Spring', 2003, 'A-');
	insert into takes values('98690', '795', '1', 'Spring', 2004, 'A-');
	insert into takes values('53496', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('88358', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('91788', '457', '1', 'Spring', 2001, 'A-');
	insert into takes values('83170', '237', '1', 'Spring', 2008, 'C+');
	insert into takes values('12362', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('93354', '561', '1', 'Fall', 2006, 'C+');
	insert into takes values('7390', '704', '1', 'Spring', 2008, 'B ');
	insert into takes values('53225', '864', '1', 'Spring', 2006, 'C+');
	insert into takes values('69632', '760', '1', 'Spring', 2004, 'B-');
	insert into takes values('78756', '527', '1', 'Fall', 2004, 'C-');
	insert into takes values('62784', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('42960', '200', '2', 'Fall', 2002, 'A+');
	insert into takes values('40457', '748', '1', 'Fall', 2003, 'B ');
	insert into takes values('79352', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('69081', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('54612', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('67657', '426', '1', 'Spring', 2006, 'A+');
	insert into takes values('4173', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('18740', '962', '1', 'Spring', 2008, 'B ');
	insert into takes values('99694', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('14829', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('90914', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('74796', '694', '1', 'Fall', 2002, 'C+');
	insert into takes values('17133', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('65688', '200', '2', 'Fall', 2002, 'B+');
	insert into takes values('62226', '571', '1', 'Spring', 2004, 'A+');
	insert into takes values('40059', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('17769', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('93708', '345', '1', 'Spring', 2008, 'A+');
	insert into takes values('55238', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('2629', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('7854', '376', '1', 'Fall', 2006, 'B-');
	insert into takes values('38899', '852', '1', 'Spring', 2008, 'B+');
	insert into takes values('46035', '457', '1', 'Spring', 2001, 'B+');
	insert into takes values('39241', '692', '1', 'Spring', 2010, 'B-');
	insert into takes values('90132', '345', '1', 'Spring', 2008, 'B-');
	insert into takes values('43226', '345', '1', 'Spring', 2008, 'C+');
	insert into takes values('57780', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('11195', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('4015', '493', '1', 'Spring', 2010, 'C+');
	insert into takes values('79170', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('95859', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('69730', '169', '2', 'Fall', 2002, 'A-');
	insert into takes values('52945', '376', '1', 'Fall', 2006, 'B+');
	insert into takes values('1080', '808', '1', 'Fall', 2003, 'A+');
	insert into takes values('7973', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('46155', '974', '1', 'Fall', 2003, 'C-');
	insert into takes values('53799', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('77218', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('15086', '158', '1', 'Fall', 2008, 'B+');
	insert into takes values('31560', '443', '2', 'Spring', 2002, 'B+');
	insert into takes values('37856', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('22003', '629', '1', 'Spring', 2003, 'A+');
	insert into takes values('74911', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('88045', '158', '1', 'Fall', 2008, 'A-');
	insert into takes values('8517', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('51817', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('93366', '338', '2', 'Spring', 2006, 'C+');
	insert into takes values('46066', '496', '1', 'Fall', 2001, 'B-');
	insert into takes values('53699', '599', '1', 'Spring', 2003, 'B-');
	insert into takes values('49244', '338', '1', 'Spring', 2007, 'B-');
	insert into takes values('5005', '581', '1', 'Spring', 2005, 'A ');
	insert into takes values('78434', '304', '1', 'Fall', 2009, 'C-');
	insert into takes values('6729', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('39925', '927', '1', 'Fall', 2002, 'C ');
	insert into takes values('39978', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('8843', '362', '2', 'Fall', 2006, 'C-');
	insert into takes values('45650', '319', '1', 'Spring', 2003, 'C+');
	insert into takes values('79205', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('69758', '591', '1', 'Spring', 2005, 'A+');
	insert into takes values('26730', '476', '1', 'Fall', 2010, 'A ');
	insert into takes values('65714', '468', '1', 'Fall', 2005, 'B ');
	insert into takes values('6195', '702', '1', 'Spring', 2001, 'A-');
	insert into takes values('94257', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('72643', '421', '1', 'Fall', 2004, 'C-');
	insert into takes values('42298', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('77130', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('10814', '493', '1', 'Spring', 2010, 'C-');
	insert into takes values('32217', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('336', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('16250', '631', '1', 'Spring', 2007, 'C-');
	insert into takes values('69752', '747', '1', 'Spring', 2004, 'C ');
	insert into takes values('57026', '875', '1', 'Spring', 2005, 'A-');
	insert into takes values('65714', '334', '1', 'Fall', 2009, 'C ');
	insert into takes values('37946', '352', '1', 'Spring', 2006, 'C-');
	insert into takes values('62754', '242', '1', 'Fall', 2009, 'B ');
	insert into takes values('2629', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('1220', '158', '1', 'Fall', 2008, 'A-');
	insert into takes values('77244', '852', '1', 'Spring', 2008, 'B+');
	insert into takes values('81638', '802', '1', 'Spring', 2003, 'C-');
	insert into takes values('34236', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('49813', '561', '1', 'Fall', 2006, 'A-');
	insert into takes values('92659', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('19245', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('5871', '561', '1', 'Fall', 2006, 'C-');
	insert into takes values('4682', '631', '1', 'Spring', 2007, 'A-');
	insert into takes values('29645', '400', '1', 'Spring', 2007, 'C-');
	insert into takes values('99073', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('17377', '867', '2', 'Fall', 2010, 'B-');
	insert into takes values('30252', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('5381', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('87706', '972', '1', 'Spring', 2009, 'C-');
	insert into takes values('69752', '443', '2', 'Spring', 2002, 'C-');
	insert into takes values('53485', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('53805', '612', '1', 'Fall', 2007, 'B+');
	insert into takes values('79446', '696', '1', 'Spring', 2002, 'B-');
	insert into takes values('11262', '200', '1', 'Spring', 2007, 'C ');
	insert into takes values('81638', '443', '2', 'Spring', 2002, 'C ');
	insert into takes values('3487', '735', '2', 'Spring', 2010, 'A+');
	insert into takes values('45002', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('827', '258', '1', 'Fall', 2007, 'C+');
	insert into takes values('90381', '468', '1', 'Fall', 2005, 'C+');
	insert into takes values('53077', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('21552', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('8252', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('34404', '362', '2', 'Fall', 2006, 'B-');
	insert into takes values('49280', '468', '2', 'Fall', 2007, 'A+');
	insert into takes values('645', '461', '1', 'Fall', 2002, 'B ');
	insert into takes values('89059', '793', '1', 'Spring', 2002, 'B+');
	insert into takes values('27140', '408', '1', 'Spring', 2007, 'B ');
	insert into takes values('9408', '468', '2', 'Fall', 2007, 'C+');
	insert into takes values('92849', '400', '2', 'Fall', 2003, 'A+');
	insert into takes values('39901', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('70389', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('19862', '158', '1', 'Fall', 2008, 'A+');
	insert into takes values('91992', '345', '1', 'Spring', 2008, 'A+');
	insert into takes values('4449', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('52494', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('37946', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('76291', '893', '1', 'Fall', 2007, 'C ');
	insert into takes values('28352', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('83002', '581', '1', 'Spring', 2005, 'A ');
	insert into takes values('69225', '991', '1', 'Spring', 2008, 'B ');
	insert into takes values('67793', '612', '1', 'Fall', 2007, 'A+');
	insert into takes values('71543', '376', '1', 'Fall', 2006, 'A-');
	insert into takes values('64724', '258', '1', 'Fall', 2007, 'C ');
	insert into takes values('46436', '603', '1', 'Fall', 2003, 'B-');
	insert into takes values('70359', '972', '1', 'Spring', 2009, 'A-');
	insert into takes values('7390', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('107', '679', '1', 'Spring', 2010, 'A+');
	insert into takes values('17424', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('32772', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('21009', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('65038', '927', '1', 'Fall', 2002, 'A-');
	insert into takes values('62716', '545', '1', 'Fall', 2001, 'A-');
	insert into takes values('36995', '304', '1', 'Fall', 2009, 'C-');
	insert into takes values('68453', '696', '1', 'Spring', 2002, 'B+');
	insert into takes values('4645', '313', '1', 'Fall', 2010, 'B-');
	insert into takes values('2561', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('123', '493', '1', 'Spring', 2010, 'C-');
	insert into takes values('21225', '793', '1', 'Spring', 2002, 'A-');
	insert into takes values('87624', '408', '2', 'Spring', 2003, 'A ');
	insert into takes values('8457', '242', '1', 'Fall', 2009, 'A+');
	insert into takes values('74796', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('4435', '400', '1', 'Spring', 2007, 'B+');
	insert into takes values('62373', '581', '1', 'Spring', 2005, 'A+');
	insert into takes values('69628', '692', '1', 'Spring', 2010, 'A ');
	insert into takes values('90353', '692', '1', 'Spring', 2010, 'A-');
	insert into takes values('96615', '489', '1', 'Fall', 2007, 'B ');
	insert into takes values('65144', '338', '2', 'Spring', 2006, 'C+');
	insert into takes values('27956', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('96895', '679', '1', 'Spring', 2010, 'B ');
	insert into takes values('81610', '972', '1', 'Spring', 2009, 'A+');
	insert into takes values('61854', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('16993', '735', '1', 'Spring', 2003, 'A ');
	insert into takes values('18234', '972', '1', 'Spring', 2009, 'C ');
	insert into takes values('21086', '527', '1', 'Fall', 2004, 'B-');
	insert into takes values('5898', '496', '1', 'Fall', 2001, 'B ');
	insert into takes values('4645', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('75547', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('56078', '169', '1', 'Spring', 2007, 'B-');
	insert into takes values('77898', '237', '2', 'Fall', 2009, 'B+');
	insert into takes values('69850', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('13880', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('82970', '482', '1', 'Fall', 2005, 'A-');
	insert into takes values('29705', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('78454', '105', '1', 'Fall', 2009, 'B+');
	insert into takes values('10033', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('94730', '793', '1', 'Spring', 2002, 'A+');
	insert into takes values('11262', '962', '1', 'Spring', 2008, 'A+');
	insert into takes values('17769', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('61003', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('52371', '457', '1', 'Spring', 2001, 'C-');
	insert into takes values('87965', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('7514', '571', '1', 'Spring', 2004, 'C+');
	insert into takes values('83003', '158', '1', 'Fall', 2008, 'A-');
	insert into takes values('78434', '158', '2', 'Spring', 2008, 'B+');
	insert into takes values('20803', '571', '1', 'Spring', 2004, 'A-');
	insert into takes values('58300', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('36685', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('49205', '192', '1', 'Fall', 2002, 'C ');
	insert into takes values('38712', '366', '1', 'Fall', 2005, 'A ');
	insert into takes values('72669', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('36265', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('15578', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('1285', '338', '1', 'Spring', 2007, 'A+');
	insert into takes values('90567', '747', '1', 'Spring', 2004, 'A ');
	insert into takes values('33094', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('46155', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('41988', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('39310', '747', '1', 'Spring', 2004, 'B-');
	insert into takes values('77130', '795', '1', 'Spring', 2004, 'B ');
	insert into takes values('94990', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('95626', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('33349', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('52872', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('69581', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('57456', '338', '2', 'Spring', 2006, 'C+');
	insert into takes values('79205', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('99764', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('4182', '443', '2', 'Spring', 2002, 'A+');
	insert into takes values('65563', '571', '1', 'Spring', 2004, 'C+');
	insert into takes values('1726', '457', '1', 'Spring', 2001, 'A-');
	insert into takes values('52876', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('23500', '604', '1', 'Spring', 2009, 'A-');
	insert into takes values('16753', '468', '1', 'Fall', 2005, 'B ');
	insert into takes values('69230', '629', '1', 'Spring', 2003, 'A ');
	insert into takes values('49450', '338', '2', 'Spring', 2006, 'A-');
	insert into takes values('90181', '408', '1', 'Spring', 2007, 'C-');
	insert into takes values('71529', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('29705', '748', '1', 'Fall', 2003, 'C-');
	insert into takes values('16528', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('72768', '137', '1', 'Spring', 2002, 'C-');
	insert into takes values('17377', '694', '1', 'Fall', 2002, 'B ');
	insert into takes values('19362', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('93039', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('29002', '137', '1', 'Spring', 2002, 'B ');
	insert into takes values('67371', '949', '1', 'Fall', 2007, 'C ');
	insert into takes values('43993', '242', '1', 'Fall', 2009, 'C-');
	insert into takes values('40276', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('58355', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('68453', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('84410', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('1018', '200', '2', 'Fall', 2002, 'B-');
	insert into takes values('33759', '949', '1', 'Fall', 2007, 'C+');
	insert into takes values('75046', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('78552', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('67146', '408', '1', 'Spring', 2007, 'B ');
	insert into takes values('44258', '486', '1', 'Fall', 2009, 'A-');
	insert into takes values('35220', '105', '1', 'Fall', 2009, 'C ');
	insert into takes values('92703', '493', '1', 'Spring', 2010, 'B+');
	insert into takes values('68712', '415', '1', 'Fall', 2010, 'C+');
	insert into takes values('51008', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('37103', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('82697', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('18286', '443', '1', 'Spring', 2010, 'B ');
	insert into takes values('72528', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('75116', '864', '1', 'Spring', 2006, 'A ');
	insert into takes values('73328', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('87048', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('98140', '559', '1', 'Fall', 2002, 'C-');
	insert into takes values('5005', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('88085', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('52876', '304', '1', 'Fall', 2009, 'A+');
	insert into takes values('32376', '603', '1', 'Fall', 2003, 'B-');
	insert into takes values('1087', '192', '1', 'Fall', 2002, 'A+');
	insert into takes values('94814', '972', '1', 'Spring', 2009, 'A-');
	insert into takes values('32490', '489', '1', 'Fall', 2007, 'C+');
	insert into takes values('46337', '629', '1', 'Spring', 2003, 'B+');
	insert into takes values('11855', '581', '1', 'Spring', 2005, 'A-');
	insert into takes values('52134', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('56212', '352', '1', 'Spring', 2006, 'C ');
	insert into takes values('10693', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('21246', '200', '1', 'Spring', 2007, 'A ');
	insert into takes values('29390', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('14581', '426', '1', 'Spring', 2006, 'A ');
	insert into takes values('75878', '960', '1', 'Fall', 2009, 'B ');
	insert into takes values('21337', '642', '1', 'Fall', 2004, 'B+');
	insert into takes values('89571', '274', '1', 'Fall', 2002, 'A+');
	insert into takes values('95626', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('99348', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('55859', '376', '1', 'Fall', 2006, 'C+');
	insert into takes values('75513', '158', '1', 'Fall', 2008, 'A-');
	insert into takes values('86753', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('15249', '237', '1', 'Spring', 2008, 'B+');
	insert into takes values('40276', '663', '1', 'Spring', 2005, 'C ');
	insert into takes values('68150', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('65208', '692', '1', 'Spring', 2010, 'B-');
	insert into takes values('8860', '476', '1', 'Fall', 2010, 'B+');
	insert into takes values('45680', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('8140', '960', '2', 'Fall', 2006, 'B-');
	insert into takes values('75241', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('67024', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('13504', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('80057', '692', '1', 'Spring', 2010, 'C-');
	insert into takes values('760', '893', '1', 'Fall', 2007, 'C+');
	insert into takes values('32130', '793', '1', 'Spring', 2002, 'B+');
	insert into takes values('30017', '612', '1', 'Fall', 2007, 'B ');
	insert into takes values('46442', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('52076', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('67310', '960', '2', 'Fall', 2006, 'A-');
	insert into takes values('46981', '631', '1', 'Spring', 2007, 'A+');
	insert into takes values('90082', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('88085', '415', '1', 'Fall', 2010, 'C ');
	insert into takes values('78143', '493', '1', 'Spring', 2010, 'C-');
	insert into takes values('71543', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('10454', '581', '1', 'Spring', 2005, 'C+');
	insert into takes values('94814', '400', '1', 'Spring', 2007, 'C ');
	insert into takes values('90381', '694', '1', 'Fall', 2002, 'A ');
	insert into takes values('87280', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('71631', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('71630', '972', '1', 'Spring', 2009, 'A+');
	insert into takes values('32419', '408', '1', 'Spring', 2007, 'C-');
	insert into takes values('32385', '802', '1', 'Spring', 2003, 'A+');
	insert into takes values('11152', '105', '1', 'Fall', 2009, 'A+');
	insert into takes values('65563', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('79772', '345', '1', 'Spring', 2008, 'B-');
	insert into takes values('90220', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('16250', '476', '1', 'Fall', 2010, 'B ');
	insert into takes values('77234', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('65101', '559', '1', 'Fall', 2002, 'A-');
	insert into takes values('30896', '893', '1', 'Fall', 2007, 'B ');
	insert into takes values('98359', '192', '1', 'Fall', 2002, 'A+');
	insert into takes values('95260', '334', '1', 'Fall', 2009, 'C ');
	insert into takes values('35498', '237', '1', 'Spring', 2008, 'A+');
	insert into takes values('18108', '748', '1', 'Fall', 2003, 'B ');
	insert into takes values('20974', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('41683', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('9947', '426', '1', 'Spring', 2006, 'C ');
	insert into takes values('67560', '426', '1', 'Spring', 2006, 'A ');
	insert into takes values('67033', '793', '1', 'Spring', 2002, 'A-');
	insert into takes values('72055', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('48678', '852', '1', 'Spring', 2008, 'C+');
	insert into takes values('13757', '105', '1', 'Fall', 2009, 'C+');
	insert into takes values('32245', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('93491', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('41450', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('50977', '362', '3', 'Spring', 2008, 'C-');
	insert into takes values('85680', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('70098', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('85680', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('15430', '808', '1', 'Fall', 2003, 'A+');
	insert into takes values('22417', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('29665', '864', '1', 'Spring', 2006, 'C-');
	insert into takes values('96324', '629', '1', 'Spring', 2003, 'B ');
	insert into takes values('85211', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('39514', '426', '1', 'Spring', 2006, 'B ');
	insert into takes values('66106', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('81638', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('37653', '972', '1', 'Spring', 2009, 'A ');
	insert into takes values('73328', '694', '1', 'Fall', 2002, 'B ');
	insert into takes values('62754', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('75123', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('33349', '457', '1', 'Spring', 2001, 'B+');
	insert into takes values('60040', '545', '1', 'Fall', 2001, 'C ');
	insert into takes values('63361', '591', '1', 'Spring', 2005, 'B ');
	insert into takes values('69132', '443', '1', 'Spring', 2010, 'A ');
	insert into takes values('76246', '352', '1', 'Spring', 2006, 'B ');
	insert into takes values('52291', '158', '1', 'Fall', 2008, 'A+');
	insert into takes values('5005', '791', '1', 'Spring', 2006, 'A ');
	insert into takes values('63288', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('39927', '679', '1', 'Spring', 2010, 'A ');
	insert into takes values('21100', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('18367', '345', '1', 'Spring', 2008, 'B-');
	insert into takes values('42956', '642', '1', 'Fall', 2004, 'A-');
	insert into takes values('77729', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('13511', '338', '2', 'Spring', 2006, 'A-');
	insert into takes values('74796', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('80227', '468', '1', 'Fall', 2005, 'B-');
	insert into takes values('90082', '237', '1', 'Spring', 2008, 'C-');
	insert into takes values('41988', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('1737', '696', '1', 'Spring', 2002, 'C+');
	insert into takes values('42019', '694', '1', 'Fall', 2002, 'B-');
	insert into takes values('62832', '960', '2', 'Fall', 2006, 'C ');
	insert into takes values('44258', '345', '1', 'Spring', 2008, 'A ');
	insert into takes values('8378', '875', '1', 'Spring', 2005, 'C ');
	insert into takes values('63289', '694', '1', 'Fall', 2002, 'C+');
	insert into takes values('16993', '599', '1', 'Spring', 2003, 'A-');
	insert into takes values('41280', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('53077', '626', '1', 'Fall', 2006, 'A-');
	insert into takes values('15340', '415', '1', 'Fall', 2010, 'A+');
	insert into takes values('25362', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('89414', '591', '1', 'Spring', 2005, 'B ');
	insert into takes values('65208', '443', '2', 'Spring', 2002, 'C+');
	insert into takes values('26802', '457', '1', 'Spring', 2001, 'A-');
	insert into takes values('17076', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('16480', '663', '1', 'Spring', 2005, 'A-');
	insert into takes values('57242', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('91616', '748', '1', 'Fall', 2003, 'C-');
	insert into takes values('5703', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('1727', '959', '1', 'Fall', 2006, 'B ');
	insert into takes values('82066', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('12069', '972', '1', 'Spring', 2009, 'A ');
	insert into takes values('75252', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('19450', '421', '1', 'Fall', 2004, 'C-');
	insert into takes values('66090', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('82974', '559', '1', 'Fall', 2002, 'C-');
	insert into takes values('64249', '169', '1', 'Spring', 2007, 'C ');
	insert into takes values('95859', '443', '1', 'Spring', 2010, 'B ');
	insert into takes values('87054', '200', '2', 'Fall', 2002, 'C-');
	insert into takes values('23992', '852', '1', 'Spring', 2008, 'B ');
	insert into takes values('25331', '493', '1', 'Spring', 2010, 'A+');
	insert into takes values('12078', '642', '1', 'Fall', 2004, 'C+');
	insert into takes values('98843', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('35935', '559', '1', 'Fall', 2002, 'A-');
	insert into takes values('94730', '443', '1', 'Spring', 2010, 'B-');
	insert into takes values('64140', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('16885', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('64169', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('15030', '629', '1', 'Spring', 2003, 'B+');
	insert into takes values('65688', '927', '1', 'Fall', 2002, 'A+');
	insert into takes values('99977', '571', '1', 'Spring', 2004, 'C+');
	insert into takes values('85754', '559', '1', 'Fall', 2002, 'C-');
	insert into takes values('83871', '795', '1', 'Spring', 2004, 'B ');
	insert into takes values('44584', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('17607', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('18499', '239', '1', 'Fall', 2006, 'B ');
	insert into takes values('10814', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('27044', '169', '1', 'Spring', 2007, 'A ');
	insert into takes values('56276', '603', '1', 'Fall', 2003, 'B+');
	insert into takes values('83214', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('40992', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('5250', '704', '1', 'Spring', 2008, 'A+');
	insert into takes values('85614', '629', '1', 'Spring', 2003, 'A+');
	insert into takes values('99760', '468', '1', 'Fall', 2005, 'A-');
	insert into takes values('1827', '338', '2', 'Spring', 2006, 'B+');
	insert into takes values('62520', '408', '1', 'Spring', 2007, 'C-');
	insert into takes values('89759', '158', '2', 'Spring', 2008, 'C+');
	insert into takes values('37339', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('16057', '864', '1', 'Spring', 2006, 'C+');
	insert into takes values('95850', '493', '1', 'Spring', 2010, 'A ');
	insert into takes values('83204', '258', '1', 'Fall', 2007, 'B-');
	insert into takes values('3493', '313', '1', 'Fall', 2010, 'A ');
	insert into takes values('16593', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('41596', '893', '1', 'Fall', 2007, 'C ');
	insert into takes values('24387', '400', '2', 'Fall', 2003, 'A ');
	insert into takes values('58606', '137', '1', 'Spring', 2002, 'B+');
	insert into takes values('84845', '426', '1', 'Spring', 2006, 'A ');
	insert into takes values('33107', '200', '2', 'Fall', 2002, 'B+');
	insert into takes values('80990', '200', '2', 'Fall', 2002, 'A+');
	insert into takes values('48611', '237', '2', 'Fall', 2009, 'C ');
	insert into takes values('3335', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('99611', '376', '1', 'Fall', 2006, 'B+');
	insert into takes values('123', '137', '1', 'Spring', 2002, 'B+');
	insert into takes values('41988', '663', '1', 'Spring', 2005, 'A ');
	insert into takes values('63538', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('39901', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('34422', '486', '1', 'Fall', 2009, 'B ');
	insert into takes values('41345', '959', '1', 'Fall', 2006, 'A-');
	insert into takes values('7514', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('5017', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('99268', '242', '1', 'Fall', 2009, 'A-');
	insert into takes values('19848', '362', '3', 'Spring', 2008, 'C+');
	insert into takes values('57985', '352', '1', 'Spring', 2006, 'C+');
	insert into takes values('36244', '237', '1', 'Spring', 2008, 'A+');
	insert into takes values('48471', '974', '1', 'Fall', 2003, 'C-');
	insert into takes values('76173', '443', '2', 'Spring', 2002, 'A-');
	insert into takes values('75791', '338', '1', 'Spring', 2007, 'A+');
	insert into takes values('94801', '362', '1', 'Fall', 2005, 'B ');
	insert into takes values('39657', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('67340', '561', '1', 'Fall', 2006, 'C ');
	insert into takes values('14432', '362', '2', 'Fall', 2006, 'A-');
	insert into takes values('33882', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('22226', '962', '1', 'Spring', 2008, 'A ');
	insert into takes values('34170', '237', '1', 'Spring', 2008, 'A-');
	insert into takes values('28361', '972', '1', 'Spring', 2009, 'B-');
	insert into takes values('12173', '629', '1', 'Spring', 2003, 'A+');
	insert into takes values('14596', '258', '1', 'Fall', 2007, 'A ');
	insert into takes values('87439', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('13921', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('81785', '843', '1', 'Fall', 2010, 'A+');
	insert into takes values('77898', '319', '1', 'Spring', 2003, 'A-');
	insert into takes values('11966', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('27043', '400', '2', 'Fall', 2003, 'A+');
	insert into takes values('28977', '927', '1', 'Fall', 2002, 'A+');
	insert into takes values('17377', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('22179', '304', '1', 'Fall', 2009, 'A+');
	insert into takes values('21766', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('37734', '362', '1', 'Fall', 2005, 'C-');
	insert into takes values('24796', '415', '1', 'Fall', 2010, 'B-');
	insert into takes values('37818', '631', '1', 'Spring', 2007, 'B ');
	insert into takes values('70362', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('17607', '893', '1', 'Fall', 2007, 'C ');
	insert into takes values('29435', '376', '1', 'Fall', 2006, 'B ');
	insert into takes values('81638', '376', '1', 'Fall', 2006, 'A ');
	insert into takes values('23475', '974', '1', 'Fall', 2003, 'C ');
	insert into takes values('31086', '445', '1', 'Spring', 2001, 'B-');
	insert into takes values('76173', '338', '1', 'Spring', 2007, 'C+');
	insert into takes values('84410', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('3127', '313', '1', 'Fall', 2010, 'A+');
	insert into takes values('64121', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('68396', '561', '1', 'Fall', 2006, 'C ');
	insert into takes values('64893', '527', '1', 'Fall', 2004, 'C ');
	insert into takes values('63310', '972', '1', 'Spring', 2009, 'B ');
	insert into takes values('29031', '629', '1', 'Spring', 2003, 'A+');
	insert into takes values('18338', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('61166', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('15086', '974', '1', 'Fall', 2003, 'C-');
	insert into takes values('20540', '793', '1', 'Spring', 2002, 'C ');
	insert into takes values('507', '338', '1', 'Spring', 2007, 'B-');
	insert into takes values('68278', '791', '1', 'Spring', 2006, 'A ');
	insert into takes values('8343', '748', '1', 'Fall', 2003, 'C ');
	insert into takes values('63489', '949', '1', 'Fall', 2007, 'C-');
	insert into takes values('94142', '486', '1', 'Fall', 2009, 'A ');
	insert into takes values('77664', '626', '1', 'Fall', 2006, 'A-');
	insert into takes values('24796', '445', '1', 'Spring', 2001, 'C ');
	insert into takes values('67583', '927', '1', 'Fall', 2002, 'A ');
	insert into takes values('83002', '352', '1', 'Spring', 2006, 'C ');
	insert into takes values('62520', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('92274', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('78434', '237', '1', 'Spring', 2008, 'A+');
	insert into takes values('69132', '867', '2', 'Fall', 2010, 'C-');
	insert into takes values('48678', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('4682', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('47627', '959', '1', 'Fall', 2006, 'C+');
	insert into takes values('49280', '679', '1', 'Spring', 2010, 'B+');
	insert into takes values('79772', '959', '1', 'Fall', 2006, 'A+');
	insert into takes values('10454', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('76173', '376', '1', 'Fall', 2006, 'A-');
	insert into takes values('14563', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('90448', '795', '1', 'Spring', 2004, 'B+');
	insert into takes values('21008', '561', '1', 'Fall', 2006, 'C+');
	insert into takes values('97868', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('56849', '421', '1', 'Fall', 2004, 'C ');
	insert into takes values('13408', '319', '1', 'Spring', 2003, 'C-');
	insert into takes values('91370', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('72186', '735', '2', 'Spring', 2010, 'A-');
	insert into takes values('66813', '591', '1', 'Spring', 2005, 'A+');
	insert into takes values('45083', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('288', '959', '1', 'Fall', 2006, 'C+');
	insert into takes values('21100', '237', '2', 'Fall', 2009, 'C+');
	insert into takes values('67660', '867', '2', 'Fall', 2010, 'B-');
	insert into takes values('11530', '313', '1', 'Fall', 2010, 'B ');
	insert into takes values('29514', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('12216', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('21246', '158', '2', 'Spring', 2008, 'B-');
	insert into takes values('89759', '376', '1', 'Fall', 2006, 'B+');
	insert into takes values('69471', '443', '1', 'Spring', 2010, 'B+');
	insert into takes values('75510', '591', '1', 'Spring', 2005, 'A+');
	insert into takes values('44258', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('51416', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('47126', '421', '1', 'Fall', 2004, 'C ');
	insert into takes values('23994', '612', '1', 'Fall', 2007, 'A-');
	insert into takes values('70099', '496', '1', 'Fall', 2001, 'C-');
	insert into takes values('7973', '974', '1', 'Fall', 2003, 'C-');
	insert into takes values('50386', '493', '1', 'Spring', 2010, 'C ');
	insert into takes values('73072', '338', '1', 'Spring', 2007, 'A+');
	insert into takes values('13741', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('792', '599', '1', 'Spring', 2003, 'C ');
	insert into takes values('64259', '663', '1', 'Spring', 2005, 'C ');
	insert into takes values('32506', '527', '1', 'Fall', 2004, 'B+');
	insert into takes values('40558', '486', '1', 'Fall', 2009, 'B ');
	insert into takes values('95697', '443', '2', 'Spring', 2002, 'A-');
	insert into takes values('52371', '158', '1', 'Fall', 2008, 'A+');
	insert into takes values('73394', '349', '1', 'Spring', 2008, 'A-');
	insert into takes values('73908', '105', '2', 'Fall', 2002, 'A ');
	insert into takes values('23311', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('53788', '760', '1', 'Spring', 2004, 'C ');
	insert into takes values('23344', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('33107', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('28409', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('6990', '345', '1', 'Spring', 2008, 'C+');
	insert into takes values('11237', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('42625', '258', '1', 'Fall', 2007, 'B-');
	insert into takes values('18469', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('15430', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('70452', '960', '1', 'Fall', 2009, 'C-');
	insert into takes values('93004', '345', '1', 'Spring', 2008, 'B-');
	insert into takes values('15578', '237', '2', 'Fall', 2009, 'C-');
	insert into takes values('2423', '493', '1', 'Spring', 2010, 'C-');
	insert into takes values('50977', '960', '1', 'Fall', 2009, 'A+');
	insert into takes values('38555', '760', '1', 'Spring', 2004, 'B-');
	insert into takes values('61783', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('46450', '237', '2', 'Fall', 2009, 'C-');
	insert into takes values('435', '489', '1', 'Fall', 2007, 'B ');
	insert into takes values('38555', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('50365', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('80227', '527', '1', 'Fall', 2004, 'C ');
	insert into takes values('37734', '334', '1', 'Fall', 2009, 'A-');
	insert into takes values('83747', '962', '1', 'Spring', 2008, 'A ');
	insert into takes values('93986', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('53225', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('1726', '493', '1', 'Spring', 2010, 'A ');
	insert into takes values('85211', '105', '2', 'Fall', 2002, 'A ');
	insert into takes values('63489', '443', '1', 'Spring', 2010, 'C+');
	insert into takes values('50039', '496', '1', 'Fall', 2001, 'B ');
	insert into takes values('30222', '735', '2', 'Spring', 2010, 'A-');
	insert into takes values('48861', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('37038', '169', '2', 'Fall', 2002, 'B+');
	insert into takes values('57511', '571', '1', 'Spring', 2004, 'A+');
	insert into takes values('31820', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('22226', '493', '1', 'Spring', 2010, 'B+');
	insert into takes values('86127', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('22004', '692', '1', 'Spring', 2010, 'C+');
	insert into takes values('85234', '352', '1', 'Spring', 2006, 'A+');
	insert into takes values('46762', '169', '2', 'Fall', 2002, 'A+');
	insert into takes values('80698', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('50013', '760', '1', 'Spring', 2004, 'B+');
	insert into takes values('1367', '949', '1', 'Fall', 2007, 'B ');
	insert into takes values('4940', '748', '1', 'Fall', 2003, 'C-');
	insert into takes values('7287', '561', '1', 'Fall', 2006, 'A+');
	insert into takes values('90381', '735', '1', 'Spring', 2003, 'C+');
	insert into takes values('78858', '960', '2', 'Fall', 2006, 'A ');
	insert into takes values('15340', '808', '1', 'Fall', 2003, 'A+');
	insert into takes values('78792', '457', '1', 'Spring', 2001, 'B-');
	insert into takes values('49503', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('10904', '696', '1', 'Spring', 2002, 'B+');
	insert into takes values('47379', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('19862', '493', '1', 'Spring', 2010, 'A+');
	insert into takes values('3005', '893', '1', 'Fall', 2007, 'B-');
	insert into takes values('67051', '959', '1', 'Fall', 2006, 'A+');
	insert into takes values('3833', '612', '1', 'Fall', 2007, 'A-');
	insert into takes values('85614', '105', '2', 'Fall', 2002, 'C+');
	insert into takes values('13081', '527', '1', 'Fall', 2004, 'B-');
	insert into takes values('98690', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('32506', '237', '1', 'Spring', 2008, 'B+');
	insert into takes values('48901', '362', '2', 'Fall', 2006, 'B-');
	insert into takes values('13028', '400', '2', 'Fall', 2003, 'B+');
	insert into takes values('72055', '629', '1', 'Spring', 2003, 'A+');
	insert into takes values('50598', '169', '1', 'Spring', 2007, 'B-');
	insert into takes values('85063', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('96772', '274', '1', 'Fall', 2002, 'A+');
	insert into takes values('68242', '482', '1', 'Fall', 2005, 'B-');
	insert into takes values('31086', '991', '1', 'Spring', 2008, 'B ');
	insert into takes values('65400', '629', '1', 'Spring', 2003, 'B-');
	insert into takes values('42096', '631', '1', 'Spring', 2007, 'A+');
	insert into takes values('95029', '362', '2', 'Fall', 2006, 'C-');
	insert into takes values('15487', '663', '1', 'Spring', 2005, 'B-');
	insert into takes values('81258', '599', '1', 'Spring', 2003, 'A ');
	insert into takes values('90124', '760', '1', 'Spring', 2004, 'A-');
	insert into takes values('58701', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('67407', '843', '1', 'Fall', 2010, 'A+');
	insert into takes values('914', '949', '1', 'Fall', 2007, 'C-');
	insert into takes values('62754', '960', '1', 'Fall', 2009, 'B ');
	insert into takes values('56598', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('22417', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('69960', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('34055', '105', '2', 'Fall', 2002, 'B+');
	insert into takes values('74672', '875', '1', 'Spring', 2005, 'B+');
	insert into takes values('77172', '696', '1', 'Spring', 2002, 'C-');
	insert into takes values('56499', '457', '1', 'Spring', 2001, 'A ');
	insert into takes values('79892', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('15144', '603', '1', 'Fall', 2003, 'B-');
	insert into takes values('19862', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('44038', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('74672', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('37430', '604', '1', 'Spring', 2009, 'B-');
	insert into takes values('40481', '735', '1', 'Spring', 2003, 'A-');
	insert into takes values('79534', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('75938', '867', '2', 'Fall', 2010, 'A-');
	insert into takes values('84702', '362', '2', 'Fall', 2006, 'A-');
	insert into takes values('39204', '875', '1', 'Spring', 2005, 'A+');
	insert into takes values('85602', '400', '2', 'Fall', 2003, 'B-');
	insert into takes values('23311', '493', '1', 'Spring', 2010, 'A-');
	insert into takes values('63288', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('10527', '362', '1', 'Fall', 2005, 'C ');
	insert into takes values('33837', '169', '1', 'Spring', 2007, 'B-');
	insert into takes values('8957', '443', '1', 'Spring', 2010, 'C ');
	insert into takes values('80285', '603', '1', 'Fall', 2003, 'C-');
	insert into takes values('95852', '137', '1', 'Spring', 2002, 'A ');
	insert into takes values('25187', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('507', '345', '1', 'Spring', 2008, 'C ');
	insert into takes values('43495', '338', '2', 'Spring', 2006, 'A ');
	insert into takes values('55329', '864', '1', 'Spring', 2006, 'C-');
	insert into takes values('64196', '169', '2', 'Fall', 2002, 'B+');
	insert into takes values('97023', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('84239', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('94142', '258', '1', 'Fall', 2007, 'A+');
	insert into takes values('73206', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('21086', '793', '1', 'Spring', 2002, 'B+');
	insert into takes values('65205', '242', '1', 'Fall', 2009, 'B+');
	insert into takes values('9183', '545', '1', 'Fall', 2001, 'A+');
	insert into takes values('95320', '362', '1', 'Fall', 2005, 'C-');
	insert into takes values('99399', '604', '1', 'Spring', 2009, 'B-');
	insert into takes values('25528', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('72768', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('63860', '599', '1', 'Spring', 2003, 'B ');
	insert into takes values('89312', '445', '1', 'Spring', 2001, 'C ');
	insert into takes values('86736', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('4345', '960', '1', 'Fall', 2009, 'A+');
	insert into takes values('82063', '692', '1', 'Spring', 2010, 'C ');
	insert into takes values('61444', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('9605', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('22260', '366', '1', 'Fall', 2005, 'A+');
	insert into takes values('36926', '591', '1', 'Spring', 2005, 'B+');
	insert into takes values('17076', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('97629', '105', '2', 'Fall', 2002, 'A+');
	insert into takes values('58701', '696', '1', 'Spring', 2002, 'B ');
	insert into takes values('57083', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('7514', '169', '2', 'Fall', 2002, 'B+');
	insert into takes values('97629', '313', '1', 'Fall', 2010, 'B+');
	insert into takes values('94766', '169', '2', 'Fall', 2002, 'B+');
	insert into takes values('46769', '927', '1', 'Fall', 2002, 'C+');
	insert into takes values('76768', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('23525', '457', '1', 'Spring', 2001, 'C+');
	insert into takes values('56139', '476', '1', 'Fall', 2010, 'A ');
	insert into takes values('35293', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('46762', '704', '1', 'Spring', 2008, 'C-');
	insert into takes values('36102', '486', '1', 'Fall', 2009, 'C ');
	insert into takes values('21552', '334', '1', 'Fall', 2009, 'C ');
	insert into takes values('58919', '791', '1', 'Spring', 2006, 'C+');
	insert into takes values('1402', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('17377', '105', '1', 'Fall', 2009, 'C ');
	insert into takes values('95320', '696', '1', 'Spring', 2002, 'B-');
	insert into takes values('30341', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('86001', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('83838', '258', '1', 'Fall', 2007, 'B-');
	insert into takes values('70395', '629', '1', 'Spring', 2003, 'B+');
	insert into takes values('96227', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('95175', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('96968', '319', '1', 'Spring', 2003, 'A-');
	insert into takes values('65400', '793', '1', 'Spring', 2002, 'B+');
	insert into takes values('37219', '319', '1', 'Spring', 2003, 'C+');
	insert into takes values('69747', '626', '1', 'Fall', 2006, 'A-');
	insert into takes values('7490', '808', '1', 'Fall', 2003, 'A+');
	insert into takes values('55531', '137', '1', 'Spring', 2002, 'A-');
	insert into takes values('1018', '476', '1', 'Fall', 2010, 'B+');
	insert into takes values('84410', '158', '1', 'Fall', 2008, 'B-');
	insert into takes values('5298', '158', '1', 'Fall', 2008, 'B+');
	insert into takes values('67222', '313', '1', 'Fall', 2010, 'B-');
	insert into takes values('29803', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('46442', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('13217', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('28518', '629', '1', 'Spring', 2003, 'B+');
	insert into takes values('50537', '400', '1', 'Spring', 2007, 'C-');
	insert into takes values('61854', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('96052', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('47025', '237', '2', 'Fall', 2009, 'A ');
	insert into takes values('6523', '313', '1', 'Fall', 2010, 'B-');
	insert into takes values('50038', '527', '1', 'Fall', 2004, 'B+');
	insert into takes values('1220', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('40682', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('91992', '486', '1', 'Fall', 2009, 'B ');
	insert into takes values('94730', '242', '1', 'Fall', 2009, 'B ');
	insert into takes values('21009', '408', '1', 'Spring', 2007, 'C ');
	insert into takes values('66469', '793', '1', 'Spring', 2002, 'A ');
	insert into takes values('29705', '158', '1', 'Fall', 2008, 'B+');
	insert into takes values('79170', '366', '1', 'Fall', 2005, 'A+');
	insert into takes values('1018', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('86651', '319', '1', 'Spring', 2003, 'C-');
	insert into takes values('99289', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('78787', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('82970', '304', '1', 'Fall', 2009, 'C-');
	insert into takes values('25187', '200', '1', 'Spring', 2007, 'A ');
	insert into takes values('40738', '875', '1', 'Spring', 2005, 'C ');
	insert into takes values('50039', '400', '1', 'Spring', 2007, 'C-');
	insert into takes values('30182', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('61737', '313', '1', 'Fall', 2010, 'B+');
	insert into takes values('41832', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('73606', '169', '1', 'Spring', 2007, 'B-');
	insert into takes values('86736', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('64164', '795', '1', 'Spring', 2004, 'B-');
	insert into takes values('17507', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('15070', '270', '1', 'Spring', 2010, 'C-');
	insert into takes values('8251', '362', '3', 'Spring', 2008, 'A+');
	insert into takes values('72501', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('83136', '591', '1', 'Spring', 2005, 'C-');
	insert into takes values('16528', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('94990', '362', '3', 'Spring', 2008, 'C-');
	insert into takes values('64067', '443', '2', 'Spring', 2002, 'A-');
	insert into takes values('39619', '338', '2', 'Spring', 2006, 'C ');
	insert into takes values('77234', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('72177', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('19638', '603', '1', 'Fall', 2003, 'C-');
	insert into takes values('88793', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('99710', '362', '1', 'Fall', 2005, 'C+');
	insert into takes values('66281', '137', '1', 'Spring', 2002, 'B ');
	insert into takes values('53699', '400', '1', 'Spring', 2007, 'C-');
	insert into takes values('68330', '599', '1', 'Spring', 2003, 'C ');
	insert into takes values('50467', '793', '1', 'Spring', 2002, 'C-');
	insert into takes values('39114', '696', '1', 'Spring', 2002, 'C-');
	insert into takes values('98056', '626', '1', 'Fall', 2006, 'B+');
	insert into takes values('73411', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('35498', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('74016', '735', '1', 'Spring', 2003, 'C+');
	insert into takes values('13880', '864', '1', 'Spring', 2006, 'C+');
	insert into takes values('45826', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('43993', '158', '1', 'Fall', 2008, 'B-');
	insert into takes values('12971', '493', '1', 'Spring', 2010, 'C ');
	insert into takes values('80698', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('30164', '927', '1', 'Fall', 2002, 'A+');
	insert into takes values('56089', '591', '1', 'Spring', 2005, 'B+');
	insert into takes values('55859', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('11055', '457', '1', 'Spring', 2001, 'C+');
	insert into takes values('73411', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('8517', '991', '1', 'Spring', 2008, 'C-');
	insert into takes values('56882', '338', '1', 'Spring', 2007, 'C-');
	insert into takes values('43912', '679', '1', 'Spring', 2010, 'A ');
	insert into takes values('57242', '599', '1', 'Spring', 2003, 'A+');
	insert into takes values('53490', '362', '3', 'Spring', 2008, 'C-');
	insert into takes values('10705', '408', '1', 'Spring', 2007, 'C ');
	insert into takes values('82868', '169', '2', 'Fall', 2002, 'B ');
	insert into takes values('42991', '415', '1', 'Fall', 2010, 'C+');
	insert into takes values('49873', '313', '1', 'Fall', 2010, 'C ');
	insert into takes values('90448', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('34197', '631', '1', 'Spring', 2007, 'C+');
	insert into takes values('12979', '843', '1', 'Fall', 2010, 'C+');
	insert into takes values('69628', '893', '1', 'Fall', 2007, 'B ');
	insert into takes values('41894', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('33107', '631', '1', 'Spring', 2007, 'C+');
	insert into takes values('12362', '852', '1', 'Spring', 2008, 'C+');
	insert into takes values('57431', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('92464', '338', '2', 'Spring', 2006, 'C+');
	insert into takes values('56212', '408', '2', 'Spring', 2003, 'C-');
	insert into takes values('97065', '496', '1', 'Fall', 2001, 'B+');
	insert into takes values('41280', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('22532', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('24197', '158', '2', 'Spring', 2008, 'C+');
	insert into takes values('75299', '158', '2', 'Spring', 2008, 'A-');
	insert into takes values('72528', '960', '1', 'Fall', 2009, 'B+');
	insert into takes values('58172', '696', '1', 'Spring', 2002, 'C ');
	insert into takes values('20445', '959', '1', 'Fall', 2006, 'A-');
	insert into takes values('67017', '679', '1', 'Spring', 2010, 'B ');
	insert into takes values('76953', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('63449', '991', '1', 'Spring', 2008, 'A ');
	insert into takes values('94535', '694', '1', 'Fall', 2002, 'A ');
	insert into takes values('94998', '400', '2', 'Fall', 2003, 'A+');
	insert into takes values('7970', '169', '1', 'Spring', 2007, 'B ');
	insert into takes values('49982', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('73606', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('49339', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('45002', '192', '1', 'Fall', 2002, 'A+');
	insert into takes values('31364', '105', '1', 'Fall', 2009, 'B ');
	insert into takes values('13749', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('77729', '352', '1', 'Spring', 2006, 'A+');
	insert into takes values('39657', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('25528', '629', '1', 'Spring', 2003, 'A ');
	insert into takes values('61854', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('17607', '962', '1', 'Spring', 2008, 'A+');
	insert into takes values('90567', '345', '1', 'Spring', 2008, 'C+');
	insert into takes values('38545', '793', '1', 'Spring', 2002, 'C-');
	insert into takes values('77364', '362', '1', 'Fall', 2005, 'B ');
	insert into takes values('81031', '200', '2', 'Fall', 2002, 'B+');
	insert into takes values('68278', '852', '1', 'Spring', 2008, 'B ');
	insert into takes values('82083', '571', '1', 'Spring', 2004, 'A+');
	insert into takes values('33882', '461', '1', 'Fall', 2002, 'C-');
	insert into takes values('92464', '612', '1', 'Fall', 2007, 'B+');
	insert into takes values('12173', '808', '1', 'Fall', 2003, 'A-');
	insert into takes values('56212', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('42560', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('24932', '200', '1', 'Spring', 2007, 'A ');
	insert into takes values('47126', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('82083', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('96052', '843', '1', 'Fall', 2010, 'A ');
	insert into takes values('80610', '239', '1', 'Fall', 2006, 'A-');
	insert into takes values('44271', '927', '1', 'Fall', 2002, 'C+');
	insert into takes values('39115', '304', '1', 'Fall', 2009, 'A+');
	insert into takes values('1737', '237', '1', 'Spring', 2008, 'B+');
	insert into takes values('69225', '843', '1', 'Fall', 2010, 'C+');
	insert into takes values('2178', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('51955', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('12683', '338', '1', 'Spring', 2007, 'B-');
	insert into takes values('60762', '960', '1', 'Fall', 2009, 'A+');
	insert into takes values('76057', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('56124', '545', '1', 'Fall', 2001, 'B-');
	insert into takes values('85910', '476', '1', 'Fall', 2010, 'A ');
	insert into takes values('42960', '362', '3', 'Spring', 2008, 'C-');
	insert into takes values('10076', '949', '1', 'Fall', 2007, 'B ');
	insert into takes values('827', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('90663', '795', '1', 'Spring', 2004, 'B+');
	insert into takes values('74163', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('71025', '237', '1', 'Spring', 2008, 'C-');
	insert into takes values('76743', '426', '1', 'Spring', 2006, 'A+');
	insert into takes values('87439', '974', '1', 'Fall', 2003, 'C-');
	insert into takes values('15517', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('7973', '864', '1', 'Spring', 2006, 'A+');
	insert into takes values('9605', '679', '1', 'Spring', 2010, 'B ');
	insert into takes values('80248', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('50467', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('15517', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('40481', '457', '1', 'Spring', 2001, 'B+');
	insert into takes values('84515', '486', '1', 'Fall', 2009, 'B ');
	insert into takes values('40558', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('62054', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('95205', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('36791', '864', '1', 'Spring', 2006, 'A+');
	insert into takes values('28518', '192', '1', 'Fall', 2002, 'C ');
	insert into takes values('18821', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('98019', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('46928', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('53424', '692', '1', 'Spring', 2010, 'A+');
	insert into takes values('83022', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('72521', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('13023', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('96153', '702', '1', 'Spring', 2001, 'C ');
	insert into takes values('70572', '200', '2', 'Fall', 2002, 'A ');
	insert into takes values('60762', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('90082', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('39157', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('32385', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('17996', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('99694', '345', '1', 'Spring', 2008, 'A-');
	insert into takes values('90779', '401', '1', 'Fall', 2003, 'A-');
	insert into takes values('71630', '747', '1', 'Spring', 2004, 'A ');
	insert into takes values('54605', '795', '1', 'Spring', 2004, 'B+');
	insert into takes values('58170', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('18740', '362', '2', 'Fall', 2006, 'B-');
	insert into takes values('15613', '200', '1', 'Spring', 2007, 'A+');
	insert into takes values('13028', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('92274', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('49611', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('48660', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('92849', '334', '1', 'Fall', 2009, 'B ');
	insert into takes values('6712', '692', '1', 'Spring', 2010, 'C+');
	insert into takes values('75547', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('67017', '960', '2', 'Fall', 2006, 'B+');
	insert into takes values('62124', '443', '1', 'Spring', 2010, 'B-');
	insert into takes values('54728', '239', '1', 'Fall', 2006, 'C-');
	insert into takes values('37038', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('59117', '443', '2', 'Spring', 2002, 'A+');
	insert into takes values('6523', '642', '1', 'Fall', 2004, 'B-');
	insert into takes values('61920', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('95175', '949', '1', 'Fall', 2007, 'C+');
	insert into takes values('96615', '571', '1', 'Spring', 2004, 'B+');
	insert into takes values('54508', '334', '1', 'Fall', 2009, 'B-');
	insert into takes values('46035', '702', '1', 'Spring', 2001, 'A-');
	insert into takes values('69853', '867', '2', 'Fall', 2010, 'B-');
	insert into takes values('15074', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('47487', '352', '1', 'Spring', 2006, 'B+');
	insert into takes values('31516', '927', '1', 'Fall', 2002, 'A ');
	insert into takes values('10834', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('56080', '974', '1', 'Fall', 2003, 'C ');
	insert into takes values('4015', '696', '1', 'Spring', 2002, 'A ');
	insert into takes values('2178', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('86641', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('25331', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('65676', '561', '1', 'Fall', 2006, 'C+');
	insert into takes values('69783', '960', '2', 'Fall', 2006, 'C ');
	insert into takes values('60224', '867', '2', 'Fall', 2010, 'B-');
	insert into takes values('89140', '137', '1', 'Spring', 2002, 'A-');
	insert into takes values('1836', '457', '1', 'Spring', 2001, 'C-');
	insert into takes values('85910', '974', '1', 'Fall', 2003, 'A+');
	insert into takes values('1922', '852', '1', 'Spring', 2008, 'C+');
	insert into takes values('86806', '612', '1', 'Fall', 2007, 'C ');
	insert into takes values('98140', '571', '1', 'Spring', 2004, 'C-');
	insert into takes values('14023', '376', '1', 'Fall', 2006, 'A-');
	insert into takes values('792', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('91343', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('94535', '443', '2', 'Spring', 2002, 'C ');
	insert into takes values('84704', '702', '1', 'Spring', 2001, 'A-');
	insert into takes values('65703', '626', '1', 'Fall', 2006, 'C ');
	insert into takes values('37521', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('10454', '468', '2', 'Fall', 2007, 'C-');
	insert into takes values('22198', '237', '1', 'Spring', 2008, 'C+');
	insert into takes values('14432', '169', '2', 'Fall', 2002, 'B-');
	insert into takes values('7602', '604', '1', 'Spring', 2009, 'A-');
	insert into takes values('19245', '200', '2', 'Fall', 2002, 'A ');
	insert into takes values('9114', '747', '1', 'Spring', 2004, 'B-');
	insert into takes values('35721', '362', '1', 'Fall', 2005, 'C ');
	insert into takes values('30177', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('75547', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('46074', '400', '1', 'Spring', 2007, 'B+');
	insert into takes values('22260', '604', '1', 'Spring', 2009, 'B-');
	insert into takes values('1533', '270', '1', 'Spring', 2010, 'A+');
	insert into takes values('64222', '893', '1', 'Fall', 2007, 'C ');
	insert into takes values('38476', '875', '1', 'Spring', 2005, 'A ');
	insert into takes values('13403', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('85534', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('87048', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('86736', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('83557', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('99268', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('13290', '960', '1', 'Fall', 2009, 'C-');
	insert into takes values('34126', '421', '1', 'Fall', 2004, 'C-');
	insert into takes values('99694', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('65681', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('94620', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('55009', '864', '1', 'Spring', 2006, 'A+');
	insert into takes values('95099', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('32744', '959', '1', 'Fall', 2006, 'A+');
	insert into takes values('76291', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('62487', '334', '1', 'Fall', 2009, 'C-');
	insert into takes values('60748', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('32506', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('70564', '313', '1', 'Fall', 2010, 'A+');
	insert into takes values('18367', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('94894', '237', '2', 'Fall', 2009, 'A-');
	insert into takes values('91580', '527', '1', 'Fall', 2004, 'C+');
	insert into takes values('9440', '735', '2', 'Spring', 2010, 'A ');
	insert into takes values('93004', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('66484', '694', '1', 'Fall', 2002, 'C ');
	insert into takes values('17424', '949', '1', 'Fall', 2007, 'A-');
	insert into takes values('91442', '626', '1', 'Fall', 2006, 'B-');
	insert into takes values('7287', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('30957', '461', '1', 'Fall', 2002, 'B-');
	insert into takes values('86969', '642', '1', 'Fall', 2004, 'A-');
	insert into takes values('20803', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('16297', '489', '1', 'Fall', 2007, 'B+');
	insert into takes values('90004', '105', '1', 'Fall', 2009, 'C-');
	insert into takes values('5703', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('91580', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('43032', '642', '1', 'Fall', 2004, 'A-');
	insert into takes values('37219', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('48660', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('92040', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('8378', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('107', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('23794', '735', '2', 'Spring', 2010, 'C ');
	insert into takes values('31079', '843', '1', 'Fall', 2010, 'C-');
	insert into takes values('8807', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('44836', '493', '1', 'Spring', 2010, 'A-');
	insert into takes values('68516', '362', '2', 'Fall', 2006, 'A ');
	insert into takes values('81028', '864', '1', 'Spring', 2006, 'B+');
	insert into takes values('10814', '591', '1', 'Spring', 2005, 'B+');
	insert into takes values('163', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('56849', '468', '1', 'Fall', 2005, 'A+');
	insert into takes values('66763', '893', '1', 'Fall', 2007, 'B+');
	insert into takes values('62705', '457', '1', 'Spring', 2001, 'B ');
	insert into takes values('71631', '415', '1', 'Fall', 2010, 'C ');
	insert into takes values('41890', '679', '1', 'Spring', 2010, 'C-');
	insert into takes values('95850', '401', '1', 'Fall', 2003, 'A ');
	insert into takes values('64039', '457', '1', 'Spring', 2001, 'B ');
	insert into takes values('69521', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('67425', '748', '1', 'Fall', 2003, 'B ');
	insert into takes values('22086', '242', '1', 'Fall', 2009, 'C-');
	insert into takes values('82970', '696', '1', 'Spring', 2002, 'C-');
	insert into takes values('36379', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('42960', '468', '1', 'Fall', 2005, 'A+');
	insert into takes values('82126', '696', '1', 'Spring', 2002, 'A-');
	insert into takes values('11262', '426', '1', 'Spring', 2006, 'A ');
	insert into takes values('8603', '200', '1', 'Spring', 2007, 'B+');
	insert into takes values('32385', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('70099', '476', '1', 'Fall', 2010, 'B+');
	insert into takes values('50702', '304', '1', 'Fall', 2009, 'A ');
	insert into takes values('96988', '561', '1', 'Fall', 2006, 'B+');
	insert into takes values('92417', '852', '1', 'Spring', 2008, 'C-');
	insert into takes values('2967', '629', '1', 'Spring', 2003, 'B+');
	insert into takes values('70099', '200', '2', 'Fall', 2002, 'C+');
	insert into takes values('92839', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('63582', '304', '1', 'Fall', 2009, 'B+');
	insert into takes values('71628', '158', '1', 'Fall', 2008, 'A ');
	insert into takes values('50467', '631', '1', 'Spring', 2007, 'C-');
	insert into takes values('23224', '591', '1', 'Spring', 2005, 'C-');
	insert into takes values('76224', '843', '1', 'Fall', 2010, 'B-');
	insert into takes values('68554', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('14621', '345', '1', 'Spring', 2008, 'A+');
	insert into takes values('46337', '400', '1', 'Spring', 2007, 'C-');
	insert into takes values('94522', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('29707', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('75231', '304', '1', 'Fall', 2009, 'B+');
	insert into takes values('83314', '791', '1', 'Spring', 2006, 'B+');
	insert into takes values('85746', '747', '1', 'Spring', 2004, 'A ');
	insert into takes values('64155', '591', '1', 'Spring', 2005, 'C+');
	insert into takes values('74639', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('37653', '852', '1', 'Spring', 2008, 'B+');
	insert into takes values('91370', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('85575', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('20002', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('37653', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('12615', '486', '1', 'Fall', 2009, 'C+');
	insert into takes values('15249', '696', '1', 'Spring', 2002, 'C ');
	insert into takes values('49073', '274', '1', 'Fall', 2002, 'A+');
	insert into takes values('64067', '158', '1', 'Fall', 2008, 'C-');
	insert into takes values('44998', '692', '1', 'Spring', 2010, 'C-');
	insert into takes values('24116', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('28316', '415', '1', 'Fall', 2010, 'B+');
	insert into takes values('89414', '642', '1', 'Fall', 2004, 'A-');
	insert into takes values('59848', '105', '1', 'Fall', 2009, 'C ');
	insert into takes values('22142', '679', '1', 'Spring', 2010, 'B-');
	insert into takes values('33401', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('99271', '960', '2', 'Fall', 2006, 'B-');
	insert into takes values('42565', '258', '1', 'Fall', 2007, 'A-');
	insert into takes values('30896', '629', '1', 'Spring', 2003, 'B-');
	insert into takes values('53048', '972', '1', 'Spring', 2009, 'C-');
	insert into takes values('17424', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('48861', '445', '1', 'Spring', 2001, 'C+');
	insert into takes values('3639', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('14284', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('49873', '748', '1', 'Fall', 2003, 'C ');
	insert into takes values('23500', '599', '1', 'Spring', 2003, 'A+');
	insert into takes values('69752', '352', '1', 'Spring', 2006, 'C ');
	insert into takes values('82083', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('11126', '493', '1', 'Spring', 2010, 'B+');
	insert into takes values('87246', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('64550', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('69521', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('56057', '496', '1', 'Fall', 2001, 'A+');
	insert into takes values('5381', '304', '1', 'Fall', 2009, 'B+');
	insert into takes values('15726', '304', '1', 'Fall', 2009, 'A+');
	insert into takes values('78581', '270', '1', 'Spring', 2010, 'C-');
	insert into takes values('36303', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('82646', '319', '1', 'Spring', 2003, 'B ');
	insert into takes values('69230', '362', '3', 'Spring', 2008, 'B ');
	insert into takes values('76743', '338', '1', 'Spring', 2007, 'C-');
	insert into takes values('69132', '571', '1', 'Spring', 2004, 'B+');
	insert into takes values('6673', '408', '2', 'Spring', 2003, 'B-');
	insert into takes values('11453', '959', '1', 'Fall', 2006, 'A ');
	insert into takes values('41683', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('85445', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('58085', '927', '1', 'Fall', 2002, 'A+');
	insert into takes values('4508', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('12216', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('79170', '692', '1', 'Spring', 2010, 'C+');
	insert into takes values('32464', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('34542', '443', '1', 'Spring', 2010, 'A-');
	insert into takes values('44258', '401', '1', 'Fall', 2003, 'A+');
	insert into takes values('52157', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('36102', '158', '2', 'Spring', 2008, 'C-');
	insert into takes values('71529', '192', '1', 'Fall', 2002, 'C-');
	insert into takes values('64945', '401', '1', 'Fall', 2003, 'A+');
	insert into takes values('97679', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('11083', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('22325', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('80057', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('13211', '959', '1', 'Fall', 2006, 'A ');
	insert into takes values('14829', '105', '1', 'Fall', 2009, 'B ');
	insert into takes values('35687', '629', '1', 'Spring', 2003, 'B+');
	insert into takes values('28738', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('72768', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('48009', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('77580', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('89246', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('36263', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('16631', '893', '1', 'Fall', 2007, 'B-');
	insert into takes values('69783', '591', '1', 'Spring', 2005, 'C+');
	insert into takes values('72768', '489', '1', 'Fall', 2007, 'A ');
	insert into takes values('31624', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('39619', '893', '1', 'Fall', 2007, 'B ');
	insert into takes values('19848', '960', '2', 'Fall', 2006, 'A-');
	insert into takes values('30124', '445', '1', 'Spring', 2001, 'C ');
	insert into takes values('9256', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('61998', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('43226', '760', '1', 'Spring', 2004, 'B ');
	insert into takes values('85451', '974', '1', 'Fall', 2003, 'C ');
	insert into takes values('5943', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('47670', '808', '1', 'Fall', 2003, 'B-');
	insert into takes values('69471', '793', '1', 'Spring', 2002, 'A-');
	insert into takes values('2423', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('5843', '893', '1', 'Fall', 2007, 'A-');
	insert into takes values('62152', '366', '1', 'Fall', 2005, 'A ');
	insert into takes values('9114', '362', '3', 'Spring', 2008, 'A+');
	insert into takes values('14484', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('11057', '345', '1', 'Spring', 2008, 'A+');
	insert into takes values('94730', '313', '1', 'Fall', 2010, 'A-');
	insert into takes values('3487', '793', '1', 'Spring', 2002, 'A-');
	insert into takes values('71878', '338', '1', 'Spring', 2007, 'A+');
	insert into takes values('95697', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('91370', '927', '1', 'Fall', 2002, 'A+');
	insert into takes values('96117', '843', '1', 'Fall', 2010, 'C+');
	insert into takes values('24002', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('12979', '258', '1', 'Fall', 2007, 'A ');
	insert into takes values('16993', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('41741', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('81245', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('11201', '468', '1', 'Fall', 2005, 'A ');
	insert into takes values('66356', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('14869', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('40189', '696', '1', 'Spring', 2002, 'A ');
	insert into takes values('52134', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('17997', '972', '1', 'Spring', 2009, 'B+');
	insert into takes values('80990', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('41965', '960', '1', 'Fall', 2009, 'B+');
	insert into takes values('99399', '802', '1', 'Spring', 2003, 'B+');
	insert into takes values('87044', '334', '1', 'Fall', 2009, 'C ');
	insert into takes values('85809', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('10269', '893', '1', 'Fall', 2007, 'B ');
	insert into takes values('75040', '747', '1', 'Spring', 2004, 'B+');
	insert into takes values('98619', '362', '2', 'Fall', 2006, 'A ');
	insert into takes values('13023', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('65753', '408', '2', 'Spring', 2003, 'A+');
	insert into takes values('63582', '949', '1', 'Fall', 2007, 'C ');
	insert into takes values('57377', '679', '1', 'Spring', 2010, 'B-');
	insert into takes values('27952', '864', '1', 'Spring', 2006, 'B ');
	insert into takes values('68150', '875', '1', 'Spring', 2005, 'A+');
	insert into takes values('58595', '559', '1', 'Fall', 2002, 'C+');
	insert into takes values('88389', '604', '1', 'Spring', 2009, 'A ');
	insert into takes values('39580', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('33759', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('59553', '545', '1', 'Fall', 2001, 'B-');
	insert into takes values('41774', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('52945', '959', '1', 'Fall', 2006, 'B ');
	insert into takes values('7020', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('54605', '457', '1', 'Spring', 2001, 'A+');
	insert into takes values('41491', '415', '1', 'Fall', 2010, 'C-');
	insert into takes values('12711', '352', '1', 'Spring', 2006, 'C+');
	insert into takes values('4438', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('91063', '974', '1', 'Fall', 2003, 'A+');
	insert into takes values('91915', '760', '1', 'Spring', 2004, 'C-');
	insert into takes values('85308', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('84410', '443', '2', 'Spring', 2002, 'A-');
	insert into takes values('93814', '808', '1', 'Fall', 2003, 'A+');
	insert into takes values('5017', '735', '1', 'Spring', 2003, 'C ');
	insert into takes values('87651', '960', '2', 'Fall', 2006, 'C+');
	insert into takes values('44551', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('87651', '629', '1', 'Spring', 2003, 'B ');
	insert into takes values('62636', '169', '1', 'Spring', 2007, 'C ');
	insert into takes values('507', '242', '1', 'Fall', 2009, 'A ');
	insert into takes values('50537', '663', '1', 'Spring', 2005, 'C-');
	insert into takes values('39238', '105', '2', 'Fall', 2002, 'A+');
	insert into takes values('86529', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('38013', '366', '1', 'Fall', 2005, 'C-');
	insert into takes values('10556', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('54610', '692', '1', 'Spring', 2010, 'C ');
	insert into takes values('90814', '843', '1', 'Fall', 2010, 'A ');
	insert into takes values('30182', '376', '1', 'Fall', 2006, 'C ');
	insert into takes values('70572', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('16969', '362', '2', 'Fall', 2006, 'C-');
	insert into takes values('85614', '137', '1', 'Spring', 2002, 'B+');
	insert into takes values('62152', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('75082', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('63502', '401', '1', 'Fall', 2003, 'C ');
	insert into takes values('59553', '679', '1', 'Spring', 2010, 'A+');
	insert into takes values('28019', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('72501', '603', '1', 'Fall', 2003, 'A+');
	insert into takes values('73606', '991', '1', 'Spring', 2008, 'C-');
	insert into takes values('91063', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('24010', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('50537', '237', '1', 'Spring', 2008, 'C+');
	insert into takes values('31476', '158', '2', 'Spring', 2008, 'C ');
	insert into takes values('36019', '362', '2', 'Fall', 2006, 'B-');
	insert into takes values('98019', '376', '1', 'Fall', 2006, 'B+');
	insert into takes values('34392', '545', '1', 'Fall', 2001, 'B-');
	insert into takes values('96988', '960', '1', 'Fall', 2009, 'C-');
	insert into takes values('32954', '304', '1', 'Fall', 2009, 'A ');
	insert into takes values('85904', '237', '1', 'Spring', 2008, 'A-');
	insert into takes values('51553', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('58170', '200', '1', 'Spring', 2007, 'B-');
	insert into takes values('35042', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('96722', '313', '1', 'Fall', 2010, 'B+');
	insert into takes values('57135', '408', '2', 'Spring', 2003, 'B ');
	insert into takes values('43505', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('76743', '443', '1', 'Spring', 2010, 'C ');
	insert into takes values('56755', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('8426', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('49813', '362', '2', 'Fall', 2006, 'A ');
	insert into takes values('33645', '962', '1', 'Spring', 2008, 'A ');
	insert into takes values('63090', '760', '1', 'Spring', 2004, 'C+');
	insert into takes values('60040', '457', '1', 'Spring', 2001, 'A-');
	insert into takes values('16969', '599', '1', 'Spring', 2003, 'C+');
	insert into takes values('10705', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('98019', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('88887', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('94324', '482', '1', 'Fall', 2005, 'B ');
	insert into takes values('72358', '200', '2', 'Fall', 2002, 'C-');
	insert into takes values('20180', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('62152', '461', '1', 'Fall', 2002, 'C-');
	insert into takes values('18740', '443', '2', 'Spring', 2002, 'A ');
	insert into takes values('55531', '591', '1', 'Spring', 2005, 'C+');
	insert into takes values('56003', '408', '2', 'Spring', 2003, 'C ');
	insert into takes values('78552', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('19862', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('99369', '338', '1', 'Spring', 2007, 'C ');
	insert into takes values('24932', '631', '1', 'Spring', 2007, 'B ');
	insert into takes values('12078', '468', '2', 'Fall', 2007, 'B ');
	insert into takes values('1232', '679', '1', 'Spring', 2010, 'B-');
	insert into takes values('21556', '486', '1', 'Fall', 2009, 'A ');
	insert into takes values('16250', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('36265', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('50537', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('60867', '489', '1', 'Fall', 2007, 'B-');
	insert into takes values('61332', '486', '1', 'Fall', 2009, 'A-');
	insert into takes values('78756', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('47265', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('74530', '642', '1', 'Fall', 2004, 'A-');
	insert into takes values('90372', '612', '1', 'Fall', 2007, 'A+');
	insert into takes values('68278', '237', '2', 'Fall', 2009, 'C+');
	insert into takes values('99463', '802', '1', 'Spring', 2003, 'B+');
	insert into takes values('38121', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('66813', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('18499', '319', '1', 'Spring', 2003, 'A-');
	insert into takes values('36881', '591', '1', 'Spring', 2005, 'B ');
	insert into takes values('70965', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('39115', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('1460', '581', '1', 'Spring', 2005, 'A-');
	insert into takes values('79352', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('27898', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('97590', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('78758', '663', '1', 'Spring', 2005, 'C ');
	insert into takes values('54620', '808', '1', 'Fall', 2003, 'B-');
	insert into takes values('38668', '319', '1', 'Spring', 2003, 'C+');
	insert into takes values('90089', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('19362', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('98984', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('20180', '362', '3', 'Spring', 2008, 'B ');
	insert into takes values('75510', '791', '1', 'Spring', 2006, 'B+');
	insert into takes values('30334', '843', '1', 'Fall', 2010, 'A ');
	insert into takes values('65190', '105', '2', 'Fall', 2002, 'B+');
	insert into takes values('2795', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('20180', '158', '1', 'Fall', 2008, 'A+');
	insert into takes values('94257', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('39619', '169', '1', 'Spring', 2007, 'C+');
	insert into takes values('84167', '991', '1', 'Spring', 2008, 'B-');
	insert into takes values('4355', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('57666', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('62124', '482', '1', 'Fall', 2005, 'A-');
	insert into takes values('37869', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('10814', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('76049', '808', '1', 'Fall', 2003, 'B-');
	insert into takes values('53077', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('68453', '237', '1', 'Spring', 2008, 'B ');
	insert into takes values('39925', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('13921', '313', '1', 'Fall', 2010, 'C ');
	insert into takes values('13352', '694', '1', 'Fall', 2002, 'A+');
	insert into takes values('53728', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('60984', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('12971', '349', '1', 'Spring', 2008, 'A ');
	insert into takes values('57185', '362', '1', 'Fall', 2005, 'C ');
	insert into takes values('2561', '604', '1', 'Spring', 2009, 'A ');
	insert into takes values('64934', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('27727', '696', '1', 'Spring', 2002, 'B-');
	insert into takes values('85754', '603', '1', 'Fall', 2003, 'B+');
	insert into takes values('39892', '443', '2', 'Spring', 2002, 'A-');
	insert into takes values('57377', '400', '2', 'Fall', 2003, 'B+');
	insert into takes values('71387', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('67655', '239', '1', 'Fall', 2006, 'C-');
	insert into takes values('62124', '604', '1', 'Spring', 2009, 'B ');
	insert into takes values('66269', '313', '1', 'Fall', 2010, 'C+');
	insert into takes values('40932', '426', '1', 'Spring', 2006, 'A ');
	insert into takes values('98388', '169', '1', 'Spring', 2007, 'A-');
	insert into takes values('52019', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('74639', '960', '1', 'Fall', 2009, 'A+');
	insert into takes values('36494', '334', '1', 'Fall', 2009, 'C ');
	insert into takes values('69307', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('93571', '694', '1', 'Fall', 2002, 'B ');
	insert into takes values('45083', '237', '1', 'Spring', 2008, 'A+');
	insert into takes values('75513', '200', '2', 'Fall', 2002, 'C-');
	insert into takes values('38676', '591', '1', 'Spring', 2005, 'A+');
	insert into takes values('88801', '200', '1', 'Spring', 2007, 'A-');
	insert into takes values('67146', '735', '2', 'Spring', 2010, 'B-');
	insert into takes values('17057', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('72657', '960', '2', 'Fall', 2006, 'C ');
	insert into takes values('69521', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('82687', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('33460', '496', '1', 'Fall', 2001, 'C-');
	insert into takes values('47670', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('858', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('1232', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('89759', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('83871', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('83557', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('86404', '867', '2', 'Fall', 2010, 'B-');
	insert into takes values('22396', '493', '1', 'Spring', 2010, 'B+');
	insert into takes values('76953', '313', '1', 'Fall', 2010, 'C-');
	insert into takes values('13511', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('18859', '270', '1', 'Spring', 2010, 'B+');
	insert into takes values('92867', '192', '1', 'Fall', 2002, 'C-');
	insert into takes values('8603', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('58919', '962', '1', 'Spring', 2008, 'A+');
	insert into takes values('39901', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('30188', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('86375', '679', '1', 'Spring', 2010, 'B+');
	insert into takes values('41345', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('56486', '603', '1', 'Fall', 2003, 'B+');
	insert into takes values('16297', '493', '1', 'Spring', 2010, 'A ');
	insert into takes values('16480', '735', '2', 'Spring', 2010, 'A ');
	insert into takes values('28252', '960', '2', 'Fall', 2006, 'B-');
	insert into takes values('14628', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('90089', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('50039', '974', '1', 'Fall', 2003, 'B-');
	insert into takes values('8426', '545', '1', 'Fall', 2001, 'B ');
	insert into takes values('78332', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('28004', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('51817', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('98140', '468', '2', 'Fall', 2007, 'B ');
	insert into takes values('69730', '893', '1', 'Fall', 2007, 'B ');
	insert into takes values('22050', '334', '1', 'Fall', 2009, 'C-');
	insert into takes values('52876', '867', '1', 'Fall', 2006, 'A+');
	insert into takes values('96067', '629', '1', 'Spring', 2003, 'A+');
	insert into takes values('49205', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('88417', '270', '1', 'Spring', 2010, 'C ');
	insert into takes values('8807', '200', '1', 'Spring', 2007, 'C-');
	insert into takes values('81245', '927', '1', 'Fall', 2002, 'C ');
	insert into takes values('336', '679', '1', 'Spring', 2010, 'A ');
	insert into takes values('14554', '400', '1', 'Spring', 2007, 'A ');
	insert into takes values('88887', '421', '1', 'Fall', 2004, 'B-');
	insert into takes values('65299', '959', '1', 'Fall', 2006, 'C+');
	insert into takes values('33206', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('8912', '808', '1', 'Fall', 2003, 'C ');
	insert into takes values('93171', '867', '2', 'Fall', 2010, 'A+');
	insert into takes values('61783', '415', '1', 'Fall', 2010, 'C+');
	insert into takes values('74464', '415', '1', 'Fall', 2010, 'B-');
	insert into takes values('94726', '843', '1', 'Fall', 2010, 'C-');
	insert into takes values('40059', '376', '1', 'Fall', 2006, 'A-');
	insert into takes values('73542', '443', '1', 'Spring', 2010, 'C+');
	insert into takes values('44258', '366', '1', 'Fall', 2005, 'A ');
	insert into takes values('76250', '991', '1', 'Spring', 2008, 'C-');
	insert into takes values('57190', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('40457', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('37521', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('9933', '258', '1', 'Fall', 2007, 'A-');
	insert into takes values('36791', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('62795', '959', '1', 'Fall', 2006, 'A+');
	insert into takes values('6195', '345', '1', 'Spring', 2008, 'C+');
	insert into takes values('28994', '974', '1', 'Fall', 2003, 'A-');
	insert into takes values('10727', '258', '1', 'Fall', 2007, 'B+');
	insert into takes values('22345', '875', '1', 'Spring', 2005, 'C-');
	insert into takes values('80057', '304', '1', 'Fall', 2009, 'C+');
	insert into takes values('46155', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('69758', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('65400', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('76743', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('93571', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('70572', '960', '2', 'Fall', 2006, 'B-');
	insert into takes values('84495', '791', '1', 'Spring', 2006, 'A-');
	insert into takes values('97400', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('89551', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('35721', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('99719', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('11530', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('64914', '793', '1', 'Spring', 2002, 'A ');
	insert into takes values('99422', '663', '1', 'Spring', 2005, 'B ');
	insert into takes values('9605', '169', '2', 'Fall', 2002, 'B ');
	insert into takes values('74016', '200', '1', 'Spring', 2007, 'C-');
	insert into takes values('20445', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('72014', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('98690', '843', '1', 'Fall', 2010, 'A ');
	insert into takes values('26147', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('20195', '735', '1', 'Spring', 2003, 'C-');
	insert into takes values('72669', '482', '1', 'Fall', 2005, 'A+');
	insert into takes values('55859', '468', '2', 'Fall', 2007, 'C-');
	insert into takes values('47379', '599', '1', 'Spring', 2003, 'C+');
	insert into takes values('21766', '408', '1', 'Spring', 2007, 'B ');
	insert into takes values('24442', '443', '1', 'Spring', 2010, 'A-');
	insert into takes values('24325', '704', '1', 'Spring', 2008, 'C-');
	insert into takes values('19321', '927', '1', 'Fall', 2002, 'C-');
	insert into takes values('35042', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('20974', '867', '1', 'Fall', 2006, 'C+');
	insert into takes values('23110', '629', '1', 'Spring', 2003, 'B ');
	insert into takes values('29645', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('4173', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('52471', '400', '2', 'Fall', 2003, 'C+');
	insert into takes values('27950', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('86375', '808', '1', 'Fall', 2003, 'A+');
	insert into takes values('50873', '875', '1', 'Spring', 2005, 'A+');
	insert into takes values('15070', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('32772', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('2501', '376', '1', 'Fall', 2006, 'B ');
	insert into takes values('336', '591', '1', 'Spring', 2005, 'B-');
	insert into takes values('79446', '237', '1', 'Spring', 2008, 'C+');
	insert into takes values('15726', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('24374', '864', '1', 'Spring', 2006, 'A ');
	insert into takes values('18808', '561', '1', 'Fall', 2006, 'A ');
	insert into takes values('75040', '496', '1', 'Fall', 2001, 'C ');
	insert into takes values('62705', '376', '1', 'Fall', 2006, 'B ');
	insert into takes values('67725', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('87015', '362', '3', 'Spring', 2008, 'B ');
	insert into takes values('69225', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('7620', '468', '2', 'Fall', 2007, 'C+');
	insert into takes values('79210', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('51723', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('67310', '237', '1', 'Spring', 2008, 'C+');
	insert into takes values('22417', '408', '1', 'Spring', 2007, 'A+');
	insert into takes values('75522', '612', '1', 'Fall', 2007, 'A-');
	insert into takes values('93653', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('89059', '319', '1', 'Spring', 2003, 'C-');
	insert into takes values('81396', '239', '1', 'Fall', 2006, 'A-');
	insert into takes values('67583', '599', '1', 'Spring', 2003, 'B+');
	insert into takes values('69850', '760', '1', 'Spring', 2004, 'C+');
	insert into takes values('97551', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('12362', '735', '1', 'Spring', 2003, 'C-');
	insert into takes values('66495', '443', '2', 'Spring', 2002, 'B ');
	insert into takes values('17128', '105', '2', 'Fall', 2002, 'A+');
	insert into takes values('28538', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('70452', '242', '1', 'Fall', 2009, 'B ');
	insert into takes values('9114', '629', '1', 'Spring', 2003, 'B-');
	insert into takes values('88472', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('69132', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('28361', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('15340', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('87831', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('92417', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('58846', '561', '1', 'Fall', 2006, 'C-');
	insert into takes values('82591', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('89312', '642', '1', 'Fall', 2004, 'A+');
	insert into takes values('78922', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('99660', '200', '2', 'Fall', 2002, 'C-');
	insert into takes values('39881', '642', '1', 'Fall', 2004, 'B+');
	insert into takes values('89551', '443', '2', 'Spring', 2002, 'C ');
	insert into takes values('35685', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('67024', '679', '1', 'Spring', 2010, 'B ');
	insert into takes values('94569', '959', '1', 'Fall', 2006, 'A+');
	insert into takes values('67024', '852', '1', 'Spring', 2008, 'C-');
	insert into takes values('97953', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('95631', '415', '1', 'Fall', 2010, 'C+');
	insert into takes values('63612', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('51579', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('51955', '696', '1', 'Spring', 2002, 'B-');
	insert into takes values('29665', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('82918', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('99348', '974', '1', 'Fall', 2003, 'A-');
	insert into takes values('80821', '527', '1', 'Fall', 2004, 'A-');
	insert into takes values('48776', '158', '2', 'Spring', 2008, 'C+');
	insert into takes values('23457', '362', '3', 'Spring', 2008, 'A+');
	insert into takes values('39310', '362', '1', 'Fall', 2005, 'C ');
	insert into takes values('95631', '760', '1', 'Spring', 2004, 'C+');
	insert into takes values('10834', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('46450', '489', '1', 'Fall', 2007, 'A-');
	insert into takes values('30943', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('46928', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('32744', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('72177', '559', '1', 'Fall', 2002, 'A-');
	insert into takes values('41751', '362', '1', 'Fall', 2005, 'C-');
	insert into takes values('60867', '319', '1', 'Spring', 2003, 'B-');
	insert into takes values('40059', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('24746', '663', '1', 'Spring', 2005, 'B ');
	insert into takes values('10556', '843', '1', 'Fall', 2010, 'A ');
	insert into takes values('44584', '421', '1', 'Fall', 2004, 'C ');
	insert into takes values('51923', '867', '1', 'Fall', 2006, 'A+');
	insert into takes values('51538', '105', '2', 'Fall', 2002, 'B-');
	insert into takes values('38899', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('51538', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('30397', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('64249', '704', '1', 'Spring', 2008, 'C ');
	insert into takes values('89000', '489', '1', 'Fall', 2007, 'A-');
	insert into takes values('14563', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('84515', '489', '1', 'Fall', 2007, 'A-');
	insert into takes values('47824', '626', '1', 'Fall', 2006, 'B+');
	insert into takes values('36513', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('99289', '362', '2', 'Fall', 2006, 'B-');
	insert into takes values('25256', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('67793', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('10481', '571', '1', 'Spring', 2004, 'C ');
	insert into takes values('22050', '421', '1', 'Fall', 2004, 'C+');
	insert into takes values('74016', '158', '2', 'Spring', 2008, 'A-');
	insert into takes values('8912', '496', '1', 'Fall', 2001, 'B ');
	insert into takes values('52385', '258', '1', 'Fall', 2007, 'A-');
	insert into takes values('259', '927', '1', 'Fall', 2002, 'A-');
	insert into takes values('39927', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('48165', '692', '1', 'Spring', 2010, 'A+');
	insert into takes values('98984', '791', '1', 'Spring', 2006, 'A-');
	insert into takes values('41674', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('19050', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('28952', '400', '1', 'Spring', 2007, 'A ');
	insert into takes values('23449', '426', '1', 'Spring', 2006, 'C ');
	insert into takes values('23457', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('67051', '137', '1', 'Spring', 2002, 'B ');
	insert into takes values('17397', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('92949', '893', '1', 'Fall', 2007, 'A ');
	insert into takes values('3833', '468', '1', 'Fall', 2005, 'B-');
	insert into takes values('44998', '694', '1', 'Fall', 2002, 'B ');
	insert into takes values('53077', '962', '1', 'Spring', 2008, 'C+');
	insert into takes values('75046', '376', '1', 'Fall', 2006, 'B ');
	insert into takes values('15980', '376', '1', 'Fall', 2006, 'B+');
	insert into takes values('51008', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('68779', '304', '1', 'Fall', 2009, 'A ');
	insert into takes values('60267', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('44998', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('33759', '362', '3', 'Spring', 2008, 'B ');
	insert into takes values('68779', '852', '1', 'Spring', 2008, 'B ');
	insert into takes values('28977', '612', '1', 'Fall', 2007, 'B ');
	insert into takes values('48611', '612', '1', 'Fall', 2007, 'B+');
	insert into takes values('53803', '376', '1', 'Fall', 2006, 'A ');
	insert into takes values('70918', '401', '1', 'Fall', 2003, 'B+');
	insert into takes values('79589', '959', '1', 'Fall', 2006, 'C+');
	insert into takes values('71944', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('19862', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('38676', '852', '1', 'Spring', 2008, 'C-');
	insert into takes values('23992', '376', '1', 'Fall', 2006, 'C ');
	insert into takes values('38545', '200', '1', 'Spring', 2007, 'A+');
	insert into takes values('85534', '960', '1', 'Fall', 2009, 'B+');
	insert into takes values('61364', '334', '1', 'Fall', 2009, 'A ');
	insert into takes values('58307', '313', '1', 'Fall', 2010, 'A ');
	insert into takes values('72358', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('82402', '457', '1', 'Spring', 2001, 'B-');
	insert into takes values('62520', '959', '1', 'Fall', 2006, 'B+');
	insert into takes values('39157', '960', '2', 'Fall', 2006, 'B-');
	insert into takes values('96911', '631', '1', 'Spring', 2007, 'B+');
	insert into takes values('37454', '642', '1', 'Fall', 2004, 'A-');
	insert into takes values('37715', '760', '1', 'Spring', 2004, 'B+');
	insert into takes values('39157', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('23794', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('64013', '237', '2', 'Fall', 2009, 'A ');
	insert into takes values('78787', '679', '1', 'Spring', 2010, 'C-');
	insert into takes values('93508', '421', '1', 'Fall', 2004, 'C+');
	insert into takes values('76049', '421', '1', 'Fall', 2004, 'C+');
	insert into takes values('53047', '867', '1', 'Fall', 2006, 'A ');
	insert into takes values('70098', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('38691', '489', '1', 'Fall', 2007, 'B-');
	insert into takes values('91992', '793', '1', 'Spring', 2002, 'C-');
	insert into takes values('12362', '105', '1', 'Fall', 2009, 'B ');
	insert into takes values('31476', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('65715', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('4004', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('4508', '105', '1', 'Fall', 2009, 'A+');
	insert into takes values('70828', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('76057', '612', '1', 'Fall', 2007, 'A+');
	insert into takes values('11422', '334', '1', 'Fall', 2009, 'B ');
	insert into takes values('88417', '599', '1', 'Spring', 2003, 'A+');
	insert into takes values('52866', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('96615', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('96722', '461', '1', 'Fall', 2002, 'C-');
	insert into takes values('22467', '559', '1', 'Fall', 2002, 'A-');
	insert into takes values('34392', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('41671', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('97023', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('44836', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('85887', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('36494', '461', '1', 'Fall', 2002, 'A-');
	insert into takes values('29849', '960', '1', 'Fall', 2009, 'B ');
	insert into takes values('37946', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('18809', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('78143', '421', '1', 'Fall', 2004, 'B-');
	insert into takes values('66969', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('39514', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('99348', '735', '2', 'Spring', 2010, 'B-');
	insert into takes values('66008', '629', '1', 'Spring', 2003, 'B-');
	insert into takes values('90448', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('39876', '200', '2', 'Fall', 2002, 'A-');
	insert into takes values('3640', '338', '1', 'Spring', 2007, 'C+');
	insert into takes values('50658', '679', '1', 'Spring', 2010, 'C-');
	insert into takes values('93125', '631', '1', 'Spring', 2007, 'C-');
	insert into takes values('48589', '401', '1', 'Fall', 2003, 'A-');
	insert into takes values('4435', '571', '1', 'Spring', 2004, 'B+');
	insert into takes values('79170', '169', '1', 'Spring', 2007, 'C+');
	insert into takes values('30896', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('75082', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('15538', '962', '1', 'Spring', 2008, 'A ');
	insert into takes values('33349', '408', '2', 'Spring', 2003, 'B ');
	insert into takes values('41973', '457', '1', 'Spring', 2001, 'B+');
	insert into takes values('86641', '242', '1', 'Fall', 2009, 'B+');
	insert into takes values('69132', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('97590', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('9605', '642', '1', 'Fall', 2004, 'A+');
	insert into takes values('28989', '875', '1', 'Spring', 2005, 'B-');
	insert into takes values('69850', '443', '1', 'Spring', 2010, 'A ');
	insert into takes values('5824', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('81294', '581', '1', 'Spring', 2005, 'A ');
	insert into takes values('82126', '561', '1', 'Fall', 2006, 'C-');
	insert into takes values('4355', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('90009', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('8986', '338', '2', 'Spring', 2006, 'A-');
	insert into takes values('81150', '603', '1', 'Fall', 2003, 'B ');
	insert into takes values('32056', '237', '1', 'Spring', 2008, 'C+');
	insert into takes values('27804', '274', '1', 'Fall', 2002, 'B ');
	insert into takes values('2201', '843', '1', 'Fall', 2010, 'C ');
	insert into takes values('45650', '496', '1', 'Fall', 2001, 'C ');
	insert into takes values('37586', '559', '1', 'Fall', 2002, 'A-');
	insert into takes values('89312', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('11057', '527', '1', 'Fall', 2004, 'B-');
	insert into takes values('96134', '200', '1', 'Spring', 2007, 'A-');
	insert into takes values('33791', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('61998', '760', '1', 'Spring', 2004, 'C+');
	insert into takes values('72622', '631', '1', 'Spring', 2007, 'C+');
	insert into takes values('90004', '747', '1', 'Spring', 2004, 'B+');
	insert into takes values('50743', '319', '1', 'Spring', 2003, 'C-');
	insert into takes values('34569', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('11195', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('13749', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('31101', '960', '1', 'Fall', 2009, 'A+');
	insert into takes values('1727', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('29803', '793', '1', 'Spring', 2002, 'B+');
	insert into takes values('34502', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('92867', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('79210', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('71287', '760', '1', 'Spring', 2004, 'B+');
	insert into takes values('59530', '408', '2', 'Spring', 2003, 'B ');
	insert into takes values('44985', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('42096', '426', '1', 'Spring', 2006, 'A-');
	insert into takes values('81638', '408', '1', 'Spring', 2007, 'C ');
	insert into takes values('62429', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('67018', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('84702', '169', '1', 'Spring', 2007, 'A ');
	insert into takes values('13211', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('89759', '270', '1', 'Spring', 2010, 'B+');
	insert into takes values('41832', '457', '1', 'Spring', 2001, 'B ');
	insert into takes values('5920', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('32954', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('11055', '604', '1', 'Spring', 2009, 'B+');
	insert into takes values('86651', '591', '1', 'Spring', 2005, 'A+');
	insert into takes values('58170', '735', '2', 'Spring', 2010, 'A-');
	insert into takes values('44258', '599', '1', 'Spring', 2003, 'A-');
	insert into takes values('65438', '443', '1', 'Spring', 2010, 'C ');
	insert into takes values('32490', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('74464', '345', '1', 'Spring', 2008, 'B-');
	insert into takes values('52291', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('90914', '808', '1', 'Fall', 2003, 'C ');
	insert into takes values('10481', '443', '2', 'Spring', 2002, 'C ');
	insert into takes values('42096', '401', '1', 'Fall', 2003, 'C-');
	insert into takes values('56486', '626', '1', 'Fall', 2006, 'A-');
	insert into takes values('67407', '443', '1', 'Spring', 2010, 'A ');
	insert into takes values('43432', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('95175', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('64893', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('45826', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('5250', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('88553', '612', '1', 'Fall', 2007, 'B-');
	insert into takes values('92464', '169', '1', 'Spring', 2007, 'A-');
	insert into takes values('83398', '760', '1', 'Spring', 2004, 'B-');
	insert into takes values('28977', '843', '1', 'Fall', 2010, 'C-');
	insert into takes values('77898', '457', '1', 'Spring', 2001, 'A+');
	insert into takes values('21556', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('74639', '760', '1', 'Spring', 2004, 'C-');
	insert into takes values('70522', '496', '1', 'Fall', 2001, 'B-');
	insert into takes values('35905', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('20084', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('8819', '362', '3', 'Spring', 2008, 'A+');
	insert into takes values('42556', '376', '1', 'Fall', 2006, 'A ');
	insert into takes values('41261', '443', '1', 'Spring', 2010, 'B+');
	insert into takes values('8251', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('81207', '192', '1', 'Fall', 2002, 'A+');
	insert into takes values('82301', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('94726', '631', '1', 'Spring', 2007, 'C+');
	insert into takes values('95201', '692', '1', 'Spring', 2010, 'C-');
	insert into takes values('35687', '735', '2', 'Spring', 2010, 'B ');
	insert into takes values('19050', '949', '1', 'Fall', 2007, 'C-');
	insert into takes values('19766', '468', '1', 'Fall', 2005, 'B ');
	insert into takes values('34386', '527', '1', 'Fall', 2004, 'B+');
	insert into takes values('34055', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('95366', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('64121', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('24442', '270', '1', 'Spring', 2010, 'C+');
	insert into takes values('92332', '457', '1', 'Spring', 2001, 'B ');
	insert into takes values('17665', '791', '1', 'Spring', 2006, 'A ');
	insert into takes values('81883', '468', '1', 'Fall', 2005, 'B+');
	insert into takes values('435', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('56276', '493', '1', 'Spring', 2010, 'B+');
	insert into takes values('99764', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('36384', '843', '1', 'Fall', 2010, 'A-');
	insert into takes values('98870', '137', '1', 'Spring', 2002, 'A ');
	insert into takes values('23506', '489', '1', 'Fall', 2007, 'A ');
	insert into takes values('85451', '747', '1', 'Spring', 2004, 'A ');
	insert into takes values('96895', '581', '1', 'Spring', 2005, 'A-');
	insert into takes values('96153', '319', '1', 'Spring', 2003, 'C+');
	insert into takes values('63886', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('5961', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('69471', '489', '1', 'Fall', 2007, 'C+');
	insert into takes values('96741', '426', '1', 'Spring', 2006, 'A-');
	insert into takes values('858', '843', '1', 'Fall', 2010, 'C-');
	insert into takes values('64192', '561', '1', 'Fall', 2006, 'B-');
	insert into takes values('760', '313', '1', 'Fall', 2010, 'A-');
	insert into takes values('93508', '867', '1', 'Fall', 2006, 'C+');
	insert into takes values('48611', '702', '1', 'Spring', 2001, 'C ');
	insert into takes values('8843', '476', '1', 'Fall', 2010, 'A+');
	insert into takes values('78911', '603', '1', 'Fall', 2003, 'B-');
	insert into takes values('71085', '893', '1', 'Fall', 2007, 'A-');
	insert into takes values('34170', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('39580', '237', '1', 'Spring', 2008, 'B+');
	insert into takes values('24201', '642', '1', 'Fall', 2004, 'B+');
	insert into takes values('60748', '791', '1', 'Spring', 2006, 'C+');
	insert into takes values('15283', '559', '1', 'Fall', 2002, 'A-');
	insert into takes values('24325', '242', '1', 'Fall', 2009, 'A-');
	insert into takes values('70918', '489', '1', 'Fall', 2007, 'A-');
	insert into takes values('62549', '258', '1', 'Fall', 2007, 'A-');
	insert into takes values('5243', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('29645', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('25780', '345', '1', 'Spring', 2008, 'C ');
	insert into takes values('10904', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('70061', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('27094', '489', '1', 'Fall', 2007, 'B-');
	insert into takes values('8957', '949', '1', 'Fall', 2007, 'A-');
	insert into takes values('82301', '735', '1', 'Spring', 2003, 'B-');
	insert into takes values('13081', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('51008', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('26080', '496', '1', 'Fall', 2001, 'A-');
	insert into takes values('61402', '443', '1', 'Spring', 2010, 'B+');
	insert into takes values('81984', '349', '1', 'Spring', 2008, 'C-');
	insert into takes values('79205', '415', '1', 'Fall', 2010, 'C ');
	insert into takes values('38973', '867', '1', 'Fall', 2006, 'A-');
	insert into takes values('87268', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('46260', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('65400', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('58300', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('20489', '362', '1', 'Fall', 2005, 'B ');
	insert into takes values('52157', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('94324', '415', '1', 'Fall', 2010, 'A+');
	insert into takes values('32056', '415', '1', 'Fall', 2010, 'A-');
	insert into takes values('26494', '545', '1', 'Fall', 2001, 'A+');
	insert into takes values('62373', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('14032', '735', '1', 'Spring', 2003, 'C-');
	insert into takes values('92867', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('65681', '959', '1', 'Fall', 2006, 'B ');
	insert into takes values('83573', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('46980', '893', '1', 'Fall', 2007, 'A+');
	insert into takes values('76911', '105', '2', 'Fall', 2002, 'C+');
	insert into takes values('6304', '468', '1', 'Fall', 2005, 'C ');
	insert into takes values('35257', '843', '1', 'Fall', 2010, 'A+');
	insert into takes values('18775', '629', '1', 'Spring', 2003, 'A+');
	insert into takes values('46035', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('1018', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('33338', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('14668', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('97551', '400', '1', 'Spring', 2007, 'C-');
	insert into takes values('56080', '468', '1', 'Fall', 2005, 'B+');
	insert into takes values('9408', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('40044', '400', '2', 'Fall', 2003, 'C-');
	insert into takes values('33645', '401', '1', 'Fall', 2003, 'A ');
	insert into takes values('87785', '561', '1', 'Fall', 2006, 'B+');
	insert into takes values('55000', '612', '1', 'Fall', 2007, 'C ');
	insert into takes values('2178', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('59117', '349', '1', 'Spring', 2008, 'A ');
	insert into takes values('93171', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('38371', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('99660', '629', '1', 'Spring', 2003, 'A+');
	insert into takes values('67425', '338', '1', 'Spring', 2007, 'C ');
	insert into takes values('14829', '338', '2', 'Spring', 2006, 'B+');
	insert into takes values('47627', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('28252', '875', '1', 'Spring', 2005, 'C ');
	insert into takes values('57941', '334', '1', 'Fall', 2009, 'B-');
	insert into takes values('56212', '489', '1', 'Fall', 2007, 'C+');
	insert into takes values('9114', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('29665', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('55354', '338', '1', 'Spring', 2007, 'A+');
	insert into takes values('6304', '408', '2', 'Spring', 2003, 'A+');
	insert into takes values('84432', '748', '1', 'Fall', 2003, 'B ');
	insert into takes values('22254', '304', '1', 'Fall', 2009, 'A+');
	insert into takes values('44816', '692', '1', 'Spring', 2010, 'C+');
	insert into takes values('57456', '105', '2', 'Fall', 2002, 'C-');
	insert into takes values('80941', '735', '2', 'Spring', 2010, 'B ');
	insert into takes values('30289', '559', '1', 'Fall', 2002, 'B ');
	insert into takes values('77172', '626', '1', 'Fall', 2006, 'A ');
	insert into takes values('64401', '242', '1', 'Fall', 2009, 'A+');
	insert into takes values('48247', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('33094', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('55859', '137', '1', 'Spring', 2002, 'B ');
	insert into takes values('37818', '642', '1', 'Fall', 2004, 'B-');
	insert into takes values('76911', '694', '1', 'Fall', 2002, 'C+');
	insert into takes values('87054', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('5017', '461', '1', 'Fall', 2002, 'B+');
	insert into takes values('49873', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('58170', '631', '1', 'Spring', 2007, 'A+');
	insert into takes values('46725', '445', '1', 'Spring', 2001, 'A-');
	insert into takes values('81785', '960', '1', 'Fall', 2009, 'A+');
	insert into takes values('9605', '352', '1', 'Spring', 2006, 'A+');
	insert into takes values('3693', '626', '1', 'Fall', 2006, 'C ');
	insert into takes values('78767', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('65979', '561', '1', 'Fall', 2006, 'B+');
	insert into takes values('85234', '747', '1', 'Spring', 2004, 'B+');
	insert into takes values('24197', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('15457', '468', '1', 'Fall', 2005, 'A-');
	insert into takes values('12971', '629', '1', 'Spring', 2003, 'B-');
	insert into takes values('36513', '313', '1', 'Fall', 2010, 'B+');
	insert into takes values('842', '426', '1', 'Spring', 2006, 'B ');
	insert into takes values('76604', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('71768', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('74460', '158', '1', 'Fall', 2008, 'C-');
	insert into takes values('50414', '496', '1', 'Fall', 2001, 'A-');
	insert into takes values('90220', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('9183', '400', '1', 'Spring', 2007, 'C-');
	insert into takes values('80610', '105', '1', 'Fall', 2009, 'C ');
	insert into takes values('80912', '443', '2', 'Spring', 2002, 'A+');
	insert into takes values('83462', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('31080', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('80698', '237', '2', 'Fall', 2009, 'A-');
	insert into takes values('10917', '960', '2', 'Fall', 2006, 'A ');
	insert into takes values('12216', '852', '1', 'Spring', 2008, 'C ');
	insert into takes values('39657', '793', '1', 'Spring', 2002, 'A-');
	insert into takes values('76270', '362', '2', 'Fall', 2006, 'A-');
	insert into takes values('8251', '445', '1', 'Spring', 2001, 'C+');
	insert into takes values('39514', '242', '1', 'Fall', 2009, 'C+');
	insert into takes values('90041', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('22417', '304', '1', 'Fall', 2009, 'B+');
	insert into takes values('24796', '242', '1', 'Fall', 2009, 'B ');
	insert into takes values('29665', '352', '1', 'Spring', 2006, 'A-');
	insert into takes values('8457', '237', '1', 'Spring', 2008, 'B ');
	insert into takes values('37818', '105', '1', 'Fall', 2009, 'A+');
	insert into takes values('41683', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('83398', '972', '1', 'Spring', 2009, 'B-');
	insert into takes values('59538', '603', '1', 'Fall', 2003, 'A ');
	insert into takes values('63489', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('27662', '421', '1', 'Fall', 2004, 'C-');
	insert into takes values('30124', '468', '1', 'Fall', 2005, 'A-');
	insert into takes values('69952', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('35293', '791', '1', 'Spring', 2006, 'B+');
	insert into takes values('89551', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('55009', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('3639', '200', '2', 'Fall', 2002, 'A ');
	insert into takes values('85445', '304', '1', 'Fall', 2009, 'C+');
	insert into takes values('44816', '486', '1', 'Fall', 2009, 'C ');
	insert into takes values('39876', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('31554', '626', '1', 'Fall', 2006, 'B-');
	insert into takes values('71387', '864', '1', 'Spring', 2006, 'C+');
	insert into takes values('61854', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('3127', '486', '1', 'Fall', 2009, 'A-');
	insert into takes values('43348', '631', '1', 'Spring', 2007, 'A-');
	insert into takes values('92949', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('99764', '426', '1', 'Spring', 2006, 'C ');
	insert into takes values('52856', '793', '1', 'Spring', 2002, 'B+');
	insert into takes values('47265', '400', '2', 'Fall', 2003, 'C-');
	insert into takes values('86736', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('86802', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('86327', '793', '1', 'Spring', 2002, 'A-');
	insert into takes values('42625', '599', '1', 'Spring', 2003, 'A-');
	insert into takes values('9993', '319', '1', 'Spring', 2003, 'B ');
	insert into takes values('88884', '486', '1', 'Fall', 2009, 'B-');
	insert into takes values('65681', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('50537', '338', '1', 'Spring', 2007, 'A+');
	insert into takes values('28829', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('11195', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('65241', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('90448', '345', '1', 'Spring', 2008, 'C ');
	insert into takes values('86674', '169', '1', 'Spring', 2007, 'A ');
	insert into takes values('25942', '795', '1', 'Spring', 2004, 'C+');
	insert into takes values('70299', '366', '1', 'Fall', 2005, 'B ');
	insert into takes values('70965', '960', '2', 'Fall', 2006, 'B+');
	insert into takes values('97042', '626', '1', 'Fall', 2006, 'B-');
	insert into takes values('61527', '631', '1', 'Spring', 2007, 'A-');
	insert into takes values('30222', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('76911', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('39521', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('96067', '169', '1', 'Spring', 2007, 'B ');
	insert into takes values('50703', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('96911', '702', '1', 'Spring', 2001, 'C ');
	insert into takes values('6304', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('41675', '571', '1', 'Spring', 2004, 'C ');
	insert into takes values('12214', '237', '2', 'Fall', 2009, 'B+');
	insert into takes values('72177', '426', '1', 'Spring', 2006, 'A-');
	insert into takes values('16515', '457', '1', 'Spring', 2001, 'C-');
	insert into takes values('8807', '376', '1', 'Fall', 2006, 'A-');
	insert into takes values('30289', '457', '1', 'Spring', 2001, 'A+');
	insert into takes values('22198', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('40457', '663', '1', 'Spring', 2005, 'C-');
	insert into takes values('99977', '795', '1', 'Spring', 2004, 'C+');
	insert into takes values('52741', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('13365', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('64259', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('82974', '748', '1', 'Fall', 2003, 'C-');
	insert into takes values('58846', '362', '1', 'Fall', 2005, 'C-');
	insert into takes values('87965', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('62054', '457', '1', 'Spring', 2001, 'C+');
	insert into takes values('14554', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('83696', '426', '1', 'Spring', 2006, 'A-');
	insert into takes values('27804', '692', '1', 'Spring', 2010, 'A+');
	insert into takes values('36926', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('16453', '468', '1', 'Fall', 2005, 'C ');
	insert into takes values('993', '400', '2', 'Fall', 2003, 'A+');
	insert into takes values('54153', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('88884', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('51093', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('68720', '200', '1', 'Spring', 2007, 'A+');
	insert into takes values('51868', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('95626', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('65715', '571', '1', 'Spring', 2004, 'A-');
	insert into takes values('81028', '415', '1', 'Fall', 2010, 'A+');
	insert into takes values('68330', '338', '2', 'Spring', 2006, 'C+');
	insert into takes values('1018', '457', '1', 'Spring', 2001, 'B+');
	insert into takes values('29091', '927', '1', 'Fall', 2002, 'C ');
	insert into takes values('49450', '415', '1', 'Fall', 2010, 'C+');
	insert into takes values('83022', '482', '1', 'Fall', 2005, 'A ');
	insert into takes values('1968', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('20445', '408', '1', 'Spring', 2007, 'B ');
	insert into takes values('66054', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('65205', '461', '1', 'Fall', 2002, 'A-');
	insert into takes values('98984', '105', '2', 'Fall', 2002, 'A ');
	insert into takes values('42991', '612', '1', 'Fall', 2007, 'A ');
	insert into takes values('71630', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('16523', '867', '1', 'Fall', 2006, 'C+');
	insert into takes values('73165', '960', '1', 'Fall', 2009, 'B ');
	insert into takes values('31101', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('78469', '795', '1', 'Spring', 2004, 'C+');
	insert into takes values('94697', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('14032', '486', '1', 'Fall', 2009, 'C ');
	insert into takes values('75510', '345', '1', 'Spring', 2008, 'B-');
	insert into takes values('61402', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('47630', '400', '2', 'Fall', 2003, 'C+');
	insert into takes values('98140', '696', '1', 'Spring', 2002, 'B-');
	insert into takes values('61065', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('99780', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('51975', '345', '1', 'Spring', 2008, 'C+');
	insert into takes values('17207', '493', '1', 'Spring', 2010, 'A+');
	insert into takes values('57925', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('90124', '237', '2', 'Fall', 2009, 'A ');
	insert into takes values('40303', '105', '2', 'Fall', 2002, 'B+');
	insert into takes values('36126', '559', '1', 'Fall', 2002, 'C-');
	insert into takes values('78767', '137', '1', 'Spring', 2002, 'A-');
	insert into takes values('25785', '959', '1', 'Fall', 2006, 'A+');
	insert into takes values('22912', '304', '1', 'Fall', 2009, 'B ');
	insert into takes values('65688', '793', '1', 'Spring', 2002, 'A ');
	insert into takes values('43123', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('39612', '581', '1', 'Spring', 2005, 'C-');
	insert into takes values('25362', '352', '1', 'Spring', 2006, 'C-');
	insert into takes values('90381', '612', '1', 'Fall', 2007, 'C ');
	insert into takes values('83136', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('29140', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('82083', '631', '1', 'Spring', 2007, 'A+');
	insert into takes values('53469', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('6195', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('9460', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('16993', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('76895', '158', '1', 'Fall', 2008, 'B-');
	insert into takes values('66008', '366', '1', 'Fall', 2005, 'A+');
	insert into takes values('19791', '867', '1', 'Fall', 2006, 'A ');
	insert into takes values('97023', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('15487', '362', '2', 'Fall', 2006, 'C-');
	insert into takes values('7490', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('20002', '274', '1', 'Fall', 2002, 'B-');
	insert into takes values('75510', '304', '1', 'Fall', 2009, 'C-');
	insert into takes values('32065', '559', '1', 'Fall', 2002, 'C-');
	insert into takes values('42991', '493', '1', 'Spring', 2010, 'A ');
	insert into takes values('84845', '704', '1', 'Spring', 2008, 'C ');
	insert into takes values('63645', '694', '1', 'Fall', 2002, 'A ');
	insert into takes values('6209', '489', '1', 'Fall', 2007, 'B+');
	insert into takes values('90132', '960', '2', 'Fall', 2006, 'A-');
	insert into takes values('11076', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('59397', '200', '2', 'Fall', 2002, 'C+');
	insert into takes values('52669', '852', '1', 'Spring', 2008, 'B-');
	insert into takes values('26730', '400', '1', 'Spring', 2007, 'A-');
	insert into takes values('75395', '192', '1', 'Fall', 2002, 'C ');
	insert into takes values('74464', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('17944', '852', '1', 'Spring', 2008, 'C+');
	insert into takes values('76895', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('81785', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('69241', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('17377', '242', '1', 'Fall', 2009, 'C-');
	insert into takes values('88302', '461', '1', 'Fall', 2002, 'C+');
	insert into takes values('79911', '443', '2', 'Spring', 2002, 'C+');
	insert into takes values('84495', '443', '2', 'Spring', 2002, 'A-');
	insert into takes values('64934', '974', '1', 'Fall', 2003, 'A-');
	insert into takes values('97042', '489', '1', 'Fall', 2007, 'A ');
	insert into takes values('888', '362', '2', 'Fall', 2006, 'B-');
	insert into takes values('67542', '735', '2', 'Spring', 2010, 'C ');
	insert into takes values('83592', '561', '1', 'Fall', 2006, 'A+');
	insert into takes values('23270', '603', '1', 'Fall', 2003, 'B ');
	insert into takes values('30334', '482', '1', 'Fall', 2005, 'C ');
	insert into takes values('65987', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('55238', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('36926', '959', '1', 'Fall', 2006, 'B+');
	insert into takes values('76895', '200', '1', 'Spring', 2007, 'A+');
	insert into takes values('37454', '604', '1', 'Spring', 2009, 'B+');
	insert into takes values('33201', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('39876', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('83557', '663', '1', 'Spring', 2005, 'C ');
	insert into takes values('51923', '748', '1', 'Fall', 2003, 'C ');
	insert into takes values('46451', '496', '1', 'Fall', 2001, 'A+');
	insert into takes values('56139', '631', '1', 'Spring', 2007, 'C+');
	insert into takes values('28977', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('49618', '663', '1', 'Spring', 2005, 'A-');
	insert into takes values('83557', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('65715', '158', '1', 'Fall', 2008, 'A+');
	insert into takes values('94730', '972', '1', 'Spring', 2009, 'B+');
	insert into takes values('71628', '545', '1', 'Fall', 2001, 'B-');
	insert into takes values('99711', '875', '1', 'Spring', 2005, 'C-');
	insert into takes values('59848', '696', '1', 'Spring', 2002, 'A ');
	insert into takes values('16993', '802', '1', 'Spring', 2003, 'B+');
	insert into takes values('53089', '105', '2', 'Fall', 2002, 'A ');
	insert into takes values('92693', '679', '1', 'Spring', 2010, 'B ');
	insert into takes values('18859', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('40738', '559', '1', 'Fall', 2002, 'C-');
	insert into takes values('57787', '496', '1', 'Fall', 2001, 'B ');
	insert into takes values('61081', '237', '2', 'Fall', 2009, 'B+');
	insert into takes values('94371', '338', '1', 'Spring', 2007, 'A+');
	insert into takes values('83022', '476', '1', 'Fall', 2010, 'B+');
	insert into takes values('57511', '338', '1', 'Spring', 2007, 'A-');
	insert into takes values('99694', '137', '1', 'Spring', 2002, 'B ');
	insert into takes values('14214', '304', '1', 'Fall', 2009, 'B+');
	insert into takes values('50206', '962', '1', 'Spring', 2008, 'A ');
	insert into takes values('64401', '489', '1', 'Fall', 2007, 'B+');
	insert into takes values('1737', '169', '1', 'Spring', 2007, 'A-');
	insert into takes values('46441', '169', '1', 'Spring', 2007, 'C ');
	insert into takes values('78552', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('15074', '345', '1', 'Spring', 2008, 'C+');
	insert into takes values('63489', '408', '1', 'Spring', 2007, 'A ');
	insert into takes values('43432', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('69081', '493', '1', 'Spring', 2010, 'B ');
	insert into takes values('18752', '242', '1', 'Fall', 2009, 'A-');
	insert into takes values('57156', '527', '1', 'Fall', 2004, 'B-');
	insert into takes values('25331', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('37809', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('36052', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('65715', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('30222', '696', '1', 'Spring', 2002, 'C+');
	insert into takes values('58595', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('31820', '376', '1', 'Fall', 2006, 'B ');
	insert into takes values('30110', '400', '2', 'Fall', 2003, 'C-');
	insert into takes values('28518', '603', '1', 'Fall', 2003, 'C-');
	insert into takes values('72622', '795', '1', 'Spring', 2004, 'B ');
	insert into takes values('163', '679', '1', 'Spring', 2010, 'A ');
	insert into takes values('47670', '443', '1', 'Spring', 2010, 'A-');
	insert into takes values('1533', '400', '2', 'Fall', 2003, 'B-');
	insert into takes values('58085', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('50331', '991', '1', 'Spring', 2008, 'C-');
	insert into takes values('40189', '791', '1', 'Spring', 2006, 'C-');
	insert into takes values('52471', '696', '1', 'Spring', 2002, 'B+');
	insert into takes values('29920', '338', '2', 'Spring', 2006, 'B+');
	insert into takes values('31337', '561', '1', 'Fall', 2006, 'C ');
	insert into takes values('40677', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('94569', '468', '1', 'Fall', 2005, 'B ');
	insert into takes values('5393', '702', '1', 'Spring', 2001, 'B-');
	insert into takes values('51868', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('95284', '959', '1', 'Fall', 2006, 'A+');
	insert into takes values('16297', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('97868', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('858', '334', '1', 'Fall', 2009, 'C-');
	insert into takes values('5017', '415', '1', 'Fall', 2010, 'B-');
	insert into takes values('27043', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('57185', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('25331', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('36657', '795', '1', 'Spring', 2004, 'B+');
	insert into takes values('36402', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('7854', '338', '2', 'Spring', 2006, 'A ');
	insert into takes values('25940', '927', '1', 'Fall', 2002, 'C+');
	insert into takes values('163', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('89051', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('48165', '362', '2', 'Fall', 2006, 'C-');
	insert into takes values('69783', '527', '1', 'Fall', 2004, 'C ');
	insert into takes values('65714', '875', '1', 'Spring', 2005, 'A+');
	insert into takes values('61166', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('88993', '545', '1', 'Fall', 2001, 'A ');
	insert into takes values('94846', '991', '1', 'Spring', 2008, 'B-');
	insert into takes values('15538', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('23500', '200', '2', 'Fall', 2002, 'B-');
	insert into takes values('44038', '338', '1', 'Spring', 2007, 'A ');
	insert into takes values('53424', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('73213', '443', '1', 'Spring', 2010, 'B-');
	insert into takes values('84702', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('76768', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('11419', '338', '1', 'Spring', 2007, 'C ');
	insert into takes values('41938', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('86651', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('34392', '852', '1', 'Spring', 2008, 'C-');
	insert into takes values('30110', '366', '1', 'Fall', 2005, 'C ');
	insert into takes values('33546', '694', '1', 'Fall', 2002, 'A ');
	insert into takes values('17424', '476', '1', 'Fall', 2010, 'B+');
	insert into takes values('72501', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('51084', '319', '1', 'Spring', 2003, 'A-');
	insert into takes values('40457', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('81396', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('41599', '376', '1', 'Fall', 2006, 'B+');
	insert into takes values('63449', '304', '1', 'Fall', 2009, 'C-');
	insert into takes values('57185', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('64222', '200', '1', 'Spring', 2007, 'C-');
	insert into takes values('96153', '694', '1', 'Fall', 2002, 'B ');
	insert into takes values('75510', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('64893', '692', '1', 'Spring', 2010, 'B-');
	insert into takes values('37809', '571', '1', 'Spring', 2004, 'C+');
	insert into takes values('56', '795', '1', 'Spring', 2004, 'B+');
	insert into takes values('73213', '679', '1', 'Spring', 2010, 'A ');
	insert into takes values('40189', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('94620', '319', '1', 'Spring', 2003, 'B-');
	insert into takes values('44352', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('99977', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('97679', '960', '1', 'Fall', 2009, 'A+');
	insert into takes values('61127', '338', '1', 'Spring', 2007, 'A-');
	insert into takes values('77172', '545', '1', 'Fall', 2001, 'A-');
	insert into takes values('4860', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('931', '445', '1', 'Spring', 2001, 'A-');
	insert into takes values('17397', '304', '1', 'Fall', 2009, 'A+');
	insert into takes values('74796', '496', '1', 'Fall', 2001, 'B-');
	insert into takes values('95201', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('23110', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('70061', '352', '1', 'Spring', 2006, 'A-');
	insert into takes values('107', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('76224', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('77664', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('6895', '408', '1', 'Spring', 2007, 'C-');
	insert into takes values('57123', '242', '1', 'Fall', 2009, 'A-');
	insert into takes values('19342', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('81984', '795', '1', 'Spring', 2004, 'B+');
	insert into takes values('95089', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('5414', '270', '1', 'Spring', 2010, 'A-');
	insert into takes values('59848', '559', '1', 'Fall', 2002, 'C-');
	insert into takes values('20985', '599', '1', 'Spring', 2003, 'A ');
	insert into takes values('50658', '476', '1', 'Fall', 2010, 'C-');
	insert into takes values('78892', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('99073', '959', '1', 'Fall', 2006, 'C+');
	insert into takes values('32881', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('23457', '401', '1', 'Fall', 2003, 'B+');
	insert into takes values('30341', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('57334', '959', '1', 'Fall', 2006, 'B ');
	insert into takes values('79170', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('20803', '105', '1', 'Fall', 2009, 'A+');
	insert into takes values('792', '242', '1', 'Fall', 2009, 'A+');
	insert into takes values('94173', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('842', '748', '1', 'Fall', 2003, 'B-');
	insert into takes values('12069', '599', '1', 'Spring', 2003, 'B+');
	insert into takes values('48778', '893', '1', 'Fall', 2007, 'B ');
	insert into takes values('45300', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('76953', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('29849', '415', '1', 'Fall', 2010, 'B-');
	insert into takes values('97658', '960', '1', 'Fall', 2009, 'C-');
	insert into takes values('94894', '421', '1', 'Fall', 2004, 'C+');
	insert into takes values('10834', '559', '1', 'Fall', 2002, 'C-');
	insert into takes values('83204', '334', '1', 'Fall', 2009, 'B ');
	insert into takes values('13408', '626', '1', 'Fall', 2006, 'C+');
	insert into takes values('53728', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('77588', '237', '2', 'Fall', 2009, 'A-');
	insert into takes values('64938', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('43505', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('89297', '415', '1', 'Fall', 2010, 'A+');
	insert into takes values('78792', '200', '2', 'Fall', 2002, 'B+');
	insert into takes values('2286', '702', '1', 'Spring', 2001, 'C+');
	insert into takes values('7149', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('30845', '581', '1', 'Spring', 2005, 'B+');
	insert into takes values('52291', '679', '1', 'Spring', 2010, 'A ');
	insert into takes values('53089', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('16907', '169', '1', 'Spring', 2007, 'A-');
	insert into takes values('1922', '443', '2', 'Spring', 2002, 'A ');
	insert into takes values('22620', '258', '1', 'Fall', 2007, 'C+');
	insert into takes values('44206', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('12941', '527', '1', 'Fall', 2004, 'A-');
	insert into takes values('95320', '591', '1', 'Spring', 2005, 'C+');
	insert into takes values('16133', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('51238', '843', '1', 'Fall', 2010, 'C+');
	insert into takes values('32376', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('50267', '237', '1', 'Spring', 2008, 'B+');
	insert into takes values('99660', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('47670', '591', '1', 'Spring', 2005, 'A-');
	insert into takes values('9605', '735', '2', 'Spring', 2010, 'C ');
	insert into takes values('56486', '581', '1', 'Spring', 2005, 'A ');
	insert into takes values('15726', '468', '2', 'Fall', 2007, 'A-');
	insert into takes values('66495', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('86753', '702', '1', 'Spring', 2001, 'B ');
	insert into takes values('57135', '642', '1', 'Fall', 2004, 'B+');
	insert into takes values('62784', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('71387', '696', '1', 'Spring', 2002, 'C-');
	insert into takes values('92867', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('59117', '421', '1', 'Fall', 2004, 'C ');
	insert into takes values('95201', '242', '1', 'Fall', 2009, 'B+');
	insert into takes values('64192', '748', '1', 'Fall', 2003, 'B ');
	insert into takes values('43348', '626', '1', 'Fall', 2006, 'C+');
	insert into takes values('67425', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('65714', '581', '1', 'Spring', 2005, 'C+');
	insert into takes values('3576', '319', '1', 'Spring', 2003, 'C+');
	insert into takes values('78434', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('24387', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('84704', '349', '1', 'Spring', 2008, 'C-');
	insert into takes values('85534', '735', '1', 'Spring', 2003, 'A-');
	insert into takes values('45650', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('23457', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('38899', '158', '1', 'Fall', 2008, 'A ');
	insert into takes values('91569', '599', '1', 'Spring', 2003, 'A-');
	insert into takes values('61402', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('54728', '959', '1', 'Fall', 2006, 'B+');
	insert into takes values('30017', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('18740', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('94998', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('45826', '158', '2', 'Spring', 2008, 'C ');
	insert into takes values('37350', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('17076', '169', '2', 'Fall', 2002, 'B+');
	insert into takes values('463', '629', '1', 'Spring', 2003, 'B+');
	insert into takes values('91851', '793', '1', 'Spring', 2002, 'A+');
	insert into takes values('71529', '808', '1', 'Fall', 2003, 'C ');
	insert into takes values('38696', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('17944', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('97355', '959', '1', 'Fall', 2006, 'A+');
	insert into takes values('52019', '760', '1', 'Spring', 2004, 'B ');
	insert into takes values('41599', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('62054', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('81789', '735', '2', 'Spring', 2010, 'B ');
	insert into takes values('96710', '875', '1', 'Spring', 2005, 'C ');
	insert into takes values('64222', '974', '1', 'Fall', 2003, 'A-');
	insert into takes values('52187', '867', '1', 'Fall', 2006, 'C+');
	insert into takes values('66813', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('34018', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('17128', '313', '1', 'Fall', 2010, 'A ');
	insert into takes values('44836', '927', '1', 'Fall', 2002, 'C-');
	insert into takes values('63860', '242', '1', 'Fall', 2009, 'C-');
	insert into takes values('52471', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('69222', '345', '1', 'Spring', 2008, 'A-');
	insert into takes values('13217', '237', '1', 'Spring', 2008, 'C-');
	insert into takes values('36791', '237', '2', 'Fall', 2009, 'A-');
	insert into takes values('22325', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('18108', '468', '1', 'Fall', 2005, 'B+');
	insert into takes values('52134', '274', '1', 'Fall', 2002, 'B ');
	insert into takes values('11855', '696', '1', 'Spring', 2002, 'C+');
	insert into takes values('38548', '105', '1', 'Fall', 2009, 'C ');
	insert into takes values('95027', '893', '1', 'Fall', 2007, 'A-');
	insert into takes values('7035', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('46442', '486', '1', 'Fall', 2009, 'A ');
	insert into takes values('36494', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('15698', '748', '1', 'Fall', 2003, 'B ');
	insert into takes values('52157', '612', '1', 'Fall', 2007, 'B-');
	insert into takes values('84845', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('34386', '443', '2', 'Spring', 2002, 'A+');
	insert into takes values('31690', '408', '1', 'Spring', 2007, 'A ');
	insert into takes values('28133', '747', '1', 'Spring', 2004, 'B-');
	insert into takes values('19321', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('18859', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('88045', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('63582', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('5414', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('33094', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('90194', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('61081', '867', '1', 'Fall', 2006, 'A+');
	insert into takes values('63449', '443', '2', 'Spring', 2002, 'B+');
	insert into takes values('45494', '105', '1', 'Fall', 2009, 'C-');
	insert into takes values('41774', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('43854', '852', '1', 'Spring', 2008, 'A-');
	insert into takes values('18709', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('34195', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('63090', '974', '1', 'Fall', 2003, 'A-');
	insert into takes values('24630', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('64297', '581', '1', 'Spring', 2005, 'C ');
	insert into takes values('9933', '791', '1', 'Spring', 2006, 'A-');
	insert into takes values('3576', '482', '1', 'Fall', 2005, 'A-');
	insert into takes values('75928', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('8252', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('87015', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('4182', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('34331', '927', '1', 'Fall', 2002, 'B-');
	insert into takes values('36513', '457', '1', 'Spring', 2001, 'A+');
	insert into takes values('90124', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('92849', '338', '1', 'Spring', 2007, 'B-');
	insert into takes values('63390', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('32385', '158', '2', 'Spring', 2008, 'C-');
	insert into takes values('72622', '561', '1', 'Fall', 2006, 'C+');
	insert into takes values('67051', '200', '2', 'Fall', 2002, 'A-');
	insert into takes values('30177', '158', '1', 'Fall', 2008, 'A-');
	insert into takes values('65563', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('70564', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('71389', '692', '1', 'Spring', 2010, 'A-');
	insert into takes values('83728', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('67222', '158', '2', 'Spring', 2008, 'C+');
	insert into takes values('36995', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('14581', '867', '1', 'Fall', 2006, 'C+');
	insert into takes values('64196', '338', '2', 'Spring', 2006, 'A+');
	insert into takes values('41406', '493', '1', 'Spring', 2010, 'C-');
	insert into takes values('35685', '376', '1', 'Fall', 2006, 'C+');
	insert into takes values('40738', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('12941', '400', '1', 'Spring', 2007, 'C-');
	insert into takes values('89132', '313', '1', 'Fall', 2010, 'B ');
	insert into takes values('99369', '482', '1', 'Fall', 2005, 'A ');
	insert into takes values('56124', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('12563', '274', '1', 'Fall', 2002, 'B-');
	insert into takes values('63243', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('1968', '169', '1', 'Spring', 2007, 'A ');
	insert into takes values('46928', '496', '1', 'Fall', 2001, 'C ');
	insert into takes values('85366', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('97694', '612', '1', 'Fall', 2007, 'C ');
	insert into takes values('76895', '852', '1', 'Spring', 2008, 'B-');
	insert into takes values('46980', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('90567', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('36244', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('86753', '949', '1', 'Fall', 2007, 'B ');
	insert into takes values('68248', '960', '1', 'Fall', 2009, 'B+');
	insert into takes values('32772', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('28299', '959', '1', 'Fall', 2006, 'A-');
	insert into takes values('68396', '200', '1', 'Spring', 2007, 'A ');
	insert into takes values('68070', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('7602', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('76604', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('62487', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('13921', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('31364', '408', '1', 'Spring', 2007, 'A-');
	insert into takes values('97228', '443', '2', 'Spring', 2002, 'C+');
	insert into takes values('9084', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('65681', '694', '1', 'Fall', 2002, 'C+');
	insert into takes values('72014', '791', '1', 'Spring', 2006, 'A-');
	insert into takes values('95099', '158', '2', 'Spring', 2008, 'B+');
	insert into takes values('35935', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('99268', '604', '1', 'Spring', 2009, 'B ');
	insert into takes values('4438', '482', '1', 'Fall', 2005, 'B ');
	insert into takes values('72014', '949', '1', 'Fall', 2007, 'C+');
	insert into takes values('60366', '591', '1', 'Spring', 2005, 'A ');
	insert into takes values('25942', '793', '1', 'Spring', 2002, 'A+');
	insert into takes values('90814', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('64934', '468', '2', 'Fall', 2007, 'C-');
	insert into takes values('52157', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('16753', '591', '1', 'Spring', 2005, 'B+');
	insert into takes values('89132', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('92332', '927', '1', 'Fall', 2002, 'B-');
	insert into takes values('91343', '591', '1', 'Spring', 2005, 'B+');
	insert into takes values('22345', '200', '2', 'Fall', 2002, 'B+');
	insert into takes values('7043', '237', '2', 'Fall', 2009, 'B+');
	insert into takes values('69679', '169', '2', 'Fall', 2002, 'A ');
	insert into takes values('60867', '334', '1', 'Fall', 2009, 'B ');
	insert into takes values('14628', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('15538', '972', '1', 'Spring', 2009, 'C-');
	insert into takes values('26102', '949', '1', 'Fall', 2007, 'C ');
	insert into takes values('64945', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('98940', '559', '1', 'Fall', 2002, 'B ');
	insert into takes values('43432', '949', '1', 'Fall', 2007, 'A-');
	insert into takes values('40189', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('8819', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('52876', '629', '1', 'Spring', 2003, 'A+');
	insert into takes values('32506', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('43123', '468', '2', 'Fall', 2007, 'A-');
	insert into takes values('7620', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('67514', '415', '1', 'Fall', 2010, 'A-');
	insert into takes values('12971', '443', '2', 'Spring', 2002, 'A+');
	insert into takes values('20244', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('13290', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('81207', '362', '3', 'Spring', 2008, 'A+');
	insert into takes values('99710', '192', '1', 'Fall', 2002, 'A+');
	insert into takes values('288', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('75513', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('67810', '169', '1', 'Spring', 2007, 'C ');
	insert into takes values('29390', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('80941', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('94142', '400', '2', 'Fall', 2003, 'C+');
	insert into takes values('99977', '258', '1', 'Fall', 2007, 'B+');
	insert into takes values('96988', '696', '1', 'Spring', 2002, 'C ');
	insert into takes values('39521', '468', '2', 'Fall', 2007, 'A-');
	insert into takes values('60984', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('79772', '603', '1', 'Fall', 2003, 'A ');
	insert into takes values('64222', '802', '1', 'Spring', 2003, 'B+');
	insert into takes values('7498', '679', '1', 'Spring', 2010, 'C-');
	insert into takes values('667', '482', '1', 'Fall', 2005, 'A-');
	insert into takes values('86375', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('83003', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('82868', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('72528', '694', '1', 'Fall', 2002, 'C ');
	insert into takes values('28128', '169', '1', 'Spring', 2007, 'B ');
	insert into takes values('8426', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('66763', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('827', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('18636', '313', '1', 'Fall', 2010, 'B+');
	insert into takes values('99694', '457', '1', 'Spring', 2001, 'B+');
	insert into takes values('2286', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('13826', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('29239', '200', '1', 'Spring', 2007, 'A-');
	insert into takes values('69241', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('98984', '591', '1', 'Spring', 2005, 'A+');
	insert into takes values('32368', '561', '1', 'Fall', 2006, 'C-');
	insert into takes values('3576', '581', '1', 'Spring', 2005, 'C ');
	insert into takes values('98563', '421', '1', 'Fall', 2004, 'A ');
	insert into takes values('96052', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('3545', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('288', '679', '1', 'Spring', 2010, 'B ');
	insert into takes values('31554', '408', '1', 'Spring', 2007, 'C+');
	insert into takes values('8378', '679', '1', 'Spring', 2010, 'B+');
	insert into takes values('57538', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('56598', '468', '1', 'Fall', 2005, 'B ');
	insert into takes values('46106', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('75123', '852', '1', 'Spring', 2008, 'B-');
	insert into takes values('39892', '461', '1', 'Fall', 2002, 'B-');
	insert into takes values('71389', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('70564', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('63243', '843', '1', 'Fall', 2010, 'C-');
	insert into takes values('75772', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('58326', '960', '2', 'Fall', 2006, 'C+');
	insert into takes values('11195', '802', '1', 'Spring', 2003, 'C+');
	insert into takes values('99719', '362', '1', 'Fall', 2005, 'C ');
	insert into takes values('35257', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('34195', '692', '1', 'Spring', 2010, 'A-');
	insert into takes values('36494', '735', '1', 'Spring', 2003, 'C ');
	insert into takes values('53699', '345', '1', 'Spring', 2008, 'B-');
	insert into takes values('29260', '875', '1', 'Spring', 2005, 'A ');
	insert into takes values('72501', '974', '1', 'Fall', 2003, 'C-');
	insert into takes values('53225', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('1827', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('39552', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('76799', '679', '1', 'Spring', 2010, 'B ');
	insert into takes values('65205', '867', '2', 'Fall', 2010, 'C ');
	insert into takes values('60249', '875', '1', 'Spring', 2005, 'B-');
	insert into takes values('51723', '158', '1', 'Fall', 2008, 'A-');
	insert into takes values('760', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('21086', '408', '1', 'Spring', 2007, 'C+');
	insert into takes values('95366', '401', '1', 'Fall', 2003, 'C+');
	insert into takes values('70924', '137', '1', 'Spring', 2002, 'A ');
	insert into takes values('21552', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('64164', '169', '2', 'Fall', 2002, 'C ');
	insert into takes values('57160', '972', '1', 'Spring', 2009, 'B-');
	insert into takes values('9495', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('37339', '545', '1', 'Fall', 2001, 'A+');
	insert into takes values('36995', '345', '1', 'Spring', 2008, 'A ');
	insert into takes values('38712', '629', '1', 'Spring', 2003, 'B ');
	insert into takes values('44206', '461', '1', 'Fall', 2002, 'B ');
	insert into takes values('8912', '663', '1', 'Spring', 2005, 'C-');
	insert into takes values('99760', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('96988', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('13211', '105', '1', 'Fall', 2009, 'C-');
	insert into takes values('26028', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('15340', '270', '1', 'Spring', 2010, 'C ');
	insert into takes values('61414', '338', '1', 'Spring', 2007, 'A ');
	insert into takes values('25187', '349', '1', 'Spring', 2008, 'A-');
	insert into takes values('45300', '793', '1', 'Spring', 2002, 'C ');
	insert into takes values('56499', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('19735', '642', '1', 'Fall', 2004, 'B+');
	insert into takes values('37038', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('667', '313', '1', 'Fall', 2010, 'B-');
	insert into takes values('86127', '338', '1', 'Spring', 2007, 'C+');
	insert into takes values('61127', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('25611', '679', '1', 'Spring', 2010, 'C+');
	insert into takes values('71085', '663', '1', 'Spring', 2005, 'C-');
	insert into takes values('53490', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('45002', '304', '1', 'Fall', 2009, 'B+');
	insert into takes values('61354', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('70098', '338', '2', 'Spring', 2006, 'B+');
	insert into takes values('51579', '482', '1', 'Fall', 2005, 'A+');
	insert into takes values('71768', '493', '1', 'Spring', 2010, 'B+');
	insert into takes values('3639', '158', '1', 'Fall', 2008, 'A-');
	insert into takes values('63886', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('86802', '237', '1', 'Spring', 2008, 'B-');
	insert into takes values('37818', '421', '1', 'Fall', 2004, 'B+');
	insert into takes values('28128', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('96615', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('16528', '696', '1', 'Spring', 2002, 'B ');
	insert into takes values('69747', '612', '1', 'Fall', 2007, 'A-');
	insert into takes values('30017', '867', '1', 'Fall', 2006, 'A-');
	insert into takes values('86806', '960', '2', 'Fall', 2006, 'C ');
	insert into takes values('82974', '747', '1', 'Spring', 2004, 'B+');
	insert into takes values('63582', '105', '1', 'Fall', 2009, 'A+');
	insert into takes values('47126', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('57242', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('56003', '338', '2', 'Spring', 2006, 'A+');
	insert into takes values('37284', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('70572', '612', '1', 'Fall', 2007, 'C ');
	insert into takes values('6729', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('8957', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('96067', '489', '1', 'Fall', 2007, 'A-');
	insert into takes values('56882', '960', '2', 'Fall', 2006, 'A ');
	insert into takes values('56003', '679', '1', 'Spring', 2010, 'A+');
	insert into takes values('42096', '489', '1', 'Fall', 2007, 'B+');
	insert into takes values('28538', '663', '1', 'Spring', 2005, 'B-');
	insert into takes values('48778', '457', '1', 'Spring', 2001, 'B+');
	insert into takes values('92864', '843', '1', 'Fall', 2010, 'A-');
	insert into takes values('29959', '793', '1', 'Spring', 2002, 'A+');
	insert into takes values('70395', '304', '1', 'Fall', 2009, 'B+');
	insert into takes values('71529', '443', '1', 'Spring', 2010, 'A+');
	insert into takes values('51538', '626', '1', 'Fall', 2006, 'B ');
	insert into takes values('44836', '334', '1', 'Fall', 2009, 'B-');
	insert into takes values('26494', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('92849', '875', '1', 'Spring', 2005, 'C ');
	insert into takes values('39114', '366', '1', 'Fall', 2005, 'A ');
	insert into takes values('64222', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('50267', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('32881', '200', '2', 'Fall', 2002, 'C-');
	insert into takes values('5871', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('42565', '105', '2', 'Fall', 2002, 'C-');
	insert into takes values('12173', '352', '1', 'Spring', 2006, 'C+');
	insert into takes values('63886', '527', '1', 'Fall', 2004, 'A ');
	insert into takes values('57238', '852', '1', 'Spring', 2008, 'C+');
	insert into takes values('96227', '793', '1', 'Spring', 2002, 'A+');
	insert into takes values('34126', '679', '1', 'Spring', 2010, 'C-');
	insert into takes values('75791', '349', '1', 'Spring', 2008, 'C-');
	insert into takes values('41890', '426', '1', 'Spring', 2006, 'A+');
	insert into takes values('36019', '631', '1', 'Spring', 2007, 'B+');
	insert into takes values('25187', '571', '1', 'Spring', 2004, 'B+');
	insert into takes values('44703', '960', '2', 'Fall', 2006, 'C+');
	insert into takes values('86552', '105', '2', 'Fall', 2002, 'B-');
	insert into takes values('61354', '258', '1', 'Fall', 2007, 'B+');
	insert into takes values('78911', '612', '1', 'Fall', 2007, 'C ');
	insert into takes values('39472', '581', '1', 'Spring', 2005, 'A-');
	insert into takes values('34542', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('45680', '158', '1', 'Fall', 2008, 'C-');
	insert into takes values('94990', '867', '1', 'Fall', 2006, 'A ');
	insert into takes values('23525', '626', '1', 'Fall', 2006, 'B-');
	insert into takes values('67793', '158', '2', 'Spring', 2008, 'C-');
	insert into takes values('57456', '852', '1', 'Spring', 2008, 'C ');
	insert into takes values('4682', '893', '1', 'Fall', 2007, 'B ');
	insert into takes values('47630', '972', '1', 'Spring', 2009, 'A ');
	insert into takes values('37350', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('39115', '802', '1', 'Spring', 2003, 'C+');
	insert into takes values('77415', '169', '1', 'Spring', 2007, 'B ');
	insert into takes values('66229', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('29705', '362', '3', 'Spring', 2008, 'A+');
	insert into takes values('77588', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('6209', '962', '1', 'Spring', 2008, 'B ');
	insert into takes values('6304', '581', '1', 'Spring', 2005, 'B+');
	insert into takes values('2177', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('91915', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('9993', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('61854', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('95953', '200', '2', 'Fall', 2002, 'B+');
	insert into takes values('37103', '400', '1', 'Spring', 2007, 'A ');
	insert into takes values('33107', '408', '1', 'Spring', 2007, 'C-');
	insert into takes values('36303', '338', '1', 'Spring', 2007, 'A ');
	insert into takes values('65901', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('993', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('1402', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('18809', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('95046', '421', '1', 'Fall', 2004, 'A ');
	insert into takes values('34170', '258', '1', 'Fall', 2007, 'C ');
	insert into takes values('96710', '612', '1', 'Fall', 2007, 'B ');
	insert into takes values('86404', '319', '1', 'Spring', 2003, 'B ');
	insert into takes values('42625', '629', '1', 'Spring', 2003, 'B ');
	insert into takes values('19293', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('76743', '105', '2', 'Fall', 2002, 'C+');
	insert into takes values('52019', '345', '1', 'Spring', 2008, 'C ');
	insert into takes values('93043', '679', '1', 'Spring', 2010, 'B-');
	insert into takes values('35257', '591', '1', 'Spring', 2005, 'B-');
	insert into takes values('36513', '527', '1', 'Fall', 2004, 'C ');
	insert into takes values('11966', '338', '2', 'Spring', 2006, 'C+');
	insert into takes values('81876', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('16993', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('31337', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('39552', '663', '1', 'Spring', 2005, 'C-');
	insert into takes values('8957', '376', '1', 'Fall', 2006, 'B+');
	insert into takes values('72186', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('34158', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('86529', '696', '1', 'Spring', 2002, 'B-');
	insert into takes values('82646', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('56299', '735', '2', 'Spring', 2010, 'B-');
	insert into takes values('48423', '692', '1', 'Spring', 2010, 'A-');
	insert into takes values('50386', '626', '1', 'Fall', 2006, 'A ');
	insert into takes values('51203', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('42625', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('70572', '313', '1', 'Fall', 2010, 'B-');
	insert into takes values('36265', '559', '1', 'Fall', 2002, 'B ');
	insert into takes values('18859', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('91091', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('11057', '735', '1', 'Spring', 2003, 'C+');
	insert into takes values('88553', '808', '1', 'Fall', 2003, 'A-');
	insert into takes values('53803', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('78767', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('65329', '304', '1', 'Fall', 2009, 'B+');
	insert into takes values('68330', '169', '2', 'Fall', 2002, 'B ');
	insert into takes values('59517', '461', '1', 'Fall', 2002, 'A-');
	insert into takes values('45494', '366', '1', 'Fall', 2005, 'A+');
	insert into takes values('6287', '443', '2', 'Spring', 2002, 'A-');
	insert into takes values('67222', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('97573', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('65258', '864', '1', 'Spring', 2006, 'C-');
	insert into takes values('5414', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('12236', '927', '1', 'Fall', 2002, 'A-');
	insert into takes values('9495', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('24932', '663', '1', 'Spring', 2005, 'A-');
	insert into takes values('96003', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('13352', '192', '1', 'Fall', 2002, 'C-');
	insert into takes values('29803', '362', '1', 'Fall', 2005, 'C ');
	insert into takes values('16523', '545', '1', 'Fall', 2001, 'A+');
	insert into takes values('39619', '158', '1', 'Fall', 2008, 'A+');
	insert into takes values('65329', '313', '1', 'Fall', 2010, 'B ');
	insert into takes values('9360', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('84239', '445', '1', 'Spring', 2001, 'C+');
	insert into takes values('48660', '192', '1', 'Fall', 2002, 'C-');
	insert into takes values('15517', '972', '1', 'Spring', 2009, 'B+');
	insert into takes values('75560', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('89104', '408', '1', 'Spring', 2007, 'C+');
	insert into takes values('98315', '489', '1', 'Fall', 2007, 'C ');
	insert into takes values('51923', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('62487', '591', '1', 'Spring', 2005, 'B ');
	insert into takes values('39612', '962', '1', 'Spring', 2008, 'A ');
	insert into takes values('108', '338', '1', 'Spring', 2007, 'C+');
	insert into takes values('11604', '468', '1', 'Fall', 2005, 'C ');
	insert into takes values('89393', '258', '1', 'Fall', 2007, 'A ');
	insert into takes values('69241', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('6523', '400', '2', 'Fall', 2003, 'C-');
	insert into takes values('97065', '443', '2', 'Spring', 2002, 'B ');
	insert into takes values('37946', '158', '1', 'Fall', 2008, 'A-');
	insert into takes values('29920', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('45494', '158', '2', 'Spring', 2008, 'A-');
	insert into takes values('9360', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('81207', '270', '1', 'Spring', 2010, 'B+');
	insert into takes values('10033', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('38548', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('76759', '421', '1', 'Fall', 2004, 'C-');
	insert into takes values('39704', '875', '1', 'Spring', 2005, 'A-');
	insert into takes values('77172', '496', '1', 'Fall', 2001, 'B-');
	insert into takes values('88287', '352', '1', 'Spring', 2006, 'C+');
	insert into takes values('49982', '864', '1', 'Spring', 2006, 'A ');
	insert into takes values('46970', '237', '2', 'Fall', 2009, 'C+');
	insert into takes values('52856', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('75547', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('5703', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('9460', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('70061', '760', '1', 'Spring', 2004, 'C ');
	insert into takes values('73268', '415', '1', 'Fall', 2010, 'C-');
	insert into takes values('39204', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('34018', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('90234', '105', '2', 'Fall', 2002, 'B+');
	insert into takes values('32886', '960', '1', 'Fall', 2009, 'B+');
	insert into takes values('83022', '468', '1', 'Fall', 2005, 'B ');
	insert into takes values('61003', '304', '1', 'Fall', 2009, 'A ');
	insert into takes values('55857', '362', '3', 'Spring', 2008, 'C+');
	insert into takes values('62716', '105', '2', 'Fall', 2002, 'A+');
	insert into takes values('69230', '603', '1', 'Fall', 2003, 'B+');
	insert into takes values('19536', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('11530', '604', '1', 'Spring', 2009, 'B-');
	insert into takes values('34770', '962', '1', 'Spring', 2008, 'A+');
	insert into takes values('45826', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('10663', '489', '1', 'Fall', 2007, 'B-');
	insert into takes values('14094', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('82974', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('42388', '304', '1', 'Fall', 2009, 'B ');
	insert into takes values('90004', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('18554', '362', '1', 'Fall', 2005, 'C+');
	insert into takes values('33791', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('25611', '445', '1', 'Spring', 2001, 'A-');
	insert into takes values('90132', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('30017', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('83871', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('41832', '468', '1', 'Fall', 2005, 'B+');
	insert into takes values('78572', '748', '1', 'Fall', 2003, 'B ');
	insert into takes values('79329', '400', '2', 'Fall', 2003, 'C-');
	insert into takes values('35588', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('18740', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('88553', '200', '1', 'Spring', 2007, 'A ');
	insert into takes values('14874', '362', '1', 'Fall', 2005, 'C-');
	insert into takes values('20803', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('8807', '258', '1', 'Fall', 2007, 'A-');
	insert into takes values('62636', '793', '1', 'Spring', 2002, 'C+');
	insert into takes values('76798', '561', '1', 'Fall', 2006, 'B+');
	insert into takes values('82918', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('80821', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('11237', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('19450', '457', '1', 'Spring', 2001, 'C ');
	insert into takes values('4582', '843', '1', 'Fall', 2010, 'A-');
	insert into takes values('45770', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('65101', '376', '1', 'Fall', 2006, 'B-');
	insert into takes values('13081', '400', '2', 'Fall', 2003, 'C-');
	insert into takes values('57456', '169', '2', 'Fall', 2002, 'C ');
	insert into takes values('53048', '561', '1', 'Fall', 2006, 'C-');
	insert into takes values('49813', '486', '1', 'Fall', 2009, 'B ');
	insert into takes values('95260', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('84654', '612', '1', 'Fall', 2007, 'B-');
	insert into takes values('46928', '561', '1', 'Fall', 2006, 'B+');
	insert into takes values('8343', '158', '2', 'Spring', 2008, 'C-');
	insert into takes values('22254', '791', '1', 'Spring', 2006, 'B+');
	insert into takes values('39925', '875', '1', 'Spring', 2005, 'B-');
	insert into takes values('99451', '791', '1', 'Spring', 2006, 'A ');
	insert into takes values('66008', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('79534', '694', '1', 'Fall', 2002, 'C ');
	insert into takes values('92703', '345', '1', 'Spring', 2008, 'A ');
	insert into takes values('88085', '875', '1', 'Spring', 2005, 'C-');
	insert into takes values('78143', '239', '1', 'Fall', 2006, 'B-');
	insert into takes values('69679', '867', '1', 'Fall', 2006, 'A-');
	insert into takes values('59290', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('66106', '793', '1', 'Spring', 2002, 'B+');
	insert into takes values('64550', '581', '1', 'Spring', 2005, 'C ');
	insert into takes values('81984', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('34195', '482', '1', 'Fall', 2005, 'C ');
	insert into takes values('7035', '875', '1', 'Spring', 2005, 'A ');
	insert into takes values('59908', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('98984', '445', '1', 'Spring', 2001, 'A-');
	insert into takes values('64067', '949', '1', 'Fall', 2007, 'B ');
	insert into takes values('81258', '105', '2', 'Fall', 2002, 'A-');
	insert into takes values('17076', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('38336', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('64249', '843', '1', 'Fall', 2010, 'C+');
	insert into takes values('41827', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('69222', '626', '1', 'Fall', 2006, 'A ');
	insert into takes values('32506', '893', '1', 'Fall', 2007, 'B-');
	insert into takes values('43123', '200', '1', 'Spring', 2007, 'C ');
	insert into takes values('52203', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('99949', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('15340', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('23994', '400', '1', 'Spring', 2007, 'C ');
	insert into takes values('81883', '408', '1', 'Spring', 2007, 'A ');
	insert into takes values('77548', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('38476', '105', '2', 'Fall', 2002, 'C-');
	insert into takes values('41091', '489', '1', 'Fall', 2007, 'A ');
	insert into takes values('1220', '319', '1', 'Spring', 2003, 'B-');
	insert into takes values('28361', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('52929', '242', '1', 'Fall', 2009, 'C ');
	insert into takes values('72741', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('64724', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('39925', '270', '1', 'Spring', 2010, 'B+');
	insert into takes values('73411', '852', '1', 'Spring', 2008, 'B ');
	insert into takes values('16907', '702', '1', 'Spring', 2001, 'B-');
	insert into takes values('5617', '349', '1', 'Spring', 2008, 'B+');
	insert into takes values('58469', '972', '1', 'Spring', 2009, 'B-');
	insert into takes values('56232', '489', '1', 'Fall', 2007, 'A ');
	insert into takes values('89000', '401', '1', 'Fall', 2003, 'A ');
	insert into takes values('6367', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('85746', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('63502', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('64938', '489', '1', 'Fall', 2007, 'A ');
	insert into takes values('91799', '258', '1', 'Fall', 2007, 'B-');
	insert into takes values('4435', '852', '1', 'Spring', 2008, 'C+');
	insert into takes values('41675', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('645', '867', '1', 'Fall', 2006, 'B+');
	insert into takes values('68712', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('20814', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('41406', '158', '2', 'Spring', 2008, 'A ');
	insert into takes values('5005', '376', '1', 'Fall', 2006, 'A ');
	insert into takes values('56057', '445', '1', 'Spring', 2001, 'C ');
	insert into takes values('69132', '704', '1', 'Spring', 2008, 'C ');
	insert into takes values('97435', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('96134', '345', '1', 'Spring', 2008, 'C ');
	insert into takes values('31341', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('15457', '591', '1', 'Spring', 2005, 'A+');
	insert into takes values('88801', '604', '1', 'Spring', 2009, 'B-');
	insert into takes values('92274', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('74911', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('68395', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('24865', '748', '1', 'Fall', 2003, 'B-');
	insert into takes values('15024', '486', '1', 'Fall', 2009, 'C+');
	insert into takes values('7514', '443', '2', 'Spring', 2002, 'A ');
	insert into takes values('29707', '604', '1', 'Spring', 2009, 'A ');
	insert into takes values('91370', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('19848', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('11076', '960', '2', 'Fall', 2006, 'C+');
	insert into takes values('90779', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('36494', '561', '1', 'Fall', 2006, 'A ');
	insert into takes values('19766', '362', '3', 'Spring', 2008, 'B ');
	insert into takes values('10705', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('14094', '349', '1', 'Spring', 2008, 'A-');
	insert into takes values('60040', '319', '1', 'Spring', 2003, 'C-');
	insert into takes values('85887', '972', '1', 'Spring', 2009, 'C-');
	insert into takes values('83871', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('30334', '793', '1', 'Spring', 2002, 'C ');
	insert into takes values('87246', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('78481', '421', '1', 'Fall', 2004, 'B-');
	insert into takes values('63560', '735', '1', 'Spring', 2003, 'B-');
	insert into takes values('68263', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('36926', '334', '1', 'Fall', 2009, 'B ');
	insert into takes values('84039', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('6195', '747', '1', 'Spring', 2004, 'A ');
	insert into takes values('38712', '200', '1', 'Spring', 2007, 'A-');
	insert into takes values('67657', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('44258', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('66279', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('90082', '105', '2', 'Fall', 2002, 'B-');
	insert into takes values('50873', '105', '1', 'Fall', 2009, 'C-');
	insert into takes values('22260', '603', '1', 'Fall', 2003, 'A ');
	insert into takes values('46980', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('81785', '496', '1', 'Fall', 2001, 'B ');
	insert into takes values('85575', '192', '1', 'Fall', 2002, 'C-');
	insert into takes values('63560', '158', '2', 'Spring', 2008, 'A ');
	insert into takes values('49792', '603', '1', 'Fall', 2003, 'B+');
	insert into takes values('44206', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('99977', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('60040', '527', '1', 'Fall', 2004, 'C+');
	insert into takes values('35588', '949', '1', 'Fall', 2007, 'B ');
	insert into takes values('83728', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('43912', '808', '1', 'Fall', 2003, 'A-');
	insert into takes values('65101', '793', '1', 'Spring', 2002, 'B ');
	insert into takes values('7602', '200', '1', 'Spring', 2007, 'B-');
	insert into takes values('64192', '415', '1', 'Fall', 2010, 'B+');
	insert into takes values('18499', '864', '1', 'Spring', 2006, 'B ');
	insert into takes values('53152', '482', '1', 'Fall', 2005, 'B-');
	insert into takes values('10204', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('75231', '415', '1', 'Fall', 2010, 'C+');
	insert into takes values('35138', '408', '2', 'Spring', 2003, 'C ');
	insert into takes values('5898', '802', '1', 'Spring', 2003, 'B+');
	insert into takes values('53225', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('91063', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('44551', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('57780', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('76743', '679', '1', 'Spring', 2010, 'B+');
	insert into takes values('64249', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('14284', '991', '1', 'Spring', 2008, 'C-');
	insert into takes values('84495', '415', '1', 'Fall', 2010, 'C ');
	insert into takes values('13741', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('91851', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('71628', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('25046', '604', '1', 'Spring', 2009, 'A ');
	insert into takes values('61920', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('85887', '496', '1', 'Fall', 2001, 'B-');
	insert into takes values('51416', '362', '1', 'Fall', 2005, 'B ');
	insert into takes values('88169', '415', '1', 'Fall', 2010, 'C+');
	insert into takes values('86736', '338', '1', 'Spring', 2007, 'C-');
	insert into takes values('29849', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('88577', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('3739', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('64550', '338', '2', 'Spring', 2006, 'B+');
	insert into takes values('78552', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('85534', '692', '1', 'Spring', 2010, 'A ');
	insert into takes values('71085', '559', '1', 'Fall', 2002, 'C+');
	insert into takes values('21789', '443', '2', 'Spring', 2002, 'C ');
	insert into takes values('39115', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('76057', '334', '1', 'Fall', 2009, 'A ');
	insert into takes values('15517', '496', '1', 'Fall', 2001, 'B-');
	insert into takes values('65329', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('38668', '927', '1', 'Fall', 2002, 'C+');
	insert into takes values('17944', '867', '1', 'Fall', 2006, 'B+');
	insert into takes values('34404', '875', '1', 'Spring', 2005, 'C-');
	insert into takes values('56941', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('107', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('81883', '808', '1', 'Fall', 2003, 'A-');
	insert into takes values('94569', '960', '2', 'Fall', 2006, 'B+');
	insert into takes values('57190', '401', '1', 'Fall', 2003, 'C+');
	insert into takes values('38271', '270', '1', 'Spring', 2010, 'C-');
	insert into takes values('8140', '527', '1', 'Fall', 2004, 'A-');
	insert into takes values('27950', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('57123', '735', '2', 'Spring', 2010, 'B-');
	insert into takes values('80254', '791', '1', 'Spring', 2006, 'A-');
	insert into takes values('14581', '591', '1', 'Spring', 2005, 'B-');
	insert into takes values('89051', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('35220', '237', '1', 'Spring', 2008, 'A-');
	insert into takes values('30188', '559', '1', 'Fall', 2002, 'C+');
	insert into takes values('69285', '527', '1', 'Fall', 2004, 'B+');
	insert into takes values('36126', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('54296', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('40992', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('62487', '468', '1', 'Fall', 2005, 'B ');
	insert into takes values('91978', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('69732', '105', '2', 'Fall', 2002, 'A ');
	insert into takes values('10481', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('94801', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('24809', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('931', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('91370', '270', '1', 'Spring', 2010, 'C+');
	insert into takes values('77580', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('83480', '893', '1', 'Fall', 2007, 'B+');
	insert into takes values('7035', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('15517', '443', '2', 'Spring', 2002, 'A-');
	insert into takes values('69747', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('85226', '629', '1', 'Spring', 2003, 'A+');
	insert into takes values('3163', '972', '1', 'Spring', 2009, 'B-');
	insert into takes values('57985', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('84845', '443', '1', 'Spring', 2010, 'B+');
	insert into takes values('87044', '426', '1', 'Spring', 2006, 'A-');
	insert into takes values('49244', '258', '1', 'Fall', 2007, 'B-');
	insert into takes values('5824', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('25552', '242', '1', 'Fall', 2009, 'C-');
	insert into takes values('40481', '581', '1', 'Spring', 2005, 'B+');
	insert into takes values('74840', '692', '1', 'Spring', 2010, 'A+');
	insert into takes values('52656', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('43616', '352', '1', 'Spring', 2006, 'A-');
	insert into takes values('85575', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('16035', '843', '1', 'Fall', 2010, 'A ');
	insert into takes values('27952', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('22057', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('48247', '443', '1', 'Spring', 2010, 'B-');
	insert into takes values('6523', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('58300', '415', '1', 'Fall', 2010, 'C ');
	insert into takes values('37430', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('81028', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('45680', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('53547', '631', '1', 'Spring', 2007, 'B ');
	insert into takes values('5250', '972', '1', 'Spring', 2009, 'A-');
	insert into takes values('59397', '408', '1', 'Spring', 2007, 'A ');
	insert into takes values('86969', '461', '1', 'Fall', 2002, 'B ');
	insert into takes values('32954', '960', '2', 'Fall', 2006, 'B+');
	insert into takes values('11453', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('52019', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('53490', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('83953', '735', '2', 'Spring', 2010, 'A+');
	insert into takes values('30845', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('78911', '949', '1', 'Fall', 2007, 'B ');
	insert into takes values('55000', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('16075', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('85981', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('51817', '493', '1', 'Spring', 2010, 'C+');
	insert into takes values('47265', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('90663', '760', '1', 'Spring', 2004, 'A ');
	insert into takes values('10834', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('32056', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('89196', '927', '1', 'Fall', 2002, 'A ');
	insert into takes values('12979', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('69230', '747', '1', 'Spring', 2004, 'C-');
	insert into takes values('45680', '137', '1', 'Spring', 2002, 'B+');
	insert into takes values('23794', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('57242', '319', '1', 'Spring', 2003, 'C-');
	insert into takes values('8957', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('51923', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('95225', '735', '2', 'Spring', 2010, 'B ');
	insert into takes values('14032', '760', '1', 'Spring', 2004, 'B-');
	insert into takes values('68516', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('59908', '960', '2', 'Fall', 2006, 'B+');
	insert into takes values('71529', '599', '1', 'Spring', 2003, 'B ');
	insert into takes values('28299', '561', '1', 'Fall', 2006, 'A+');
	insert into takes values('53485', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('99949', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('63645', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('87015', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('94371', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('95574', '795', '1', 'Spring', 2004, 'A-');
	insert into takes values('11510', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('95840', '158', '2', 'Spring', 2008, 'A-');
	insert into takes values('51238', '760', '1', 'Spring', 2004, 'A-');
	insert into takes values('28252', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('83686', '237', '1', 'Spring', 2008, 'B+');
	insert into takes values('33759', '496', '1', 'Fall', 2001, 'C-');
	insert into takes values('29091', '443', '1', 'Spring', 2010, 'A+');
	insert into takes values('81245', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('17377', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('87651', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('13023', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('76169', '319', '1', 'Spring', 2003, 'B-');
	insert into takes values('48471', '408', '1', 'Spring', 2007, 'A-');
	insert into takes values('80821', '704', '1', 'Spring', 2008, 'C ');
	insert into takes values('83002', '843', '1', 'Fall', 2010, 'C-');
	insert into takes values('89414', '960', '1', 'Fall', 2009, 'B ');
	insert into takes values('29399', '445', '1', 'Spring', 2001, 'B+');
	insert into takes values('77664', '349', '1', 'Spring', 2008, 'C-');
	insert into takes values('17924', '694', '1', 'Fall', 2002, 'B ');
	insert into takes values('82974', '457', '1', 'Spring', 2001, 'B ');
	insert into takes values('47001', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('68242', '338', '2', 'Spring', 2006, 'C+');
	insert into takes values('97679', '400', '1', 'Spring', 2007, 'B+');
	insert into takes values('21102', '791', '1', 'Spring', 2006, 'C+');
	insert into takes values('34404', '962', '1', 'Spring', 2008, 'C-');
	insert into takes values('96003', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('38696', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('24374', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('31761', '599', '1', 'Spring', 2003, 'B+');
	insert into takes values('65714', '319', '1', 'Spring', 2003, 'C-');
	insert into takes values('21766', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('66293', '376', '1', 'Fall', 2006, 'B ');
	insert into takes values('11201', '702', '1', 'Spring', 2001, 'C+');
	insert into takes values('67407', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('65715', '158', '2', 'Spring', 2008, 'A-');
	insert into takes values('55329', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('64945', '959', '1', 'Fall', 2006, 'B ');
	insert into takes values('69521', '843', '1', 'Fall', 2010, 'C ');
	insert into takes values('30943', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('48678', '692', '1', 'Spring', 2010, 'C ');
	insert into takes values('27044', '237', '2', 'Fall', 2009, 'C-');
	insert into takes values('5298', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('13753', '400', '1', 'Spring', 2007, 'A ');
	insert into takes values('24442', '972', '1', 'Spring', 2009, 'A+');
	insert into takes values('29705', '496', '1', 'Fall', 2001, 'A+');
	insert into takes values('40992', '237', '2', 'Fall', 2009, 'C ');
	insert into takes values('66106', '852', '1', 'Spring', 2008, 'C ');
	insert into takes values('34236', '200', '1', 'Spring', 2007, 'B+');
	insert into takes values('16528', '692', '1', 'Spring', 2010, 'A ');
	insert into takes values('51008', '581', '1', 'Spring', 2005, 'A ');
	insert into takes values('51975', '735', '1', 'Spring', 2003, 'C+');
	insert into takes values('79589', '927', '1', 'Fall', 2002, 'A ');
	insert into takes values('24784', '612', '1', 'Fall', 2007, 'A+');
	insert into takes values('63538', '421', '1', 'Fall', 2004, 'C+');
	insert into takes values('47126', '561', '1', 'Fall', 2006, 'C+');
	insert into takes values('62520', '200', '1', 'Spring', 2007, 'C-');
	insert into takes values('93039', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('7656', '949', '1', 'Fall', 2007, 'C+');
	insert into takes values('27017', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('46928', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('73807', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('82126', '338', '2', 'Spring', 2006, 'A+');
	insert into takes values('29514', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('65676', '443', '1', 'Spring', 2010, 'A ');
	insert into takes values('77415', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('108', '345', '1', 'Spring', 2008, 'A-');
	insert into takes values('71543', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('16347', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('73268', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('45002', '949', '1', 'Fall', 2007, 'B ');
	insert into takes values('22260', '426', '1', 'Spring', 2006, 'A-');
	insert into takes values('93814', '443', '1', 'Spring', 2010, 'A ');
	insert into takes values('78481', '629', '1', 'Spring', 2003, 'B ');
	insert into takes values('22260', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('73072', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('10527', '631', '1', 'Spring', 2007, 'C-');
	insert into takes values('67810', '443', '1', 'Spring', 2010, 'C ');
	insert into takes values('13408', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('37818', '802', '1', 'Spring', 2003, 'A+');
	insert into takes values('94814', '692', '1', 'Spring', 2010, 'C ');
	insert into takes values('48611', '468', '1', 'Fall', 2005, 'A+');
	insert into takes values('61364', '443', '2', 'Spring', 2002, 'A-');
	insert into takes values('48778', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('30650', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('80610', '468', '1', 'Fall', 2005, 'B ');
	insert into takes values('92442', '237', '1', 'Spring', 2008, 'C+');
	insert into takes values('63489', '169', '1', 'Spring', 2007, 'B+');
	insert into takes values('67018', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('83039', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('70389', '843', '1', 'Fall', 2010, 'C+');
	insert into takes values('83953', '468', '1', 'Fall', 2005, 'B ');
	insert into takes values('69222', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('96153', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('83002', '793', '1', 'Spring', 2002, 'A+');
	insert into takes values('5250', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('41345', '603', '1', 'Fall', 2003, 'A+');
	insert into takes values('58594', '959', '1', 'Fall', 2006, 'B+');
	insert into takes values('88308', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('58300', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('70359', '949', '1', 'Fall', 2007, 'C+');
	insert into takes values('34957', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('57787', '200', '2', 'Fall', 2002, 'C+');
	insert into takes values('29091', '893', '1', 'Fall', 2007, 'B ');
	insert into takes values('288', '400', '1', 'Spring', 2007, 'A-');
	insert into takes values('96246', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('91343', '991', '1', 'Spring', 2008, 'B ');
	insert into takes values('99553', '362', '3', 'Spring', 2008, 'A+');
	insert into takes values('8912', '158', '2', 'Spring', 2008, 'B+');
	insert into takes values('30957', '200', '1', 'Spring', 2007, 'C-');
	insert into takes values('50598', '345', '1', 'Spring', 2008, 'A-');
	insert into takes values('34404', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('20180', '105', '1', 'Fall', 2009, 'C ');
	insert into takes values('13753', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('28352', '169', '1', 'Spring', 2007, 'C ');
	insert into takes values('75252', '486', '1', 'Fall', 2009, 'B-');
	insert into takes values('6712', '793', '1', 'Spring', 2002, 'C+');
	insert into takes values('39204', '696', '1', 'Spring', 2002, 'C ');
	insert into takes values('27687', '200', '2', 'Fall', 2002, 'C-');
	insert into takes values('56232', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('1000', '696', '1', 'Spring', 2002, 'B ');
	insert into takes values('49611', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('77361', '692', '1', 'Spring', 2010, 'A-');
	insert into takes values('34195', '545', '1', 'Fall', 2001, 'B-');
	insert into takes values('35462', '747', '1', 'Spring', 2004, 'B+');
	insert into takes values('55859', '408', '2', 'Spring', 2003, 'A ');
	insert into takes values('64401', '893', '1', 'Fall', 2007, 'C ');
	insert into takes values('55531', '959', '1', 'Fall', 2006, 'B+');
	insert into takes values('90372', '313', '1', 'Fall', 2010, 'C+');
	insert into takes values('25611', '313', '1', 'Fall', 2010, 'B ');
	insert into takes values('58085', '338', '2', 'Spring', 2006, 'A+');
	insert into takes values('56212', '867', '1', 'Fall', 2006, 'C+');
	insert into takes values('29031', '313', '1', 'Fall', 2010, 'A-');
	insert into takes values('13757', '747', '1', 'Spring', 2004, 'B+');
	insert into takes values('66753', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('35588', '443', '2', 'Spring', 2002, 'C+');
	insert into takes values('6195', '242', '1', 'Fall', 2009, 'B+');
	insert into takes values('96895', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('78314', '468', '2', 'Fall', 2007, 'B ');
	insert into takes values('31364', '352', '1', 'Spring', 2006, 'C ');
	insert into takes values('71389', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('7287', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('37818', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('51084', '793', '1', 'Spring', 2002, 'A ');
	insert into takes values('62152', '696', '1', 'Spring', 2002, 'B+');
	insert into takes values('32490', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('1968', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('47001', '270', '1', 'Spring', 2010, 'C+');
	insert into takes values('73206', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('37946', '692', '1', 'Spring', 2010, 'A+');
	insert into takes values('43658', '748', '1', 'Fall', 2003, 'B-');
	insert into takes values('46155', '679', '1', 'Spring', 2010, 'A ');
	insert into takes values('84704', '443', '1', 'Spring', 2010, 'B ');
	insert into takes values('70061', '476', '1', 'Fall', 2010, 'B+');
	insert into takes values('58081', '545', '1', 'Fall', 2001, 'A-');
	insert into takes values('33651', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('49618', '362', '2', 'Fall', 2006, 'B-');
	insert into takes values('18941', '694', '1', 'Fall', 2002, 'C ');
	insert into takes values('10527', '735', '2', 'Spring', 2010, 'A ');
	insert into takes values('13511', '735', '2', 'Spring', 2010, 'B ');
	insert into takes values('75273', '793', '1', 'Spring', 2002, 'A ');
	insert into takes values('2286', '599', '1', 'Spring', 2003, 'B-');
	insert into takes values('79697', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('20540', '258', '1', 'Fall', 2007, 'C+');
	insert into takes values('52872', '692', '1', 'Spring', 2010, 'C+');
	insert into takes values('77000', '527', '1', 'Fall', 2004, 'B-');
	insert into takes values('71631', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('13749', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('53089', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('8426', '338', '1', 'Spring', 2007, 'C+');
	insert into takes values('20180', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('59553', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('86327', '604', '1', 'Spring', 2009, 'C ');
	insert into takes values('55170', '400', '1', 'Spring', 2007, 'B+');
	insert into takes values('88085', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('87246', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('30474', '486', '1', 'Fall', 2009, 'A-');
	insert into takes values('34018', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('25725', '663', '1', 'Spring', 2005, 'C ');
	insert into takes values('9659', '559', '1', 'Fall', 2002, 'C+');
	insert into takes values('79210', '443', '2', 'Spring', 2002, 'A+');
	insert into takes values('77003', '352', '1', 'Spring', 2006, 'C ');
	insert into takes values('84792', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('34569', '679', '1', 'Spring', 2010, 'A+');
	insert into takes values('1110', '735', '1', 'Spring', 2003, 'A-');
	insert into takes values('85308', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('96085', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('12615', '852', '1', 'Spring', 2008, 'C-');
	insert into takes values('71389', '802', '1', 'Spring', 2003, 'C+');
	insert into takes values('30182', '401', '1', 'Fall', 2003, 'C-');
	insert into takes values('15538', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('83136', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('50664', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('94836', '421', '1', 'Fall', 2004, 'B-');
	insert into takes values('39114', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('32483', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('84515', '629', '1', 'Spring', 2003, 'B-');
	insert into takes values('53547', '376', '1', 'Fall', 2006, 'B+');
	insert into takes values('9084', '599', '1', 'Spring', 2003, 'A ');
	insert into takes values('3576', '694', '1', 'Fall', 2002, 'A ');
	insert into takes values('55354', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('55009', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('28133', '604', '1', 'Spring', 2009, 'C ');
	insert into takes values('94801', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('85451', '599', '1', 'Spring', 2003, 'C ');
	insert into takes values('28409', '158', '1', 'Fall', 2008, 'B+');
	insert into takes values('36265', '169', '1', 'Spring', 2007, 'A ');
	insert into takes values('22620', '581', '1', 'Spring', 2005, 'C+');
	insert into takes values('9440', '482', '1', 'Fall', 2005, 'A ');
	insert into takes values('44998', '362', '3', 'Spring', 2008, 'A+');
	insert into takes values('45770', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('43211', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('53225', '843', '1', 'Fall', 2010, 'C+');
	insert into takes values('4438', '349', '1', 'Spring', 2008, 'C-');
	insert into takes values('16515', '974', '1', 'Fall', 2003, 'C ');
	insert into takes values('95850', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('25780', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('15538', '338', '2', 'Spring', 2006, 'C ');
	insert into takes values('37856', '735', '2', 'Spring', 2010, 'B-');
	insert into takes values('12069', '443', '2', 'Spring', 2002, 'C+');
	insert into takes values('1826', '304', '1', 'Fall', 2009, 'A ');
	insert into takes values('53165', '927', '1', 'Fall', 2002, 'A-');
	insert into takes values('65396', '808', '1', 'Fall', 2003, 'B ');
	insert into takes values('7490', '626', '1', 'Fall', 2006, 'B ');
	insert into takes values('24796', '793', '1', 'Spring', 2002, 'C ');
	insert into takes values('1812', '105', '1', 'Fall', 2009, 'A+');
	insert into takes values('92776', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('94569', '852', '1', 'Spring', 2008, 'C ');
	insert into takes values('21246', '704', '1', 'Spring', 2008, 'C-');
	insert into takes values('67793', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('26147', '974', '1', 'Fall', 2003, 'B-');
	insert into takes values('56080', '345', '1', 'Spring', 2008, 'B-');
	insert into takes values('95201', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('77003', '696', '1', 'Spring', 2002, 'C ');
	insert into takes values('14668', '949', '1', 'Fall', 2007, 'C ');
	insert into takes values('74974', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('18752', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('72165', '748', '1', 'Fall', 2003, 'C ');
	insert into takes values('32119', '735', '1', 'Spring', 2003, 'C ');
	insert into takes values('14214', '270', '1', 'Spring', 2010, 'A+');
	insert into takes values('84865', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('4508', '974', '1', 'Fall', 2003, 'C-');
	insert into takes values('41211', '808', '1', 'Fall', 2003, 'C ');
	insert into takes values('94569', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('8843', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('18859', '493', '1', 'Spring', 2010, 'C-');
	insert into takes values('29514', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('21126', '561', '1', 'Fall', 2006, 'A+');
	insert into takes values('71389', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('51768', '795', '1', 'Spring', 2004, 'B-');
	insert into takes values('80742', '376', '1', 'Fall', 2006, 'A-');
	insert into takes values('75878', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('40303', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('15980', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('63538', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('95626', '169', '1', 'Spring', 2007, 'B-');
	insert into takes values('30017', '545', '1', 'Fall', 2001, 'B ');
	insert into takes values('93125', '927', '1', 'Fall', 2002, 'A-');
	insert into takes values('69581', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('40059', '445', '1', 'Spring', 2001, 'C ');
	insert into takes values('73807', '696', '1', 'Spring', 2002, 'C+');
	insert into takes values('17424', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('85849', '376', '1', 'Fall', 2006, 'C+');
	insert into takes values('71631', '169', '2', 'Fall', 2002, 'A-');
	insert into takes values('76911', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('46956', '408', '2', 'Spring', 2003, 'C ');
	insert into takes values('34158', '960', '2', 'Fall', 2006, 'C-');
	insert into takes values('93043', '581', '1', 'Spring', 2005, 'C-');
	insert into takes values('35721', '489', '1', 'Fall', 2007, 'A-');
	insert into takes values('31993', '468', '1', 'Fall', 2005, 'A-');
	insert into takes values('898', '962', '1', 'Spring', 2008, 'A ');
	insert into takes values('94894', '415', '1', 'Fall', 2010, 'C ');
	insert into takes values('50206', '949', '1', 'Fall', 2007, 'C-');
	insert into takes values('19824', '852', '1', 'Spring', 2008, 'B+');
	insert into takes values('14639', '852', '1', 'Spring', 2008, 'B+');
	insert into takes values('71904', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('67660', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('39881', '496', '1', 'Fall', 2001, 'B-');
	insert into takes values('64121', '561', '1', 'Fall', 2006, 'A+');
	insert into takes values('65056', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('15083', '581', '1', 'Spring', 2005, 'C ');
	insert into takes values('3005', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('5943', '679', '1', 'Spring', 2010, 'A ');
	insert into takes values('95840', '169', '1', 'Spring', 2007, 'C+');
	insert into takes values('65038', '747', '1', 'Spring', 2004, 'B-');
	insert into takes values('54728', '626', '1', 'Fall', 2006, 'B ');
	insert into takes values('34055', '603', '1', 'Fall', 2003, 'B ');
	insert into takes values('20445', '852', '1', 'Spring', 2008, 'C+');
	insert into takes values('18554', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('64297', '696', '1', 'Spring', 2002, 'C-');
	insert into takes values('41818', '461', '1', 'Fall', 2002, 'C+');
	insert into takes values('20489', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('58413', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('11453', '747', '1', 'Spring', 2004, 'C ');
	insert into takes values('87222', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('99399', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('72768', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('7043', '401', '1', 'Fall', 2003, 'B+');
	insert into takes values('4182', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('82688', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('67051', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('22912', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('79469', '376', '1', 'Fall', 2006, 'B ');
	insert into takes values('49611', '702', '1', 'Spring', 2001, 'C-');
	insert into takes values('11055', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('29140', '864', '1', 'Spring', 2006, 'B ');
	insert into takes values('81207', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('95225', '200', '1', 'Spring', 2007, 'B-');
	insert into takes values('4345', '735', '1', 'Spring', 2003, 'A ');
	insert into takes values('36303', '852', '1', 'Spring', 2008, 'C-');
	insert into takes values('72521', '200', '1', 'Spring', 2007, 'C-');
	insert into takes values('56058', '599', '1', 'Spring', 2003, 'A-');
	insert into takes values('14554', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('89312', '468', '2', 'Fall', 2007, 'C-');
	insert into takes values('57083', '496', '1', 'Fall', 2001, 'C-');
	insert into takes values('35687', '408', '1', 'Spring', 2007, 'A-');
	insert into takes values('435', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('14065', '400', '2', 'Fall', 2003, 'A-');
	insert into takes values('37586', '338', '2', 'Spring', 2006, 'A+');
	insert into takes values('88418', '376', '1', 'Fall', 2006, 'C ');
	insert into takes values('12214', '696', '1', 'Spring', 2002, 'C+');
	insert into takes values('31560', '493', '1', 'Spring', 2010, 'C+');
	insert into takes values('14182', '313', '1', 'Fall', 2010, 'A ');
	insert into takes values('1726', '158', '2', 'Spring', 2008, 'A ');
	insert into takes values('59530', '991', '1', 'Spring', 2008, 'C-');
	insert into takes values('61402', '200', '2', 'Fall', 2002, 'A ');
	insert into takes values('22467', '352', '1', 'Spring', 2006, 'B ');
	insert into takes values('52866', '270', '1', 'Spring', 2010, 'A-');
	insert into takes values('17192', '626', '1', 'Fall', 2006, 'B+');
	insert into takes values('90609', '443', '1', 'Spring', 2010, 'A-');
	insert into takes values('92867', '345', '1', 'Spring', 2008, 'A+');
	insert into takes values('35220', '631', '1', 'Spring', 2007, 'B ');
	insert into takes values('79329', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('52019', '974', '1', 'Fall', 2003, 'C-');
	insert into takes values('92867', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('54153', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('42843', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('18234', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('75040', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('86833', '974', '1', 'Fall', 2003, 'A+');
	insert into takes values('16993', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('35175', '476', '1', 'Fall', 2010, 'C ');
	insert into takes values('17607', '461', '1', 'Fall', 2002, 'B-');
	insert into takes values('5414', '747', '1', 'Spring', 2004, 'B+');
	insert into takes values('72006', '313', '1', 'Fall', 2010, 'B+');
	insert into takes values('83747', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('5920', '468', '1', 'Fall', 2005, 'C ');
	insert into takes values('23457', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('50039', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('74070', '376', '1', 'Fall', 2006, 'B+');
	insert into takes values('41894', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('41599', '486', '1', 'Fall', 2009, 'C+');
	insert into takes values('94990', '852', '1', 'Spring', 2008, 'C-');
	insert into takes values('89059', '158', '2', 'Spring', 2008, 'C+');
	insert into takes values('16035', '663', '1', 'Spring', 2005, 'A-');
	insert into takes values('47630', '960', '1', 'Fall', 2009, 'A+');
	insert into takes values('39927', '415', '1', 'Fall', 2010, 'C+');
	insert into takes values('19917', '445', '1', 'Spring', 2001, 'B-');
	insert into takes values('73606', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('68242', '960', '2', 'Fall', 2006, 'A ');
	insert into takes values('11126', '415', '1', 'Fall', 2010, 'B ');
	insert into takes values('19203', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('69132', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('67018', '735', '2', 'Spring', 2010, 'A-');
	insert into takes values('52707', '972', '1', 'Spring', 2009, 'A ');
	insert into takes values('44985', '864', '1', 'Spring', 2006, 'B+');
	insert into takes values('67542', '200', '2', 'Fall', 2002, 'C-');
	insert into takes values('98140', '962', '1', 'Spring', 2008, 'A+');
	insert into takes values('39241', '696', '1', 'Spring', 2002, 'A-');
	insert into takes values('64082', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('64642', '313', '1', 'Fall', 2010, 'B ');
	insert into takes values('67657', '679', '1', 'Spring', 2010, 'A+');
	insert into takes values('53172', '612', '1', 'Fall', 2007, 'B-');
	insert into takes values('27430', '960', '2', 'Fall', 2006, 'C ');
	insert into takes values('53728', '158', '1', 'Fall', 2008, 'A-');
	insert into takes values('96134', '702', '1', 'Spring', 2001, 'C ');
	insert into takes values('17924', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('48861', '867', '1', 'Fall', 2006, 'B ');
	insert into takes values('90009', '468', '2', 'Fall', 2007, 'A+');
	insert into takes values('65438', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('69628', '603', '1', 'Fall', 2003, 'B-');
	insert into takes values('85366', '747', '1', 'Spring', 2004, 'C ');
	insert into takes values('89246', '599', '1', 'Spring', 2003, 'A+');
	insert into takes values('58889', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('29803', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('55531', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('73602', '802', '1', 'Spring', 2003, 'B+');
	insert into takes values('41596', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('8819', '137', '1', 'Spring', 2002, 'C-');
	insert into takes values('14094', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('69222', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('67657', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('48660', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('62705', '408', '1', 'Spring', 2007, 'A-');
	insert into takes values('47627', '493', '1', 'Spring', 2010, 'B+');
	insert into takes values('31035', '735', '1', 'Spring', 2003, 'A+');
	insert into takes values('14284', '571', '1', 'Spring', 2004, 'A+');
	insert into takes values('8819', '105', '1', 'Fall', 2009, 'C-');
	insert into takes values('16885', '972', '1', 'Spring', 2009, 'C-');
	insert into takes values('30021', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('98423', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('8912', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('10736', '864', '1', 'Spring', 2006, 'A+');
	insert into takes values('65681', '349', '1', 'Spring', 2008, 'B+');
	insert into takes values('39901', '421', '1', 'Fall', 2004, 'A ');
	insert into takes values('8457', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('73072', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('66212', '376', '1', 'Fall', 2006, 'C+');
	insert into takes values('86001', '192', '1', 'Fall', 2002, 'C-');
	insert into takes values('63243', '893', '1', 'Fall', 2007, 'B+');
	insert into takes values('80248', '362', '1', 'Fall', 2005, 'C+');
	insert into takes values('75423', '313', '1', 'Fall', 2010, 'B ');
	insert into takes values('52856', '304', '1', 'Fall', 2009, 'B ');
	insert into takes values('11578', '476', '1', 'Fall', 2010, 'A ');
	insert into takes values('87785', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('40481', '949', '1', 'Fall', 2007, 'A-');
	insert into takes values('35357', '366', '1', 'Fall', 2005, 'C ');
	insert into takes values('36685', '376', '1', 'Fall', 2006, 'B ');
	insert into takes values('30252', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('52876', '482', '1', 'Fall', 2005, 'A+');
	insert into takes values('72521', '960', '2', 'Fall', 2006, 'B+');
	insert into takes values('7854', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('72055', '631', '1', 'Spring', 2007, 'C-');
	insert into takes values('56598', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('6712', '679', '1', 'Spring', 2010, 'A+');
	insert into takes values('68150', '338', '1', 'Spring', 2007, 'A-');
	insert into takes values('46762', '338', '1', 'Spring', 2007, 'C ');
	insert into takes values('45359', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('6367', '468', '1', 'Fall', 2005, 'C+');
	insert into takes values('97042', '486', '1', 'Fall', 2009, 'A-');
	insert into takes values('90234', '626', '1', 'Fall', 2006, 'A-');
	insert into takes values('40677', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('41988', '400', '2', 'Fall', 2003, 'C-');
	insert into takes values('47677', '927', '1', 'Fall', 2002, 'A-');
	insert into takes values('29002', '962', '1', 'Spring', 2008, 'B ');
	insert into takes values('40937', '169', '2', 'Fall', 2002, 'A ');
	insert into takes values('18941', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('44038', '631', '1', 'Spring', 2007, 'A ');
	insert into takes values('61364', '401', '1', 'Fall', 2003, 'C ');
	insert into takes values('390', '702', '1', 'Spring', 2001, 'C+');
	insert into takes values('79911', '496', '1', 'Fall', 2001, 'B-');
	insert into takes values('64259', '591', '1', 'Spring', 2005, 'A+');
	insert into takes values('44836', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('23373', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('29260', '561', '1', 'Fall', 2006, 'C ');
	insert into takes values('33882', '760', '1', 'Spring', 2004, 'B-');
	insert into takes values('81245', '362', '2', 'Fall', 2006, 'B-');
	insert into takes values('5843', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('83836', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('45300', '352', '1', 'Spring', 2006, 'C+');
	insert into takes values('39241', '242', '1', 'Fall', 2009, 'A-');
	insert into takes values('52203', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('80420', '443', '2', 'Spring', 2002, 'C+');
	insert into takes values('78858', '242', '1', 'Fall', 2009, 'C ');
	insert into takes values('42114', '352', '1', 'Spring', 2006, 'B+');
	insert into takes values('84808', '581', '1', 'Spring', 2005, 'A-');
	insert into takes values('78922', '642', '1', 'Fall', 2004, 'A+');
	insert into takes values('44584', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('99754', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('10814', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('65241', '748', '1', 'Fall', 2003, 'A-');
	insert into takes values('59046', '612', '1', 'Fall', 2007, 'B-');
	insert into takes values('71543', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('8426', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('69752', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('66293', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('10917', '559', '1', 'Fall', 2002, 'C+');
	insert into takes values('84654', '461', '1', 'Fall', 2002, 'B-');
	insert into takes values('92693', '603', '1', 'Fall', 2003, 'B+');
	insert into takes values('13757', '200', '1', 'Spring', 2007, 'A+');
	insert into takes values('46074', '704', '1', 'Spring', 2008, 'C-');
	insert into takes values('40481', '496', '1', 'Fall', 2001, 'B ');
	insert into takes values('34404', '105', '2', 'Fall', 2002, 'B-');
	insert into takes values('39927', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('79205', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('26427', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('94178', '962', '1', 'Spring', 2008, 'A ');
	insert into takes values('76768', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('4438', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('81789', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('54508', '200', '2', 'Fall', 2002, 'B+');
	insert into takes values('30252', '319', '1', 'Spring', 2003, 'B ');
	insert into takes values('81031', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('64914', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('1727', '561', '1', 'Fall', 2006, 'C+');
	insert into takes values('90814', '476', '1', 'Fall', 2010, 'B ');
	insert into takes values('74473', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('4435', '493', '1', 'Spring', 2010, 'C ');
	insert into takes values('63449', '258', '1', 'Fall', 2007, 'A+');
	insert into takes values('82970', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('96178', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('90448', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('77289', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('87044', '461', '1', 'Fall', 2002, 'B-');
	insert into takes values('52371', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('53728', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('75772', '974', '1', 'Fall', 2003, 'A-');
	insert into takes values('91580', '319', '1', 'Spring', 2003, 'C+');
	insert into takes values('41751', '959', '1', 'Fall', 2006, 'C+');
	insert into takes values('94535', '352', '1', 'Spring', 2006, 'A+');
	insert into takes values('61232', '415', '1', 'Fall', 2010, 'C+');
	insert into takes values('15070', '599', '1', 'Spring', 2003, 'A-');
	insert into takes values('99268', '959', '1', 'Fall', 2006, 'B+');
	insert into takes values('76799', '169', '2', 'Fall', 2002, 'B+');
	insert into takes values('83836', '158', '2', 'Spring', 2008, 'A-');
	insert into takes values('86344', '748', '1', 'Fall', 2003, 'B ');
	insert into takes values('41211', '802', '1', 'Spring', 2003, 'C+');
	insert into takes values('52076', '808', '1', 'Fall', 2003, 'B-');
	insert into takes values('43981', '735', '2', 'Spring', 2010, 'A+');
	insert into takes values('89104', '482', '1', 'Fall', 2005, 'C ');
	insert into takes values('23110', '791', '1', 'Spring', 2006, 'B+');
	insert into takes values('22086', '808', '1', 'Fall', 2003, 'B-');
	insert into takes values('68263', '852', '1', 'Spring', 2008, 'C ');
	insert into takes values('10204', '443', '1', 'Spring', 2010, 'C ');
	insert into takes values('49391', '313', '1', 'Fall', 2010, 'A ');
	insert into takes values('18338', '591', '1', 'Spring', 2005, 'A+');
	insert into takes values('25718', '366', '1', 'Fall', 2005, 'C-');
	insert into takes values('13826', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('91132', '158', '1', 'Fall', 2008, 'A ');
	insert into takes values('29665', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('43495', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('288', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('66259', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('64164', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('77289', '571', '1', 'Spring', 2004, 'C ');
	insert into takes values('90779', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('72521', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('19824', '415', '1', 'Fall', 2010, 'B ');
	insert into takes values('68150', '493', '1', 'Spring', 2010, 'C ');
	insert into takes values('30188', '400', '1', 'Spring', 2007, 'A ');
	insert into takes values('37734', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('98047', '338', '1', 'Spring', 2007, 'C-');
	insert into takes values('41280', '137', '1', 'Spring', 2002, 'A-');
	insert into takes values('72959', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('32464', '489', '1', 'Fall', 2007, 'C ');
	insert into takes values('98870', '642', '1', 'Fall', 2004, 'B-');
	insert into takes values('11604', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('32954', '457', '1', 'Spring', 2001, 'A ');
	insert into takes values('65979', '747', '1', 'Spring', 2004, 'C ');
	insert into takes values('36379', '793', '1', 'Spring', 2002, 'A ');
	insert into takes values('34195', '313', '1', 'Fall', 2010, 'B-');
	insert into takes values('78143', '400', '1', 'Spring', 2007, 'B+');
	insert into takes values('95850', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('53496', '486', '1', 'Fall', 2009, 'C+');
	insert into takes values('28829', '603', '1', 'Fall', 2003, 'A ');
	insert into takes values('30341', '692', '1', 'Spring', 2010, 'A-');
	insert into takes values('75273', '493', '1', 'Spring', 2010, 'B ');
	insert into takes values('31035', '760', '1', 'Spring', 2004, 'B+');
	insert into takes values('62784', '747', '1', 'Spring', 2004, 'B-');
	insert into takes values('19536', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('62054', '158', '1', 'Fall', 2008, 'C ');
	insert into takes values('84654', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('7956', '158', '2', 'Spring', 2008, 'B+');
	insert into takes values('25380', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('75794', '493', '1', 'Spring', 2010, 'A-');
	insert into takes values('4355', '972', '1', 'Spring', 2009, 'A-');
	insert into takes values('61356', '735', '2', 'Spring', 2010, 'B ');
	insert into takes values('78756', '349', '1', 'Spring', 2008, 'B+');
	insert into takes values('61854', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('39881', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('26080', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('66281', '694', '1', 'Fall', 2002, 'A ');
	insert into takes values('69628', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('18583', '105', '2', 'Fall', 2002, 'B-');
	insert into takes values('38899', '415', '1', 'Fall', 2010, 'A+');
	insert into takes values('91580', '867', '2', 'Fall', 2010, 'B-');
	insert into takes values('80420', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('46066', '105', '1', 'Fall', 2009, 'B ');
	insert into takes values('69853', '591', '1', 'Spring', 2005, 'C-');
	insert into takes values('898', '415', '1', 'Fall', 2010, 'A-');
	insert into takes values('336', '476', '1', 'Fall', 2010, 'C-');
	insert into takes values('39238', '735', '2', 'Spring', 2010, 'A ');
	insert into takes values('90372', '352', '1', 'Spring', 2006, 'B+');
	insert into takes values('42956', '960', '1', 'Fall', 2009, 'B-');
	insert into takes values('66763', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('88884', '338', '2', 'Spring', 2006, 'B+');
	insert into takes values('28361', '545', '1', 'Fall', 2001, 'A-');
	insert into takes values('14668', '748', '1', 'Fall', 2003, 'A-');
	insert into takes values('61998', '401', '1', 'Fall', 2003, 'C ');
	insert into takes values('41599', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('10204', '875', '1', 'Spring', 2005, 'A+');
	insert into takes values('91091', '496', '1', 'Fall', 2001, 'C-');
	insert into takes values('87054', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('57334', '795', '1', 'Spring', 2004, 'B-');
	insert into takes values('25077', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('58935', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('99348', '527', '1', 'Fall', 2004, 'C-');
	insert into takes values('63612', '893', '1', 'Fall', 2007, 'C+');
	insert into takes values('9933', '443', '2', 'Spring', 2002, 'A+');
	insert into takes values('37734', '927', '1', 'Fall', 2002, 'C+');
	insert into takes values('81984', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('67293', '808', '1', 'Fall', 2003, 'B ');
	insert into takes values('13504', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('47677', '843', '1', 'Fall', 2010, 'B-');
	insert into takes values('52856', '760', '1', 'Spring', 2004, 'C ');
	insert into takes values('45720', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('54612', '663', '1', 'Spring', 2005, 'A ');
	insert into takes values('37759', '893', '1', 'Fall', 2007, 'A+');
	insert into takes values('14829', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('78116', '599', '1', 'Spring', 2003, 'C+');
	insert into takes values('58595', '400', '2', 'Fall', 2003, 'C+');
	insert into takes values('34957', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('11101', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('34329', '468', '1', 'Fall', 2005, 'C+');
	insert into takes values('39876', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('11377', '704', '1', 'Spring', 2008, 'C-');
	insert into takes values('56089', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('52494', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('63090', '345', '1', 'Spring', 2008, 'B ');
	insert into takes values('65299', '852', '1', 'Spring', 2008, 'C+');
	insert into takes values('2848', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('94522', '493', '1', 'Spring', 2010, 'B ');
	insert into takes values('23392', '694', '1', 'Fall', 2002, 'C+');
	insert into takes values('45826', '493', '1', 'Spring', 2010, 'A+');
	insert into takes values('77729', '400', '2', 'Fall', 2003, 'A+');
	insert into takes values('19050', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('1884', '362', '1', 'Fall', 2005, 'C ');
	insert into takes values('53788', '468', '2', 'Fall', 2007, 'A+');
	insert into takes values('56598', '237', '2', 'Fall', 2009, 'A-');
	insert into takes values('46260', '105', '2', 'Fall', 2002, 'A ');
	insert into takes values('20985', '875', '1', 'Spring', 2005, 'C ');
	insert into takes values('86327', '319', '1', 'Spring', 2003, 'B ');
	insert into takes values('39619', '400', '1', 'Spring', 2007, 'C ');
	insert into takes values('32345', '366', '1', 'Fall', 2005, 'C-');
	insert into takes values('63886', '366', '1', 'Fall', 2005, 'C ');
	insert into takes values('21401', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('55940', '105', '2', 'Fall', 2002, 'C+');
	insert into takes values('2178', '169', '2', 'Fall', 2002, 'B-');
	insert into takes values('9659', '338', '1', 'Spring', 2007, 'B-');
	insert into takes values('41973', '237', '1', 'Spring', 2008, 'C-');
	insert into takes values('18808', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('19220', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('8986', '692', '1', 'Spring', 2010, 'A-');
	insert into takes values('94846', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('56139', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('78434', '843', '1', 'Fall', 2010, 'C+');
	insert into takes values('57666', '242', '1', 'Fall', 2009, 'B+');
	insert into takes values('52856', '169', '1', 'Spring', 2007, 'B-');
	insert into takes values('68779', '867', '2', 'Fall', 2010, 'C ');
	insert into takes values('86127', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('88287', '642', '1', 'Fall', 2004, 'C+');
	insert into takes values('41406', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('31035', '338', '1', 'Spring', 2007, 'C ');
	insert into takes values('80113', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('16631', '559', '1', 'Fall', 2002, 'B+');
	insert into takes values('32217', '960', '1', 'Fall', 2009, 'A+');
	insert into takes values('68516', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('82918', '400', '1', 'Spring', 2007, 'A+');
	insert into takes values('35', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('59117', '604', '1', 'Spring', 2009, 'C ');
	insert into takes values('1402', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('79329', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('6287', '242', '1', 'Fall', 2009, 'A-');
	insert into takes values('69752', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('25940', '476', '1', 'Fall', 2010, 'B ');
	insert into takes values('57135', '747', '1', 'Spring', 2004, 'B-');
	insert into takes values('14094', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('12683', '319', '1', 'Spring', 2003, 'B-');
	insert into takes values('81028', '702', '1', 'Spring', 2001, 'A-');
	insert into takes values('13757', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('10727', '959', '1', 'Fall', 2006, 'B ');
	insert into takes values('86552', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('25725', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('30474', '702', '1', 'Spring', 2001, 'C-');
	insert into takes values('51008', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('50039', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('75241', '791', '1', 'Spring', 2006, 'A ');
	insert into takes values('22345', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('38691', '571', '1', 'Spring', 2004, 'C ');
	insert into takes values('1827', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('39892', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('27430', '571', '1', 'Spring', 2004, 'C+');
	insert into takes values('53805', '362', '2', 'Fall', 2006, 'B-');
	insert into takes values('66054', '400', '2', 'Fall', 2003, 'C+');
	insert into takes values('69132', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('35498', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('16969', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('50537', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('17207', '476', '1', 'Fall', 2010, 'A ');
	insert into takes values('8378', '493', '1', 'Spring', 2010, 'A-');
	insert into takes values('42114', '960', '1', 'Fall', 2009, 'B+');
	insert into takes values('24201', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('47670', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('30650', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('20378', '893', '1', 'Fall', 2007, 'A+');
	insert into takes values('78572', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('50702', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('23270', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('52741', '169', '1', 'Spring', 2007, 'A ');
	insert into takes values('77218', '795', '1', 'Spring', 2004, 'B-');
	insert into takes values('11682', '735', '1', 'Spring', 2003, 'C ');
	insert into takes values('57135', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('95089', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('39892', '867', '1', 'Fall', 2006, 'A+');
	insert into takes values('43505', '304', '1', 'Fall', 2009, 'A ');
	insert into takes values('70452', '581', '1', 'Spring', 2005, 'C-');
	insert into takes values('9947', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('11095', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('12069', '748', '1', 'Fall', 2003, 'A-');
	insert into takes values('7390', '735', '2', 'Spring', 2010, 'C ');
	insert into takes values('62520', '704', '1', 'Spring', 2008, 'A+');
	insert into takes values('15249', '319', '1', 'Spring', 2003, 'A-');
	insert into takes values('59046', '137', '1', 'Spring', 2002, 'A-');
	insert into takes values('49701', '200', '1', 'Spring', 2007, 'B-');
	insert into takes values('69225', '612', '1', 'Fall', 2007, 'A+');
	insert into takes values('1827', '376', '1', 'Fall', 2006, 'B-');
	insert into takes values('32506', '612', '1', 'Fall', 2007, 'B ');
	insert into takes values('96324', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('41280', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('38545', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('59673', '631', '1', 'Spring', 2007, 'C-');
	insert into takes values('57160', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('63289', '426', '1', 'Spring', 2006, 'A ');
	insert into takes values('4173', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('50013', '679', '1', 'Spring', 2010, 'C-');
	insert into takes values('58846', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('87784', '401', '1', 'Fall', 2003, 'A-');
	insert into takes values('32490', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('34404', '867', '2', 'Fall', 2010, 'C ');
	insert into takes values('32217', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('81876', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('24746', '408', '2', 'Spring', 2003, 'C ');
	insert into takes values('57962', '200', '2', 'Fall', 2002, 'C+');
	insert into takes values('59553', '696', '1', 'Spring', 2002, 'A-');
	insert into takes values('72528', '338', '2', 'Spring', 2006, 'B+');
	insert into takes values('14874', '345', '1', 'Spring', 2008, 'B-');
	insert into takes values('36657', '612', '1', 'Fall', 2007, 'A ');
	insert into takes values('19245', '559', '1', 'Fall', 2002, 'C-');
	insert into takes values('61081', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('64192', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('73606', '702', '1', 'Spring', 2001, 'B ');
	insert into takes values('19450', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('23270', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('93039', '793', '1', 'Spring', 2002, 'A-');
	insert into takes values('36052', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('13290', '319', '1', 'Spring', 2003, 'B-');
	insert into takes values('90372', '793', '1', 'Spring', 2002, 'C-');
	insert into takes values('77172', '468', '2', 'Fall', 2007, 'A-');
	insert into takes values('99710', '408', '2', 'Spring', 2003, 'B ');
	insert into takes values('667', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('76911', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('35357', '867', '1', 'Fall', 2006, 'C+');
	insert into takes values('92464', '482', '1', 'Fall', 2005, 'A+');
	insert into takes values('49618', '352', '1', 'Spring', 2006, 'A+');
	insert into takes values('72768', '345', '1', 'Spring', 2008, 'A ');
	insert into takes values('98619', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('29849', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('42956', '443', '1', 'Spring', 2010, 'C ');
	insert into takes values('30017', '400', '1', 'Spring', 2007, 'C ');
	insert into takes values('76953', '258', '1', 'Fall', 2007, 'A ');
	insert into takes values('60249', '692', '1', 'Spring', 2010, 'C ');
	insert into takes values('33338', '760', '1', 'Spring', 2004, 'A-');
	insert into takes values('80047', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('96003', '426', '1', 'Spring', 2006, 'A+');
	insert into takes values('85063', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('14214', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('93571', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('83592', '496', '1', 'Fall', 2001, 'A-');
	insert into takes values('79469', '867', '1', 'Fall', 2006, 'A+');
	insert into takes values('30474', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('1826', '443', '2', 'Spring', 2002, 'C+');
	insert into takes values('66969', '105', '2', 'Fall', 2002, 'B+');
	insert into takes values('52203', '334', '1', 'Fall', 2009, 'B+');
	insert into takes values('85356', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('77289', '959', '1', 'Fall', 2006, 'A+');
	insert into takes values('74070', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('5920', '426', '1', 'Spring', 2006, 'C ');
	insert into takes values('27094', '927', '1', 'Fall', 2002, 'C+');
	insert into takes values('86707', '626', '1', 'Fall', 2006, 'B+');
	insert into takes values('11578', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('56499', '258', '1', 'Fall', 2007, 'A ');
	insert into takes values('17911', '864', '1', 'Spring', 2006, 'A+');
	insert into takes values('85746', '137', '1', 'Spring', 2002, 'A ');
	insert into takes values('44985', '571', '1', 'Spring', 2004, 'C ');
	insert into takes values('56849', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('32385', '258', '1', 'Fall', 2007, 'B-');
	insert into takes values('87044', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('74974', '362', '1', 'Fall', 2005, 'C+');
	insert into takes values('37856', '426', '1', 'Spring', 2006, 'A ');
	insert into takes values('15249', '493', '1', 'Spring', 2010, 'C-');
	insert into takes values('26730', '949', '1', 'Fall', 2007, 'B ');
	insert into takes values('14596', '468', '1', 'Fall', 2005, 'A-');
	insert into takes values('33645', '274', '1', 'Fall', 2002, 'C+');
	insert into takes values('71543', '496', '1', 'Fall', 2001, 'B ');
	insert into takes values('55009', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('56486', '258', '1', 'Fall', 2007, 'C ');
	insert into takes values('24197', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('25256', '696', '1', 'Spring', 2002, 'A-');
	insert into takes values('67371', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('69230', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('99730', '401', '1', 'Fall', 2003, 'A+');
	insert into takes values('13741', '486', '1', 'Fall', 2009, 'C+');
	insert into takes values('64550', '793', '1', 'Spring', 2002, 'C-');
	insert into takes values('21766', '401', '1', 'Fall', 2003, 'A-');
	insert into takes values('36791', '158', '1', 'Fall', 2008, 'C ');
	insert into takes values('69307', '702', '1', 'Spring', 2001, 'C ');
	insert into takes values('914', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('64192', '808', '1', 'Fall', 2003, 'B ');
	insert into takes values('51868', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('95205', '962', '1', 'Spring', 2008, 'B-');
	insert into takes values('44551', '319', '1', 'Spring', 2003, 'B ');
	insert into takes values('94142', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('80047', '200', '1', 'Spring', 2007, 'B+');
	insert into takes values('13081', '304', '1', 'Fall', 2009, 'C+');
	insert into takes values('76049', '852', '1', 'Spring', 2008, 'B-');
	insert into takes values('33882', '960', '1', 'Fall', 2009, 'C-');
	insert into takes values('58465', '843', '1', 'Fall', 2010, 'A-');
	insert into takes values('43226', '334', '1', 'Fall', 2009, 'A ');
	insert into takes values('8140', '696', '1', 'Spring', 2002, 'A-');
	insert into takes values('25552', '443', '2', 'Spring', 2002, 'C+');
	insert into takes values('83480', '867', '2', 'Fall', 2010, 'C ');
	insert into takes values('32369', '791', '1', 'Spring', 2006, 'A-');
	insert into takes values('15144', '445', '1', 'Spring', 2001, 'B-');
	insert into takes values('91992', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('77130', '893', '1', 'Fall', 2007, 'C+');
	insert into takes values('17996', '545', '1', 'Fall', 2001, 'A-');
	insert into takes values('16133', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('10033', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('5843', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('29462', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('16753', '445', '1', 'Spring', 2001, 'B-');
	insert into takes values('93653', '334', '1', 'Fall', 2009, 'A ');
	insert into takes values('70522', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('80254', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('41345', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('80698', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('96710', '352', '1', 'Spring', 2006, 'C ');
	insert into takes values('24865', '443', '2', 'Spring', 2002, 'A-');
	insert into takes values('41671', '200', '1', 'Spring', 2007, 'C ');
	insert into takes values('19048', '457', '1', 'Spring', 2001, 'C ');
	insert into takes values('37586', '468', '1', 'Fall', 2005, 'C ');
	insert into takes values('14596', '237', '1', 'Spring', 2008, 'C-');
	insert into takes values('72959', '735', '1', 'Spring', 2003, 'C ');
	insert into takes values('15083', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('27662', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('888', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('1922', '604', '1', 'Spring', 2009, 'B-');
	insert into takes values('10076', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('44551', '169', '2', 'Fall', 2002, 'C ');
	insert into takes values('43989', '864', '1', 'Spring', 2006, 'C-');
	insert into takes values('35175', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('80912', '362', '1', 'Fall', 2005, 'B ');
	insert into takes values('74464', '421', '1', 'Fall', 2004, 'A ');
	insert into takes values('97228', '496', '1', 'Fall', 2001, 'B+');
	insert into takes values('15083', '237', '2', 'Fall', 2009, 'C ');
	insert into takes values('69285', '571', '1', 'Spring', 2004, 'B+');
	insert into takes values('24784', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('51579', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('65987', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('52385', '105', '2', 'Fall', 2002, 'A ');
	insert into takes values('18367', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('95574', '319', '1', 'Spring', 2003, 'A-');
	insert into takes values('49450', '612', '1', 'Fall', 2007, 'B-');
	insert into takes values('37103', '545', '1', 'Fall', 2001, 'A ');
	insert into takes values('67436', '927', '1', 'Fall', 2002, 'C+');
	insert into takes values('2419', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('37759', '445', '1', 'Spring', 2001, 'B+');
	insert into takes values('31554', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('68712', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('73165', '581', '1', 'Spring', 2005, 'A-');
	insert into takes values('96227', '489', '1', 'Fall', 2007, 'B-');
	insert into takes values('15538', '137', '1', 'Spring', 2002, 'B ');
	insert into takes values('93171', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('59538', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('6209', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('58919', '334', '1', 'Fall', 2009, 'A ');
	insert into takes values('30772', '692', '1', 'Spring', 2010, 'C-');
	insert into takes values('32217', '426', '1', 'Spring', 2006, 'A+');
	insert into takes values('14581', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('58594', '631', '1', 'Spring', 2007, 'A-');
	insert into takes values('30858', '362', '1', 'Fall', 2005, 'C ');
	insert into takes values('67560', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('44816', '242', '1', 'Fall', 2009, 'B+');
	insert into takes values('90779', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('72959', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('25780', '482', '1', 'Fall', 2005, 'B-');
	insert into takes values('91788', '338', '2', 'Spring', 2006, 'A+');
	insert into takes values('31476', '443', '2', 'Spring', 2002, 'A-');
	insert into takes values('95574', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('23794', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('50467', '443', '2', 'Spring', 2002, 'C-');
	insert into takes values('80976', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('27952', '960', '1', 'Fall', 2009, 'B ');
	insert into takes values('80610', '559', '1', 'Fall', 2002, 'A-');
	insert into takes values('20195', '626', '1', 'Fall', 2006, 'C ');
	insert into takes values('66106', '338', '2', 'Spring', 2006, 'A+');
	insert into takes values('31266', '105', '2', 'Fall', 2002, 'A+');
	insert into takes values('67725', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('12078', '105', '1', 'Fall', 2009, 'C+');
	insert into takes values('91197', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('11076', '974', '1', 'Fall', 2003, 'B-');
	insert into takes values('2967', '468', '2', 'Fall', 2007, 'C+');
	insert into takes values('95840', '960', '1', 'Fall', 2009, 'A-');
	insert into takes values('28409', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('50658', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('11095', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('74840', '991', '1', 'Spring', 2008, 'B-');
	insert into takes values('63310', '400', '2', 'Fall', 2003, 'B-');
	insert into takes values('84865', '793', '1', 'Spring', 2002, 'B+');
	insert into takes values('30474', '561', '1', 'Fall', 2006, 'C ');
	insert into takes values('463', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('34018', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('31266', '426', '1', 'Spring', 2006, 'B ');
	insert into takes values('13921', '105', '2', 'Fall', 2002, 'C+');
	insert into takes values('84039', '362', '2', 'Fall', 2006, 'A ');
	insert into takes values('53152', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('85505', '476', '1', 'Fall', 2010, 'A+');
	insert into takes values('95099', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('49450', '793', '1', 'Spring', 2002, 'C-');
	insert into takes values('8603', '795', '1', 'Spring', 2004, 'B+');
	insert into takes values('70395', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('68999', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('80610', '489', '1', 'Fall', 2007, 'B ');
	insert into takes values('16515', '366', '1', 'Fall', 2005, 'A ');
	insert into takes values('53118', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('18809', '270', '1', 'Spring', 2010, 'B-');
	insert into takes values('52656', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('16515', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('1954', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('94569', '349', '1', 'Spring', 2008, 'B+');
	insert into takes values('82646', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('43211', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('21126', '400', '2', 'Fall', 2003, 'A+');
	insert into takes values('2795', '270', '1', 'Spring', 2010, 'B+');
	insert into takes values('99760', '702', '1', 'Spring', 2001, 'C+');
	insert into takes values('23934', '408', '1', 'Spring', 2007, 'C ');
	insert into takes values('74509', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('87785', '748', '1', 'Fall', 2003, 'C-');
	insert into takes values('53225', '468', '1', 'Fall', 2005, 'A ');
	insert into takes values('53485', '362', '2', 'Fall', 2006, 'A ');
	insert into takes values('499', '960', '1', 'Fall', 2009, 'C-');
	insert into takes values('91370', '313', '1', 'Fall', 2010, 'C-');
	insert into takes values('97041', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('42956', '421', '1', 'Fall', 2004, 'B-');
	insert into takes values('84410', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('68779', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('45436', '603', '1', 'Fall', 2003, 'B ');
	insert into takes values('18821', '626', '1', 'Fall', 2006, 'B ');
	insert into takes values('29705', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('70688', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('99553', '748', '1', 'Fall', 2003, 'B-');
	insert into takes values('26427', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('86127', '974', '1', 'Fall', 2003, 'A+');
	insert into takes values('79589', '137', '1', 'Spring', 2002, 'B ');
	insert into takes values('24932', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('40178', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('98315', '192', '1', 'Fall', 2002, 'A+');
	insert into takes values('12711', '959', '1', 'Fall', 2006, 'C+');
	insert into takes values('31337', '408', '1', 'Spring', 2007, 'C+');
	insert into takes values('99711', '489', '1', 'Fall', 2007, 'C ');
	insert into takes values('91580', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('84239', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('94324', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('11083', '793', '1', 'Spring', 2002, 'A-');
	insert into takes values('9460', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('99226', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('12078', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('96911', '304', '1', 'Fall', 2009, 'B+');
	insert into takes values('41345', '972', '1', 'Spring', 2009, 'A ');
	insert into takes values('44271', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('65190', '493', '1', 'Spring', 2010, 'A-');
	insert into takes values('40937', '376', '1', 'Fall', 2006, 'B ');
	insert into takes values('44706', '893', '1', 'Fall', 2007, 'B+');
	insert into takes values('42843', '401', '1', 'Fall', 2003, 'C+');
	insert into takes values('36263', '760', '1', 'Spring', 2004, 'C ');
	insert into takes values('16528', '629', '1', 'Spring', 2003, 'A+');
	insert into takes values('43123', '793', '1', 'Spring', 2002, 'A+');
	insert into takes values('78581', '313', '1', 'Fall', 2010, 'A-');
	insert into takes values('67660', '239', '1', 'Fall', 2006, 'C+');
	insert into takes values('8378', '237', '1', 'Spring', 2008, 'B-');
	insert into takes values('51868', '421', '1', 'Fall', 2004, 'C ');
	insert into takes values('15487', '962', '1', 'Spring', 2008, 'B-');
	insert into takes values('67371', '169', '1', 'Spring', 2007, 'B-');
	insert into takes values('28977', '571', '1', 'Spring', 2004, 'B+');
	insert into takes values('83871', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('96134', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('81031', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('7498', '158', '2', 'Spring', 2008, 'B-');
	insert into takes values('18367', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('80057', '242', '1', 'Fall', 2009, 'C+');
	insert into takes values('70965', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('72485', '793', '1', 'Spring', 2002, 'B ');
	insert into takes values('96772', '443', '1', 'Spring', 2010, 'A-');
	insert into takes values('13023', '362', '2', 'Fall', 2006, 'C-');
	insert into takes values('72669', '802', '1', 'Spring', 2003, 'B+');
	insert into takes values('5399', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('40481', '793', '1', 'Spring', 2002, 'C ');
	insert into takes values('41938', '200', '1', 'Spring', 2007, 'C-');
	insert into takes values('78767', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('65299', '352', '1', 'Spring', 2006, 'B ');
	insert into takes values('50966', '603', '1', 'Fall', 2003, 'C-');
	insert into takes values('94814', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('29707', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('16133', '376', '1', 'Fall', 2006, 'A ');
	insert into takes values('38696', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('6523', '443', '2', 'Spring', 2002, 'C ');
	insert into takes values('66106', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('29871', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('74070', '559', '1', 'Fall', 2002, 'B ');
	insert into takes values('86934', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('6474', '457', '1', 'Spring', 2001, 'B-');
	insert into takes values('61356', '457', '1', 'Spring', 2001, 'A ');
	insert into takes values('987', '200', '1', 'Spring', 2007, 'B-');
	insert into takes values('35175', '760', '1', 'Spring', 2004, 'B-');
	insert into takes values('17665', '445', '1', 'Spring', 2001, 'A-');
	insert into takes values('4015', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('53728', '493', '1', 'Spring', 2010, 'C+');
	insert into takes values('39521', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('49873', '443', '1', 'Spring', 2010, 'C ');
	insert into takes values('85614', '158', '1', 'Fall', 2008, 'A+');
	insert into takes values('69222', '443', '1', 'Spring', 2010, 'B-');
	insert into takes values('57787', '867', '1', 'Fall', 2006, 'A+');
	insert into takes values('36384', '735', '2', 'Spring', 2010, 'B ');
	insert into takes values('84039', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('16480', '852', '1', 'Spring', 2008, 'A ');
	insert into takes values('435', '400', '1', 'Spring', 2007, 'A+');
	insert into takes values('24630', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('67222', '457', '1', 'Spring', 2001, 'C ');
	insert into takes values('52076', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('77003', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('68999', '972', '1', 'Spring', 2009, 'A ');
	insert into takes values('80698', '735', '1', 'Spring', 2003, 'A+');
	insert into takes values('86075', '338', '2', 'Spring', 2006, 'C+');
	insert into takes values('52656', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('76759', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('42388', '629', '1', 'Spring', 2003, 'A+');
	insert into takes values('17076', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('81883', '200', '2', 'Fall', 2002, 'A ');
	insert into takes values('73328', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('75772', '338', '1', 'Spring', 2007, 'C+');
	insert into takes values('36685', '338', '2', 'Spring', 2006, 'B ');
	insert into takes values('18941', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('15613', '496', '1', 'Fall', 2001, 'C-');
	insert into takes values('8347', '415', '1', 'Fall', 2010, 'A-');
	insert into takes values('72521', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('39472', '527', '1', 'Fall', 2004, 'C ');
	insert into takes values('43658', '400', '1', 'Spring', 2007, 'B ');
	insert into takes values('38545', '626', '1', 'Fall', 2006, 'B-');
	insert into takes values('89106', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('39115', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('65329', '843', '1', 'Fall', 2010, 'C ');
	insert into takes values('88577', '631', '1', 'Spring', 2007, 'A ');
	insert into takes values('36845', '426', '1', 'Spring', 2006, 'A-');
	insert into takes values('19638', '345', '1', 'Spring', 2008, 'C ');
	insert into takes values('36685', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('12615', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('23992', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('39978', '591', '1', 'Spring', 2005, 'B-');
	insert into takes values('22620', '158', '2', 'Spring', 2008, 'A ');
	insert into takes values('10076', '137', '1', 'Spring', 2002, 'B+');
	insert into takes values('88472', '349', '1', 'Spring', 2008, 'A ');
	insert into takes values('35935', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('29803', '242', '1', 'Fall', 2009, 'A+');
	insert into takes values('12236', '960', '2', 'Fall', 2006, 'C-');
	insert into takes values('29031', '791', '1', 'Spring', 2006, 'A-');
	insert into takes values('28409', '400', '2', 'Fall', 2003, 'A-');
	insert into takes values('7043', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('78581', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('98843', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('80821', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('84792', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('95320', '692', '1', 'Spring', 2010, 'A+');
	insert into takes values('63886', '408', '1', 'Spring', 2007, 'B ');
	insert into takes values('93039', '493', '1', 'Spring', 2010, 'B ');
	insert into takes values('46074', '362', '1', 'Fall', 2005, 'C-');
	insert into takes values('98315', '692', '1', 'Spring', 2010, 'B-');
	insert into takes values('31820', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('83686', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('95284', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('90220', '679', '1', 'Spring', 2010, 'B+');
	insert into takes values('98984', '864', '1', 'Spring', 2006, 'A+');
	insert into takes values('74530', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('82970', '991', '1', 'Spring', 2008, 'B ');
	insert into takes values('22086', '345', '1', 'Spring', 2008, 'A-');
	insert into takes values('51698', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('36265', '105', '2', 'Fall', 2002, 'A-');
	insert into takes values('33817', '486', '1', 'Fall', 2009, 'C ');
	insert into takes values('69758', '747', '1', 'Spring', 2004, 'C-');
	insert into takes values('10527', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('81984', '443', '2', 'Spring', 2002, 'A+');
	insert into takes values('36379', '237', '2', 'Fall', 2009, 'C ');
	insert into takes values('69132', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('18859', '972', '1', 'Spring', 2009, 'B-');
	insert into takes values('48850', '200', '2', 'Fall', 2002, 'B-');
	insert into takes values('67017', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('54728', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('75395', '843', '1', 'Fall', 2010, 'B-');
	insert into takes values('78481', '158', '2', 'Spring', 2008, 'A ');
	insert into takes values('5943', '334', '1', 'Fall', 2009, 'B ');
	insert into takes values('95366', '476', '1', 'Fall', 2010, 'A ');
	insert into takes values('90448', '599', '1', 'Spring', 2003, 'B ');
	insert into takes values('51862', '893', '1', 'Fall', 2007, 'B-');
	insert into takes values('91132', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('30943', '702', '1', 'Spring', 2001, 'C+');
	insert into takes values('85602', '927', '1', 'Fall', 2002, 'B-');
	insert into takes values('46436', '242', '1', 'Fall', 2009, 'A ');
	insert into takes values('25528', '793', '1', 'Spring', 2002, 'C ');
	insert into takes values('56755', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('50039', '270', '1', 'Spring', 2010, 'A+');
	insert into takes values('8343', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('93508', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('11262', '105', '2', 'Fall', 2002, 'B+');
	insert into takes values('78434', '679', '1', 'Spring', 2010, 'A ');
	insert into takes values('31035', '875', '1', 'Spring', 2005, 'A+');
	insert into takes values('41965', '852', '1', 'Spring', 2008, 'B+');
	insert into takes values('62716', '349', '1', 'Spring', 2008, 'A ');
	insert into takes values('53152', '591', '1', 'Spring', 2005, 'A+');
	insert into takes values('13753', '960', '2', 'Fall', 2006, 'A ');
	insert into takes values('56755', '421', '1', 'Fall', 2004, 'A ');
	insert into takes values('79170', '445', '1', 'Spring', 2001, 'A-');
	insert into takes values('3335', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('15883', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('92417', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('30474', '527', '1', 'Fall', 2004, 'B+');
	insert into takes values('22057', '443', '2', 'Spring', 2002, 'A-');
	insert into takes values('21126', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('57185', '468', '1', 'Fall', 2005, 'B+');
	insert into takes values('96003', '663', '1', 'Spring', 2005, 'C ');
	insert into takes values('8819', '626', '1', 'Fall', 2006, 'A ');
	insert into takes values('1367', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('58889', '158', '2', 'Spring', 2008, 'C-');
	insert into takes values('41683', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('13028', '631', '1', 'Spring', 2007, 'B ');
	insert into takes values('80227', '158', '2', 'Spring', 2008, 'A ');
	insert into takes values('23500', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('18821', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('24116', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('96895', '591', '1', 'Spring', 2005, 'B ');
	insert into takes values('88140', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('34197', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('61232', '852', '1', 'Spring', 2008, 'B ');
	insert into takes values('82918', '581', '1', 'Spring', 2005, 'B+');
	insert into takes values('92385', '304', '1', 'Fall', 2009, 'B ');
	insert into takes values('77234', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('95626', '808', '1', 'Fall', 2003, 'B ');
	insert into takes values('42092', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('56882', '270', '1', 'Spring', 2010, 'A+');
	insert into takes values('36126', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('41832', '338', '1', 'Spring', 2007, 'B ');
	insert into takes values('32345', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('59397', '612', '1', 'Fall', 2007, 'B-');
	insert into takes values('84704', '445', '1', 'Spring', 2001, 'B-');
	insert into takes values('72521', '626', '1', 'Fall', 2006, 'C ');
	insert into takes values('90567', '960', '2', 'Fall', 2006, 'B-');
	insert into takes values('7204', '366', '1', 'Fall', 2005, 'B ');
	insert into takes values('44703', '319', '1', 'Spring', 2003, 'C+');
	insert into takes values('27366', '694', '1', 'Fall', 2002, 'A+');
	insert into takes values('87054', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('53089', '962', '1', 'Spring', 2008, 'C+');
	insert into takes values('259', '735', '1', 'Spring', 2003, 'C+');
	insert into takes values('41596', '496', '1', 'Fall', 2001, 'A+');
	insert into takes values('34322', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('67560', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('55698', '735', '1', 'Spring', 2003, 'A+');
	insert into takes values('9440', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('75878', '362', '3', 'Spring', 2008, 'B ');
	insert into takes values('21086', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('48861', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('37581', '408', '1', 'Spring', 2007, 'A-');
	insert into takes values('82707', '270', '1', 'Spring', 2010, 'C-');
	insert into takes values('28738', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('31080', '258', '1', 'Fall', 2007, 'B-');
	insert into takes values('14023', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('39876', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('17133', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('76291', '612', '1', 'Fall', 2007, 'B ');
	insert into takes values('82580', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('86806', '304', '1', 'Fall', 2009, 'B ');
	insert into takes values('12711', '345', '1', 'Spring', 2008, 'B ');
	insert into takes values('96003', '852', '1', 'Spring', 2008, 'C-');
	insert into takes values('14581', '960', '1', 'Fall', 2009, 'B+');
	insert into takes values('18859', '457', '1', 'Spring', 2001, 'B+');
	insert into takes values('33460', '604', '1', 'Spring', 2009, 'A-');
	insert into takes values('95626', '949', '1', 'Fall', 2007, 'C ');
	insert into takes values('39612', '443', '1', 'Spring', 2010, 'B ');
	insert into takes values('85234', '237', '2', 'Fall', 2009, 'B+');
	insert into takes values('86802', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('97400', '864', '1', 'Spring', 2006, 'A+');
	insert into takes values('6712', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('28538', '476', '1', 'Fall', 2010, 'C ');
	insert into takes values('22268', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('3739', '962', '1', 'Spring', 2008, 'B ');
	insert into takes values('59517', '795', '1', 'Spring', 2004, 'B ');
	insert into takes values('23994', '991', '1', 'Spring', 2008, 'C-');
	insert into takes values('26147', '808', '1', 'Fall', 2003, 'C ');
	insert into takes values('12216', '927', '1', 'Fall', 2002, 'C-');
	insert into takes values('75082', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('67725', '482', '1', 'Fall', 2005, 'A-');
	insert into takes values('86674', '258', '1', 'Fall', 2007, 'B-');
	insert into takes values('34236', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('47379', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('77361', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('37581', '679', '1', 'Spring', 2010, 'A ');
	insert into takes values('71630', '376', '1', 'Fall', 2006, 'C+');
	insert into takes values('38668', '960', '2', 'Fall', 2006, 'A-');
	insert into takes values('58170', '642', '1', 'Fall', 2004, 'A-');
	insert into takes values('11455', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('65101', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('46260', '559', '1', 'Fall', 2002, 'A ');
	insert into takes values('53699', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('1726', '242', '1', 'Fall', 2009, 'A-');
	insert into takes values('94311', '599', '1', 'Spring', 2003, 'A ');
	insert into takes values('86674', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('13826', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('11855', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('70299', '445', '1', 'Spring', 2001, 'B+');
	insert into takes values('42298', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('18108', '867', '2', 'Fall', 2010, 'C-');
	insert into takes values('41599', '105', '1', 'Fall', 2009, 'C-');
	insert into takes values('76270', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('37734', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('41596', '200', '1', 'Spring', 2007, 'B-');
	insert into takes values('61127', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('7204', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('53547', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('69581', '748', '1', 'Fall', 2003, 'A-');
	insert into takes values('35042', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('58085', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('59172', '408', '1', 'Spring', 2007, 'C+');
	insert into takes values('98870', '612', '1', 'Fall', 2007, 'A-');
	insert into takes values('25611', '893', '1', 'Fall', 2007, 'C+');
	insert into takes values('87651', '313', '1', 'Fall', 2010, 'A-');
	insert into takes values('41751', '962', '1', 'Spring', 2008, 'B ');
	insert into takes values('5920', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('30110', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('10904', '105', '2', 'Fall', 2002, 'A ');
	insert into takes values('19638', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('59553', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('55286', '482', '1', 'Fall', 2005, 'A ');
	insert into takes values('30182', '486', '1', 'Fall', 2009, 'B-');
	insert into takes values('70359', '362', '2', 'Fall', 2006, 'C-');
	insert into takes values('81638', '349', '1', 'Spring', 2008, 'B+');
	insert into takes values('63390', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('50331', '258', '1', 'Fall', 2007, 'C-');
	insert into takes values('70362', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('64121', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('24784', '476', '1', 'Fall', 2010, 'A+');
	insert into takes values('40932', '493', '1', 'Spring', 2010, 'C+');
	insert into takes values('50414', '704', '1', 'Spring', 2008, 'C-');
	insert into takes values('90004', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('83002', '604', '1', 'Spring', 2009, 'A-');
	insert into takes values('13408', '304', '1', 'Fall', 2009, 'A+');
	insert into takes values('63288', '927', '1', 'Fall', 2002, 'B-');
	insert into takes values('40116', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('88793', '599', '1', 'Spring', 2003, 'C+');
	insert into takes values('499', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('48589', '304', '1', 'Fall', 2009, 'B ');
	insert into takes values('4449', '795', '1', 'Spring', 2004, 'A-');
	insert into takes values('58326', '591', '1', 'Spring', 2005, 'B-');
	insert into takes values('89246', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('97023', '696', '1', 'Spring', 2002, 'B-');
	insert into takes values('79911', '867', '2', 'Fall', 2010, 'B-');
	insert into takes values('31035', '158', '1', 'Fall', 2008, 'B-');
	insert into takes values('70572', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('36052', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('90779', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('32483', '559', '1', 'Fall', 2002, 'A-');
	insert into takes values('60267', '274', '1', 'Fall', 2002, 'A+');
	insert into takes values('44998', '791', '1', 'Spring', 2006, 'A-');
	insert into takes values('6710', '795', '1', 'Spring', 2004, 'A-');
	insert into takes values('41211', '443', '2', 'Spring', 2002, 'C-');
	insert into takes values('92839', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('93571', '791', '1', 'Spring', 2006, 'B+');
	insert into takes values('20489', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('85356', '581', '1', 'Spring', 2005, 'C-');
	insert into takes values('41596', '864', '1', 'Spring', 2006, 'A+');
	insert into takes values('88302', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('65681', '408', '2', 'Spring', 2003, 'B-');
	insert into takes values('84792', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('76911', '927', '1', 'Fall', 2002, 'C+');
	insert into takes values('35042', '867', '1', 'Fall', 2006, 'B ');
	insert into takes values('21086', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('68554', '401', '1', 'Fall', 2003, 'C+');
	insert into takes values('46260', '631', '1', 'Spring', 2007, 'C-');
	insert into takes values('35138', '200', '1', 'Spring', 2007, 'A-');
	insert into takes values('46981', '237', '2', 'Fall', 2009, 'C+');
	insert into takes values('74911', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('78469', '457', '1', 'Spring', 2001, 'C ');
	insert into takes values('47824', '376', '1', 'Fall', 2006, 'B ');
	insert into takes values('37430', '760', '1', 'Spring', 2004, 'C ');
	insert into takes values('30723', '468', '2', 'Fall', 2007, 'C+');
	insert into takes values('70384', '867', '2', 'Fall', 2010, 'B-');
	insert into takes values('8843', '696', '1', 'Spring', 2002, 'B ');
	insert into takes values('83462', '864', '1', 'Spring', 2006, 'B ');
	insert into takes values('22325', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('65433', '875', '1', 'Spring', 2005, 'C-');
	insert into takes values('88085', '559', '1', 'Fall', 2002, 'B ');
	insert into takes values('35220', '663', '1', 'Spring', 2005, 'A ');
	insert into takes values('47487', '468', '1', 'Fall', 2005, 'B+');
	insert into takes values('20180', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('99268', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('31250', '571', '1', 'Spring', 2004, 'C ');
	insert into takes values('56849', '629', '1', 'Spring', 2003, 'B+');
	insert into takes values('842', '603', '1', 'Fall', 2003, 'A ');
	insert into takes values('64731', '493', '1', 'Spring', 2010, 'B ');
	insert into takes values('35175', '561', '1', 'Fall', 2006, 'C ');
	insert into takes values('48053', '400', '1', 'Spring', 2007, 'A ');
	insert into takes values('97590', '962', '1', 'Spring', 2008, 'A ');
	insert into takes values('64893', '852', '1', 'Spring', 2008, 'C+');
	insert into takes values('57985', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('49792', '735', '2', 'Spring', 2010, 'A+');
	insert into takes values('65715', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('92839', '304', '1', 'Fall', 2009, 'B+');
	insert into takes values('14869', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('13757', '692', '1', 'Spring', 2010, 'A-');
	insert into takes values('1232', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('56089', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('37946', '105', '1', 'Fall', 2009, 'B ');
	insert into takes values('6400', '105', '1', 'Fall', 2009, 'C ');
	insert into takes values('48589', '242', '1', 'Fall', 2009, 'B+');
	insert into takes values('41741', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('23994', '362', '1', 'Fall', 2005, 'C+');
	insert into takes values('91851', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('5925', '867', '2', 'Fall', 2010, 'A-');
	insert into takes values('6729', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('32490', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('85849', '489', '1', 'Fall', 2007, 'B+');
	insert into takes values('17076', '760', '1', 'Spring', 2004, 'C+');
	insert into takes values('31341', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('15457', '962', '1', 'Spring', 2008, 'B ');
	insert into takes values('13290', '561', '1', 'Fall', 2006, 'B-');
	insert into takes values('94142', '843', '1', 'Fall', 2010, 'B-');
	insert into takes values('15024', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('20985', '527', '1', 'Fall', 2004, 'A ');
	insert into takes values('49618', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('24387', '561', '1', 'Fall', 2006, 'B+');
	insert into takes values('34322', '468', '1', 'Fall', 2005, 'A-');
	insert into takes values('51084', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('8347', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('77364', '482', '1', 'Fall', 2005, 'B ');
	insert into takes values('898', '408', '1', 'Spring', 2007, 'A ');
	insert into takes values('78892', '604', '1', 'Spring', 2009, 'B+');
	insert into takes values('28252', '791', '1', 'Spring', 2006, 'C-');
	insert into takes values('77000', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('32119', '663', '1', 'Spring', 2005, 'A ');
	insert into takes values('63502', '694', '1', 'Fall', 2002, 'A ');
	insert into takes values('75878', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('19541', '852', '1', 'Spring', 2008, 'A ');
	insert into takes values('50977', '875', '1', 'Spring', 2005, 'B+');
	insert into takes values('7490', '962', '1', 'Spring', 2008, 'A+');
	insert into takes values('96117', '239', '1', 'Fall', 2006, 'B-');
	insert into takes values('2178', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('5943', '972', '1', 'Spring', 2009, 'B+');
	insert into takes values('9256', '421', '1', 'Fall', 2004, 'A-');
	insert into takes values('65400', '642', '1', 'Fall', 2004, 'C+');
	insert into takes values('44258', '545', '1', 'Fall', 2001, 'B-');
	insert into takes values('93986', '468', '2', 'Fall', 2007, 'B ');
	insert into takes values('52134', '334', '1', 'Fall', 2009, 'A-');
	insert into takes values('64642', '445', '1', 'Spring', 2001, 'C ');
	insert into takes values('34158', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('69732', '612', '1', 'Fall', 2007, 'A+');
	insert into takes values('35462', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('52866', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('1922', '927', '1', 'Fall', 2002, 'A-');
	insert into takes values('95953', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('760', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('56486', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('33759', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('61065', '192', '1', 'Fall', 2002, 'C-');
	insert into takes values('40558', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('4004', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('33837', '875', '1', 'Spring', 2005, 'A ');
	insert into takes values('39514', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('32369', '376', '1', 'Fall', 2006, 'A-');
	insert into takes values('64249', '468', '1', 'Fall', 2005, 'A ');
	insert into takes values('59290', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('56598', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('70362', '599', '1', 'Spring', 2003, 'B+');
	insert into takes values('13352', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('22467', '169', '2', 'Fall', 2002, 'B-');
	insert into takes values('17057', '362', '2', 'Fall', 2006, 'B-');
	insert into takes values('27687', '482', '1', 'Fall', 2005, 'B-');
	insert into takes values('76911', '875', '1', 'Spring', 2005, 'C-');
	insert into takes values('5250', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('90814', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('74460', '461', '1', 'Fall', 2002, 'B-');
	insert into takes values('2795', '443', '1', 'Spring', 2010, 'A+');
	insert into takes values('21009', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('123', '443', '2', 'Spring', 2002, 'A-');
	insert into takes values('7732', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('97101', '679', '1', 'Spring', 2010, 'C+');
	insert into takes values('85680', '486', '1', 'Fall', 2009, 'C+');
	insert into takes values('55286', '962', '1', 'Spring', 2008, 'A+');
	insert into takes values('25718', '349', '1', 'Spring', 2008, 'B+');
	insert into takes values('99451', '735', '2', 'Spring', 2010, 'B-');
	insert into takes values('69783', '408', '1', 'Spring', 2007, 'C+');
	insert into takes values('14621', '158', '1', 'Fall', 2008, 'A-');
	insert into takes values('63645', '843', '1', 'Fall', 2010, 'C+');
	insert into takes values('58846', '200', '2', 'Fall', 2002, 'B-');
	insert into takes values('90814', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('69747', '468', '2', 'Fall', 2007, 'C-');
	insert into takes values('51768', '169', '1', 'Spring', 2007, 'C ');
	insert into takes values('83622', '696', '1', 'Spring', 2002, 'C+');
	insert into takes values('914', '559', '1', 'Fall', 2002, 'A-');
	insert into takes values('44998', '352', '1', 'Spring', 2006, 'C ');
	insert into takes values('14668', '629', '1', 'Spring', 2003, 'B-');
	insert into takes values('71944', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('54620', '237', '2', 'Fall', 2009, 'A ');
	insert into takes values('70099', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('14023', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('69730', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('6474', '476', '1', 'Fall', 2010, 'C-');
	insert into takes values('71878', '991', '1', 'Spring', 2008, 'B ');
	insert into takes values('4435', '158', '2', 'Spring', 2008, 'A ');
	insert into takes values('82688', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('9183', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('499', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('25362', '612', '1', 'Fall', 2007, 'A ');
	insert into takes values('46725', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('70384', '843', '1', 'Fall', 2010, 'C-');
	insert into takes values('38902', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('7035', '408', '2', 'Spring', 2003, 'A+');
	insert into takes values('36513', '237', '2', 'Fall', 2009, 'A-');
	insert into takes values('99189', '679', '1', 'Spring', 2010, 'A+');
	insert into takes values('96134', '875', '1', 'Spring', 2005, 'A-');
	insert into takes values('15726', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('94371', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('52076', '852', '1', 'Spring', 2008, 'C+');
	insert into takes values('61232', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('80698', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('71944', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('84432', '663', '1', 'Spring', 2005, 'B ');
	insert into takes values('33546', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('13403', '493', '1', 'Spring', 2010, 'B ');
	insert into takes values('67021', '489', '1', 'Fall', 2007, 'B-');
	insert into takes values('93708', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('71287', '192', '1', 'Fall', 2002, 'C ');
	insert into takes values('51975', '843', '1', 'Fall', 2010, 'C-');
	insert into takes values('45002', '581', '1', 'Spring', 2005, 'C-');
	insert into takes values('64934', '893', '1', 'Fall', 2007, 'A ');
	insert into takes values('59172', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('75173', '960', '1', 'Fall', 2009, 'C-');
	insert into takes values('89551', '105', '1', 'Fall', 2009, 'B+');
	insert into takes values('44816', '696', '1', 'Spring', 2002, 'A-');
	insert into takes values('86641', '808', '1', 'Fall', 2003, 'B ');
	insert into takes values('70564', '591', '1', 'Spring', 2005, 'C-');
	insert into takes values('70828', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('65329', '242', '1', 'Fall', 2009, 'B+');
	insert into takes values('40558', '571', '1', 'Spring', 2004, 'B+');
	insert into takes values('10834', '603', '1', 'Fall', 2003, 'B-');
	insert into takes values('68242', '401', '1', 'Fall', 2003, 'A ');
	insert into takes values('16075', '493', '1', 'Spring', 2010, 'C-');
	insert into takes values('76250', '415', '1', 'Fall', 2010, 'B+');
	insert into takes values('66212', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('37946', '400', '2', 'Fall', 2003, 'C+');
	insert into takes values('88887', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('78787', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('63243', '735', '2', 'Spring', 2010, 'C ');
	insert into takes values('43854', '960', '2', 'Fall', 2006, 'B+');
	insert into takes values('11262', '200', '2', 'Fall', 2002, 'B-');
	insert into takes values('57190', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('13403', '352', '1', 'Spring', 2006, 'C-');
	insert into takes values('17192', '489', '1', 'Fall', 2007, 'B ');
	insert into takes values('9947', '408', '2', 'Spring', 2003, 'A ');
	insert into takes values('72186', '893', '1', 'Fall', 2007, 'B-');
	insert into takes values('18469', '603', '1', 'Fall', 2003, 'B+');
	insert into takes values('75046', '476', '1', 'Fall', 2010, 'B+');
	insert into takes values('66494', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('16993', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('39612', '559', '1', 'Fall', 2002, 'A ');
	insert into takes values('57456', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('14214', '735', '2', 'Spring', 2010, 'A-');
	insert into takes values('85534', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('52134', '137', '1', 'Spring', 2002, 'A-');
	insert into takes values('35362', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('18941', '401', '1', 'Fall', 2003, 'B+');
	insert into takes values('37219', '313', '1', 'Fall', 2010, 'B ');
	insert into takes values('5208', '696', '1', 'Spring', 2002, 'C ');
	insert into takes values('3639', '105', '1', 'Fall', 2009, 'C+');
	insert into takes values('52523', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('94814', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('70918', '735', '2', 'Spring', 2010, 'B ');
	insert into takes values('89734', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('35462', '694', '1', 'Fall', 2002, 'A+');
	insert into takes values('79210', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('70924', '760', '1', 'Spring', 2004, 'B+');
	insert into takes values('93986', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('7514', '704', '1', 'Spring', 2008, 'B ');
	insert into takes values('81638', '959', '1', 'Fall', 2006, 'B+');
	insert into takes values('10033', '692', '1', 'Spring', 2010, 'A ');
	insert into takes values('51549', '338', '1', 'Spring', 2007, 'C-');
	insert into takes values('43130', '400', '1', 'Spring', 2007, 'B+');
	insert into takes values('50664', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('47025', '760', '1', 'Spring', 2004, 'C-');
	insert into takes values('63538', '735', '2', 'Spring', 2010, 'A ');
	insert into takes values('7035', '468', '1', 'Fall', 2005, 'B ');
	insert into takes values('27236', '604', '1', 'Spring', 2009, 'B-');
	insert into takes values('72006', '864', '1', 'Spring', 2006, 'B ');
	insert into takes values('31554', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('15249', '362', '1', 'Fall', 2005, 'C ');
	insert into takes values('30650', '313', '1', 'Fall', 2010, 'A-');
	insert into takes values('63040', '258', '1', 'Fall', 2007, 'A-');
	insert into takes values('40738', '631', '1', 'Spring', 2007, 'A+');
	insert into takes values('88045', '457', '1', 'Spring', 2001, 'C+');
	insert into takes values('41450', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('57431', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('75116', '735', '1', 'Spring', 2003, 'A ');
	insert into takes values('30858', '604', '1', 'Spring', 2009, 'B ');
	insert into takes values('29849', '270', '1', 'Spring', 2010, 'B-');
	insert into takes values('82063', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('63582', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('64249', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('86934', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('17831', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('7123', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('95626', '972', '1', 'Spring', 2009, 'B ');
	insert into takes values('75116', '852', '1', 'Spring', 2008, 'B+');
	insert into takes values('13365', '962', '1', 'Spring', 2008, 'B ');
	insert into takes values('26473', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('96117', '352', '1', 'Spring', 2006, 'A+');
	insert into takes values('94311', '319', '1', 'Spring', 2003, 'A-');
	insert into takes values('79210', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('40116', '679', '1', 'Spring', 2010, 'A+');
	insert into takes values('30896', '408', '2', 'Spring', 2003, 'B ');
	insert into takes values('76895', '242', '1', 'Fall', 2009, 'C ');
	insert into takes values('85849', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('1110', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('14563', '313', '1', 'Fall', 2010, 'A-');
	insert into takes values('4508', '192', '1', 'Fall', 2002, 'A+');
	insert into takes values('36052', '702', '1', 'Spring', 2001, 'C-');
	insert into takes values('5414', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('53728', '959', '1', 'Fall', 2006, 'A+');
	insert into takes values('65433', '972', '1', 'Spring', 2009, 'B ');
	insert into takes values('15883', '561', '1', 'Fall', 2006, 'B-');
	insert into takes values('38013', '486', '1', 'Fall', 2009, 'C ');
	insert into takes values('65676', '864', '1', 'Spring', 2006, 'C+');
	insert into takes values('65038', '242', '1', 'Fall', 2009, 'C+');
	insert into takes values('25362', '362', '2', 'Fall', 2006, 'A ');
	insert into takes values('84495', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('14023', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('28977', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('25068', '629', '1', 'Spring', 2003, 'B ');
	insert into takes values('24809', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('25940', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('37869', '445', '1', 'Spring', 2001, 'B+');
	insert into takes values('50039', '345', '1', 'Spring', 2008, 'A-');
	insert into takes values('41261', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('43989', '242', '1', 'Fall', 2009, 'C-');
	insert into takes values('48469', '927', '1', 'Fall', 2002, 'A-');
	insert into takes values('81789', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('35523', '415', '1', 'Fall', 2010, 'A+');
	insert into takes values('51975', '401', '1', 'Fall', 2003, 'A-');
	insert into takes values('36657', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('39978', '200', '1', 'Spring', 2007, 'A ');
	insert into takes values('48778', '376', '1', 'Fall', 2006, 'C+');
	insert into takes values('48778', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('48678', '702', '1', 'Spring', 2001, 'C+');
	insert into takes values('16593', '200', '2', 'Fall', 2002, 'B-');
	insert into takes values('81785', '169', '2', 'Fall', 2002, 'B+');
	insert into takes values('32368', '626', '1', 'Fall', 2006, 'A-');
	insert into takes values('72622', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('83728', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('80990', '105', '2', 'Fall', 2002, 'A-');
	insert into takes values('22467', '237', '2', 'Fall', 2009, 'C+');
	insert into takes values('23439', '927', '1', 'Fall', 2002, 'B-');
	insert into takes values('17397', '642', '1', 'Fall', 2004, 'B+');
	insert into takes values('84189', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('67051', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('15698', '626', '1', 'Fall', 2006, 'B+');
	insert into takes values('9360', '352', '1', 'Spring', 2006, 'B+');
	insert into takes values('31442', '493', '1', 'Spring', 2010, 'C ');
	insert into takes values('37715', '426', '1', 'Spring', 2006, 'C ');
	insert into takes values('64401', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('83557', '200', '1', 'Spring', 2007, 'A+');
	insert into takes values('43016', '169', '1', 'Spring', 2007, 'A ');
	insert into takes values('55915', '443', '1', 'Spring', 2010, 'A+');
	insert into takes values('47379', '679', '1', 'Spring', 2010, 'A+');
	insert into takes values('56941', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('64164', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('75878', '702', '1', 'Spring', 2001, 'C ');
	insert into takes values('5005', '362', '3', 'Spring', 2008, 'A+');
	insert into takes values('7854', '400', '1', 'Spring', 2007, 'A-');
	insert into takes values('74163', '421', '1', 'Fall', 2004, 'C ');
	insert into takes values('75241', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('14499', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('49280', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('95284', '345', '1', 'Spring', 2008, 'C+');
	insert into takes values('37653', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('17997', '843', '1', 'Fall', 2010, 'C-');
	insert into takes values('75772', '443', '2', 'Spring', 2002, 'A-');
	insert into takes values('87015', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('46155', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('50719', '200', '1', 'Spring', 2007, 'A-');
	insert into takes values('80113', '974', '1', 'Fall', 2003, 'C ');
	insert into takes values('35', '366', '1', 'Fall', 2005, 'A ');
	insert into takes values('1812', '421', '1', 'Fall', 2004, 'C-');
	insert into takes values('54728', '258', '1', 'Fall', 2007, 'A-');
	insert into takes values('93631', '747', '1', 'Spring', 2004, 'B+');
	insert into takes values('7390', '679', '1', 'Spring', 2010, 'A+');
	insert into takes values('34386', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('95697', '489', '1', 'Fall', 2007, 'B ');
	insert into takes values('91992', '468', '2', 'Fall', 2007, 'A+');
	insert into takes values('64820', '400', '2', 'Fall', 2003, 'C+');
	insert into takes values('85754', '457', '1', 'Spring', 2001, 'B+');
	insert into takes values('20974', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('31337', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('6209', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('28518', '105', '2', 'Fall', 2002, 'B+');
	insert into takes values('65987', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('49073', '421', '1', 'Fall', 2004, 'A ');
	insert into takes values('28299', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('30110', '237', '1', 'Spring', 2008, 'B-');
	insert into takes values('50703', '843', '1', 'Fall', 2010, 'B-');
	insert into takes values('18808', '960', '2', 'Fall', 2006, 'B-');
	insert into takes values('77364', '200', '1', 'Spring', 2007, 'B+');
	insert into takes values('8483', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('19861', '875', '1', 'Spring', 2005, 'B-');
	insert into takes values('78552', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('55857', '334', '1', 'Fall', 2009, 'C-');
	insert into takes values('3640', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('72014', '735', '1', 'Spring', 2003, 'C ');
	insert into takes values('94522', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('21766', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('11201', '349', '1', 'Spring', 2008, 'B+');
	insert into takes values('47379', '258', '1', 'Fall', 2007, 'C ');
	insert into takes values('57941', '679', '1', 'Spring', 2010, 'C+');
	insert into takes values('90353', '200', '2', 'Fall', 2002, 'A+');
	insert into takes values('58701', '496', '1', 'Fall', 2001, 'A+');
	insert into takes values('84410', '927', '1', 'Fall', 2002, 'C-');
	insert into takes values('41818', '561', '1', 'Fall', 2006, 'A ');
	insert into takes values('95840', '991', '1', 'Spring', 2008, 'B ');
	insert into takes values('91616', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('38668', '362', '2', 'Fall', 2006, 'A-');
	insert into takes values('39046', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('47126', '893', '1', 'Fall', 2007, 'C ');
	insert into takes values('11578', '972', '1', 'Spring', 2009, 'A-');
	insert into takes values('75299', '137', '1', 'Spring', 2002, 'C-');
	insert into takes values('37430', '362', '1', 'Fall', 2005, 'B ');
	insert into takes values('52157', '972', '1', 'Spring', 2009, 'A-');
	insert into takes values('78434', '400', '1', 'Spring', 2007, 'A+');
	insert into takes values('67018', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('98056', '599', '1', 'Spring', 2003, 'B-');
	insert into takes values('87193', '105', '2', 'Fall', 2002, 'A+');
	insert into takes values('25942', '200', '2', 'Fall', 2002, 'C+');
	insert into takes values('75560', '791', '1', 'Spring', 2006, 'C+');
	insert into takes values('73602', '604', '1', 'Spring', 2009, 'B ');
	insert into takes values('34770', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('91978', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('2419', '496', '1', 'Fall', 2001, 'C ');
	insert into takes values('42556', '270', '1', 'Spring', 2010, 'A+');
	insert into takes values('11682', '313', '1', 'Fall', 2010, 'A+');
	insert into takes values('49759', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('22226', '489', '1', 'Fall', 2007, 'C ');
	insert into takes values('75040', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('85575', '443', '1', 'Spring', 2010, 'A+');
	insert into takes values('76224', '258', '1', 'Fall', 2007, 'B-');
	insert into takes values('94178', '692', '1', 'Spring', 2010, 'C ');
	insert into takes values('78116', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('51955', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('52945', '408', '1', 'Spring', 2007, 'A-');
	insert into takes values('89140', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('23992', '237', '2', 'Fall', 2009, 'C ');
	insert into takes values('3143', '200', '1', 'Spring', 2007, 'C-');
	insert into takes values('38602', '338', '1', 'Spring', 2007, 'C ');
	insert into takes values('59397', '200', '1', 'Spring', 2007, 'A+');
	insert into takes values('20985', '158', '2', 'Spring', 2008, 'B+');
	insert into takes values('47487', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('46762', '843', '1', 'Fall', 2010, 'B-');
	insert into takes values('89140', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('65433', '612', '1', 'Fall', 2007, 'C ');
	insert into takes values('52523', '795', '1', 'Spring', 2004, 'A-');
	insert into takes values('77364', '443', '2', 'Spring', 2002, 'B-');
	insert into takes values('30110', '852', '1', 'Spring', 2008, 'B-');
	insert into takes values('34542', '200', '1', 'Spring', 2007, 'B+');
	insert into takes values('68720', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('23311', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('14284', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('56232', '319', '1', 'Spring', 2003, 'B-');
	insert into takes values('67657', '313', '1', 'Fall', 2010, 'C+');
	insert into takes values('78434', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('14874', '338', '2', 'Spring', 2006, 'A+');
	insert into takes values('82591', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('35935', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('48901', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('48640', '959', '1', 'Fall', 2006, 'B ');
	insert into takes values('79446', '949', '1', 'Fall', 2007, 'C+');
	insert into takes values('92417', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('67542', '581', '1', 'Spring', 2005, 'C ');
	insert into takes values('62749', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('12615', '443', '2', 'Spring', 2002, 'B+');
	insert into takes values('14563', '200', '1', 'Spring', 2007, 'A ');
	insert into takes values('31086', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('46725', '679', '1', 'Spring', 2010, 'B-');
	insert into takes values('35498', '527', '1', 'Fall', 2004, 'C ');
	insert into takes values('33206', '864', '1', 'Spring', 2006, 'A ');
	insert into takes values('37339', '349', '1', 'Spring', 2008, 'B+');
	insert into takes values('77289', '443', '2', 'Spring', 2002, 'B ');
	insert into takes values('4248', '702', '1', 'Spring', 2001, 'C+');
	insert into takes values('92849', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('43616', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('47487', '893', '1', 'Fall', 2007, 'A ');
	insert into takes values('78314', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('987', '237', '2', 'Fall', 2009, 'C+');
	insert into takes values('96153', '972', '1', 'Spring', 2009, 'C-');
	insert into takes values('16075', '338', '1', 'Spring', 2007, 'B ');
	insert into takes values('23506', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('22198', '704', '1', 'Spring', 2008, 'C ');
	insert into takes values('3693', '169', '1', 'Spring', 2007, 'A ');
	insert into takes values('31137', '527', '1', 'Fall', 2004, 'B-');
	insert into takes values('27804', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('71085', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('53047', '735', '1', 'Spring', 2003, 'A+');
	insert into takes values('10663', '972', '1', 'Spring', 2009, 'B+');
	insert into takes values('18108', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('14628', '735', '2', 'Spring', 2010, 'C ');
	insert into takes values('81883', '581', '1', 'Spring', 2005, 'A+');
	insert into takes values('25143', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('85602', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('45300', '612', '1', 'Fall', 2007, 'A ');
	insert into takes values('78434', '192', '1', 'Fall', 2002, 'C ');
	insert into takes values('8022', '400', '2', 'Fall', 2003, 'B+');
	insert into takes values('33837', '408', '1', 'Spring', 2007, 'C+');
	insert into takes values('52494', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('17911', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('65987', '158', '1', 'Fall', 2008, 'A+');
	insert into takes values('72177', '959', '1', 'Fall', 2006, 'A-');
	insert into takes values('71387', '852', '1', 'Spring', 2008, 'C+');
	insert into takes values('58874', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('4004', '352', '1', 'Spring', 2006, 'B+');
	insert into takes values('34126', '352', '1', 'Spring', 2006, 'B+');
	insert into takes values('93631', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('44206', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('32376', '795', '1', 'Spring', 2004, 'B ');
	insert into takes values('60762', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('52929', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('81789', '270', '1', 'Spring', 2010, 'B-');
	insert into takes values('6523', '599', '1', 'Spring', 2003, 'C ');
	insert into takes values('1922', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('66356', '421', '1', 'Fall', 2004, 'C-');
	insert into takes values('92417', '400', '1', 'Spring', 2007, 'B+');
	insert into takes values('75241', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('898', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('75938', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('90082', '603', '1', 'Fall', 2003, 'B ');
	insert into takes values('81638', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('79170', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('38602', '345', '1', 'Spring', 2008, 'B ');
	insert into takes values('68516', '400', '2', 'Fall', 2003, 'C+');
	insert into takes values('10834', '962', '1', 'Spring', 2008, 'B ');
	insert into takes values('40682', '338', '1', 'Spring', 2007, 'B-');
	insert into takes values('36303', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('84189', '760', '1', 'Spring', 2004, 'B+');
	insert into takes values('44551', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('40992', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('96895', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('94766', '747', '1', 'Spring', 2004, 'C-');
	insert into takes values('36052', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('92385', '747', '1', 'Spring', 2004, 'B-');
	insert into takes values('43016', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('11201', '793', '1', 'Spring', 2002, 'B ');
	insert into takes values('16480', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('93708', '612', '1', 'Fall', 2007, 'A-');
	insert into takes values('98690', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('6195', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('46769', '158', '1', 'Fall', 2008, 'A-');
	insert into takes values('99073', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('57185', '169', '1', 'Spring', 2007, 'C+');
	insert into takes values('71426', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('99730', '599', '1', 'Spring', 2003, 'A ');
	insert into takes values('30650', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('23457', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('8457', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('83573', '192', '1', 'Fall', 2002, 'A+');
	insert into takes values('8957', '400', '2', 'Fall', 2003, 'A+');
	insert into takes values('96741', '400', '2', 'Fall', 2003, 'B-');
	insert into takes values('62054', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('46694', '338', '2', 'Spring', 2006, 'A-');
	insert into takes values('56299', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('55915', '400', '2', 'Fall', 2003, 'A ');
	insert into takes values('86573', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('15430', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('90814', '612', '1', 'Fall', 2007, 'B ');
	insert into takes values('92040', '362', '3', 'Spring', 2008, 'C+');
	insert into takes values('36102', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('21394', '345', '1', 'Spring', 2008, 'C+');
	insert into takes values('14639', '642', '1', 'Fall', 2004, 'A+');
	insert into takes values('96085', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('17924', '626', '1', 'Fall', 2006, 'A ');
	insert into takes values('44985', '793', '1', 'Spring', 2002, 'A-');
	insert into takes values('35588', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('70965', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('40897', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('25077', '400', '2', 'Fall', 2003, 'A+');
	insert into takes values('81550', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('57962', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('35588', '137', '1', 'Spring', 2002, 'B+');
	insert into takes values('61402', '802', '1', 'Spring', 2003, 'A+');
	insert into takes values('44816', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('54508', '545', '1', 'Fall', 2001, 'B ');
	insert into takes values('2561', '591', '1', 'Spring', 2005, 'C+');
	insert into takes values('49813', '169', '2', 'Fall', 2002, 'C ');
	insert into takes values('27662', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('1285', '237', '1', 'Spring', 2008, 'C+');
	insert into takes values('96988', '482', '1', 'Fall', 2005, 'B ');
	insert into takes values('81150', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('95046', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('80420', '192', '1', 'Fall', 2002, 'C-');
	insert into takes values('85809', '893', '1', 'Fall', 2007, 'A+');
	insert into takes values('33837', '345', '1', 'Spring', 2008, 'C ');
	insert into takes values('61364', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('47379', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('56299', '875', '1', 'Spring', 2005, 'C ');
	insert into takes values('48640', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('43226', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('30397', '319', '1', 'Spring', 2003, 'C-');
	insert into takes values('57160', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('65396', '400', '2', 'Fall', 2003, 'A ');
	insert into takes values('14628', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('8957', '362', '1', 'Fall', 2005, 'C+');
	insert into takes values('85746', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('57456', '808', '1', 'Fall', 2003, 'A-');
	insert into takes values('9440', '445', '1', 'Spring', 2001, 'B+');
	insert into takes values('86552', '559', '1', 'Fall', 2002, 'C+');
	insert into takes values('73206', '468', '1', 'Fall', 2005, 'B+');
	insert into takes values('15578', '352', '1', 'Spring', 2006, 'C+');
	insert into takes values('36263', '843', '1', 'Fall', 2010, 'B-');
	insert into takes values('44206', '581', '1', 'Spring', 2005, 'C+');
	insert into takes values('52120', '843', '1', 'Fall', 2010, 'A-');
	insert into takes values('74639', '105', '1', 'Fall', 2009, 'C+');
	insert into takes values('90124', '960', '1', 'Fall', 2009, 'A+');
	insert into takes values('75231', '169', '1', 'Spring', 2007, 'B+');
	insert into takes values('68779', '760', '1', 'Spring', 2004, 'C+');
	insert into takes values('4034', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('53089', '445', '1', 'Spring', 2001, 'B-');
	insert into takes values('10727', '237', '1', 'Spring', 2008, 'B ');
	insert into takes values('29665', '696', '1', 'Spring', 2002, 'C-');
	insert into takes values('20489', '864', '1', 'Spring', 2006, 'B+');
	insert into takes values('54296', '334', '1', 'Fall', 2009, 'C ');
	insert into takes values('16528', '679', '1', 'Spring', 2010, 'B ');
	insert into takes values('914', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('83622', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('21556', '808', '1', 'Fall', 2003, 'B-');
	insert into takes values('85211', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('4355', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('22142', '489', '1', 'Fall', 2007, 'C ');
	insert into takes values('69632', '960', '2', 'Fall', 2006, 'C-');
	insert into takes values('58081', '875', '1', 'Spring', 2005, 'A ');
	insert into takes values('7854', '612', '1', 'Fall', 2007, 'B-');
	insert into takes values('20445', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('27952', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('46106', '852', '1', 'Spring', 2008, 'C+');
	insert into takes values('77364', '545', '1', 'Fall', 2001, 'C ');
	insert into takes values('92464', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('90004', '702', '1', 'Spring', 2001, 'B ');
	insert into takes values('33107', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('83747', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('92332', '334', '1', 'Fall', 2009, 'A ');
	insert into takes values('11194', '545', '1', 'Fall', 2001, 'B-');
	insert into takes values('41599', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('70021', '493', '1', 'Spring', 2010, 'A+');
	insert into takes values('88045', '852', '1', 'Spring', 2008, 'B ');
	insert into takes values('33201', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('95027', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('56003', '760', '1', 'Spring', 2004, 'C+');
	insert into takes values('83691', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('90234', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('13081', '795', '1', 'Spring', 2004, 'A-');
	insert into takes values('50873', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('24442', '962', '1', 'Spring', 2008, 'B-');
	insert into takes values('88302', '864', '1', 'Spring', 2006, 'C+');
	insert into takes values('38676', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('39254', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('39892', '362', '2', 'Fall', 2006, 'A-');
	insert into takes values('78892', '867', '2', 'Fall', 2010, 'B-');
	insert into takes values('40044', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('80610', '443', '2', 'Spring', 2002, 'A ');
	insert into takes values('66813', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('37103', '692', '1', 'Spring', 2010, 'C-');
	insert into takes values('86573', '158', '1', 'Fall', 2008, 'A-');
	insert into takes values('67514', '482', '1', 'Fall', 2005, 'B-');
	insert into takes values('22086', '959', '1', 'Fall', 2006, 'B+');
	insert into takes values('32345', '864', '1', 'Spring', 2006, 'C-');
	insert into takes values('66469', '304', '1', 'Fall', 2009, 'A ');
	insert into takes values('5298', '959', '1', 'Fall', 2006, 'C+');
	insert into takes values('89188', '959', '1', 'Fall', 2006, 'A-');
	insert into takes values('19342', '612', '1', 'Fall', 2007, 'A+');
	insert into takes values('94801', '696', '1', 'Spring', 2002, 'A-');
	insert into takes values('52750', '604', '1', 'Spring', 2009, 'A-');
	insert into takes values('53225', '158', '2', 'Spring', 2008, 'C ');
	insert into takes values('41988', '352', '1', 'Spring', 2006, 'B+');
	insert into takes values('46106', '169', '1', 'Spring', 2007, 'B+');
	insert into takes values('12666', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('41938', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('82301', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('84432', '893', '1', 'Fall', 2007, 'B+');
	insert into takes values('48469', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('55940', '482', '1', 'Fall', 2005, 'C ');
	insert into takes values('66279', '421', '1', 'Fall', 2004, 'A ');
	insert into takes values('64724', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('72741', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('39925', '362', '3', 'Spring', 2008, 'B ');
	insert into takes values('17944', '808', '1', 'Fall', 2003, 'A+');
	insert into takes values('26494', '304', '1', 'Fall', 2009, 'B+');
	insert into takes values('40932', '237', '1', 'Spring', 2008, 'B+');
	insert into takes values('97042', '972', '1', 'Spring', 2009, 'B+');
	insert into takes values('1110', '612', '1', 'Fall', 2007, 'A-');
	insert into takes values('19917', '457', '1', 'Spring', 2001, 'B+');
	insert into takes values('93508', '443', '1', 'Spring', 2010, 'B ');
	insert into takes values('63489', '974', '1', 'Fall', 2003, 'A+');
	insert into takes values('54875', '457', '1', 'Spring', 2001, 'B-');
	insert into takes values('64039', '960', '1', 'Fall', 2009, 'A+');
	insert into takes values('94730', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('69632', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('36513', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('69960', '468', '2', 'Fall', 2007, 'C-');
	insert into takes values('23373', '242', '1', 'Fall', 2009, 'C-');
	insert into takes values('41599', '169', '1', 'Spring', 2007, 'B-');
	insert into takes values('27094', '581', '1', 'Spring', 2005, 'C-');
	insert into takes values('61081', '694', '1', 'Fall', 2002, 'C+');
	insert into takes values('83686', '629', '1', 'Spring', 2003, 'A+');
	insert into takes values('75123', '313', '1', 'Fall', 2010, 'C-');
	insert into takes values('89234', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('27556', '158', '2', 'Spring', 2008, 'B-');
	insert into takes values('95260', '338', '1', 'Spring', 2007, 'C+');
	insert into takes values('14668', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('67033', '631', '1', 'Spring', 2007, 'A ');
	insert into takes values('41091', '795', '1', 'Spring', 2004, 'A-');
	insert into takes values('48678', '974', '1', 'Fall', 2003, 'A+');
	insert into takes values('2967', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('1460', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('3639', '960', '2', 'Fall', 2006, 'A-');
	insert into takes values('87624', '366', '1', 'Fall', 2005, 'B ');
	insert into takes values('80976', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('79697', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('34502', '158', '1', 'Fall', 2008, 'B-');
	insert into takes values('35362', '242', '1', 'Fall', 2009, 'C ');
	insert into takes values('41406', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('18809', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('61003', '704', '1', 'Spring', 2008, 'C-');
	insert into takes values('76246', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('24809', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('56849', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('99422', '626', '1', 'Fall', 2006, 'A-');
	insert into takes values('99754', '748', '1', 'Fall', 2003, 'C-');
	insert into takes values('58326', '696', '1', 'Spring', 2002, 'B-');
	insert into takes values('6990', '400', '2', 'Fall', 2003, 'C-');
	insert into takes values('10904', '802', '1', 'Spring', 2003, 'A+');
	insert into takes values('91442', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('90448', '445', '1', 'Spring', 2001, 'C ');
	insert into takes values('41894', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('35687', '362', '3', 'Spring', 2008, 'C+');
	insert into takes values('43495', '843', '1', 'Fall', 2010, 'A+');
	insert into takes values('21401', '158', '1', 'Fall', 2008, 'C-');
	insert into takes values('59046', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('41938', '105', '1', 'Fall', 2009, 'A+');
	insert into takes values('51203', '461', '1', 'Fall', 2002, 'C+');
	insert into takes values('46035', '408', '1', 'Spring', 2007, 'B ');
	insert into takes values('86573', '461', '1', 'Fall', 2002, 'C-');
	insert into takes values('83002', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('77130', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('32217', '747', '1', 'Spring', 2004, 'C-');
	insert into takes values('60867', '927', '1', 'Fall', 2002, 'C ');
	insert into takes values('42956', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('89188', '960', '2', 'Fall', 2006, 'B-');
	insert into takes values('75534', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('78434', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('1110', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('64138', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('53805', '237', '2', 'Fall', 2009, 'C+');
	insert into takes values('69730', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('19362', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('66969', '808', '1', 'Fall', 2003, 'A-');
	insert into takes values('46451', '991', '1', 'Spring', 2008, 'B ');
	insert into takes values('25380', '972', '1', 'Spring', 2009, 'C ');
	insert into takes values('65038', '559', '1', 'Fall', 2002, 'A ');
	insert into takes values('74911', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('75395', '408', '1', 'Spring', 2007, 'A-');
	insert into takes values('18367', '408', '2', 'Spring', 2003, 'C ');
	insert into takes values('16133', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('49503', '561', '1', 'Fall', 2006, 'C ');
	insert into takes values('72959', '415', '1', 'Fall', 2010, 'C-');
	insert into takes values('10736', '735', '2', 'Spring', 2010, 'A+');
	insert into takes values('5925', '663', '1', 'Spring', 2005, 'B-');
	insert into takes values('46655', '468', '2', 'Fall', 2007, 'C+');
	insert into takes values('5243', '631', '1', 'Spring', 2007, 'B+');
	insert into takes values('53225', '443', '1', 'Spring', 2010, 'B ');
	insert into takes values('96722', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('57026', '581', '1', 'Spring', 2005, 'B+');
	insert into takes values('11604', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('52494', '852', '1', 'Spring', 2008, 'B ');
	insert into takes values('2423', '663', '1', 'Spring', 2005, 'B ');
	insert into takes values('69960', '345', '1', 'Spring', 2008, 'A+');
	insert into takes values('77289', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('55698', '991', '1', 'Spring', 2008, 'A ');
	insert into takes values('90220', '735', '1', 'Spring', 2003, 'C ');
	insert into takes values('71944', '482', '1', 'Fall', 2005, 'B ');
	insert into takes values('81550', '258', '1', 'Fall', 2007, 'B+');
	insert into takes values('88417', '366', '1', 'Fall', 2005, 'A+');
	insert into takes values('1460', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('8807', '974', '1', 'Fall', 2003, 'B-');
	insert into takes values('33338', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('83170', '105', '2', 'Fall', 2002, 'B-');
	insert into takes values('21401', '679', '1', 'Spring', 2010, 'B-');
	insert into takes values('80057', '426', '1', 'Spring', 2006, 'C ');
	insert into takes values('10481', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('15980', '631', '1', 'Spring', 2007, 'A-');
	insert into takes values('10663', '415', '1', 'Fall', 2010, 'C ');
	insert into takes values('56089', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('336', '415', '1', 'Fall', 2010, 'A+');
	insert into takes values('50267', '376', '1', 'Fall', 2006, 'C+');
	insert into takes values('55329', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('86641', '137', '1', 'Spring', 2002, 'C-');
	insert into takes values('70452', '843', '1', 'Fall', 2010, 'A+');
	insert into takes values('69471', '991', '1', 'Spring', 2008, 'A ');
	insert into takes values('83557', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('58595', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('68263', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('88140', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('56057', '561', '1', 'Fall', 2006, 'B-');
	insert into takes values('41827', '443', '2', 'Spring', 2002, 'B ');
	insert into takes values('85904', '599', '1', 'Spring', 2003, 'B+');
	insert into takes values('58413', '421', '1', 'Fall', 2004, 'B-');
	insert into takes values('34422', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('92385', '237', '1', 'Spring', 2008, 'B+');
	insert into takes values('39876', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('11419', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('13403', '338', '2', 'Spring', 2006, 'A-');
	insert into takes values('90353', '949', '1', 'Fall', 2007, 'A-');
	insert into takes values('60748', '362', '3', 'Spring', 2008, 'C+');
	insert into takes values('53185', '426', '1', 'Spring', 2006, 'B ');
	insert into takes values('27528', '702', '1', 'Spring', 2001, 'B ');
	insert into takes values('67810', '443', '2', 'Spring', 2002, 'A ');
	insert into takes values('28252', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('7602', '843', '1', 'Fall', 2010, 'B-');
	insert into takes values('97065', '338', '1', 'Spring', 2007, 'C-');
	insert into takes values('69222', '735', '2', 'Spring', 2010, 'B ');
	insert into takes values('93061', '200', '1', 'Spring', 2007, 'C ');
	insert into takes values('44271', '270', '1', 'Spring', 2010, 'A-');
	insert into takes values('41774', '735', '2', 'Spring', 2010, 'A ');
	insert into takes values('68280', '366', '1', 'Fall', 2005, 'A+');
	insert into takes values('9495', '875', '1', 'Spring', 2005, 'A ');
	insert into takes values('59920', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('13826', '362', '2', 'Fall', 2006, 'A ');
	insert into takes values('46980', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('65208', '795', '1', 'Spring', 2004, 'B+');
	insert into takes values('57055', '345', '1', 'Spring', 2008, 'B ');
	insert into takes values('12711', '696', '1', 'Spring', 2002, 'B ');
	insert into takes values('78143', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('90220', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('75040', '304', '1', 'Fall', 2009, 'B ');
	insert into takes values('36263', '304', '1', 'Fall', 2009, 'B ');
	insert into takes values('67583', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('79589', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('45436', '496', '1', 'Fall', 2001, 'B+');
	insert into takes values('62226', '760', '1', 'Spring', 2004, 'B ');
	insert into takes values('37946', '545', '1', 'Fall', 2001, 'A-');
	insert into takes values('45083', '893', '1', 'Fall', 2007, 'A+');
	insert into takes values('1285', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('5824', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('78792', '338', '1', 'Spring', 2007, 'A-');
	insert into takes values('39876', '169', '1', 'Spring', 2007, 'B ');
	insert into takes values('2967', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('52494', '864', '1', 'Spring', 2006, 'C+');
	insert into takes values('95574', '704', '1', 'Spring', 2008, 'B ');
	insert into takes values('5871', '559', '1', 'Fall', 2002, 'B+');
	insert into takes values('65753', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('7020', '376', '1', 'Fall', 2006, 'B ');
	insert into takes values('78782', '974', '1', 'Fall', 2003, 'C ');
	insert into takes values('48471', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('28538', '400', '2', 'Fall', 2003, 'B-');
	insert into takes values('11201', '362', '3', 'Spring', 2008, 'A+');
	insert into takes values('89234', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('96710', '972', '1', 'Spring', 2009, 'A ');
	insert into takes values('72528', '366', '1', 'Fall', 2005, 'C ');
	insert into takes values('52494', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('87246', '237', '2', 'Fall', 2009, 'C ');
	insert into takes values('435', '545', '1', 'Fall', 2001, 'A ');
	insert into takes values('36102', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('20244', '105', '1', 'Fall', 2009, 'B+');
	insert into takes values('18469', '795', '1', 'Spring', 2004, 'B-');
	insert into takes values('65056', '791', '1', 'Spring', 2006, 'A ');
	insert into takes values('62520', '927', '1', 'Fall', 2002, 'C+');
	insert into takes values('29959', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('13741', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('95089', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('70522', '599', '1', 'Spring', 2003, 'B-');
	insert into takes values('57456', '959', '1', 'Fall', 2006, 'B+');
	insert into takes values('41894', '791', '1', 'Spring', 2006, 'B+');
	insert into takes values('22179', '461', '1', 'Fall', 2002, 'A-');
	insert into takes values('34770', '349', '1', 'Spring', 2008, 'B+');
	insert into takes values('17665', '679', '1', 'Spring', 2010, 'B+');
	insert into takes values('17997', '408', '1', 'Spring', 2007, 'A-');
	insert into takes values('81538', '443', '1', 'Spring', 2010, 'B-');
	insert into takes values('66763', '791', '1', 'Spring', 2006, 'A-');
	insert into takes values('41832', '696', '1', 'Spring', 2002, 'A-');
	insert into takes values('58170', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('83696', '242', '1', 'Fall', 2009, 'C ');
	insert into takes values('99422', '421', '1', 'Fall', 2004, 'B+');
	insert into takes values('90814', '274', '1', 'Fall', 2002, 'B ');
	insert into takes values('92040', '867', '1', 'Fall', 2006, 'B ');
	insert into takes values('12941', '852', '1', 'Spring', 2008, 'B-');
	insert into takes values('78572', '603', '1', 'Fall', 2003, 'B+');
	insert into takes values('1402', '274', '1', 'Fall', 2002, 'B-');
	insert into takes values('72528', '760', '1', 'Spring', 2004, 'B-');
	insert into takes values('41818', '704', '1', 'Spring', 2008, 'B ');
	insert into takes values('20489', '304', '1', 'Fall', 2009, 'A ');
	insert into takes values('77231', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('6712', '443', '2', 'Spring', 2002, 'A+');
	insert into takes values('34957', '105', '2', 'Fall', 2002, 'C-');
	insert into takes values('48660', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('8912', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('98140', '105', '2', 'Fall', 2002, 'B-');
	insert into takes values('33817', '561', '1', 'Fall', 2006, 'A+');
	insert into takes values('95284', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('94815', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('68453', '704', '1', 'Spring', 2008, 'C-');
	insert into takes values('4435', '443', '2', 'Spring', 2002, 'C-');
	insert into takes values('68395', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('21225', '962', '1', 'Spring', 2008, 'C+');
	insert into takes values('90220', '489', '1', 'Fall', 2007, 'A-');
	insert into takes values('49073', '843', '1', 'Fall', 2010, 'A+');
	insert into takes values('55354', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('45494', '338', '1', 'Spring', 2007, 'C ');
	insert into takes values('54875', '468', '1', 'Fall', 2005, 'B+');
	insert into takes values('81031', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('37809', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('76270', '319', '1', 'Spring', 2003, 'B ');
	insert into takes values('91799', '270', '1', 'Spring', 2010, 'C ');
	insert into takes values('68779', '663', '1', 'Spring', 2005, 'B ');
	insert into takes values('46106', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('30650', '893', '1', 'Fall', 2007, 'A ');
	insert into takes values('18821', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('61356', '443', '2', 'Spring', 2002, 'A-');
	insert into takes values('14596', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('87831', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('96206', '304', '1', 'Fall', 2009, 'C-');
	insert into takes values('49813', '760', '1', 'Spring', 2004, 'B-');
	insert into takes values('49759', '468', '2', 'Fall', 2007, 'A+');
	insert into takes values('31820', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('46451', '972', '1', 'Spring', 2009, 'C ');
	insert into takes values('66269', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('79352', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('62152', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('7149', '972', '1', 'Spring', 2009, 'A+');
	insert into takes values('70564', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('84189', '991', '1', 'Spring', 2008, 'B ');
	insert into takes values('46981', '735', '2', 'Spring', 2010, 'A+');
	insert into takes values('78758', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('14628', '415', '1', 'Fall', 2010, 'A-');
	insert into takes values('66469', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('90663', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('40738', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('1737', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('16515', '476', '1', 'Fall', 2010, 'A+');
	insert into takes values('2419', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('75116', '237', '2', 'Fall', 2009, 'C-');
	insert into takes values('43912', '408', '2', 'Spring', 2003, 'A+');
	insert into takes values('68330', '352', '1', 'Spring', 2006, 'B ');
	insert into takes values('48423', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('35721', '200', '1', 'Spring', 2007, 'A+');
	insert into takes values('19048', '468', '1', 'Fall', 2005, 'A+');
	insert into takes values('4860', '345', '1', 'Spring', 2008, 'B ');
	insert into takes values('5250', '415', '1', 'Fall', 2010, 'B+');
	insert into takes values('49503', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('57156', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('48660', '352', '1', 'Spring', 2006, 'C-');
	insert into takes values('14829', '626', '1', 'Fall', 2006, 'B ');
	insert into takes values('46655', '486', '1', 'Fall', 2009, 'C ');
	insert into takes values('89059', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('86753', '493', '1', 'Spring', 2010, 'A ');
	insert into takes values('75596', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('90009', '959', '1', 'Fall', 2006, 'C+');
	insert into takes values('24932', '400', '2', 'Fall', 2003, 'B+');
	insert into takes values('95029', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('97023', '496', '1', 'Fall', 2001, 'C-');
	insert into takes values('84239', '735', '1', 'Spring', 2003, 'C-');
	insert into takes values('50944', '852', '1', 'Spring', 2008, 'B ');
	insert into takes values('70688', '270', '1', 'Spring', 2010, 'A+');
	insert into takes values('23270', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('21337', '362', '2', 'Fall', 2006, 'A ');
	insert into takes values('75173', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('18636', '808', '1', 'Fall', 2003, 'B-');
	insert into takes values('3833', '338', '1', 'Spring', 2007, 'C ');
	insert into takes values('21102', '313', '1', 'Fall', 2010, 'B ');
	insert into takes values('88358', '270', '1', 'Spring', 2010, 'B+');
	insert into takes values('87280', '415', '1', 'Fall', 2010, 'A+');
	insert into takes values('57787', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('91197', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('29514', '591', '1', 'Spring', 2005, 'A+');
	insert into takes values('29959', '443', '1', 'Spring', 2010, 'B+');
	insert into takes values('87222', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('15457', '400', '1', 'Spring', 2007, 'C-');
	insert into takes values('53788', '400', '1', 'Spring', 2007, 'A-');
	insert into takes values('60040', '304', '1', 'Fall', 2009, 'B ');
	insert into takes values('82974', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('21102', '631', '1', 'Spring', 2007, 'C+');
	insert into takes values('18286', '793', '1', 'Spring', 2002, 'A ');
	insert into takes values('18775', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('31101', '843', '1', 'Fall', 2010, 'B-');
	insert into takes values('51238', '852', '1', 'Spring', 2008, 'C ');
	insert into takes values('56486', '270', '1', 'Spring', 2010, 'C+');
	insert into takes values('76224', '927', '1', 'Fall', 2002, 'C-');
	insert into takes values('60748', '489', '1', 'Fall', 2007, 'B+');
	insert into takes values('86753', '426', '1', 'Spring', 2006, 'B ');
	insert into takes values('71631', '545', '1', 'Fall', 2001, 'B ');
	insert into takes values('5336', '443', '1', 'Spring', 2010, 'C ');
	insert into takes values('23994', '867', '1', 'Fall', 2006, 'B ');
	insert into takes values('20489', '400', '2', 'Fall', 2003, 'C+');
	insert into takes values('46074', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('73394', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('16035', '545', '1', 'Fall', 2001, 'B ');
	insert into takes values('13495', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('36263', '400', '2', 'Fall', 2003, 'A ');
	insert into takes values('50703', '808', '1', 'Fall', 2003, 'A-');
	insert into takes values('8807', '482', '1', 'Fall', 2005, 'A-');
	insert into takes values('88418', '735', '1', 'Spring', 2003, 'C ');
	insert into takes values('57238', '482', '1', 'Fall', 2005, 'B-');
	insert into takes values('67655', '362', '1', 'Fall', 2005, 'C+');
	insert into takes values('47025', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('42019', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('55915', '702', '1', 'Spring', 2001, 'C-');
	insert into takes values('51698', '237', '1', 'Spring', 2008, 'A-');
	insert into takes values('18809', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('27952', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('26695', '258', '1', 'Fall', 2007, 'C-');
	insert into takes values('11422', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('83696', '793', '1', 'Spring', 2002, 'C+');
	insert into takes values('60366', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('56755', '991', '1', 'Spring', 2008, 'C-');
	insert into takes values('11422', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('53803', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('78756', '158', '1', 'Fall', 2008, 'A-');
	insert into takes values('13081', '313', '1', 'Fall', 2010, 'A-');
	insert into takes values('51579', '468', '2', 'Fall', 2007, 'C+');
	insert into takes values('85809', '313', '1', 'Fall', 2010, 'A ');
	insert into takes values('99250', '962', '1', 'Spring', 2008, 'C-');
	insert into takes values('13826', '169', '2', 'Fall', 2002, 'C ');
	insert into takes values('50873', '545', '1', 'Fall', 2001, 'A ');
	insert into takes values('61920', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('30723', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('9495', '137', '1', 'Spring', 2002, 'C-');
	insert into takes values('3005', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('36244', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('71426', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('42625', '852', '1', 'Spring', 2008, 'A ');
	insert into takes values('21766', '270', '1', 'Spring', 2010, 'C ');
	insert into takes values('5144', '694', '1', 'Fall', 2002, 'B ');
	insert into takes values('71025', '400', '1', 'Spring', 2007, 'B+');
	insert into takes values('42625', '158', '2', 'Spring', 2008, 'A ');
	insert into takes values('94726', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('19791', '893', '1', 'Fall', 2007, 'B+');
	insert into takes values('17057', '793', '1', 'Spring', 2002, 'B ');
	insert into takes values('33759', '270', '1', 'Spring', 2010, 'C-');
	insert into takes values('97042', '366', '1', 'Fall', 2005, 'C-');
	insert into takes values('48247', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('9114', '445', '1', 'Spring', 2001, 'C+');
	insert into takes values('47487', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('86981', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('65901', '791', '1', 'Spring', 2006, 'A ');
	insert into takes values('67407', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('40937', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('898', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('1826', '960', '2', 'Fall', 2006, 'A-');
	insert into takes values('58594', '401', '1', 'Fall', 2003, 'A+');
	insert into takes values('41683', '468', '2', 'Fall', 2007, 'A+');
	insert into takes values('14484', '694', '1', 'Fall', 2002, 'C ');
	insert into takes values('40992', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('92839', '200', '2', 'Fall', 2002, 'C+');
	insert into takes values('76953', '105', '1', 'Fall', 2009, 'C+');
	insert into takes values('86753', '604', '1', 'Spring', 2009, 'A ');
	insert into takes values('80248', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('20195', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('55000', '760', '1', 'Spring', 2004, 'B-');
	insert into takes values('46436', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('87044', '960', '1', 'Fall', 2009, 'B-');
	insert into takes values('52741', '867', '2', 'Fall', 2010, 'C-');
	insert into takes values('64893', '349', '1', 'Spring', 2008, 'B+');
	insert into takes values('64297', '105', '2', 'Fall', 2002, 'A-');
	insert into takes values('29462', '401', '1', 'Fall', 2003, 'A-');
	insert into takes values('26028', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('65396', '591', '1', 'Spring', 2005, 'C-');
	insert into takes values('76246', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('1954', '852', '1', 'Spring', 2008, 'A-');
	insert into takes values('13081', '274', '1', 'Fall', 2002, 'C+');
	insert into takes values('41832', '338', '2', 'Spring', 2006, 'B+');
	insert into takes values('61127', '791', '1', 'Spring', 2006, 'A ');
	insert into takes values('57962', '748', '1', 'Fall', 2003, 'B-');
	insert into takes values('87706', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('31560', '158', '2', 'Spring', 2008, 'C+');
	insert into takes values('34502', '626', '1', 'Fall', 2006, 'C+');
	insert into takes values('74070', '692', '1', 'Spring', 2010, 'A ');
	insert into takes values('61854', '808', '1', 'Fall', 2003, 'A-');
	insert into takes values('18554', '352', '1', 'Spring', 2006, 'C-');
	insert into takes values('64938', '545', '1', 'Fall', 2001, 'A+');
	insert into takes values('7973', '791', '1', 'Spring', 2006, 'C-');
	insert into takes values('28361', '493', '1', 'Spring', 2010, 'B+');
	insert into takes values('98870', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('29849', '642', '1', 'Fall', 2004, 'B+');
	insert into takes values('71426', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('80247', '362', '3', 'Spring', 2008, 'B ');
	insert into takes values('16480', '362', '1', 'Fall', 2005, 'C-');
	insert into takes values('23500', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('15980', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('75241', '270', '1', 'Spring', 2010, 'C ');
	insert into takes values('53047', '400', '1', 'Spring', 2007, 'A-');
	insert into takes values('336', '408', '2', 'Spring', 2003, 'A ');
	insert into takes values('7035', '802', '1', 'Spring', 2003, 'C+');
	insert into takes values('3545', '334', '1', 'Fall', 2009, 'A ');
	insert into takes values('90567', '960', '1', 'Fall', 2009, 'B ');
	insert into takes values('5920', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('41741', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('23506', '867', '1', 'Fall', 2006, 'A ');
	insert into takes values('92385', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('53172', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('27044', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('71628', '304', '1', 'Fall', 2009, 'A ');
	insert into takes values('72358', '105', '1', 'Fall', 2009, 'C-');
	insert into takes values('5824', '591', '1', 'Spring', 2005, 'C-');
	insert into takes values('858', '415', '1', 'Fall', 2010, 'B-');
	insert into takes values('62054', '626', '1', 'Fall', 2006, 'C ');
	insert into takes values('288', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('63243', '489', '1', 'Fall', 2007, 'A ');
	insert into takes values('14621', '581', '1', 'Spring', 2005, 'A ');
	insert into takes values('71944', '169', '2', 'Fall', 2002, 'A ');
	insert into takes values('21101', '486', '1', 'Fall', 2009, 'C ');
	insert into takes values('48165', '445', '1', 'Spring', 2001, 'C ');
	insert into takes values('75938', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('79352', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('93986', '158', '2', 'Spring', 2008, 'C ');
	insert into takes values('65101', '527', '1', 'Fall', 2004, 'A ');
	insert into takes values('17086', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('17397', '169', '2', 'Fall', 2002, 'A ');
	insert into takes values('51975', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('91799', '408', '1', 'Spring', 2007, 'B ');
	insert into takes values('79446', '571', '1', 'Spring', 2004, 'A+');
	insert into takes values('11455', '591', '1', 'Spring', 2005, 'C-');
	insert into takes values('27952', '843', '1', 'Fall', 2010, 'C-');
	insert into takes values('37038', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('40992', '415', '1', 'Fall', 2010, 'A-');
	insert into takes values('51817', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('27952', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('41774', '626', '1', 'Fall', 2006, 'B-');
	insert into takes values('93039', '468', '1', 'Fall', 2005, 'C ');
	insert into takes values('56057', '493', '1', 'Spring', 2010, 'A ');
	insert into takes values('15340', '476', '1', 'Fall', 2010, 'C-');
	insert into takes values('48861', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('53547', '867', '1', 'Fall', 2006, 'C+');
	insert into takes values('3693', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('65753', '400', '2', 'Fall', 2003, 'C-');
	insert into takes values('61232', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('31266', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('57190', '482', '1', 'Fall', 2005, 'B-');
	insert into takes values('42991', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('99073', '137', '1', 'Spring', 2002, 'A-');
	insert into takes values('95225', '169', '1', 'Spring', 2007, 'A ');
	insert into takes values('41211', '545', '1', 'Fall', 2001, 'A+');
	insert into takes values('11453', '867', '2', 'Fall', 2010, 'B-');
	insert into takes values('62795', '679', '1', 'Spring', 2010, 'C+');
	insert into takes values('87048', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('86806', '760', '1', 'Spring', 2004, 'B ');
	insert into takes values('29665', '443', '1', 'Spring', 2010, 'B ');
	insert into takes values('29863', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('31516', '362', '2', 'Fall', 2006, 'A ');
	insert into takes values('75423', '345', '1', 'Spring', 2008, 'C+');
	insert into takes values('39619', '486', '1', 'Fall', 2009, 'C ');
	insert into takes values('83573', '400', '1', 'Spring', 2007, 'C-');
	insert into takes values('78581', '599', '1', 'Spring', 2003, 'B+');
	insert into takes values('28952', '496', '1', 'Fall', 2001, 'C ');
	insert into takes values('93631', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('7123', '169', '2', 'Fall', 2002, 'B-');
	insert into takes values('70021', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('92442', '581', '1', 'Spring', 2005, 'C-');
	insert into takes values('63288', '258', '1', 'Fall', 2007, 'A ');
	insert into takes values('13921', '486', '1', 'Fall', 2009, 'C ');
	insert into takes values('29705', '408', '1', 'Spring', 2007, 'C+');
	insert into takes values('2970', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('42560', '735', '1', 'Spring', 2003, 'A-');
	insert into takes values('33651', '468', '2', 'Fall', 2007, 'A-');
	insert into takes values('74464', '105', '1', 'Fall', 2009, 'A+');
	insert into takes values('39046', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('27366', '927', '1', 'Fall', 2002, 'A+');
	insert into takes values('16311', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('11966', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('6895', '604', '1', 'Spring', 2009, 'B+');
	insert into takes values('71878', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('75273', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('35042', '237', '1', 'Spring', 2008, 'A-');
	insert into takes values('40116', '852', '1', 'Spring', 2008, 'A-');
	insert into takes values('40558', '581', '1', 'Spring', 2005, 'C-');
	insert into takes values('45680', '338', '1', 'Spring', 2007, 'B-');
	insert into takes values('35881', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('46769', '445', '1', 'Spring', 2001, 'A-');
	insert into takes values('74974', '352', '1', 'Spring', 2006, 'C ');
	insert into takes values('33460', '599', '1', 'Spring', 2003, 'B ');
	insert into takes values('37586', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('46155', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('73387', '362', '1', 'Fall', 2005, 'C+');
	insert into takes values('66106', '795', '1', 'Spring', 2004, 'B-');
	insert into takes values('31442', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('10033', '334', '1', 'Fall', 2009, 'C-');
	insert into takes values('47670', '476', '1', 'Fall', 2010, 'C ');
	insert into takes values('77003', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('1087', '679', '1', 'Spring', 2010, 'B-');
	insert into takes values('435', '274', '1', 'Fall', 2002, 'B ');
	insert into takes values('30017', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('2501', '362', '1', 'Fall', 2005, 'C+');
	insert into takes values('16543', '571', '1', 'Spring', 2004, 'A-');
	insert into takes values('62226', '408', '1', 'Spring', 2007, 'C+');
	insert into takes values('9495', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('34236', '735', '2', 'Spring', 2010, 'A-');
	insert into takes values('8819', '927', '1', 'Fall', 2002, 'C ');
	insert into takes values('17600', '476', '1', 'Fall', 2010, 'C-');
	insert into takes values('55329', '527', '1', 'Fall', 2004, 'C+');
	insert into takes values('33206', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('98120', '843', '1', 'Fall', 2010, 'A ');
	insert into takes values('98056', '561', '1', 'Fall', 2006, 'B+');
	insert into takes values('64401', '747', '1', 'Spring', 2004, 'A ');
	insert into takes values('41818', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('71878', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('64249', '338', '1', 'Spring', 2007, 'A+');
	insert into takes values('86674', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('83622', '158', '2', 'Spring', 2008, 'A ');
	insert into takes values('30723', '239', '1', 'Fall', 2006, 'A-');
	insert into takes values('52750', '927', '1', 'Fall', 2002, 'C+');
	insert into takes values('26619', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('28133', '105', '1', 'Fall', 2009, 'B ');
	insert into takes values('17377', '313', '1', 'Fall', 2010, 'C+');
	insert into takes values('78792', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('63390', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('66281', '313', '1', 'Fall', 2010, 'C ');
	insert into takes values('28352', '486', '1', 'Fall', 2009, 'B ');
	insert into takes values('36052', '962', '1', 'Spring', 2008, 'B-');
	insert into takes values('70828', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('29399', '158', '2', 'Spring', 2008, 'B+');
	insert into takes values('33837', '237', '2', 'Fall', 2009, 'A-');
	insert into takes values('36384', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('57190', '443', '1', 'Spring', 2010, 'C ');
	insert into takes values('2201', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('34236', '694', '1', 'Fall', 2002, 'C+');
	insert into takes values('85746', '962', '1', 'Spring', 2008, 'B ');
	insert into takes values('32483', '105', '1', 'Fall', 2009, 'B ');
	insert into takes values('83747', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('57780', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('16753', '408', '1', 'Spring', 2007, 'C-');
	insert into takes values('51553', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('44881', '468', '2', 'Fall', 2007, 'B ');
	insert into takes values('8986', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('78314', '581', '1', 'Spring', 2005, 'C+');
	insert into takes values('61920', '319', '1', 'Spring', 2003, 'A-');
	insert into takes values('79487', '362', '1', 'Fall', 2005, 'B ');
	insert into takes values('38288', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('65205', '875', '1', 'Spring', 2005, 'B-');
	insert into takes values('43432', '237', '1', 'Spring', 2008, 'B ');
	insert into takes values('59117', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('78782', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('61403', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('4383', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('37809', '735', '1', 'Spring', 2003, 'A ');
	insert into takes values('41675', '237', '2', 'Fall', 2009, 'A-');
	insert into takes values('16057', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('46260', '362', '3', 'Spring', 2008, 'C+');
	insert into takes values('69783', '200', '1', 'Spring', 2007, 'A-');
	insert into takes values('65979', '169', '1', 'Spring', 2007, 'A-');
	insert into takes values('31554', '875', '1', 'Spring', 2005, 'C-');
	insert into takes values('77000', '270', '1', 'Spring', 2010, 'A-');
	insert into takes values('33460', '867', '2', 'Fall', 2010, 'C-');
	insert into takes values('56755', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('22620', '482', '1', 'Fall', 2005, 'A ');
	insert into takes values('42688', '400', '1', 'Spring', 2007, 'C ');
	insert into takes values('62636', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('37869', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('39521', '843', '1', 'Fall', 2010, 'B+');
	insert into takes values('8807', '735', '1', 'Spring', 2003, 'C ');
	insert into takes values('17057', '461', '1', 'Fall', 2002, 'B ');
	insert into takes values('71287', '496', '1', 'Fall', 2001, 'A-');
	insert into takes values('80254', '443', '1', 'Spring', 2010, 'B ');
	insert into takes values('43016', '137', '1', 'Spring', 2002, 'A ');
	insert into takes values('93061', '362', '2', 'Fall', 2006, 'A-');
	insert into takes values('70362', '927', '1', 'Fall', 2002, 'A ');
	insert into takes values('95175', '457', '1', 'Spring', 2001, 'A+');
	insert into takes values('50331', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('54620', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('51238', '408', '2', 'Spring', 2003, 'B ');
	insert into takes values('92864', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('35257', '748', '1', 'Fall', 2003, 'B ');
	insert into takes values('70389', '366', '1', 'Fall', 2005, 'A+');
	insert into takes values('4860', '702', '1', 'Spring', 2001, 'C-');
	insert into takes values('98619', '991', '1', 'Spring', 2008, 'A ');
	insert into takes values('92949', '631', '1', 'Spring', 2007, 'A+');
	insert into takes values('39552', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('14596', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('32376', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('1726', '313', '1', 'Fall', 2010, 'B+');
	insert into takes values('49339', '949', '1', 'Fall', 2007, 'C-');
	insert into takes values('54508', '270', '1', 'Spring', 2010, 'C+');
	insert into takes values('35685', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('64121', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('94178', '960', '1', 'Fall', 2009, 'B ');
	insert into takes values('92040', '200', '2', 'Fall', 2002, 'C-');
	insert into takes values('43981', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('11201', '802', '1', 'Spring', 2003, 'B+');
	insert into takes values('46066', '735', '1', 'Spring', 2003, 'A-');
	insert into takes values('82591', '421', '1', 'Fall', 2004, 'C ');
	insert into takes values('85910', '991', '1', 'Spring', 2008, 'A ');
	insert into takes values('73387', '415', '1', 'Fall', 2010, 'C+');
	insert into takes values('34195', '400', '1', 'Spring', 2007, 'B+');
	insert into takes values('66494', '696', '1', 'Spring', 2002, 'A ');
	insert into takes values('25942', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('84239', '735', '2', 'Spring', 2010, 'C ');
	insert into takes values('65987', '258', '1', 'Fall', 2007, 'A+');
	insert into takes values('40178', '443', '1', 'Spring', 2010, 'B-');
	insert into takes values('32506', '426', '1', 'Spring', 2006, 'B ');
	insert into takes values('85534', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('87193', '400', '2', 'Fall', 2003, 'A-');
	insert into takes values('39657', '852', '1', 'Spring', 2008, 'C-');
	insert into takes values('57511', '313', '1', 'Fall', 2010, 'A+');
	insert into takes values('14563', '242', '1', 'Fall', 2009, 'C+');
	insert into takes values('4383', '591', '1', 'Spring', 2005, 'A ');
	insert into takes values('40116', '345', '1', 'Spring', 2008, 'A ');
	insert into takes values('34197', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('80247', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('24746', '852', '1', 'Spring', 2008, 'B-');
	insert into takes values('92867', '400', '1', 'Spring', 2007, 'C+');
	insert into takes values('62728', '696', '1', 'Spring', 2002, 'A+');
	insert into takes values('21126', '258', '1', 'Fall', 2007, 'C ');
	insert into takes values('75878', '345', '1', 'Spring', 2008, 'A-');
	insert into takes values('54620', '400', '1', 'Spring', 2007, 'A+');
	insert into takes values('39114', '893', '1', 'Fall', 2007, 'B-');
	insert into takes values('70235', '105', '2', 'Fall', 2002, 'A ');
	insert into takes values('499', '696', '1', 'Spring', 2002, 'B+');
	insert into takes values('75241', '760', '1', 'Spring', 2004, 'B+');
	insert into takes values('76759', '334', '1', 'Fall', 2009, 'B ');
	insert into takes values('68096', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('95175', '694', '1', 'Fall', 2002, 'C ');
	insert into takes values('82970', '237', '1', 'Spring', 2008, 'A+');
	insert into takes values('46694', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('54153', '875', '1', 'Spring', 2005, 'C ');
	insert into takes values('59673', '415', '1', 'Fall', 2010, 'C ');
	insert into takes values('36657', '793', '1', 'Spring', 2002, 'A-');
	insert into takes values('29863', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('44881', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('14668', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('13921', '808', '1', 'Fall', 2003, 'C ');
	insert into takes values('27687', '626', '1', 'Fall', 2006, 'C ');
	insert into takes values('72528', '704', '1', 'Spring', 2008, 'B ');
	insert into takes values('35293', '169', '2', 'Fall', 2002, 'C ');
	insert into takes values('76246', '702', '1', 'Spring', 2001, 'C+');
	insert into takes values('39619', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('67725', '960', '2', 'Fall', 2006, 'B+');
	insert into takes values('40059', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('96003', '604', '1', 'Spring', 2009, 'B ');
	insert into takes values('5943', '626', '1', 'Fall', 2006, 'C ');
	insert into takes values('41741', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('29002', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('792', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('67371', '376', '1', 'Fall', 2006, 'B+');
	insert into takes values('53490', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('24746', '237', '1', 'Spring', 2008, 'A+');
	insert into takes values('92965', '468', '1', 'Fall', 2005, 'C ');
	insert into takes values('83002', '376', '1', 'Fall', 2006, 'A ');
	insert into takes values('79892', '702', '1', 'Spring', 2001, 'C ');
	insert into takes values('99463', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('66279', '960', '1', 'Fall', 2009, 'A-');
	insert into takes values('9183', '696', '1', 'Spring', 2002, 'C-');
	insert into takes values('3576', '443', '2', 'Spring', 2002, 'B ');
	insert into takes values('41675', '599', '1', 'Spring', 2003, 'C ');
	insert into takes values('61527', '239', '1', 'Fall', 2006, 'B ');
	insert into takes values('76953', '169', '2', 'Fall', 2002, 'A+');
	insert into takes values('12214', '791', '1', 'Spring', 2006, 'A ');
	insert into takes values('67810', '105', '2', 'Fall', 2002, 'B+');
	insert into takes values('43211', '270', '1', 'Spring', 2010, 'A+');
	insert into takes values('3335', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('83728', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('82974', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('38696', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('65563', '875', '1', 'Spring', 2005, 'A ');
	insert into takes values('645', '629', '1', 'Spring', 2003, 'B-');
	insert into takes values('18941', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('26102', '496', '1', 'Fall', 2001, 'B-');
	insert into takes values('74509', '158', '2', 'Spring', 2008, 'B-');
	insert into takes values('15030', '702', '1', 'Spring', 2001, 'C+');
	insert into takes values('85505', '696', '1', 'Spring', 2002, 'B-');
	insert into takes values('64259', '875', '1', 'Spring', 2005, 'A ');
	insert into takes values('81028', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('64192', '559', '1', 'Fall', 2002, 'C+');
	insert into takes values('30397', '158', '1', 'Fall', 2008, 'A ');
	insert into takes values('9947', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('48589', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('3143', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('27727', '802', '1', 'Spring', 2003, 'C-');
	insert into takes values('30334', '158', '1', 'Fall', 2008, 'A-');
	insert into takes values('1000', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('88389', '274', '1', 'Fall', 2002, 'B ');
	insert into takes values('31624', '169', '2', 'Fall', 2002, 'B-');
	insert into takes values('85505', '158', '1', 'Fall', 2008, 'B-');
	insert into takes values('4682', '239', '1', 'Fall', 2006, 'C-');
	insert into takes values('19450', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('61920', '237', '2', 'Fall', 2009, 'A ');
	insert into takes values('18941', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('57135', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('62124', '864', '1', 'Spring', 2006, 'C-');
	insert into takes values('87044', '960', '2', 'Fall', 2006, 'B+');
	insert into takes values('96206', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('95046', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('50664', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('4345', '158', '1', 'Fall', 2008, 'C ');
	insert into takes values('59908', '237', '2', 'Fall', 2009, 'A ');
	insert into takes values('6673', '893', '1', 'Fall', 2007, 'A+');
	insert into takes values('11194', '791', '1', 'Spring', 2006, 'C-');
	insert into takes values('29091', '274', '1', 'Fall', 2002, 'C+');
	insert into takes values('19342', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('78922', '679', '1', 'Spring', 2010, 'B ');
	insert into takes values('96052', '748', '1', 'Fall', 2003, 'A-');
	insert into takes values('94726', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('17133', '679', '1', 'Spring', 2010, 'A ');
	insert into takes values('20099', '642', '1', 'Fall', 2004, 'B-');
	insert into takes values('9440', '591', '1', 'Spring', 2005, 'C-');
	insert into takes values('15340', '468', '1', 'Fall', 2005, 'C+');
	insert into takes values('19861', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('37759', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('27017', '200', '1', 'Spring', 2007, 'B+');
	insert into takes values('16885', '489', '1', 'Fall', 2007, 'C ');
	insert into takes values('51768', '974', '1', 'Fall', 2003, 'C-');
	insert into takes values('65714', '545', '1', 'Fall', 2001, 'B ');
	insert into takes values('64039', '169', '1', 'Spring', 2007, 'A-');
	insert into takes values('34055', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('14668', '313', '1', 'Fall', 2010, 'C+');
	insert into takes values('75791', '604', '1', 'Spring', 2009, 'B ');
	insert into takes values('62373', '400', '2', 'Fall', 2003, 'A-');
	insert into takes values('64724', '791', '1', 'Spring', 2006, 'C-');
	insert into takes values('27017', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('79352', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('1080', '352', '1', 'Spring', 2006, 'B ');
	insert into takes values('73394', '169', '2', 'Fall', 2002, 'A+');
	insert into takes values('5703', '376', '1', 'Fall', 2006, 'A ');
	insert into takes values('52134', '960', '2', 'Fall', 2006, 'C ');
	insert into takes values('18367', '366', '1', 'Fall', 2005, 'A+');
	insert into takes values('62520', '338', '2', 'Spring', 2006, 'C ');
	insert into takes values('3693', '704', '1', 'Spring', 2008, 'C ');
	insert into takes values('98726', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('53485', '735', '1', 'Spring', 2003, 'B-');
	insert into takes values('62754', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('37869', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('5617', '960', '1', 'Fall', 2009, 'B+');
	insert into takes values('9993', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('94846', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('88887', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('29645', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('22254', '274', '1', 'Fall', 2002, 'B ');
	insert into takes values('65714', '603', '1', 'Fall', 2003, 'C-');
	insert into takes values('64067', '793', '1', 'Spring', 2002, 'C ');
	insert into takes values('69225', '304', '1', 'Fall', 2009, 'B+');
	insert into takes values('97042', '692', '1', 'Spring', 2010, 'A-');
	insert into takes values('90353', '626', '1', 'Fall', 2006, 'B-');
	insert into takes values('88389', '237', '2', 'Fall', 2009, 'C-');
	insert into takes values('93125', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('35588', '581', '1', 'Spring', 2005, 'C ');
	insert into takes values('1827', '415', '1', 'Fall', 2010, 'B-');
	insert into takes values('46436', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('38336', '692', '1', 'Spring', 2010, 'B-');
	insert into takes values('17665', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('88887', '793', '1', 'Spring', 2002, 'B ');
	insert into takes values('30182', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('46655', '200', '1', 'Spring', 2007, 'B-');
	insert into takes values('5381', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('63489', '561', '1', 'Fall', 2006, 'C-');
	insert into takes values('80113', '468', '2', 'Fall', 2007, 'B ');
	insert into takes values('83314', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('57242', '959', '1', 'Fall', 2006, 'A ');
	insert into takes values('4508', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('73908', '545', '1', 'Fall', 2001, 'C ');
	insert into takes values('73606', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('23934', '461', '1', 'Fall', 2002, 'B+');
	insert into takes values('5381', '527', '1', 'Fall', 2004, 'B-');
	insert into takes values('31476', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('22142', '105', '1', 'Fall', 2009, 'B+');
	insert into takes values('61998', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('67371', '401', '1', 'Fall', 2003, 'B+');
	insert into takes values('53118', '991', '1', 'Spring', 2008, 'B ');
	insert into takes values('90567', '158', '1', 'Fall', 2008, 'A+');
	insert into takes values('69285', '974', '1', 'Fall', 2003, 'A+');
	insert into takes values('31137', '270', '1', 'Spring', 2010, 'A-');
	insert into takes values('85809', '105', '2', 'Fall', 2002, 'A-');
	insert into takes values('68999', '581', '1', 'Spring', 2005, 'B+');
	insert into takes values('31035', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('51416', '642', '1', 'Fall', 2004, 'B-');
	insert into takes values('89234', '795', '1', 'Spring', 2004, 'B-');
	insert into takes values('73908', '626', '1', 'Fall', 2006, 'B+');
	insert into takes values('39704', '852', '1', 'Spring', 2008, 'B ');
	insert into takes values('25785', '694', '1', 'Fall', 2002, 'C ');
	insert into takes values('36995', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('46956', '200', '1', 'Spring', 2007, 'B-');
	insert into takes values('58081', '599', '1', 'Spring', 2003, 'A+');
	insert into takes values('77000', '443', '1', 'Spring', 2010, 'A ');
	insert into takes values('65979', '604', '1', 'Spring', 2009, 'A ');
	insert into takes values('87054', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('24387', '105', '1', 'Fall', 2009, 'C-');
	insert into takes values('66469', '959', '1', 'Fall', 2006, 'A ');
	insert into takes values('63489', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('9256', '791', '1', 'Spring', 2006, 'C-');
	insert into takes values('10736', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('27952', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('83314', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('64169', '401', '1', 'Fall', 2003, 'A-');
	insert into takes values('45300', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('66281', '415', '1', 'Fall', 2010, 'B ');
	insert into takes values('94801', '852', '1', 'Spring', 2008, 'B+');
	insert into takes values('70807', '457', '1', 'Spring', 2001, 'A ');
	insert into takes values('15457', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('19735', '629', '1', 'Spring', 2003, 'B+');
	insert into takes values('82082', '974', '1', 'Fall', 2003, 'A-');
	insert into takes values('95366', '105', '2', 'Fall', 2002, 'A ');
	insert into takes values('91788', '631', '1', 'Spring', 2007, 'B+');
	insert into takes values('37521', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('70310', '735', '2', 'Spring', 2010, 'A+');
	insert into takes values('19541', '489', '1', 'Fall', 2007, 'B ');
	insert into takes values('65438', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('72768', '974', '1', 'Fall', 2003, 'A+');
	insert into takes values('50703', '893', '1', 'Fall', 2007, 'C+');
	insert into takes values('59908', '457', '1', 'Spring', 2001, 'A ');
	insert into takes values('59172', '486', '1', 'Fall', 2009, 'C+');
	insert into takes values('9953', '972', '1', 'Spring', 2009, 'A-');
	insert into takes values('4508', '415', '1', 'Fall', 2010, 'C ');
	insert into takes values('91851', '237', '2', 'Fall', 2009, 'A ');
	insert into takes values('28518', '599', '1', 'Spring', 2003, 'C+');
	insert into takes values('28133', '864', '1', 'Spring', 2006, 'B+');
	insert into takes values('52656', '949', '1', 'Fall', 2007, 'B ');
	insert into takes values('12069', '960', '1', 'Fall', 2009, 'A+');
	insert into takes values('53225', '974', '1', 'Fall', 2003, 'C-');
	insert into takes values('15070', '704', '1', 'Spring', 2008, 'C-');
	insert into takes values('87965', '527', '1', 'Fall', 2004, 'A-');
	insert into takes values('40677', '960', '2', 'Fall', 2006, 'B+');
	insert into takes values('29803', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('5298', '169', '1', 'Spring', 2007, 'A-');
	insert into takes values('64138', '949', '1', 'Fall', 2007, 'C ');
	insert into takes values('9495', '352', '1', 'Spring', 2006, 'C+');
	insert into takes values('10727', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('98940', '972', '1', 'Spring', 2009, 'B-');
	insert into takes values('76799', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('84432', '362', '2', 'Fall', 2006, 'A-');
	insert into takes values('56', '400', '1', 'Spring', 2007, 'B+');
	insert into takes values('11419', '304', '1', 'Fall', 2009, 'C-');
	insert into takes values('62784', '972', '1', 'Spring', 2009, 'B-');
	insert into takes values('108', '893', '1', 'Fall', 2007, 'C+');
	insert into takes values('27804', '313', '1', 'Fall', 2010, 'B-');
	insert into takes values('43993', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('96227', '401', '1', 'Fall', 2003, 'A ');
	insert into takes values('31486', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('50658', '445', '1', 'Spring', 2001, 'B+');
	insert into takes values('96153', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('66356', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('69628', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('91788', '704', '1', 'Spring', 2008, 'C ');
	insert into takes values('79589', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('56299', '604', '1', 'Spring', 2009, 'B ');
	insert into takes values('20985', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('21394', '867', '1', 'Fall', 2006, 'A ');
	insert into takes values('9495', '400', '2', 'Fall', 2003, 'B+');
	insert into takes values('30161', '468', '1', 'Fall', 2005, 'A+');
	insert into takes values('37430', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('9084', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('27140', '400', '2', 'Fall', 2003, 'A-');
	insert into takes values('499', '793', '1', 'Spring', 2002, 'C+');
	insert into takes values('56598', '960', '2', 'Fall', 2006, 'C-');
	insert into takes values('83573', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('99268', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('98056', '496', '1', 'Fall', 2001, 'C ');
	insert into takes values('11578', '468', '1', 'Fall', 2005, 'A ');
	insert into takes values('81610', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('95850', '366', '1', 'Fall', 2005, 'C ');
	insert into takes values('77580', '158', '2', 'Spring', 2008, 'B+');
	insert into takes values('9440', '415', '1', 'Fall', 2010, 'C+');
	insert into takes values('96134', '867', '2', 'Fall', 2010, 'A+');
	insert into takes values('18583', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('95029', '591', '1', 'Spring', 2005, 'B+');
	insert into takes values('74672', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('93354', '338', '1', 'Spring', 2007, 'C+');
	insert into takes values('435', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('2970', '626', '1', 'Fall', 2006, 'B+');
	insert into takes values('19861', '793', '1', 'Spring', 2002, 'A+');
	insert into takes values('81031', '663', '1', 'Spring', 2005, 'C ');
	insert into takes values('90663', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('37759', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('827', '960', '2', 'Fall', 2006, 'C ');
	insert into takes values('89140', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('41751', '599', '1', 'Spring', 2003, 'B-');
	insert into takes values('33645', '852', '1', 'Spring', 2008, 'C ');
	insert into takes values('62549', '493', '1', 'Spring', 2010, 'B ');
	insert into takes values('82688', '457', '1', 'Spring', 2001, 'A+');
	insert into takes values('67655', '476', '1', 'Fall', 2010, 'B ');
	insert into takes values('67425', '962', '1', 'Spring', 2008, 'A ');
	insert into takes values('50267', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('27236', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('13757', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('92864', '599', '1', 'Spring', 2003, 'C+');
	insert into takes values('96710', '345', '1', 'Spring', 2008, 'C-');
	insert into takes values('61166', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('69225', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('76224', '338', '2', 'Spring', 2006, 'A+');
	insert into takes values('37430', '319', '1', 'Spring', 2003, 'B-');
	insert into takes values('96895', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('34386', '629', '1', 'Spring', 2003, 'B+');
	insert into takes values('63288', '200', '1', 'Spring', 2007, 'C-');
	insert into takes values('75395', '468', '1', 'Fall', 2005, 'A-');
	insert into takes values('24387', '694', '1', 'Fall', 2002, 'A+');
	insert into takes values('37869', '949', '1', 'Fall', 2007, 'C-');
	insert into takes values('80285', '400', '2', 'Fall', 2003, 'A ');
	insert into takes values('61127', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('11422', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('99073', '704', '1', 'Spring', 2008, 'A+');
	insert into takes values('92776', '629', '1', 'Spring', 2003, 'B ');
	insert into takes values('34422', '960', '1', 'Fall', 2009, 'A+');
	insert into takes values('36685', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('62705', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('86641', '401', '1', 'Fall', 2003, 'A ');
	insert into takes values('32483', '338', '1', 'Spring', 2007, 'C-');
	insert into takes values('11194', '200', '2', 'Fall', 2002, 'B+');
	insert into takes values('78758', '808', '1', 'Fall', 2003, 'A-');
	insert into takes values('43616', '599', '1', 'Spring', 2003, 'C+');
	insert into takes values('94815', '793', '1', 'Spring', 2002, 'B ');
	insert into takes values('69307', '468', '1', 'Fall', 2005, 'B+');
	insert into takes values('98315', '696', '1', 'Spring', 2002, 'B+');
	insert into takes values('97435', '852', '1', 'Spring', 2008, 'C ');
	insert into takes values('96772', '875', '1', 'Spring', 2005, 'C-');
	insert into takes values('38288', '603', '1', 'Fall', 2003, 'A+');
	insert into takes values('75252', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('57026', '694', '1', 'Fall', 2002, 'B ');
	insert into takes values('78892', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('10834', '366', '1', 'Fall', 2005, 'B ');
	insert into takes values('25077', '158', '2', 'Spring', 2008, 'A ');
	insert into takes values('64013', '200', '1', 'Spring', 2007, 'C-');
	insert into takes values('85746', '604', '1', 'Spring', 2009, 'A-');
	insert into takes values('83622', '960', '1', 'Fall', 2009, 'B+');
	insert into takes values('17769', '793', '1', 'Spring', 2002, 'A ');
	insert into takes values('8457', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('21009', '274', '1', 'Fall', 2002, 'B-');
	insert into takes values('66090', '408', '2', 'Spring', 2003, 'A+');
	insert into takes values('61737', '875', '1', 'Spring', 2005, 'B+');
	insert into takes values('69225', '864', '1', 'Spring', 2006, 'A+');
	insert into takes values('92864', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('55286', '852', '1', 'Spring', 2008, 'A ');
	insert into takes values('16969', '468', '1', 'Fall', 2005, 'B ');
	insert into takes values('65299', '169', '1', 'Spring', 2007, 'A ');
	insert into takes values('46035', '864', '1', 'Spring', 2006, 'C+');
	insert into takes values('83747', '843', '1', 'Fall', 2010, 'A ');
	insert into takes values('62795', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('41683', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('15283', '793', '1', 'Spring', 2002, 'A ');
	insert into takes values('98619', '158', '1', 'Fall', 2008, 'A ');
	insert into takes values('78469', '852', '1', 'Spring', 2008, 'B+');
	insert into takes values('57156', '400', '2', 'Fall', 2003, 'A ');
	insert into takes values('11377', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('69081', '313', '1', 'Fall', 2010, 'C-');
	insert into takes values('29707', '702', '1', 'Spring', 2001, 'C ');
	insert into takes values('82126', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('32130', '468', '1', 'Fall', 2005, 'B+');
	insert into takes values('64039', '408', '2', 'Spring', 2003, 'B ');
	insert into takes values('62373', '927', '1', 'Fall', 2002, 'C+');
	insert into takes values('42096', '158', '2', 'Spring', 2008, 'C+');
	insert into takes values('2561', '960', '1', 'Fall', 2009, 'C-');
	insert into takes values('50039', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('8252', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('75794', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('73492', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('17600', '200', '2', 'Fall', 2002, 'C-');
	insert into takes values('94990', '237', '2', 'Fall', 2009, 'A-');
	insert into takes values('27662', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('7956', '400', '1', 'Spring', 2007, 'A-');
	insert into takes values('92659', '702', '1', 'Spring', 2001, 'B-');
	insert into takes values('914', '702', '1', 'Spring', 2001, 'B-');
	insert into takes values('29462', '200', '2', 'Fall', 2002, 'C+');
	insert into takes values('96178', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('22417', '852', '1', 'Spring', 2008, 'C+');
	insert into takes values('43432', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('12216', '482', '1', 'Fall', 2005, 'A+');
	insert into takes values('41894', '747', '1', 'Spring', 2004, 'A ');
	insert into takes values('54875', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('76768', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('74163', '237', '1', 'Spring', 2008, 'B ');
	insert into takes values('61166', '468', '2', 'Fall', 2007, 'B ');
	insert into takes values('46260', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('14284', '415', '1', 'Fall', 2010, 'C ');
	insert into takes values('39472', '158', '2', 'Spring', 2008, 'C ');
	insert into takes values('65241', '200', '1', 'Spring', 2007, 'A ');
	insert into takes values('63582', '591', '1', 'Spring', 2005, 'B-');
	insert into takes values('96741', '527', '1', 'Fall', 2004, 'C-');
	insert into takes values('74460', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('17996', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('34331', '959', '1', 'Fall', 2006, 'A ');
	insert into takes values('34386', '200', '1', 'Spring', 2007, 'A-');
	insert into takes values('82970', '400', '2', 'Fall', 2003, 'C-');
	insert into takes values('76173', '793', '1', 'Spring', 2002, 'C ');
	insert into takes values('63040', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('89759', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('24010', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('92385', '696', '1', 'Spring', 2002, 'C-');
	insert into takes values('10481', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('17769', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('35257', '692', '1', 'Spring', 2010, 'C-');
	insert into takes values('19245', '401', '1', 'Fall', 2003, 'C ');
	insert into takes values('84515', '476', '1', 'Fall', 2010, 'B+');
	insert into takes values('12173', '237', '2', 'Fall', 2009, 'A-');
	insert into takes values('7656', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('97679', '408', '2', 'Spring', 2003, 'A ');
	insert into takes values('67222', '476', '1', 'Fall', 2010, 'A ');
	insert into takes values('48861', '334', '1', 'Fall', 2009, 'A ');
	insert into takes values('26102', '843', '1', 'Fall', 2010, 'C-');
	insert into takes values('56882', '631', '1', 'Spring', 2007, 'B ');
	insert into takes values('91343', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('17607', '696', '1', 'Spring', 2002, 'C+');
	insert into takes values('64593', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('46655', '426', '1', 'Spring', 2006, 'A ');
	insert into takes values('26695', '852', '1', 'Spring', 2008, 'B-');
	insert into takes values('25718', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('98140', '875', '1', 'Spring', 2005, 'C ');
	insert into takes values('47025', '793', '1', 'Spring', 2002, 'B+');
	insert into takes values('90814', '571', '1', 'Spring', 2004, 'B+');
	insert into takes values('37521', '795', '1', 'Spring', 2004, 'A-');
	insert into takes values('79352', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('83022', '696', '1', 'Spring', 2002, 'A+');
	insert into takes values('54612', '760', '1', 'Spring', 2004, 'B ');
	insert into takes values('97679', '338', '1', 'Spring', 2007, 'C+');
	insert into takes values('1402', '599', '1', 'Spring', 2003, 'B-');
	insert into takes values('65563', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('96206', '493', '1', 'Spring', 2010, 'A ');
	insert into takes values('91442', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('25468', '960', '2', 'Fall', 2006, 'C ');
	insert into takes values('29863', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('40189', '760', '1', 'Spring', 2004, 'B+');
	insert into takes values('81258', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('70452', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('42956', '864', '1', 'Spring', 2006, 'A ');
	insert into takes values('63612', '169', '1', 'Spring', 2007, 'C+');
	insert into takes values('27898', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('46066', '468', '1', 'Fall', 2005, 'A ');
	insert into takes values('99719', '559', '1', 'Fall', 2002, 'A-');
	insert into takes values('37809', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('18007', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('67542', '663', '1', 'Spring', 2005, 'B ');
	insert into takes values('2967', '808', '1', 'Fall', 2003, 'C ');
	insert into takes values('37219', '258', '1', 'Fall', 2007, 'B-');
	insert into takes values('82402', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('40276', '702', '1', 'Spring', 2001, 'B-');
	insert into takes values('95574', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('26881', '169', '1', 'Spring', 2007, 'B+');
	insert into takes values('7956', '274', '1', 'Fall', 2002, 'B-');
	insert into takes values('12971', '972', '1', 'Spring', 2009, 'A ');
	insert into takes values('19203', '927', '1', 'Fall', 2002, 'A ');
	insert into takes values('58469', '867', '2', 'Fall', 2010, 'A+');
	insert into takes values('58846', '408', '1', 'Spring', 2007, 'A ');
	insert into takes values('59908', '843', '1', 'Fall', 2010, 'B-');
	insert into takes values('60249', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('92864', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('35462', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('38271', '591', '1', 'Spring', 2005, 'A ');
	insert into takes values('31086', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('51868', '960', '1', 'Fall', 2009, 'A+');
	insert into takes values('79205', '105', '1', 'Fall', 2009, 'A+');
	insert into takes values('73807', '421', '1', 'Fall', 2004, 'B-');
	insert into takes values('74460', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('51768', '304', '1', 'Fall', 2009, 'B ');
	insert into takes values('99694', '468', '2', 'Fall', 2007, 'C+');
	insert into takes values('92385', '468', '2', 'Fall', 2007, 'A-');
	insert into takes values('30021', '493', '1', 'Spring', 2010, 'C ');
	insert into takes values('19203', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('41818', '493', '1', 'Spring', 2010, 'C-');
	insert into takes values('84410', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('79170', '735', '2', 'Spring', 2010, 'A+');
	insert into takes values('28299', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('89312', '962', '1', 'Spring', 2008, 'C+');
	insert into takes values('49280', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('83170', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('45826', '200', '2', 'Fall', 2002, 'A-');
	insert into takes values('27017', '352', '1', 'Spring', 2006, 'A-');
	insert into takes values('44551', '496', '1', 'Fall', 2001, 'A-');
	insert into takes values('20540', '561', '1', 'Fall', 2006, 'B-');
	insert into takes values('99660', '802', '1', 'Spring', 2003, 'A+');
	insert into takes values('24010', '457', '1', 'Spring', 2001, 'B+');
	insert into takes values('55354', '476', '1', 'Fall', 2010, 'B+');
	insert into takes values('96988', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('30017', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('38676', '362', '1', 'Fall', 2005, 'C-');
	insert into takes values('34236', '169', '1', 'Spring', 2007, 'C+');
	insert into takes values('65979', '200', '1', 'Spring', 2007, 'C ');
	insert into takes values('74840', '270', '1', 'Spring', 2010, 'A+');
	insert into takes values('19582', '476', '1', 'Fall', 2010, 'B+');
	insert into takes values('2139', '626', '1', 'Fall', 2006, 'C+');
	insert into takes values('99369', '591', '1', 'Spring', 2005, 'A-');
	insert into takes values('57055', '158', '1', 'Fall', 2008, 'A+');
	insert into takes values('38288', '760', '1', 'Spring', 2004, 'C+');
	insert into takes values('44352', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('90124', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('2848', '313', '1', 'Fall', 2010, 'B-');
	insert into takes values('52291', '200', '1', 'Spring', 2007, 'A-');
	insert into takes values('54875', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('84704', '760', '1', 'Spring', 2004, 'B-');
	insert into takes values('97065', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('93708', '482', '1', 'Fall', 2005, 'A+');
	insert into takes values('93508', '561', '1', 'Fall', 2006, 'A+');
	insert into takes values('22532', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('15726', '679', '1', 'Spring', 2010, 'C-');
	insert into takes values('4034', '237', '1', 'Spring', 2008, 'C+');
	insert into takes values('14032', '864', '1', 'Spring', 2006, 'B ');
	insert into takes values('42956', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('1110', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('36881', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('75522', '793', '1', 'Spring', 2002, 'A ');
	insert into takes values('30334', '400', '2', 'Fall', 2003, 'B-');
	insert into takes values('89188', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('847', '972', '1', 'Spring', 2009, 'A ');
	insert into takes values('69241', '604', '1', 'Spring', 2009, 'B-');
	insert into takes values('75423', '599', '1', 'Spring', 2003, 'B ');
	insert into takes values('65101', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('57083', '591', '1', 'Spring', 2005, 'B-');
	insert into takes values('22003', '949', '1', 'Fall', 2007, 'C+');
	insert into takes values('1087', '237', '1', 'Spring', 2008, 'B ');
	insert into takes values('59172', '493', '1', 'Spring', 2010, 'C-');
	insert into takes values('7970', '696', '1', 'Spring', 2002, 'C+');
	insert into takes values('842', '496', '1', 'Fall', 2001, 'B+');
	insert into takes values('77415', '760', '1', 'Spring', 2004, 'B-');
	insert into takes values('89196', '694', '1', 'Fall', 2002, 'A+');
	insert into takes values('11237', '486', '1', 'Fall', 2009, 'B-');
	insert into takes values('80047', '169', '1', 'Spring', 2007, 'A-');
	insert into takes values('21395', '581', '1', 'Spring', 2005, 'A-');
	insert into takes values('79352', '959', '1', 'Fall', 2006, 'B ');
	insert into takes values('60762', '735', '2', 'Spring', 2010, 'B ');
	insert into takes values('87706', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('88085', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('83557', '376', '1', 'Fall', 2006, 'B-');
	insert into takes values('14094', '476', '1', 'Fall', 2010, 'B ');
	insert into takes values('81031', '493', '1', 'Spring', 2010, 'C+');
	insert into takes values('22467', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('57083', '408', '1', 'Spring', 2007, 'C ');
	insert into takes values('93814', '571', '1', 'Spring', 2004, 'C ');
	insert into takes values('25552', '461', '1', 'Fall', 2002, 'A-');
	insert into takes values('5920', '169', '2', 'Fall', 2002, 'B+');
	insert into takes values('14639', '242', '1', 'Fall', 2009, 'B+');
	insert into takes values('30161', '352', '1', 'Spring', 2006, 'C+');
	insert into takes values('11201', '338', '2', 'Spring', 2006, 'C ');
	insert into takes values('9084', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('94371', '401', '1', 'Fall', 2003, 'C-');
	insert into takes values('46155', '349', '1', 'Spring', 2008, 'C-');
	insert into takes values('27140', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('31086', '338', '1', 'Spring', 2007, 'C+');
	insert into takes values('48469', '237', '1', 'Spring', 2008, 'A-');
	insert into takes values('11126', '867', '1', 'Fall', 2006, 'A+');
	insert into takes values('46441', '137', '1', 'Spring', 2002, 'A ');
	insert into takes values('43211', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('83838', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('76759', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('91616', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('52134', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('33094', '962', '1', 'Spring', 2008, 'A ');
	insert into takes values('15283', '893', '1', 'Fall', 2007, 'B-');
	insert into takes values('37284', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('64169', '274', '1', 'Fall', 2002, 'A+');
	insert into takes values('68070', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('82126', '591', '1', 'Spring', 2005, 'A-');
	insert into takes values('31486', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('55009', '663', '1', 'Spring', 2005, 'B ');
	insert into takes values('18108', '875', '1', 'Spring', 2005, 'C-');
	insert into takes values('87048', '571', '1', 'Spring', 2004, 'C ');
	insert into takes values('64642', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('78454', '489', '1', 'Fall', 2007, 'B-');
	insert into takes values('51868', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('89106', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('91132', '105', '1', 'Fall', 2009, 'C ');
	insert into takes values('46956', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('95175', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('34018', '489', '1', 'Fall', 2007, 'B-');
	insert into takes values('75123', '415', '1', 'Fall', 2010, 'C-');
	insert into takes values('6195', '631', '1', 'Spring', 2007, 'A-');
	insert into takes values('67371', '338', '1', 'Spring', 2007, 'A-');
	insert into takes values('4182', '696', '1', 'Spring', 2002, 'B ');
	insert into takes values('28004', '949', '1', 'Fall', 2007, 'C ');
	insert into takes values('82868', '158', '2', 'Spring', 2008, 'B+');
	insert into takes values('29462', '949', '1', 'Fall', 2007, 'A-');
	insert into takes values('29390', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('69122', '400', '1', 'Spring', 2007, 'B ');
	insert into takes values('69628', '258', '1', 'Fall', 2007, 'C+');
	insert into takes values('99369', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('9605', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('60040', '802', '1', 'Spring', 2003, 'C-');
	insert into takes values('62716', '237', '1', 'Spring', 2008, 'C+');
	insert into takes values('61364', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('37521', '270', '1', 'Spring', 2010, 'C ');
	insert into takes values('18108', '735', '1', 'Spring', 2003, 'C-');
	insert into takes values('31442', '960', '2', 'Fall', 2006, 'C ');
	insert into takes values('28133', '991', '1', 'Spring', 2008, 'B-');
	insert into takes values('64724', '426', '1', 'Spring', 2006, 'A ');
	insert into takes values('28299', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('83686', '237', '2', 'Fall', 2009, 'C ');
	insert into takes values('35220', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('16631', '735', '1', 'Spring', 2003, 'A ');
	insert into takes values('14023', '242', '1', 'Fall', 2009, 'C-');
	insert into takes values('5243', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('28004', '875', '1', 'Spring', 2005, 'A+');
	insert into takes values('4940', '591', '1', 'Spring', 2005, 'B-');
	insert into takes values('97573', '735', '2', 'Spring', 2010, 'A+');
	insert into takes values('52494', '808', '1', 'Fall', 2003, 'A+');
	insert into takes values('37430', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('90234', '443', '2', 'Spring', 2002, 'C+');
	insert into takes values('78314', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('91992', '362', '3', 'Spring', 2008, 'B ');
	insert into takes values('86674', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('96710', '237', '2', 'Fall', 2009, 'A ');
	insert into takes values('97573', '843', '1', 'Fall', 2010, 'B-');
	insert into takes values('46762', '338', '2', 'Spring', 2006, 'C+');
	insert into takes values('67033', '603', '1', 'Fall', 2003, 'B-');
	insert into takes values('6400', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('51579', '604', '1', 'Spring', 2009, 'A-');
	insert into takes values('83022', '561', '1', 'Fall', 2006, 'B+');
	insert into takes values('48423', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('75362', '591', '1', 'Spring', 2005, 'A ');
	insert into takes values('65038', '200', '1', 'Spring', 2007, 'C-');
	insert into takes values('16035', '867', '1', 'Fall', 2006, 'C+');
	insert into takes values('53152', '242', '1', 'Fall', 2009, 'B+');
	insert into takes values('39238', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('59290', '362', '1', 'Fall', 2005, 'B ');
	insert into takes values('38899', '893', '1', 'Fall', 2007, 'A ');
	insert into takes values('4015', '760', '1', 'Spring', 2004, 'B+');
	insert into takes values('83573', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('4355', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('8192', '843', '1', 'Fall', 2010, 'A ');
	insert into takes values('94998', '663', '1', 'Spring', 2005, 'C-');
	insert into takes values('23439', '679', '1', 'Spring', 2010, 'A+');
	insert into takes values('15980', '334', '1', 'Fall', 2009, 'C ');
	insert into takes values('80698', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('29514', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('47487', '415', '1', 'Fall', 2010, 'C-');
	insert into takes values('55000', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('89140', '692', '1', 'Spring', 2010, 'C ');
	insert into takes values('76799', '603', '1', 'Fall', 2003, 'B-');
	insert into takes values('4435', '486', '1', 'Fall', 2009, 'C+');
	insert into takes values('898', '158', '2', 'Spring', 2008, 'B-');
	insert into takes values('88085', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('23475', '642', '1', 'Fall', 2004, 'C+');
	insert into takes values('21102', '527', '1', 'Fall', 2004, 'C+');
	insert into takes values('29705', '258', '1', 'Fall', 2007, 'A ');
	insert into takes values('88553', '362', '2', 'Fall', 2006, 'A ');
	insert into takes values('16849', '663', '1', 'Spring', 2005, 'A ');
	insert into takes values('45570', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('2848', '482', '1', 'Fall', 2005, 'A+');
	insert into takes values('50386', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('9440', '169', '1', 'Spring', 2007, 'C+');
	insert into takes values('51817', '702', '1', 'Spring', 2001, 'A-');
	insert into takes values('90194', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('70828', '760', '1', 'Spring', 2004, 'B ');
	insert into takes values('53469', '867', '1', 'Fall', 2006, 'A ');
	insert into takes values('59290', '747', '1', 'Spring', 2004, 'C-');
	insert into takes values('18108', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('11510', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('34569', '991', '1', 'Spring', 2008, 'B ');
	insert into takes values('17086', '362', '1', 'Fall', 2005, 'C+');
	insert into takes values('70828', '338', '1', 'Spring', 2007, 'B-');
	insert into takes values('95046', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('32490', '545', '1', 'Fall', 2001, 'A-');
	insert into takes values('77244', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('94178', '445', '1', 'Spring', 2001, 'B-');
	insert into takes values('72768', '461', '1', 'Fall', 2002, 'C-');
	insert into takes values('96193', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('46066', '200', '2', 'Fall', 2002, 'A ');
	insert into takes values('67560', '105', '1', 'Fall', 2009, 'C ');
	insert into takes values('81884', '591', '1', 'Spring', 2005, 'B ');
	insert into takes values('85910', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('32954', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('73186', '599', '1', 'Spring', 2003, 'C+');
	insert into takes values('40059', '415', '1', 'Fall', 2010, 'C-');
	insert into takes values('40558', '962', '1', 'Spring', 2008, 'C-');
	insert into takes values('64945', '258', '1', 'Fall', 2007, 'C-');
	insert into takes values('11202', '313', '1', 'Fall', 2010, 'C ');
	insert into takes values('85904', '105', '2', 'Fall', 2002, 'A+');
	insert into takes values('76224', '704', '1', 'Spring', 2008, 'C-');
	insert into takes values('11201', '843', '1', 'Fall', 2010, 'B+');
	insert into takes values('87785', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('94257', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('16523', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('34422', '843', '1', 'Fall', 2010, 'A+');
	insert into takes values('99422', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('81610', '192', '1', 'Fall', 2002, 'A+');
	insert into takes values('90609', '867', '2', 'Fall', 2010, 'C ');
	insert into takes values('9440', '545', '1', 'Fall', 2001, 'A+');
	insert into takes values('49759', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('18367', '158', '2', 'Spring', 2008, 'C ');
	insert into takes values('86327', '852', '1', 'Spring', 2008, 'C-');
	insert into takes values('98870', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('38973', '959', '1', 'Fall', 2006, 'A+');
	insert into takes values('9460', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('88993', '603', '1', 'Fall', 2003, 'A+');
	insert into takes values('70310', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('99760', '692', '1', 'Spring', 2010, 'C+');
	insert into takes values('95852', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('48165', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('48611', '867', '1', 'Fall', 2006, 'B ');
	insert into takes values('18809', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('69241', '445', '1', 'Spring', 2001, 'A-');
	insert into takes values('62832', '679', '1', 'Spring', 2010, 'C+');
	insert into takes values('82646', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('34542', '760', '1', 'Spring', 2004, 'C ');
	insert into takes values('51768', '345', '1', 'Spring', 2008, 'C ');
	insert into takes values('98423', '974', '1', 'Fall', 2003, 'C-');
	insert into takes values('95284', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('8986', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('91580', '864', '1', 'Spring', 2006, 'C+');
	insert into takes values('59553', '349', '1', 'Spring', 2008, 'C-');
	insert into takes values('65329', '352', '1', 'Spring', 2006, 'C-');
	insert into takes values('28952', '239', '1', 'Fall', 2006, 'B-');
	insert into takes values('45083', '200', '2', 'Fall', 2002, 'C-');
	insert into takes values('26695', '376', '1', 'Fall', 2006, 'B-');
	insert into takes values('499', '158', '1', 'Fall', 2008, 'A ');
	insert into takes values('12941', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('7620', '349', '1', 'Spring', 2008, 'A ');
	insert into takes values('37101', '313', '1', 'Fall', 2010, 'C+');
	insert into takes values('67514', '443', '1', 'Spring', 2010, 'A-');
	insert into takes values('32065', '200', '2', 'Fall', 2002, 'A ');
	insert into takes values('9183', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('11057', '642', '1', 'Fall', 2004, 'A+');
	insert into takes values('56486', '313', '1', 'Fall', 2010, 'C-');
	insert into takes values('34542', '735', '1', 'Spring', 2003, 'B-');
	insert into takes values('45436', '559', '1', 'Fall', 2002, 'C+');
	insert into takes values('53803', '735', '1', 'Spring', 2003, 'A ');
	insert into takes values('51416', '457', '1', 'Spring', 2001, 'A+');
	insert into takes values('93986', '237', '1', 'Spring', 2008, 'A-');
	insert into takes values('65190', '702', '1', 'Spring', 2001, 'C ');
	insert into takes values('56', '612', '1', 'Fall', 2007, 'B+');
	insert into takes values('64259', '105', '1', 'Fall', 2009, 'A+');
	insert into takes values('26802', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('63612', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('88389', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('39925', '559', '1', 'Fall', 2002, 'B+');
	insert into takes values('25528', '496', '1', 'Fall', 2001, 'B+');
	insert into takes values('32490', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('29462', '795', '1', 'Spring', 2004, 'A-');
	insert into takes values('92867', '313', '1', 'Fall', 2010, 'A-');
	insert into takes values('57135', '169', '1', 'Spring', 2007, 'B ');
	insert into takes values('63310', '338', '1', 'Spring', 2007, 'C ');
	insert into takes values('63538', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('89571', '545', '1', 'Fall', 2001, 'B-');
	insert into takes values('69521', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('70299', '338', '2', 'Spring', 2006, 'A-');
	insert into takes values('8843', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('31690', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('50873', '679', '1', 'Spring', 2010, 'B+');
	insert into takes values('18941', '949', '1', 'Fall', 2007, 'C ');
	insert into takes values('99764', '581', '1', 'Spring', 2005, 'A ');
	insert into takes values('18554', '493', '1', 'Spring', 2010, 'A+');
	insert into takes values('30177', '959', '1', 'Fall', 2006, 'B+');
	insert into takes values('89196', '793', '1', 'Spring', 2002, 'A ');
	insert into takes values('29002', '408', '2', 'Spring', 2003, 'A ');
	insert into takes values('43226', '200', '2', 'Fall', 2002, 'C+');
	insert into takes values('84865', '169', '1', 'Spring', 2007, 'B+');
	insert into takes values('21225', '400', '1', 'Spring', 2007, 'B ');
	insert into takes values('99780', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('91442', '158', '2', 'Spring', 2008, 'C-');
	insert into takes values('78792', '591', '1', 'Spring', 2005, 'A-');
	insert into takes values('30858', '408', '2', 'Spring', 2003, 'A ');
	insert into takes values('68396', '445', '1', 'Spring', 2001, 'C+');
	insert into takes values('71529', '242', '1', 'Fall', 2009, 'A ');
	insert into takes values('19220', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('28977', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('92417', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('99775', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('11419', '864', '1', 'Spring', 2006, 'A+');
	insert into takes values('17128', '867', '2', 'Fall', 2010, 'B-');
	insert into takes values('28316', '200', '1', 'Spring', 2007, 'B+');
	insert into takes values('8483', '808', '1', 'Fall', 2003, 'B-');
	insert into takes values('58307', '258', '1', 'Fall', 2007, 'B-');
	insert into takes values('51203', '496', '1', 'Fall', 2001, 'B ');
	insert into takes values('17769', '352', '1', 'Spring', 2006, 'C+');
	insert into takes values('61354', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('53165', '802', '1', 'Spring', 2003, 'A+');
	insert into takes values('4645', '852', '1', 'Spring', 2008, 'B ');
	insert into takes values('16907', '319', '1', 'Spring', 2003, 'C-');
	insert into takes values('35685', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('34329', '559', '1', 'Fall', 2002, 'A ');
	insert into takes values('85211', '642', '1', 'Fall', 2004, 'A-');
	insert into takes values('14032', '679', '1', 'Spring', 2010, 'C-');
	insert into takes values('46337', '457', '1', 'Spring', 2001, 'C ');
	insert into takes values('68720', '345', '1', 'Spring', 2008, 'A-');
	insert into takes values('53451', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('9408', '629', '1', 'Spring', 2003, 'A ');
	insert into takes values('74163', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('98563', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('66484', '795', '1', 'Spring', 2004, 'B ');
	insert into takes values('54605', '237', '1', 'Spring', 2008, 'B+');
	insert into takes values('80047', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('1812', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('39704', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('5898', '334', '1', 'Fall', 2009, 'B ');
	insert into takes values('11604', '604', '1', 'Spring', 2009, 'A ');
	insert into takes values('842', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('86806', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('86934', '258', '1', 'Fall', 2007, 'B+');
	insert into takes values('71287', '421', '1', 'Fall', 2004, 'C+');
	insert into takes values('2561', '692', '1', 'Spring', 2010, 'A ');
	insert into takes values('60406', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('7287', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('43211', '747', '1', 'Spring', 2004, 'C-');
	insert into takes values('64259', '747', '1', 'Spring', 2004, 'A ');
	insert into takes values('67542', '626', '1', 'Fall', 2006, 'B-');
	insert into takes values('75510', '571', '1', 'Spring', 2004, 'A-');
	insert into takes values('49205', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('15283', '843', '1', 'Fall', 2010, 'A+');
	insert into takes values('49982', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('23344', '496', '1', 'Fall', 2001, 'A-');
	insert into takes values('32464', '376', '1', 'Fall', 2006, 'A-');
	insert into takes values('24116', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('38288', '629', '1', 'Spring', 2003, 'A ');
	insert into takes values('97042', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('87280', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('71904', '408', '1', 'Spring', 2007, 'A+');
	insert into takes values('41832', '239', '1', 'Fall', 2006, 'A-');
	insert into takes values('35721', '468', '2', 'Fall', 2007, 'A+');
	insert into takes values('1232', '496', '1', 'Fall', 2001, 'B-');
	insert into takes values('31442', '852', '1', 'Spring', 2008, 'C-');
	insert into takes values('53485', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('36881', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('82082', '867', '1', 'Fall', 2006, 'B ');
	insert into takes values('65299', '400', '2', 'Fall', 2003, 'B+');
	insert into takes values('91799', '443', '2', 'Spring', 2002, 'C ');
	insert into takes values('70924', '626', '1', 'Fall', 2006, 'C+');
	insert into takes values('20084', '304', '1', 'Fall', 2009, 'A ');
	insert into takes values('71630', '852', '1', 'Spring', 2008, 'C+');
	insert into takes values('22258', '461', '1', 'Fall', 2002, 'B-');
	insert into takes values('93653', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('8860', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('12069', '702', '1', 'Spring', 2001, 'C+');
	insert into takes values('32744', '843', '1', 'Fall', 2010, 'B+');
	insert into takes values('57026', '400', '1', 'Spring', 2007, 'B ');
	insert into takes values('73602', '443', '2', 'Spring', 2002, 'C-');
	insert into takes values('47824', '443', '1', 'Spring', 2010, 'C ');
	insert into takes values('73807', '591', '1', 'Spring', 2005, 'B+');
	insert into takes values('83480', '192', '1', 'Fall', 2002, 'C-');
	insert into takes values('58170', '974', '1', 'Fall', 2003, 'C-');
	insert into takes values('50664', '875', '1', 'Spring', 2005, 'B-');
	insert into takes values('914', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('66753', '443', '2', 'Spring', 2002, 'A-');
	insert into takes values('9256', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('86802', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('79534', '642', '1', 'Fall', 2004, 'A+');
	insert into takes values('61402', '974', '1', 'Fall', 2003, 'A+');
	insert into takes values('36402', '443', '1', 'Spring', 2010, 'B+');
	insert into takes values('34542', '702', '1', 'Spring', 2001, 'A-');
	insert into takes values('58469', '581', '1', 'Spring', 2005, 'B+');
	insert into takes values('38696', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('67017', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('18338', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('49339', '169', '1', 'Spring', 2007, 'A ');
	insert into takes values('52187', '496', '1', 'Fall', 2001, 'B ');
	insert into takes values('72006', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('56139', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('15074', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('37734', '105', '2', 'Fall', 2002, 'A-');
	insert into takes values('85308', '158', '1', 'Fall', 2008, 'C-');
	insert into takes values('18821', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('98047', '349', '1', 'Spring', 2008, 'B+');
	insert into takes values('52291', '735', '1', 'Spring', 2003, 'C-');
	insert into takes values('23439', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('30182', '158', '1', 'Fall', 2008, 'B+');
	insert into takes values('32245', '599', '1', 'Spring', 2003, 'A ');
	insert into takes values('4345', '793', '1', 'Spring', 2002, 'A+');
	insert into takes values('70384', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('38691', '304', '1', 'Fall', 2009, 'C+');
	insert into takes values('7973', '604', '1', 'Spring', 2009, 'B+');
	insert into takes values('74163', '443', '1', 'Spring', 2010, 'A+');
	insert into takes values('89734', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('74974', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('56124', '408', '1', 'Spring', 2007, 'A+');
	insert into takes values('54728', '663', '1', 'Spring', 2005, 'A-');
	insert into takes values('53803', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('44881', '545', '1', 'Fall', 2001, 'B-');
	insert into takes values('3039', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('78552', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('20195', '692', '1', 'Spring', 2010, 'A ');
	insert into takes values('71426', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('75123', '408', '1', 'Spring', 2007, 'A-');
	insert into takes values('9360', '338', '1', 'Spring', 2007, 'C+');
	insert into takes values('75362', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('96153', '200', '2', 'Fall', 2002, 'C+');
	insert into takes values('32368', '482', '1', 'Fall', 2005, 'B-');
	insert into takes values('32886', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('32130', '591', '1', 'Spring', 2005, 'C-');
	insert into takes values('35881', '237', '2', 'Fall', 2009, 'C+');
	insert into takes values('57474', '561', '1', 'Fall', 2006, 'A-');
	insert into takes values('8251', '760', '1', 'Spring', 2004, 'B+');
	insert into takes values('51975', '493', '1', 'Spring', 2010, 'C ');
	insert into takes values('89104', '631', '1', 'Spring', 2007, 'C+');
	insert into takes values('29707', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('91616', '158', '2', 'Spring', 2008, 'A ');
	insert into takes values('52157', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('14032', '599', '1', 'Spring', 2003, 'A-');
	insert into takes values('46769', '760', '1', 'Spring', 2004, 'A-');
	insert into takes values('80248', '571', '1', 'Spring', 2004, 'C ');
	insert into takes values('3005', '476', '1', 'Fall', 2010, 'A ');
	insert into takes values('1533', '489', '1', 'Fall', 2007, 'A ');
	insert into takes values('59553', '527', '1', 'Fall', 2004, 'B-');
	insert into takes values('40059', '599', '1', 'Spring', 2003, 'C ');
	insert into takes values('9256', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('60267', '137', '1', 'Spring', 2002, 'A-');
	insert into takes values('19735', '200', '2', 'Fall', 2002, 'B+');
	insert into takes values('52656', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('80254', '476', '1', 'Fall', 2010, 'C-');
	insert into takes values('59455', '169', '2', 'Fall', 2002, 'A+');
	insert into takes values('17831', '959', '1', 'Fall', 2006, 'B+');
	insert into takes values('34236', '338', '1', 'Spring', 2007, 'A+');
	insert into takes values('29390', '200', '2', 'Fall', 2002, 'C+');
	insert into takes values('2201', '468', '1', 'Fall', 2005, 'A-');
	insert into takes values('31250', '864', '1', 'Spring', 2006, 'A ');
	insert into takes values('50267', '893', '1', 'Fall', 2007, 'B-');
	insert into takes values('53805', '158', '1', 'Fall', 2008, 'A+');
	insert into takes values('77244', '400', '2', 'Fall', 2003, 'C+');
	insert into takes values('82082', '408', '1', 'Spring', 2007, 'B ');
	insert into takes values('13403', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('99711', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('78552', '663', '1', 'Spring', 2005, 'A-');
	insert into takes values('85366', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('94801', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('56057', '612', '1', 'Fall', 2007, 'A+');
	insert into takes values('25362', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('89571', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('65688', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('11194', '200', '1', 'Spring', 2007, 'B+');
	insert into takes values('20002', '338', '2', 'Spring', 2006, 'C+');
	insert into takes values('94324', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('83511', '169', '2', 'Fall', 2002, 'A-');
	insert into takes values('33349', '443', '1', 'Spring', 2010, 'B+');
	insert into takes values('63243', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('63289', '692', '1', 'Spring', 2010, 'B-');
	insert into takes values('33791', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('49244', '808', '1', 'Fall', 2003, 'C ');
	insert into takes values('847', '559', '1', 'Fall', 2002, 'C+');
	insert into takes values('70564', '696', '1', 'Spring', 2002, 'A+');
	insert into takes values('41774', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('16133', '747', '1', 'Spring', 2004, 'B-');
	insert into takes values('67222', '105', '2', 'Fall', 2002, 'A+');
	insert into takes values('78481', '400', '1', 'Spring', 2007, 'A-');
	insert into takes values('78792', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('53047', '702', '1', 'Spring', 2001, 'B-');
	insert into takes values('31250', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('99463', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('32376', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('70688', '105', '1', 'Fall', 2009, 'B ');
	insert into takes values('16993', '748', '1', 'Fall', 2003, 'A-');
	insert into takes values('11455', '468', '2', 'Fall', 2007, 'A-');
	insert into takes values('27687', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('28019', '760', '1', 'Spring', 2004, 'C-');
	insert into takes values('62226', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('11453', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('47487', '461', '1', 'Fall', 2002, 'A-');
	insert into takes values('69679', '663', '1', 'Spring', 2005, 'A ');
	insert into takes values('20378', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('96193', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('81884', '735', '1', 'Spring', 2003, 'A-');
	insert into takes values('57431', '486', '1', 'Fall', 2009, 'B-');
	insert into takes values('98870', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('17086', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('42019', '421', '1', 'Fall', 2004, 'A ');
	insert into takes values('9993', '927', '1', 'Fall', 2002, 'C+');
	insert into takes values('50038', '694', '1', 'Fall', 2002, 'A ');
	insert into takes values('96615', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('8426', '604', '1', 'Spring', 2009, 'B ');
	insert into takes values('5250', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('74530', '626', '1', 'Fall', 2006, 'B+');
	insert into takes values('67793', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('88884', '352', '1', 'Spring', 2006, 'B+');
	insert into takes values('71543', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('70965', '747', '1', 'Spring', 2004, 'B-');
	insert into takes values('36685', '604', '1', 'Spring', 2009, 'B+');
	insert into takes values('93631', '591', '1', 'Spring', 2005, 'A-');
	insert into takes values('72669', '401', '1', 'Fall', 2003, 'B+');
	insert into takes values('81150', '242', '1', 'Fall', 2009, 'C ');
	insert into takes values('66106', '274', '1', 'Fall', 2002, 'B ');
	insert into takes values('13217', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('21766', '169', '2', 'Fall', 2002, 'C ');
	insert into takes values('34788', '242', '1', 'Fall', 2009, 'A+');
	insert into takes values('31993', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('57787', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('19342', '493', '1', 'Spring', 2010, 'A-');
	insert into takes values('69225', '527', '1', 'Fall', 2004, 'B+');
	insert into takes values('56', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('20378', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('51579', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('61127', '493', '1', 'Spring', 2010, 'A-');
	insert into takes values('18108', '893', '1', 'Fall', 2007, 'B+');
	insert into takes values('98423', '960', '1', 'Fall', 2009, 'B ');
	insert into takes values('10556', '962', '1', 'Spring', 2008, 'A ');
	insert into takes values('53588', '408', '2', 'Spring', 2003, 'B ');
	insert into takes values('46337', '376', '1', 'Fall', 2006, 'B+');
	insert into takes values('79502', '137', '1', 'Spring', 2002, 'B ');
	insert into takes values('18941', '489', '1', 'Fall', 2007, 'B+');
	insert into takes values('76672', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('15340', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('96246', '748', '1', 'Fall', 2003, 'C ');
	insert into takes values('50977', '748', '1', 'Fall', 2003, 'A-');
	insert into takes values('94173', '694', '1', 'Fall', 2002, 'C ');
	insert into takes values('63645', '489', '1', 'Fall', 2007, 'B ');
	insert into takes values('96324', '443', '1', 'Spring', 2010, 'A+');
	insert into takes values('76169', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('85356', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('4355', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('62716', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('40059', '867', '2', 'Fall', 2010, 'C-');
	insert into takes values('57962', '612', '1', 'Fall', 2007, 'B-');
	insert into takes values('11604', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('27662', '489', '1', 'Fall', 2007, 'B+');
	insert into takes values('4383', '974', '1', 'Fall', 2003, 'A-');
	insert into takes values('51817', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('12173', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('65208', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('58469', '962', '1', 'Spring', 2008, 'A ');
	insert into takes values('91915', '443', '2', 'Spring', 2002, 'C ');
	insert into takes values('34386', '319', '1', 'Spring', 2003, 'B ');
	insert into takes values('5393', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('66484', '274', '1', 'Fall', 2002, 'A+');
	insert into takes values('77729', '875', '1', 'Spring', 2005, 'A ');
	insert into takes values('1826', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('53469', '345', '1', 'Spring', 2008, 'A+');
	insert into takes values('74473', '237', '1', 'Spring', 2008, 'B+');
	insert into takes values('7970', '893', '1', 'Fall', 2007, 'C+');
	insert into takes values('25046', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('69628', '612', '1', 'Fall', 2007, 'C ');
	insert into takes values('22254', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('507', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('40059', '400', '1', 'Spring', 2007, 'A+');
	insert into takes values('39901', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('49214', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('32464', '545', '1', 'Fall', 2001, 'A-');
	insert into takes values('68720', '626', '1', 'Fall', 2006, 'A-');
	insert into takes values('98726', '334', '1', 'Fall', 2009, 'A ');
	insert into takes values('99611', '461', '1', 'Fall', 2002, 'C+');
	insert into takes values('83592', '105', '1', 'Fall', 2009, 'B+');
	insert into takes values('3039', '239', '1', 'Fall', 2006, 'C+');
	insert into takes values('4182', '426', '1', 'Spring', 2006, 'A-');
	insert into takes values('75395', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('84792', '169', '1', 'Spring', 2007, 'B ');
	insert into takes values('53799', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('80990', '702', '1', 'Spring', 2001, 'A-');
	insert into takes values('22198', '599', '1', 'Spring', 2003, 'C ');
	insert into takes values('53451', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('97551', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('95260', '338', '2', 'Spring', 2006, 'A+');
	insert into takes values('40992', '581', '1', 'Spring', 2005, 'C+');
	insert into takes values('88169', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('89393', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('75423', '443', '2', 'Spring', 2002, 'A ');
	insert into takes values('97023', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('9440', '603', '1', 'Fall', 2003, 'A ');
	insert into takes values('23992', '169', '2', 'Fall', 2002, 'A-');
	insert into takes values('23224', '105', '1', 'Fall', 2009, 'C ');
	insert into takes values('46956', '696', '1', 'Spring', 2002, 'A+');
	insert into takes values('43616', '105', '1', 'Fall', 2009, 'C-');
	insert into takes values('82580', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('53803', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('69471', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('85680', '169', '2', 'Fall', 2002, 'A ');
	insert into takes values('32772', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('40189', '843', '1', 'Fall', 2010, 'C+');
	insert into takes values('56139', '376', '1', 'Fall', 2006, 'A-');
	insert into takes values('65396', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('40738', '401', '1', 'Fall', 2003, 'C ');
	insert into takes values('88169', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('39472', '852', '1', 'Spring', 2008, 'A-');
	insert into takes values('34126', '612', '1', 'Fall', 2007, 'B ');
	insert into takes values('1110', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('12362', '468', '1', 'Fall', 2005, 'C ');
	insert into takes values('65241', '338', '2', 'Spring', 2006, 'A+');
	insert into takes values('72622', '867', '2', 'Fall', 2010, 'A+');
	insert into takes values('43989', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('8843', '349', '1', 'Spring', 2008, 'A-');
	insert into takes values('44551', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('75878', '496', '1', 'Fall', 2001, 'C-');
	insert into takes values('17769', '319', '1', 'Spring', 2003, 'C+');
	insert into takes values('14182', '461', '1', 'Fall', 2002, 'B ');
	insert into takes values('78892', '334', '1', 'Fall', 2009, 'A ');
	insert into takes values('72358', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('85226', '304', '1', 'Fall', 2009, 'A ');
	insert into takes values('63886', '242', '1', 'Fall', 2009, 'B+');
	insert into takes values('66279', '735', '2', 'Spring', 2010, 'A+');
	insert into takes values('5920', '694', '1', 'Fall', 2002, 'A+');
	insert into takes values('9953', '376', '1', 'Fall', 2006, 'B-');
	insert into takes values('94697', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('14869', '443', '2', 'Spring', 2002, 'B ');
	insert into takes values('93004', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('37284', '561', '1', 'Fall', 2006, 'A-');
	insert into takes values('32217', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('88140', '692', '1', 'Spring', 2010, 'A+');
	insert into takes values('64192', '893', '1', 'Fall', 2007, 'A ');
	insert into takes values('82580', '867', '1', 'Fall', 2006, 'A-');
	insert into takes values('17377', '421', '1', 'Fall', 2004, 'A-');
	insert into takes values('12979', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('2201', '972', '1', 'Spring', 2009, 'A+');
	insert into takes values('99730', '242', '1', 'Fall', 2009, 'C ');
	insert into takes values('32245', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('95029', '169', '2', 'Fall', 2002, 'A-');
	insert into takes values('39254', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('67657', '962', '1', 'Spring', 2008, 'A+');
	insert into takes values('4582', '893', '1', 'Fall', 2007, 'C ');
	insert into takes values('21009', '735', '1', 'Spring', 2003, 'A+');
	insert into takes values('48247', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('5943', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('78767', '274', '1', 'Fall', 2002, 'A+');
	insert into takes values('9360', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('64140', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('39046', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('5017', '599', '1', 'Spring', 2003, 'B ');
	insert into takes values('84167', '237', '2', 'Fall', 2009, 'C ');
	insert into takes values('22325', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('64013', '959', '1', 'Fall', 2006, 'A+');
	insert into takes values('59117', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('50658', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('61737', '443', '2', 'Spring', 2002, 'B-');
	insert into takes values('49611', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('34386', '105', '2', 'Fall', 2002, 'C+');
	insert into takes values('59673', '476', '1', 'Fall', 2010, 'A+');
	insert into takes values('36052', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('56', '561', '1', 'Fall', 2006, 'C ');
	insert into takes values('4355', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('95850', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('4860', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('82580', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('79329', '852', '1', 'Spring', 2008, 'B-');
	insert into takes values('20974', '663', '1', 'Spring', 2005, 'C ');
	insert into takes values('27528', '694', '1', 'Fall', 2002, 'C ');
	insert into takes values('98047', '338', '2', 'Spring', 2006, 'C+');
	insert into takes values('36513', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('47677', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('27430', '105', '1', 'Fall', 2009, 'C+');
	insert into takes values('25611', '704', '1', 'Spring', 2008, 'A+');
	insert into takes values('89104', '663', '1', 'Spring', 2005, 'B-');
	insert into takes values('20489', '258', '1', 'Fall', 2007, 'B-');
	insert into takes values('61414', '893', '1', 'Fall', 2007, 'B+');
	insert into takes values('49684', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('84845', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('42956', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('87048', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('72657', '457', '1', 'Spring', 2001, 'C ');
	insert into takes values('67293', '445', '1', 'Spring', 2001, 'C ');
	insert into takes values('65703', '400', '1', 'Spring', 2007, 'A+');
	insert into takes values('76049', '400', '2', 'Fall', 2003, 'A ');
	insert into takes values('17133', '200', '2', 'Fall', 2002, 'A ');
	insert into takes values('22003', '852', '1', 'Spring', 2008, 'C ');
	insert into takes values('78637', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('28004', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('9183', '200', '2', 'Fall', 2002, 'B+');
	insert into takes values('39472', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('84845', '679', '1', 'Spring', 2010, 'C+');
	insert into takes values('7620', '338', '1', 'Spring', 2007, 'B-');
	insert into takes values('40558', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('46451', '795', '1', 'Spring', 2004, 'C+');
	insert into takes values('99719', '960', '1', 'Fall', 2009, 'A-');
	insert into takes values('30182', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('32056', '137', '1', 'Spring', 2002, 'B+');
	insert into takes values('74473', '808', '1', 'Fall', 2003, 'C ');
	insert into takes values('93061', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('51203', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('4355', '345', '1', 'Spring', 2008, 'C+');
	insert into takes values('66293', '793', '1', 'Spring', 2002, 'B ');
	insert into takes values('78314', '352', '1', 'Spring', 2006, 'A+');
	insert into takes values('91616', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('97590', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('75040', '893', '1', 'Fall', 2007, 'C+');
	insert into takes values('107', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('10736', '626', '1', 'Fall', 2006, 'C ');
	insert into takes values('70918', '468', '1', 'Fall', 2005, 'B+');
	insert into takes values('82868', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('5898', '571', '1', 'Spring', 2004, 'A+');
	insert into takes values('85910', '421', '1', 'Fall', 2004, 'C-');
	insert into takes values('46260', '561', '1', 'Fall', 2006, 'A ');
	insert into takes values('65396', '169', '2', 'Fall', 2002, 'A ');
	insert into takes values('68330', '852', '1', 'Spring', 2008, 'B-');
	insert into takes values('79534', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('20974', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('57962', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('81984', '200', '1', 'Spring', 2007, 'A-');
	insert into takes values('85680', '852', '1', 'Spring', 2008, 'C ');
	insert into takes values('53547', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('90779', '457', '1', 'Spring', 2001, 'A ');
	insert into takes values('64082', '696', '1', 'Spring', 2002, 'A+');
	insert into takes values('58606', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('71025', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('12941', '200', '2', 'Fall', 2002, 'B+');
	insert into takes values('55238', '366', '1', 'Fall', 2005, 'B ');
	insert into takes values('36019', '599', '1', 'Spring', 2003, 'A+');
	insert into takes values('31624', '274', '1', 'Fall', 2002, 'B ');
	insert into takes values('75395', '867', '1', 'Fall', 2006, 'B ');
	insert into takes values('30124', '694', '1', 'Fall', 2002, 'B ');
	insert into takes values('83214', '867', '1', 'Fall', 2006, 'C+');
	insert into takes values('63361', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('95205', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('21337', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('38476', '629', '1', 'Spring', 2003, 'B ');
	insert into takes values('15457', '313', '1', 'Fall', 2010, 'A ');
	insert into takes values('1836', '400', '2', 'Fall', 2003, 'A ');
	insert into takes values('94846', '893', '1', 'Fall', 2007, 'A+');
	insert into takes values('20180', '867', '1', 'Fall', 2006, 'A ');
	insert into takes values('76291', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('25528', '169', '1', 'Spring', 2007, 'C+');
	insert into takes values('69960', '443', '1', 'Spring', 2010, 'B-');
	insert into takes values('33882', '735', '2', 'Spring', 2010, 'A ');
	insert into takes values('4248', '338', '1', 'Spring', 2007, 'A-');
	insert into takes values('15024', '960', '1', 'Fall', 2009, 'B ');
	insert into takes values('69952', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('87193', '612', '1', 'Fall', 2007, 'A+');
	insert into takes values('89312', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('63886', '735', '2', 'Spring', 2010, 'B-');
	insert into takes values('86127', '445', '1', 'Spring', 2001, 'A-');
	insert into takes values('67017', '349', '1', 'Spring', 2008, 'A-');
	insert into takes values('88993', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('64155', '443', '2', 'Spring', 2002, 'C+');
	insert into takes values('60984', '493', '1', 'Spring', 2010, 'C-');
	insert into takes values('76672', '376', '1', 'Fall', 2006, 'B-');
	insert into takes values('50598', '591', '1', 'Spring', 2005, 'A ');
	insert into takes values('51923', '313', '1', 'Fall', 2010, 'B+');
	insert into takes values('66494', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('66813', '692', '1', 'Spring', 2010, 'A+');
	insert into takes values('94730', '852', '1', 'Spring', 2008, 'C+');
	insert into takes values('58701', '461', '1', 'Fall', 2002, 'C+');
	insert into takes values('27017', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('31035', '972', '1', 'Spring', 2009, 'C ');
	insert into takes values('24201', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('35220', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('89234', '105', '1', 'Fall', 2009, 'A+');
	insert into takes values('49214', '237', '2', 'Fall', 2009, 'A ');
	insert into takes values('63489', '376', '1', 'Fall', 2006, 'C+');
	insert into takes values('36657', '258', '1', 'Fall', 2007, 'C ');
	insert into takes values('97679', '345', '1', 'Spring', 2008, 'A-');
	insert into takes values('65396', '692', '1', 'Spring', 2010, 'A ');
	insert into takes values('36019', '972', '1', 'Spring', 2009, 'B ');
	insert into takes values('1000', '962', '1', 'Spring', 2008, 'B-');
	insert into takes values('32345', '747', '1', 'Spring', 2004, 'A ');
	insert into takes values('61127', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('53496', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('98726', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('32065', '561', '1', 'Fall', 2006, 'A-');
	insert into takes values('71878', '258', '1', 'Fall', 2007, 'A ');
	insert into takes values('25940', '692', '1', 'Spring', 2010, 'B-');
	insert into takes values('47126', '362', '1', 'Fall', 2005, 'B ');
	insert into takes values('80821', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('83170', '679', '1', 'Spring', 2010, 'A+');
	insert into takes values('65901', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('3739', '400', '1', 'Spring', 2007, 'B+');
	insert into takes values('64401', '959', '1', 'Fall', 2006, 'A ');
	insert into takes values('76246', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('38271', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('92965', '352', '1', 'Spring', 2006, 'B+');
	insert into takes values('19450', '867', '2', 'Fall', 2010, 'B-');
	insert into takes values('11578', '696', '1', 'Spring', 2002, 'B ');
	insert into takes values('36845', '603', '1', 'Fall', 2003, 'B+');
	insert into takes values('72657', '631', '1', 'Spring', 2007, 'A-');
	insert into takes values('73387', '461', '1', 'Fall', 2002, 'C-');
	insert into takes values('89104', '875', '1', 'Spring', 2005, 'A ');
	insert into takes values('64259', '239', '1', 'Fall', 2006, 'B ');
	insert into takes values('69952', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('4182', '338', '1', 'Spring', 2007, 'B ');
	insert into takes values('72768', '559', '1', 'Fall', 2002, 'C+');
	insert into takes values('17424', '239', '1', 'Fall', 2006, 'C+');
	insert into takes values('73387', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('67655', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('61003', '604', '1', 'Spring', 2009, 'C ');
	insert into takes values('85308', '489', '1', 'Fall', 2007, 'A-');
	insert into takes values('73213', '991', '1', 'Spring', 2008, 'B ');
	insert into takes values('43130', '591', '1', 'Spring', 2005, 'C-');
	insert into takes values('41671', '960', '2', 'Fall', 2006, 'B-');
	insert into takes values('94814', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('64945', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('50719', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('65753', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('52656', '443', '1', 'Spring', 2010, 'B-');
	insert into takes values('36019', '200', '2', 'Fall', 2002, 'A-');
	insert into takes values('92385', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('30021', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('18499', '591', '1', 'Spring', 2005, 'A-');
	insert into takes values('63860', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('9659', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('43123', '338', '2', 'Spring', 2006, 'A ');
	insert into takes values('72622', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('88389', '702', '1', 'Spring', 2001, 'B-');
	insert into takes values('39927', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('81566', '468', '1', 'Fall', 2005, 'A-');
	insert into takes values('2423', '959', '1', 'Fall', 2006, 'C+');
	insert into takes values('4355', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('82580', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('43993', '258', '1', 'Fall', 2007, 'C+');
	insert into takes values('51862', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('96968', '604', '1', 'Spring', 2009, 'A ');
	insert into takes values('99694', '802', '1', 'Spring', 2003, 'C+');
	insert into takes values('72186', '599', '1', 'Spring', 2003, 'C+');
	insert into takes values('15883', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('43123', '604', '1', 'Spring', 2009, 'B+');
	insert into takes values('24116', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('34197', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('86934', '927', '1', 'Fall', 2002, 'A+');
	insert into takes values('27662', '808', '1', 'Fall', 2003, 'B-');
	insert into takes values('75534', '270', '1', 'Spring', 2010, 'A-');
	insert into takes values('34502', '802', '1', 'Spring', 2003, 'C+');
	insert into takes values('22532', '401', '1', 'Fall', 2003, 'B+');
	insert into takes values('22179', '927', '1', 'Fall', 2002, 'C-');
	insert into takes values('53047', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('78782', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('48850', '319', '1', 'Spring', 2003, 'B ');
	insert into takes values('78767', '561', '1', 'Fall', 2006, 'B+');
	insert into takes values('89188', '972', '1', 'Spring', 2009, 'B+');
	insert into takes values('10556', '376', '1', 'Fall', 2006, 'B+');
	insert into takes values('73328', '802', '1', 'Spring', 2003, 'A+');
	insert into takes values('86674', '962', '1', 'Spring', 2008, 'A+');
	insert into takes values('43981', '270', '1', 'Spring', 2010, 'B-');
	insert into takes values('31341', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('27094', '791', '1', 'Spring', 2006, 'A-');
	insert into takes values('96895', '352', '1', 'Spring', 2006, 'B+');
	insert into takes values('74672', '461', '1', 'Fall', 2002, 'B ');
	insert into takes values('21552', '237', '2', 'Fall', 2009, 'B+');
	insert into takes values('79589', '415', '1', 'Fall', 2010, 'B ');
	insert into takes values('37759', '274', '1', 'Fall', 2002, 'C+');
	insert into takes values('81610', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('43495', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('16593', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('99226', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('73213', '808', '1', 'Fall', 2003, 'C ');
	insert into takes values('77289', '443', '1', 'Spring', 2010, 'B+');
	insert into takes values('259', '692', '1', 'Spring', 2010, 'B-');
	insert into takes values('37038', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('1220', '237', '2', 'Fall', 2009, 'C ');
	insert into takes values('25942', '696', '1', 'Spring', 2002, 'B-');
	insert into takes values('33791', '468', '1', 'Fall', 2005, 'A-');
	insert into takes values('10904', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('22254', '421', '1', 'Fall', 2004, 'B-');
	insert into takes values('76799', '105', '1', 'Fall', 2009, 'B ');
	insert into takes values('37581', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('4345', '349', '1', 'Spring', 2008, 'C-');
	insert into takes values('2177', '443', '2', 'Spring', 2002, 'C ');
	insert into takes values('88358', '304', '1', 'Fall', 2009, 'C-');
	insert into takes values('67560', '960', '1', 'Fall', 2009, 'B+');
	insert into takes values('86552', '626', '1', 'Fall', 2006, 'A-');
	insert into takes values('31442', '352', '1', 'Spring', 2006, 'C+');
	insert into takes values('66229', '345', '1', 'Spring', 2008, 'A ');
	insert into takes values('10481', '852', '1', 'Spring', 2008, 'C ');
	insert into takes values('20099', '808', '1', 'Fall', 2003, 'A-');
	insert into takes values('77588', '793', '1', 'Spring', 2002, 'C+');
	insert into takes values('83136', '867', '1', 'Fall', 2006, 'C+');
	insert into takes values('27556', '105', '1', 'Fall', 2009, 'B+');
	insert into takes values('76953', '599', '1', 'Spring', 2003, 'A ');
	insert into takes values('51579', '696', '1', 'Spring', 2002, 'C+');
	insert into takes values('66469', '864', '1', 'Spring', 2006, 'B+');
	insert into takes values('70384', '808', '1', 'Fall', 2003, 'A+');
	insert into takes values('92864', '679', '1', 'Spring', 2010, 'A ');
	insert into takes values('92040', '158', '2', 'Spring', 2008, 'C-');
	insert into takes values('51817', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('2848', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('6710', '527', '1', 'Fall', 2004, 'B-');
	insert into takes values('19824', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('98870', '747', '1', 'Spring', 2004, 'C-');
	insert into takes values('25528', '571', '1', 'Spring', 2004, 'A-');
	insert into takes values('82083', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('94311', '338', '1', 'Spring', 2007, 'A+');
	insert into takes values('7973', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('14596', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('81638', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('54672', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('81028', '991', '1', 'Spring', 2008, 'B-');
	insert into takes values('82868', '696', '1', 'Spring', 2002, 'B ');
	insert into takes values('85366', '169', '2', 'Fall', 2002, 'A ');
	insert into takes values('56139', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('50719', '626', '1', 'Fall', 2006, 'B+');
	insert into takes values('20803', '527', '1', 'Fall', 2004, 'C+');
	insert into takes values('94836', '158', '2', 'Spring', 2008, 'B+');
	insert into takes values('1285', '401', '1', 'Fall', 2003, 'B+');
	insert into takes values('50719', '679', '1', 'Spring', 2010, 'B+');
	insert into takes values('92040', '793', '1', 'Spring', 2002, 'C+');
	insert into takes values('21692', '696', '1', 'Spring', 2002, 'C+');
	insert into takes values('33817', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('1460', '704', '1', 'Spring', 2008, 'C-');
	insert into takes values('73394', '408', '1', 'Spring', 2007, 'A+');
	insert into takes values('88793', '843', '1', 'Fall', 2010, 'A-');
	insert into takes values('24865', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('95027', '960', '2', 'Fall', 2006, 'C+');
	insert into takes values('11095', '304', '1', 'Fall', 2009, 'A+');
	insert into takes values('2967', '527', '1', 'Fall', 2004, 'C-');
	insert into takes values('35257', '527', '1', 'Fall', 2004, 'C-');
	insert into takes values('53172', '476', '1', 'Fall', 2010, 'C ');
	insert into takes values('78434', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('74016', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('42625', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('57962', '949', '1', 'Fall', 2007, 'A-');
	insert into takes values('27094', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('67017', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('28518', '476', '1', 'Fall', 2010, 'A ');
	insert into takes values('28738', '258', '1', 'Fall', 2007, 'A ');
	insert into takes values('29920', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('86736', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('51997', '401', '1', 'Fall', 2003, 'C+');
	insert into takes values('93508', '591', '1', 'Spring', 2005, 'C-');
	insert into takes values('62549', '158', '1', 'Fall', 2008, 'B+');
	insert into takes values('87706', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('64731', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('52876', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('1080', '105', '2', 'Fall', 2002, 'C+');
	insert into takes values('25725', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('31250', '793', '1', 'Spring', 2002, 'A ');
	insert into takes values('18859', '169', '2', 'Fall', 2002, 'B-');
	insert into takes values('44703', '486', '1', 'Fall', 2009, 'A ');
	insert into takes values('90663', '105', '1', 'Fall', 2009, 'B+');
	insert into takes values('18469', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('34329', '875', '1', 'Spring', 2005, 'A-');
	insert into takes values('15698', '270', '1', 'Spring', 2010, 'C+');
	insert into takes values('47379', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('79697', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('10904', '169', '1', 'Spring', 2007, 'A-');
	insert into takes values('75241', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('8457', '893', '1', 'Fall', 2007, 'A ');
	insert into takes values('89312', '237', '2', 'Fall', 2009, 'B+');
	insert into takes values('40897', '338', '1', 'Spring', 2007, 'A-');
	insert into takes values('888', '345', '1', 'Spring', 2008, 'A ');
	insert into takes values('41491', '696', '1', 'Spring', 2002, 'C-');
	insert into takes values('53490', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('13081', '867', '1', 'Fall', 2006, 'A+');
	insert into takes values('23992', '200', '1', 'Spring', 2007, 'B+');
	insert into takes values('17600', '960', '1', 'Fall', 2009, 'B ');
	insert into takes values('69122', '319', '1', 'Spring', 2003, 'C-');
	insert into takes values('14432', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('79352', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('16297', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('39612', '496', '1', 'Fall', 2001, 'B+');
	insert into takes values('51768', '338', '1', 'Spring', 2007, 'A+');
	insert into takes values('56057', '408', '2', 'Spring', 2003, 'C-');
	insert into takes values('38973', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('9514', '760', '1', 'Spring', 2004, 'A-');
	insert into takes values('56598', '867', '2', 'Fall', 2010, 'A-');
	insert into takes values('76173', '629', '1', 'Spring', 2003, 'B-');
	insert into takes values('83314', '169', '2', 'Fall', 2002, 'B+');
	insert into takes values('37809', '612', '1', 'Fall', 2007, 'C ');
	insert into takes values('96988', '612', '1', 'Fall', 2007, 'C ');
	insert into takes values('23311', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('34195', '791', '1', 'Spring', 2006, 'C+');
	insert into takes values('12214', '496', '1', 'Fall', 2001, 'C ');
	insert into takes values('75273', '476', '1', 'Fall', 2010, 'A+');
	insert into takes values('72643', '962', '1', 'Spring', 2008, 'C-');
	insert into takes values('19362', '443', '1', 'Spring', 2010, 'A ');
	insert into takes values('17207', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('93043', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('1727', '599', '1', 'Spring', 2003, 'C ');
	insert into takes values('50267', '629', '1', 'Spring', 2003, 'B ');
	insert into takes values('70359', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('69850', '468', '2', 'Fall', 2007, 'C+');
	insert into takes values('50537', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('36126', '927', '1', 'Fall', 2002, 'C-');
	insert into takes values('21692', '949', '1', 'Fall', 2007, 'A-');
	insert into takes values('2139', '158', '1', 'Fall', 2008, 'A+');
	insert into takes values('95697', '468', '1', 'Fall', 2005, 'C+');
	insert into takes values('55170', '991', '1', 'Spring', 2008, 'B ');
	insert into takes values('96193', '692', '1', 'Spring', 2010, 'C+');
	insert into takes values('90089', '791', '1', 'Spring', 2006, 'B+');
	insert into takes values('76173', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('31690', '376', '1', 'Fall', 2006, 'A-');
	insert into takes values('12214', '559', '1', 'Fall', 2002, 'C+');
	insert into takes values('48640', '366', '1', 'Fall', 2005, 'C-');
	insert into takes values('75231', '802', '1', 'Spring', 2003, 'A+');
	insert into takes values('71631', '457', '1', 'Spring', 2001, 'C ');
	insert into takes values('36102', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('11083', '443', '1', 'Spring', 2010, 'B ');
	insert into takes values('45680', '603', '1', 'Fall', 2003, 'A+');
	insert into takes values('50966', '313', '1', 'Fall', 2010, 'B ');
	insert into takes values('8347', '408', '2', 'Spring', 2003, 'A ');
	insert into takes values('16631', '482', '1', 'Fall', 2005, 'A+');
	insert into takes values('59673', '486', '1', 'Fall', 2009, 'C+');
	insert into takes values('46694', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('78858', '974', '1', 'Fall', 2003, 'B-');
	insert into takes values('31079', '959', '1', 'Fall', 2006, 'C+');
	insert into takes values('52669', '105', '1', 'Fall', 2009, 'C ');
	insert into takes values('85602', '242', '1', 'Fall', 2009, 'C+');
	insert into takes values('73072', '631', '1', 'Spring', 2007, 'B+');
	insert into takes values('7204', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('34322', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('10814', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('46074', '338', '1', 'Spring', 2007, 'C-');
	insert into takes values('35138', '626', '1', 'Fall', 2006, 'A ');
	insert into takes values('79469', '843', '1', 'Fall', 2010, 'C-');
	insert into takes values('52057', '843', '1', 'Fall', 2010, 'A+');
	insert into takes values('57213', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('50537', '415', '1', 'Fall', 2010, 'C+');
	insert into takes values('6895', '270', '1', 'Spring', 2010, 'C-');
	insert into takes values('65329', '696', '1', 'Spring', 2002, 'C+');
	insert into takes values('89234', '338', '1', 'Spring', 2007, 'B ');
	insert into takes values('21766', '631', '1', 'Spring', 2007, 'B+');
	insert into takes values('95225', '352', '1', 'Spring', 2006, 'C ');
	insert into takes values('68096', '489', '1', 'Fall', 2007, 'B ');
	insert into takes values('59172', '808', '1', 'Fall', 2003, 'A-');
	insert into takes values('24197', '663', '1', 'Spring', 2005, 'B-');
	insert into takes values('499', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('23525', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('19791', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('95366', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('83691', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('34195', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('49450', '137', '1', 'Spring', 2002, 'B ');
	insert into takes values('6209', '867', '1', 'Fall', 2006, 'B ');
	insert into takes values('96895', '571', '1', 'Spring', 2004, 'C+');
	insert into takes values('54508', '443', '1', 'Spring', 2010, 'B-');
	insert into takes values('2501', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('16849', '949', '1', 'Fall', 2007, 'C ');
	insert into takes values('38973', '237', '2', 'Fall', 2009, 'C+');
	insert into takes values('52856', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('6474', '591', '1', 'Spring', 2005, 'B+');
	insert into takes values('56080', '352', '1', 'Spring', 2006, 'A-');
	insert into takes values('96203', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('6895', '972', '1', 'Spring', 2009, 'B ');
	insert into takes values('2201', '476', '1', 'Fall', 2010, 'B ');
	insert into takes values('47630', '468', '1', 'Fall', 2005, 'C ');
	insert into takes values('96324', '105', '2', 'Fall', 2002, 'C+');
	insert into takes values('42688', '493', '1', 'Spring', 2010, 'A-');
	insert into takes values('51862', '443', '2', 'Spring', 2002, 'B-');
	insert into takes values('94726', '972', '1', 'Spring', 2009, 'B-');
	insert into takes values('48901', '692', '1', 'Spring', 2010, 'C+');
	insert into takes values('39881', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('43658', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('73542', '927', '1', 'Fall', 2002, 'A ');
	insert into takes values('64914', '270', '1', 'Spring', 2010, 'A+');
	insert into takes values('73602', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('37715', '239', '1', 'Fall', 2006, 'B ');
	insert into takes values('72741', '237', '2', 'Fall', 2009, 'C-');
	insert into takes values('79352', '561', '1', 'Fall', 2006, 'A+');
	insert into takes values('50658', '349', '1', 'Spring', 2008, 'A ');
	insert into takes values('91616', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('76798', '461', '1', 'Fall', 2002, 'B ');
	insert into takes values('37869', '852', '1', 'Spring', 2008, 'C-');
	insert into takes values('77234', '843', '1', 'Fall', 2010, 'B+');
	insert into takes values('29707', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('61127', '581', '1', 'Spring', 2005, 'A ');
	insert into takes values('16593', '334', '1', 'Fall', 2009, 'B ');
	insert into takes values('19203', '443', '2', 'Spring', 2002, 'A ');
	insert into takes values('85505', '319', '1', 'Spring', 2003, 'C-');
	insert into takes values('60688', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('43505', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('31476', '334', '1', 'Fall', 2009, 'A-');
	insert into takes values('85445', '960', '2', 'Fall', 2006, 'C-');
	insert into takes values('87246', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('77000', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('84702', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('18775', '270', '1', 'Spring', 2010, 'B+');
	insert into takes values('98359', '893', '1', 'Fall', 2007, 'C ');
	insert into takes values('52750', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('56143', '319', '1', 'Spring', 2003, 'C+');
	insert into takes values('87439', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('56003', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('82402', '158', '2', 'Spring', 2008, 'B+');
	insert into takes values('1460', '852', '1', 'Spring', 2008, 'B-');
	insert into takes values('4004', '527', '1', 'Fall', 2004, 'C-');
	insert into takes values('76173', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('3335', '489', '1', 'Fall', 2007, 'B-');
	insert into takes values('10204', '274', '1', 'Fall', 2002, 'B ');
	insert into takes values('12362', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('56089', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('93491', '338', '1', 'Spring', 2007, 'B-');
	insert into takes values('39115', '169', '1', 'Spring', 2007, 'B ');
	insert into takes values('36881', '313', '1', 'Fall', 2010, 'A ');
	insert into takes values('98984', '692', '1', 'Spring', 2010, 'A+');
	insert into takes values('37715', '974', '1', 'Fall', 2003, 'C ');
	insert into takes values('92464', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('37521', '496', '1', 'Fall', 2001, 'C-');
	insert into takes values('11126', '461', '1', 'Fall', 2002, 'B ');
	insert into takes values('87706', '313', '1', 'Fall', 2010, 'B+');
	insert into takes values('69225', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('6195', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('25552', '338', '1', 'Spring', 2007, 'C-');
	insert into takes values('12971', '468', '1', 'Fall', 2005, 'C ');
	insert into takes values('19220', '791', '1', 'Spring', 2006, 'C+');
	insert into takes values('28352', '735', '2', 'Spring', 2010, 'B ');
	insert into takes values('83686', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('76173', '852', '1', 'Spring', 2008, 'B-');
	insert into takes values('51768', '158', '2', 'Spring', 2008, 'B+');
	insert into takes values('38602', '962', '1', 'Spring', 2008, 'A+');
	insert into takes values('86375', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('51084', '400', '2', 'Fall', 2003, 'A-');
	insert into takes values('89132', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('68263', '972', '1', 'Spring', 2009, 'A-');
	insert into takes values('36379', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('58594', '457', '1', 'Spring', 2001, 'C ');
	insert into takes values('29091', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('81175', '496', '1', 'Fall', 2001, 'A-');
	insert into takes values('50365', '313', '1', 'Fall', 2010, 'B-');
	insert into takes values('35935', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('6712', '415', '1', 'Fall', 2010, 'A-');
	insert into takes values('52471', '702', '1', 'Spring', 2001, 'C+');
	insert into takes values('40932', '258', '1', 'Fall', 2007, 'A-');
	insert into takes values('77003', '400', '1', 'Spring', 2007, 'C+');
	insert into takes values('45570', '663', '1', 'Spring', 2005, 'B-');
	insert into takes values('22268', '200', '1', 'Spring', 2007, 'A+');
	insert into takes values('13217', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('15578', '991', '1', 'Spring', 2008, 'C-');
	insert into takes values('23224', '237', '1', 'Spring', 2008, 'B+');
	insert into takes values('11202', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('4940', '239', '1', 'Fall', 2006, 'A-');
	insert into takes values('16133', '200', '2', 'Fall', 2002, 'B-');
	insert into takes values('1922', '629', '1', 'Spring', 2003, 'B-');
	insert into takes values('46956', '443', '1', 'Spring', 2010, 'A ');
	insert into takes values('48611', '408', '1', 'Spring', 2007, 'C+');
	insert into takes values('73908', '949', '1', 'Fall', 2007, 'C-');
	insert into takes values('34322', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('68263', '242', '1', 'Fall', 2009, 'A-');
	insert into takes values('6195', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('90181', '334', '1', 'Fall', 2009, 'B+');
	insert into takes values('42560', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('83696', '692', '1', 'Spring', 2010, 'A-');
	insert into takes values('49339', '962', '1', 'Spring', 2008, 'C-');
	insert into takes values('91197', '735', '2', 'Spring', 2010, 'A-');
	insert into takes values('4383', '612', '1', 'Fall', 2007, 'B ');
	insert into takes values('53047', '867', '2', 'Fall', 2010, 'A+');
	insert into takes values('83204', '200', '1', 'Spring', 2007, 'C ');
	insert into takes values('49611', '401', '1', 'Fall', 2003, 'A ');
	insert into takes values('11966', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('44206', '345', '1', 'Spring', 2008, 'A-');
	insert into takes values('22620', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('12078', '893', '1', 'Fall', 2007, 'A-');
	insert into takes values('34422', '629', '1', 'Spring', 2003, 'A ');
	insert into takes values('88418', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('22142', '603', '1', 'Fall', 2003, 'B ');
	insert into takes values('30334', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('74460', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('51416', '158', '2', 'Spring', 2008, 'C-');
	insert into takes values('61127', '735', '2', 'Spring', 2010, 'C ');
	insert into takes values('98619', '893', '1', 'Fall', 2007, 'A-');
	insert into takes values('78922', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('33094', '864', '1', 'Spring', 2006, 'A+');
	insert into takes values('94324', '158', '2', 'Spring', 2008, 'C-');
	insert into takes values('78143', '603', '1', 'Fall', 2003, 'C-');
	insert into takes values('27366', '274', '1', 'Fall', 2002, 'C+');
	insert into takes values('61402', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('31302', '401', '1', 'Fall', 2003, 'C+');
	insert into takes values('76270', '461', '1', 'Fall', 2002, 'B-');
	insert into takes values('66813', '258', '1', 'Fall', 2007, 'B-');
	insert into takes values('13757', '545', '1', 'Fall', 2001, 'A-');
	insert into takes values('57242', '875', '1', 'Spring', 2005, 'C-');
	insert into takes values('83622', '581', '1', 'Spring', 2005, 'C ');
	insert into takes values('62784', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('65438', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('93708', '443', '2', 'Spring', 2002, 'A+');
	insert into takes values('41261', '604', '1', 'Spring', 2009, 'B ');
	insert into takes values('85366', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('52134', '461', '1', 'Fall', 2002, 'A-');
	insert into takes values('62705', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('53424', '561', '1', 'Fall', 2006, 'C ');
	insert into takes values('44584', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('7390', '795', '1', 'Spring', 2004, 'B+');
	insert into takes values('75123', '793', '1', 'Spring', 2002, 'A ');
	insert into takes values('59397', '158', '1', 'Fall', 2008, 'C ');
	insert into takes values('12236', '338', '1', 'Spring', 2007, 'B ');
	insert into takes values('35175', '867', '2', 'Fall', 2010, 'C-');
	insert into takes values('32345', '457', '1', 'Spring', 2001, 'A ');
	insert into takes values('14874', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('50702', '959', '1', 'Fall', 2006, 'C+');
	insert into takes values('29002', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('40992', '376', '1', 'Fall', 2006, 'C ');
	insert into takes values('47126', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('34197', '852', '1', 'Spring', 2008, 'B+');
	insert into takes values('57334', '571', '1', 'Spring', 2004, 'A+');
	insert into takes values('82126', '631', '1', 'Spring', 2007, 'B+');
	insert into takes values('48640', '376', '1', 'Fall', 2006, 'B+');
	insert into takes values('62152', '545', '1', 'Fall', 2001, 'B ');
	insert into takes values('16133', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('46450', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('47025', '445', '1', 'Spring', 2001, 'B-');
	insert into takes values('30188', '696', '1', 'Spring', 2002, 'B+');
	insert into takes values('84727', '802', '1', 'Spring', 2003, 'B+');
	insert into takes values('61232', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('99780', '581', '1', 'Spring', 2005, 'A-');
	insert into takes values('22004', '893', '1', 'Fall', 2007, 'A+');
	insert into takes values('1826', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('57055', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('95284', '493', '1', 'Spring', 2010, 'C-');
	insert into takes values('66090', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('73328', '239', '1', 'Fall', 2006, 'B-');
	insert into takes values('38676', '258', '1', 'Fall', 2007, 'B-');
	insert into takes values('35588', '415', '1', 'Fall', 2010, 'B-');
	insert into takes values('36926', '401', '1', 'Fall', 2003, 'C+');
	insert into takes values('5208', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('33882', '893', '1', 'Fall', 2007, 'A+');
	insert into takes values('25380', '852', '1', 'Spring', 2008, 'A ');
	insert into takes values('75928', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('63489', '604', '1', 'Spring', 2009, 'B+');
	insert into takes values('12362', '400', '1', 'Spring', 2007, 'B ');
	insert into takes values('31993', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('40481', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('91343', '158', '1', 'Fall', 2008, 'B+');
	insert into takes values('11422', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('97573', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('67425', '735', '1', 'Spring', 2003, 'A ');
	insert into takes values('99271', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('38691', '457', '1', 'Spring', 2001, 'B+');
	insert into takes values('83136', '795', '1', 'Spring', 2004, 'A-');
	insert into takes values('35721', '591', '1', 'Spring', 2005, 'A ');
	insert into takes values('89051', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('41211', '200', '2', 'Fall', 2002, 'C-');
	insert into takes values('38121', '468', '1', 'Fall', 2005, 'C+');
	insert into takes values('34236', '843', '1', 'Fall', 2010, 'A ');
	insert into takes values('30164', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('76911', '158', '2', 'Spring', 2008, 'A-');
	insert into takes values('30858', '599', '1', 'Spring', 2003, 'B-');
	insert into takes values('97551', '561', '1', 'Fall', 2006, 'A-');
	insert into takes values('5843', '400', '2', 'Fall', 2003, 'A-');
	insert into takes values('57787', '663', '1', 'Spring', 2005, 'A-');
	insert into takes values('75547', '493', '1', 'Spring', 2010, 'C-');
	insert into takes values('40937', '747', '1', 'Spring', 2004, 'A ');
	insert into takes values('7204', '338', '1', 'Spring', 2007, 'C+');
	insert into takes values('19342', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('50583', '604', '1', 'Spring', 2009, 'A-');
	insert into takes values('98830', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('13921', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('45436', '468', '1', 'Fall', 2005, 'C ');
	insert into takes values('56143', '304', '1', 'Fall', 2009, 'C-');
	insert into takes values('23392', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('25942', '349', '1', 'Spring', 2008, 'A ');
	insert into takes values('81638', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('22050', '875', '1', 'Spring', 2005, 'C ');
	insert into takes values('45720', '959', '1', 'Fall', 2006, 'B+');
	insert into takes values('12563', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('70965', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('25611', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('40080', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('56058', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('83204', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('13217', '626', '1', 'Fall', 2006, 'B ');
	insert into takes values('75395', '237', '2', 'Fall', 2009, 'A-');
	insert into takes values('28952', '679', '1', 'Spring', 2010, 'C-');
	insert into takes values('42688', '972', '1', 'Spring', 2009, 'C-');
	insert into takes values('6195', '545', '1', 'Fall', 2001, 'A ');
	insert into takes values('69230', '679', '1', 'Spring', 2010, 'C+');
	insert into takes values('67583', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('80227', '352', '1', 'Spring', 2006, 'C-');
	insert into takes values('16405', '334', '1', 'Fall', 2009, 'B ');
	insert into takes values('96246', '468', '1', 'Fall', 2005, 'B-');
	insert into takes values('17076', '696', '1', 'Spring', 2002, 'A+');
	insert into takes values('99268', '421', '1', 'Fall', 2004, 'A ');
	insert into takes values('11237', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('22179', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('18740', '415', '1', 'Fall', 2010, 'A+');
	insert into takes values('78858', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('58307', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('27236', '760', '1', 'Spring', 2004, 'C+');
	insert into takes values('14639', '313', '1', 'Fall', 2010, 'A+');
	insert into takes values('6195', '559', '1', 'Fall', 2002, 'C+');
	insert into takes values('90234', '137', '1', 'Spring', 2002, 'C-');
	insert into takes values('36384', '338', '1', 'Spring', 2007, 'C ');
	insert into takes values('46980', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('80285', '158', '2', 'Spring', 2008, 'A-');
	insert into takes values('86552', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('40116', '169', '2', 'Fall', 2002, 'A+');
	insert into takes values('15030', '663', '1', 'Spring', 2005, 'C ');
	insert into takes values('81258', '960', '1', 'Fall', 2009, 'B ');
	insert into takes values('97041', '200', '1', 'Spring', 2007, 'B-');
	insert into takes values('98019', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('31337', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('92839', '974', '1', 'Fall', 2003, 'B-');
	insert into takes values('25143', '237', '1', 'Spring', 2008, 'B+');
	insert into takes values('78892', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('31302', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('47630', '527', '1', 'Fall', 2004, 'B+');
	insert into takes values('26619', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('99760', '959', '1', 'Fall', 2006, 'B+');
	insert into takes values('21692', '867', '2', 'Fall', 2010, 'C-');
	insert into takes values('9659', '949', '1', 'Fall', 2007, 'C+');
	insert into takes values('73072', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('89551', '599', '1', 'Spring', 2003, 'B-');
	insert into takes values('29239', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('29514', '489', '1', 'Fall', 2007, 'C ');
	insert into takes values('35198', '949', '1', 'Fall', 2007, 'B ');
	insert into takes values('80742', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('92849', '476', '1', 'Fall', 2010, 'B+');
	insert into takes values('645', '791', '1', 'Spring', 2006, 'C+');
	insert into takes values('4383', '852', '1', 'Spring', 2008, 'B+');
	insert into takes values('50039', '735', '1', 'Spring', 2003, 'A-');
	insert into takes values('97400', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('80254', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('61414', '852', '1', 'Spring', 2008, 'C+');
	insert into takes values('49611', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('81896', '760', '1', 'Spring', 2004, 'A ');
	insert into takes values('85904', '338', '2', 'Spring', 2006, 'A ');
	insert into takes values('54508', '200', '1', 'Spring', 2007, 'B-');
	insert into takes values('31101', '527', '1', 'Fall', 2004, 'B+');
	insert into takes values('37219', '735', '1', 'Spring', 2003, 'A ');
	insert into takes values('17997', '352', '1', 'Spring', 2006, 'C ');
	insert into takes values('39619', '843', '1', 'Fall', 2010, 'B+');
	insert into takes values('94766', '974', '1', 'Fall', 2003, 'C-');
	insert into takes values('29140', '545', '1', 'Fall', 2001, 'C ');
	insert into takes values('52945', '808', '1', 'Fall', 2003, 'B ');
	insert into takes values('51723', '959', '1', 'Fall', 2006, 'B+');
	insert into takes values('8426', '581', '1', 'Spring', 2005, 'C ');
	insert into takes values('84167', '747', '1', 'Spring', 2004, 'B-');
	insert into takes values('28829', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('21337', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('28409', '313', '1', 'Fall', 2010, 'A+');
	insert into takes values('34195', '852', '1', 'Spring', 2008, 'B+');
	insert into takes values('39157', '489', '1', 'Fall', 2007, 'B-');
	insert into takes values('81538', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('11377', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('65258', '991', '1', 'Spring', 2008, 'A ');
	insert into takes values('96988', '864', '1', 'Spring', 2006, 'A ');
	insert into takes values('50331', '867', '1', 'Fall', 2006, 'C+');
	insert into takes values('44706', '991', '1', 'Spring', 2008, 'C-');
	insert into takes values('55857', '571', '1', 'Spring', 2004, 'A-');
	insert into takes values('93061', '791', '1', 'Spring', 2006, 'C-');
	insert into takes values('39612', '169', '2', 'Fall', 2002, 'A+');
	insert into takes values('92385', '875', '1', 'Spring', 2005, 'A+');
	insert into takes values('23344', '591', '1', 'Spring', 2005, 'B ');
	insert into takes values('28994', '626', '1', 'Fall', 2006, 'A-');
	insert into takes values('42092', '443', '2', 'Spring', 2002, 'A ');
	insert into takes values('32490', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('15613', '443', '2', 'Spring', 2002, 'B-');
	insert into takes values('31476', '258', '1', 'Fall', 2007, 'A-');
	insert into takes values('95027', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('21692', '791', '1', 'Spring', 2006, 'A ');
	insert into takes values('78892', '962', '1', 'Spring', 2008, 'B ');
	insert into takes values('35588', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('23110', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('11604', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('39978', '105', '1', 'Fall', 2009, 'C+');
	insert into takes values('22417', '362', '3', 'Spring', 2008, 'B ');
	insert into takes values('60762', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('83838', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('37715', '313', '1', 'Fall', 2010, 'A-');
	insert into takes values('29435', '927', '1', 'Fall', 2002, 'C ');
	insert into takes values('96052', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('51678', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('22004', '158', '1', 'Fall', 2008, 'C ');
	insert into takes values('52291', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('3639', '137', '1', 'Spring', 2002, 'B+');
	insert into takes values('93814', '468', '1', 'Fall', 2005, 'B ');
	insert into takes values('42991', '461', '1', 'Fall', 2002, 'A-');
	insert into takes values('34569', '237', '1', 'Spring', 2008, 'B-');
	insert into takes values('29871', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('74509', '663', '1', 'Spring', 2005, 'B-');
	insert into takes values('37350', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('37856', '843', '1', 'Fall', 2010, 'B+');
	insert into takes values('12666', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('79772', '313', '1', 'Fall', 2010, 'C-');
	insert into takes values('57925', '200', '1', 'Spring', 2007, 'B+');
	insert into takes values('37101', '795', '1', 'Spring', 2004, 'B ');
	insert into takes values('56139', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('35687', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('50013', '352', '1', 'Spring', 2006, 'A+');
	insert into takes values('65676', '694', '1', 'Fall', 2002, 'A+');
	insert into takes values('85614', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('1826', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('91616', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('66259', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('76799', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('3639', '927', '1', 'Fall', 2002, 'C-');
	insert into takes values('68278', '468', '1', 'Fall', 2005, 'A+');
	insert into takes values('16885', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('90004', '496', '1', 'Fall', 2001, 'B-');
	insert into takes values('15487', '313', '1', 'Fall', 2010, 'B-');
	insert into takes values('80285', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('69960', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('57156', '443', '1', 'Spring', 2010, 'A ');
	insert into takes values('41674', '747', '1', 'Spring', 2004, 'B+');
	insert into takes values('23439', '626', '1', 'Fall', 2006, 'B+');
	insert into takes values('9183', '704', '1', 'Spring', 2008, 'B ');
	insert into takes values('48901', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('58085', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('19917', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('11530', '960', '1', 'Fall', 2009, 'B-');
	insert into takes values('63645', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('63502', '237', '1', 'Spring', 2008, 'C-');
	insert into takes values('5925', '604', '1', 'Spring', 2009, 'A ');
	insert into takes values('67560', '793', '1', 'Spring', 2002, 'C-');
	insert into takes values('88302', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('58594', '105', '1', 'Fall', 2009, 'A+');
	insert into takes values('72501', '415', '1', 'Fall', 2010, 'A-');
	insert into takes values('39892', '559', '1', 'Fall', 2002, 'A ');
	insert into takes values('39520', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('75273', '791', '1', 'Spring', 2006, 'A ');
	insert into takes values('93171', '349', '1', 'Spring', 2008, 'B+');
	insert into takes values('35175', '631', '1', 'Spring', 2007, 'C-');
	insert into takes values('99268', '319', '1', 'Spring', 2003, 'B ');
	insert into takes values('97101', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('55170', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('90914', '679', '1', 'Spring', 2010, 'B+');
	insert into takes values('21086', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('25785', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('52876', '748', '1', 'Fall', 2003, 'B ');
	insert into takes values('11441', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('16885', '169', '2', 'Fall', 2002, 'B-');
	insert into takes values('25725', '571', '1', 'Spring', 2004, 'C ');
	insert into takes values('12971', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('12563', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('19848', '401', '1', 'Fall', 2003, 'C ');
	insert into takes values('37809', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('31250', '349', '1', 'Spring', 2008, 'A-');
	insert into takes values('71944', '692', '1', 'Spring', 2010, 'A+');
	insert into takes values('59673', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('54620', '802', '1', 'Spring', 2003, 'B+');
	insert into takes values('11419', '599', '1', 'Spring', 2003, 'B+');
	insert into takes values('16993', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('86753', '319', '1', 'Spring', 2003, 'B ');
	insert into takes values('81175', '893', '1', 'Fall', 2007, 'C ');
	insert into takes values('82918', '408', '1', 'Spring', 2007, 'A ');
	insert into takes values('58595', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('99780', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('58413', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('65438', '445', '1', 'Spring', 2001, 'B-');
	insert into takes values('23500', '696', '1', 'Spring', 2002, 'B+');
	insert into takes values('26802', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('22912', '760', '1', 'Spring', 2004, 'A-');
	insert into takes values('61403', '200', '2', 'Fall', 2002, 'B+');
	insert into takes values('85809', '489', '1', 'Fall', 2007, 'A-');
	insert into takes values('82580', '603', '1', 'Fall', 2003, 'C-');
	insert into takes values('97355', '735', '2', 'Spring', 2010, 'A-');
	insert into takes values('1087', '496', '1', 'Fall', 2001, 'A-');
	insert into takes values('24784', '561', '1', 'Fall', 2006, 'B-');
	insert into takes values('1737', '304', '1', 'Fall', 2009, 'B ');
	insert into takes values('76798', '960', '1', 'Fall', 2009, 'B-');
	insert into takes values('58170', '704', '1', 'Spring', 2008, 'A+');
	insert into takes values('78637', '808', '1', 'Fall', 2003, 'A+');
	insert into takes values('77244', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('67051', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('76911', '258', '1', 'Fall', 2007, 'C-');
	insert into takes values('23525', '747', '1', 'Spring', 2004, 'C-');
	insert into takes values('25380', '105', '1', 'Fall', 2009, 'B+');
	insert into takes values('66484', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('83398', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('55915', '468', '1', 'Fall', 2005, 'B ');
	insert into takes values('13365', '345', '1', 'Spring', 2008, 'C ');
	insert into takes values('15578', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('71878', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('931', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('55698', '802', '1', 'Spring', 2003, 'C+');
	insert into takes values('62429', '960', '2', 'Fall', 2006, 'C ');
	insert into takes values('91992', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('57787', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('7956', '352', '1', 'Spring', 2006, 'A+');
	insert into takes values('76672', '702', '1', 'Spring', 2001, 'C-');
	insert into takes values('52385', '338', '2', 'Spring', 2006, 'A+');
	insert into takes values('45770', '852', '1', 'Spring', 2008, 'B ');
	insert into takes values('85754', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('66054', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('33401', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('99611', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('59673', '192', '1', 'Fall', 2002, 'C ');
	insert into takes values('14484', '304', '1', 'Fall', 2009, 'B+');
	insert into takes values('11126', '642', '1', 'Fall', 2004, 'B+');
	insert into takes values('85063', '415', '1', 'Fall', 2010, 'C-');
	insert into takes values('62784', '960', '2', 'Fall', 2006, 'A ');
	insert into takes values('46106', '400', '1', 'Spring', 2007, 'B ');
	insert into takes values('65208', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('51868', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('19048', '679', '1', 'Spring', 2010, 'C-');
	insert into takes values('73602', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('70098', '702', '1', 'Spring', 2001, 'C ');
	insert into takes values('52291', '893', '1', 'Fall', 2007, 'C ');
	insert into takes values('48423', '791', '1', 'Spring', 2006, 'C+');
	insert into takes values('15538', '559', '1', 'Fall', 2002, 'B+');
	insert into takes values('9408', '591', '1', 'Spring', 2005, 'A-');
	insert into takes values('49982', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('42688', '486', '1', 'Fall', 2009, 'B-');
	insert into takes values('98870', '808', '1', 'Fall', 2003, 'B-');
	insert into takes values('81984', '527', '1', 'Fall', 2004, 'B+');
	insert into takes values('898', '760', '1', 'Spring', 2004, 'B ');
	insert into takes values('80976', '527', '1', 'Fall', 2004, 'C-');
	insert into takes values('27687', '793', '1', 'Spring', 2002, 'A ');
	insert into takes values('48850', '352', '1', 'Spring', 2006, 'A+');
	insert into takes values('83003', '692', '1', 'Spring', 2010, 'A ');
	insert into takes values('33837', '334', '1', 'Fall', 2009, 'B-');
	insert into takes values('83696', '200', '1', 'Spring', 2007, 'A ');
	insert into takes values('62728', '421', '1', 'Fall', 2004, 'C+');
	insert into takes values('90194', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('11101', '319', '1', 'Spring', 2003, 'B-');
	insert into takes values('58634', '864', '1', 'Spring', 2006, 'B ');
	insert into takes values('27236', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('61354', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('70924', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('3335', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('40738', '400', '2', 'Fall', 2003, 'C+');
	insert into takes values('75534', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('6712', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('40189', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('89734', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('41741', '200', '1', 'Spring', 2007, 'A+');
	insert into takes values('68395', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('76246', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('82066', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('88993', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('5208', '893', '1', 'Fall', 2007, 'A ');
	insert into takes values('64642', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('1220', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('90089', '748', '1', 'Fall', 2003, 'C ');
	insert into takes values('72768', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('16969', '972', '1', 'Spring', 2009, 'B ');
	insert into takes values('77231', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('93653', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('19766', '169', '1', 'Spring', 2007, 'B ');
	insert into takes values('74911', '237', '1', 'Spring', 2008, 'A-');
	insert into takes values('26730', '408', '1', 'Spring', 2007, 'B ');
	insert into takes values('29707', '345', '1', 'Spring', 2008, 'A+');
	insert into takes values('56598', '875', '1', 'Spring', 2005, 'C ');
	insert into takes values('88417', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('93491', '362', '2', 'Fall', 2006, 'A-');
	insert into takes values('15086', '401', '1', 'Fall', 2003, 'A ');
	insert into takes values('58307', '808', '1', 'Fall', 2003, 'B-');
	insert into takes values('68554', '852', '1', 'Spring', 2008, 'C ');
	insert into takes values('41827', '631', '1', 'Spring', 2007, 'C-');
	insert into takes values('57107', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('39241', '747', '1', 'Spring', 2004, 'B-');
	insert into takes values('17057', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('29031', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('11455', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('18675', '893', '1', 'Fall', 2007, 'B-');
	insert into takes values('23224', '239', '1', 'Fall', 2006, 'C+');
	insert into takes values('34195', '875', '1', 'Spring', 2005, 'A-');
	insert into takes values('58469', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('41894', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('86573', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('35198', '400', '1', 'Spring', 2007, 'A-');
	insert into takes values('6673', '200', '2', 'Fall', 2002, 'A ');
	insert into takes values('95626', '603', '1', 'Fall', 2003, 'B ');
	insert into takes values('85746', '626', '1', 'Fall', 2006, 'A-');
	insert into takes values('85366', '679', '1', 'Spring', 2010, 'A ');
	insert into takes values('37581', '443', '1', 'Spring', 2010, 'C ');
	insert into takes values('19321', '443', '1', 'Spring', 2010, 'B+');
	insert into takes values('15883', '603', '1', 'Fall', 2003, 'B+');
	insert into takes values('61402', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('7854', '105', '1', 'Fall', 2009, 'C ');
	insert into takes values('15980', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('20180', '237', '2', 'Fall', 2009, 'A ');
	insert into takes values('72669', '362', '3', 'Spring', 2008, 'A+');
	insert into takes values('97355', '366', '1', 'Fall', 2005, 'A ');
	insert into takes values('89000', '802', '1', 'Spring', 2003, 'C+');
	insert into takes values('61065', '631', '1', 'Spring', 2007, 'C+');
	insert into takes values('66293', '105', '1', 'Fall', 2009, 'A+');
	insert into takes values('67793', '400', '2', 'Fall', 2003, 'C+');
	insert into takes values('75596', '400', '1', 'Spring', 2007, 'A ');
	insert into takes values('39552', '559', '1', 'Fall', 2002, 'A-');
	insert into takes values('66279', '527', '1', 'Fall', 2004, 'C-');
	insert into takes values('96246', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('36995', '864', '1', 'Spring', 2006, 'B ');
	insert into takes values('41818', '631', '1', 'Spring', 2007, 'B ');
	insert into takes values('38271', '105', '2', 'Fall', 2002, 'A ');
	insert into takes values('11855', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('63502', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('21246', '974', '1', 'Fall', 2003, 'C-');
	insert into takes values('6209', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('92849', '408', '1', 'Spring', 2007, 'C-');
	insert into takes values('39580', '200', '2', 'Fall', 2002, 'C+');
	insert into takes values('51093', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('11453', '476', '1', 'Fall', 2010, 'A+');
	insert into takes values('38712', '527', '1', 'Fall', 2004, 'C-');
	insert into takes values('91370', '408', '1', 'Spring', 2007, 'C+');
	insert into takes values('10481', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('76224', '362', '2', 'Fall', 2006, 'B-');
	insert into takes values('21394', '626', '1', 'Fall', 2006, 'A ');
	insert into takes values('68096', '962', '1', 'Spring', 2008, 'C+');
	insert into takes values('87651', '468', '2', 'Fall', 2007, 'C-');
	insert into takes values('28994', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('46980', '338', '1', 'Spring', 2007, 'B ');
	insert into takes values('46956', '960', '2', 'Fall', 2006, 'B+');
	insert into takes values('84792', '893', '1', 'Fall', 2007, 'C+');
	insert into takes values('13081', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('77898', '158', '1', 'Fall', 2008, 'B-');
	insert into takes values('18941', '338', '1', 'Spring', 2007, 'B ');
	insert into takes values('91569', '692', '1', 'Spring', 2010, 'A-');
	insert into takes values('99348', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('47824', '496', '1', 'Fall', 2001, 'A+');
	insert into takes values('27002', '239', '1', 'Fall', 2006, 'B ');
	insert into takes values('931', '692', '1', 'Spring', 2010, 'C ');
	insert into takes values('50944', '612', '1', 'Fall', 2007, 'C ');
	insert into takes values('29462', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('63361', '158', '2', 'Spring', 2008, 'C ');
	insert into takes values('16347', '319', '1', 'Spring', 2003, 'A-');
	insert into takes values('94142', '415', '1', 'Fall', 2010, 'C-');
	insert into takes values('98019', '169', '1', 'Spring', 2007, 'A ');
	insert into takes values('30943', '270', '1', 'Spring', 2010, 'A-');
	insert into takes values('79763', '345', '1', 'Spring', 2008, 'B ');
	insert into takes values('31302', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('75772', '486', '1', 'Fall', 2009, 'A-');
	insert into takes values('66229', '426', '1', 'Spring', 2006, 'C ');
	insert into takes values('19735', '493', '1', 'Spring', 2010, 'C+');
	insert into takes values('85234', '852', '1', 'Spring', 2008, 'B ');
	insert into takes values('25785', '338', '1', 'Spring', 2007, 'A+');
	insert into takes values('24784', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('96710', '591', '1', 'Spring', 2005, 'B-');
	insert into takes values('99711', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('44038', '696', '1', 'Spring', 2002, 'B-');
	insert into takes values('78581', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('53152', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('19203', '489', '1', 'Fall', 2007, 'C ');
	insert into takes values('74163', '704', '1', 'Spring', 2008, 'A-');
	insert into takes values('74639', '599', '1', 'Spring', 2003, 'A-');
	insert into takes values('83557', '867', '1', 'Fall', 2006, 'A ');
	insert into takes values('792', '169', '1', 'Spring', 2007, 'C ');
	insert into takes values('92693', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('66259', '629', '1', 'Spring', 2003, 'A ');
	insert into takes values('50719', '496', '1', 'Fall', 2001, 'C ');
	insert into takes values('41751', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('52656', '421', '1', 'Fall', 2004, 'C-');
	insert into takes values('33349', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('10838', '237', '2', 'Fall', 2009, 'C ');
	insert into takes values('99694', '927', '1', 'Fall', 2002, 'C-');
	insert into takes values('81258', '352', '1', 'Spring', 2006, 'C+');
	insert into takes values('85746', '443', '1', 'Spring', 2010, 'A+');
	insert into takes values('42114', '991', '1', 'Spring', 2008, 'A ');
	insert into takes values('35257', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('27140', '631', '1', 'Spring', 2007, 'A+');
	insert into takes values('34195', '599', '1', 'Spring', 2003, 'A ');
	insert into takes values('98056', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('88302', '408', '1', 'Spring', 2007, 'C ');
	insert into takes values('18809', '496', '1', 'Fall', 2001, 'B ');
	insert into takes values('96206', '735', '1', 'Spring', 2003, 'C+');
	insert into takes values('50386', '319', '1', 'Spring', 2003, 'C-');
	insert into takes values('85226', '334', '1', 'Fall', 2009, 'A ');
	insert into takes values('84865', '735', '2', 'Spring', 2010, 'B ');
	insert into takes values('41818', '927', '1', 'Fall', 2002, 'B-');
	insert into takes values('2848', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('55000', '962', '1', 'Spring', 2008, 'B ');
	insert into takes values('85451', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('60224', '338', '1', 'Spring', 2007, 'C+');
	insert into takes values('82126', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('35523', '599', '1', 'Spring', 2003, 'C+');
	insert into takes values('79469', '591', '1', 'Spring', 2005, 'A+');
	insert into takes values('74509', '489', '1', 'Fall', 2007, 'A ');
	insert into takes values('3005', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('73394', '415', '1', 'Fall', 2010, 'A+');
	insert into takes values('40682', '362', '2', 'Fall', 2006, 'B-');
	insert into takes values('38691', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('60748', '696', '1', 'Spring', 2002, 'B+');
	insert into takes values('62795', '237', '1', 'Spring', 2008, 'A+');
	insert into takes values('76173', '603', '1', 'Fall', 2003, 'B+');
	insert into takes values('90089', '258', '1', 'Fall', 2007, 'A+');
	insert into takes values('69730', '852', '1', 'Spring', 2008, 'A-');
	insert into takes values('53225', '959', '1', 'Fall', 2006, 'A+');
	insert into takes values('31820', '169', '2', 'Fall', 2002, 'A+');
	insert into takes values('8819', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('93354', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('52669', '376', '1', 'Fall', 2006, 'A ');
	insert into takes values('5961', '581', '1', 'Spring', 2005, 'C-');
	insert into takes values('97679', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('16311', '338', '1', 'Spring', 2007, 'B ');
	insert into takes values('93571', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('77021', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('12214', '426', '1', 'Spring', 2006, 'A-');
	insert into takes values('18234', '258', '1', 'Fall', 2007, 'B-');
	insert into takes values('10736', '493', '1', 'Spring', 2010, 'C-');
	insert into takes values('88577', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('48660', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('92867', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('68248', '476', '1', 'Fall', 2010, 'C ');
	insert into takes values('81294', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('71389', '239', '1', 'Fall', 2006, 'C+');
	insert into takes values('67810', '852', '1', 'Spring', 2008, 'A ');
	insert into takes values('27662', '304', '1', 'Fall', 2009, 'B+');
	insert into takes values('63560', '482', '1', 'Fall', 2005, 'A+');
	insert into takes values('72485', '258', '1', 'Fall', 2007, 'A ');
	insert into takes values('66054', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('91978', '603', '1', 'Fall', 2003, 'B ');
	insert into takes values('67425', '696', '1', 'Spring', 2002, 'B-');
	insert into takes values('78143', '599', '1', 'Spring', 2003, 'B-');
	insert into takes values('20985', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('99760', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('10033', '338', '1', 'Spring', 2007, 'A ');
	insert into takes values('96741', '237', '1', 'Spring', 2008, 'B+');
	insert into takes values('61403', '808', '1', 'Fall', 2003, 'B-');
	insert into takes values('69952', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('39927', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('85356', '443', '2', 'Spring', 2002, 'C-');
	insert into takes values('63040', '748', '1', 'Fall', 2003, 'A-');
	insert into takes values('41965', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('68396', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('41938', '401', '1', 'Fall', 2003, 'C ');
	insert into takes values('20378', '468', '1', 'Fall', 2005, 'A+');
	insert into takes values('61402', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('99780', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('44551', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('95046', '169', '2', 'Fall', 2002, 'A ');
	insert into takes values('12326', '445', '1', 'Spring', 2001, 'C+');
	insert into takes values('24387', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('3335', '401', '1', 'Fall', 2003, 'B+');
	insert into takes values('27956', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('72485', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('32744', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('67340', '802', '1', 'Spring', 2003, 'C+');
	insert into takes values('18859', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('63582', '443', '1', 'Spring', 2010, 'A+');
	insert into takes values('60748', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('16993', '366', '1', 'Fall', 2005, 'C-');
	insert into takes values('82301', '242', '1', 'Fall', 2009, 'B ');
	insert into takes values('78758', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('70572', '468', '1', 'Fall', 2005, 'A-');
	insert into takes values('544', '334', '1', 'Fall', 2009, 'A-');
	insert into takes values('13403', '400', '1', 'Spring', 2007, 'B ');
	insert into takes values('83002', '692', '1', 'Spring', 2010, 'C-');
	insert into takes values('28361', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('27687', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('5393', '927', '1', 'Fall', 2002, 'A+');
	insert into takes values('34329', '352', '1', 'Spring', 2006, 'C-');
	insert into takes values('52750', '457', '1', 'Spring', 2001, 'B-');
	insert into takes values('3143', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('94766', '571', '1', 'Spring', 2004, 'C-');
	insert into takes values('63090', '581', '1', 'Spring', 2005, 'A+');
	insert into takes values('6712', '304', '1', 'Fall', 2009, 'B ');
	insert into takes values('39881', '626', '1', 'Fall', 2006, 'B+');
	insert into takes values('96067', '972', '1', 'Spring', 2009, 'C ');
	insert into takes values('76798', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('86001', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('61356', '663', '1', 'Spring', 2005, 'C ');
	insert into takes values('2201', '408', '1', 'Spring', 2007, 'C-');
	insert into takes values('94173', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('21766', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('18752', '867', '2', 'Fall', 2010, 'A-');
	insert into takes values('67514', '237', '1', 'Spring', 2008, 'C-');
	insert into takes values('68070', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('83480', '496', '1', 'Fall', 2001, 'B-');
	insert into takes values('69581', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('15070', '748', '1', 'Fall', 2003, 'B-');
	insert into takes values('47487', '237', '2', 'Fall', 2009, 'C ');
	insert into takes values('23439', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('6673', '760', '1', 'Spring', 2004, 'C+');
	insert into takes values('87706', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('35685', '496', '1', 'Fall', 2001, 'B-');
	insert into takes values('17207', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('72055', '426', '1', 'Spring', 2006, 'A ');
	insert into takes values('86833', '169', '2', 'Fall', 2002, 'C ');
	insert into takes values('35685', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('2561', '735', '1', 'Spring', 2003, 'A ');
	insert into takes values('43912', '960', '2', 'Fall', 2006, 'A-');
	insert into takes values('99226', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('22258', '603', '1', 'Fall', 2003, 'B+');
	insert into takes values('42560', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('88577', '482', '1', 'Fall', 2005, 'B-');
	insert into takes values('31250', '158', '2', 'Spring', 2008, 'B-');
	insert into takes values('79534', '702', '1', 'Spring', 2001, 'C ');
	insert into takes values('54875', '972', '1', 'Spring', 2009, 'B-');
	insert into takes values('52876', '200', '1', 'Spring', 2007, 'C ');
	insert into takes values('64164', '334', '1', 'Fall', 2009, 'B+');
	insert into takes values('31486', '626', '1', 'Fall', 2006, 'C+');
	insert into takes values('38371', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('77548', '704', '1', 'Spring', 2008, 'B ');
	insert into takes values('60867', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('4860', '105', '2', 'Fall', 2002, 'A+');
	insert into takes values('66269', '735', '1', 'Spring', 2003, 'C+');
	insert into takes values('52707', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('72177', '137', '1', 'Spring', 2002, 'B+');
	insert into takes values('59673', '791', '1', 'Spring', 2006, 'A-');
	insert into takes values('95099', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('38691', '349', '1', 'Spring', 2008, 'A-');
	insert into takes values('1727', '960', '1', 'Fall', 2009, 'A+');
	insert into takes values('48660', '334', '1', 'Fall', 2009, 'B-');
	insert into takes values('61527', '105', '2', 'Fall', 2002, 'A+');
	insert into takes values('30164', '793', '1', 'Spring', 2002, 'C ');
	insert into takes values('11422', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('39238', '345', '1', 'Spring', 2008, 'C ');
	insert into takes values('49450', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('25525', '457', '1', 'Spring', 2001, 'C-');
	insert into takes values('52291', '631', '1', 'Spring', 2007, 'A+');
	insert into takes values('90448', '349', '1', 'Spring', 2008, 'A-');
	insert into takes values('26802', '137', '1', 'Spring', 2002, 'A ');
	insert into takes values('96003', '345', '1', 'Spring', 2008, 'A-');
	insert into takes values('20814', '468', '1', 'Fall', 2005, 'B+');
	insert into takes values('858', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('858', '875', '1', 'Spring', 2005, 'A+');
	insert into takes values('79446', '443', '1', 'Spring', 2010, 'B ');
	insert into takes values('62373', '408', '1', 'Spring', 2007, 'A-');
	insert into takes values('66813', '105', '1', 'Fall', 2009, 'A+');
	insert into takes values('48589', '599', '1', 'Spring', 2003, 'C ');
	insert into takes values('75123', '962', '1', 'Spring', 2008, 'A+');
	insert into takes values('40059', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('15980', '158', '1', 'Fall', 2008, 'A+');
	insert into takes values('8347', '867', '1', 'Fall', 2006, 'A ');
	insert into takes values('64013', '875', '1', 'Spring', 2005, 'C-');
	insert into takes values('72521', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('80990', '679', '1', 'Spring', 2010, 'B-');
	insert into takes values('88302', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('31086', '313', '1', 'Fall', 2010, 'A+');
	insert into takes values('68096', '242', '1', 'Fall', 2009, 'C+');
	insert into takes values('9183', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('75116', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('78434', '696', '1', 'Spring', 2002, 'C-');
	insert into takes values('78892', '760', '1', 'Spring', 2004, 'C+');
	insert into takes values('52876', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('77244', '867', '2', 'Fall', 2010, 'A-');
	insert into takes values('25718', '237', '1', 'Spring', 2008, 'B-');
	insert into takes values('84792', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('69241', '192', '1', 'Fall', 2002, 'C ');
	insert into takes values('27366', '527', '1', 'Fall', 2004, 'A-');
	insert into takes values('29863', '972', '1', 'Spring', 2009, 'B+');
	insert into takes values('35198', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('9947', '239', '1', 'Fall', 2006, 'B-');
	insert into takes values('8517', '927', '1', 'Fall', 2002, 'C+');
	insert into takes values('41091', '105', '1', 'Fall', 2009, 'C-');
	insert into takes values('24387', '200', '2', 'Fall', 2002, 'C+');
	insert into takes values('14065', '748', '1', 'Fall', 2003, 'C ');
	insert into takes values('32217', '493', '1', 'Spring', 2010, 'B ');
	insert into takes values('37856', '400', '2', 'Fall', 2003, 'C+');
	insert into takes values('30650', '791', '1', 'Spring', 2006, 'A-');
	insert into takes values('93125', '663', '1', 'Spring', 2005, 'A ');
	insert into takes values('63886', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('99289', '258', '1', 'Fall', 2007, 'A ');
	insert into takes values('34404', '791', '1', 'Spring', 2006, 'C-');
	insert into takes values('52523', '461', '1', 'Fall', 2002, 'B-');
	insert into takes values('48471', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('4015', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('69521', '105', '2', 'Fall', 2002, 'C-');
	insert into takes values('37339', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('86934', '581', '1', 'Spring', 2005, 'A ');
	insert into takes values('53225', '443', '2', 'Spring', 2002, 'C-');
	insert into takes values('8192', '960', '1', 'Fall', 2009, 'A-');
	insert into takes values('14628', '604', '1', 'Spring', 2009, 'B+');
	insert into takes values('27002', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('81876', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('1110', '692', '1', 'Spring', 2010, 'A+');
	insert into takes values('74464', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('45720', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('70235', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('32369', '599', '1', 'Spring', 2003, 'C+');
	insert into takes values('13757', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('74509', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('41973', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('37759', '352', '1', 'Spring', 2006, 'C ');
	insert into takes values('21102', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('89297', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('2967', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('13403', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('67051', '496', '1', 'Fall', 2001, 'B ');
	insert into takes values('11237', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('12214', '304', '1', 'Fall', 2009, 'C+');
	insert into takes values('37521', '362', '3', 'Spring', 2008, 'A+');
	insert into takes values('87439', '408', '1', 'Spring', 2007, 'C ');
	insert into takes values('78756', '137', '1', 'Spring', 2002, 'A ');
	insert into takes values('91063', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('53185', '893', '1', 'Fall', 2007, 'A-');
	insert into takes values('24746', '274', '1', 'Fall', 2002, 'B ');
	insert into takes values('41774', '334', '1', 'Fall', 2009, 'A-');
	insert into takes values('25143', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('23373', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('42960', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('23373', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('76768', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('5208', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('34788', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('79205', '482', '1', 'Fall', 2005, 'C ');
	insert into takes values('69960', '415', '1', 'Fall', 2010, 'B+');
	insert into takes values('56598', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('67725', '692', '1', 'Spring', 2010, 'A+');
	insert into takes values('62716', '105', '1', 'Fall', 2009, 'C ');
	insert into takes values('77548', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('18234', '408', '1', 'Spring', 2007, 'C+');
	insert into takes values('24197', '445', '1', 'Spring', 2001, 'C+');
	insert into takes values('42843', '561', '1', 'Fall', 2006, 'C ');
	insert into takes values('827', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('62429', '200', '1', 'Spring', 2007, 'A ');
	insert into takes values('51549', '696', '1', 'Spring', 2002, 'B+');
	insert into takes values('12173', '486', '1', 'Fall', 2009, 'B ');
	insert into takes values('14829', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('24201', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('41599', '927', '1', 'Fall', 2002, 'A ');
	insert into takes values('87222', '791', '1', 'Spring', 2006, 'B+');
	insert into takes values('81538', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('14023', '864', '1', 'Spring', 2006, 'C-');
	insert into takes values('53424', '400', '2', 'Fall', 2003, 'A-');
	insert into takes values('80113', '169', '1', 'Spring', 2007, 'B+');
	insert into takes values('26102', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('3640', '760', '1', 'Spring', 2004, 'C+');
	insert into takes values('59530', '629', '1', 'Spring', 2003, 'A+');
	insert into takes values('46106', '274', '1', 'Fall', 2002, 'C+');
	insert into takes values('12615', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('68779', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('57511', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('11422', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('6209', '663', '1', 'Spring', 2005, 'A ');
	insert into takes values('11055', '200', '1', 'Spring', 2007, 'C-');
	insert into takes values('20540', '362', '2', 'Fall', 2006, 'A-');
	insert into takes values('87246', '468', '1', 'Fall', 2005, 'B ');
	insert into takes values('65121', '319', '1', 'Spring', 2003, 'B ');
	insert into takes values('67146', '493', '1', 'Spring', 2010, 'A+');
	insert into takes values('71631', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('35462', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('87193', '169', '2', 'Fall', 2002, 'A+');
	insert into takes values('42991', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('40897', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('83170', '400', '1', 'Spring', 2007, 'A-');
	insert into takes values('33460', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('41832', '476', '1', 'Fall', 2010, 'C ');
	insert into takes values('22198', '581', '1', 'Spring', 2005, 'B+');
	insert into takes values('4940', '338', '1', 'Spring', 2007, 'B ');
	insert into takes values('11419', '960', '2', 'Fall', 2006, 'C+');
	insert into takes values('73807', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('88140', '445', '1', 'Spring', 2001, 'B-');
	insert into takes values('34197', '338', '1', 'Spring', 2007, 'B-');
	insert into takes values('7043', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('46155', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('92274', '893', '1', 'Fall', 2007, 'A-');
	insert into takes values('41491', '735', '2', 'Spring', 2010, 'A+');
	insert into takes values('81031', '338', '2', 'Spring', 2006, 'A-');
	insert into takes values('69628', '105', '1', 'Fall', 2009, 'B ');
	insert into takes values('69122', '192', '1', 'Fall', 2002, 'C-');
	insert into takes values('6287', '105', '1', 'Fall', 2009, 'C ');
	insert into takes values('22004', '338', '2', 'Spring', 2006, 'A ');
	insert into takes values('25940', '313', '1', 'Fall', 2010, 'A ');
	insert into takes values('18809', '747', '1', 'Spring', 2004, 'C ');
	insert into takes values('19293', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('58701', '702', '1', 'Spring', 2001, 'A-');
	insert into takes values('86707', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('75513', '760', '1', 'Spring', 2004, 'B+');
	insert into takes values('77130', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('12214', '893', '1', 'Fall', 2007, 'B+');
	insert into takes values('63390', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('6287', '274', '1', 'Fall', 2002, 'A+');
	insert into takes values('28829', '972', '1', 'Spring', 2009, 'B-');
	insert into takes values('67293', '864', '1', 'Spring', 2006, 'B+');
	insert into takes values('92417', '258', '1', 'Fall', 2007, 'A-');
	insert into takes values('76672', '852', '1', 'Spring', 2008, 'C ');
	insert into takes values('90353', '313', '1', 'Fall', 2010, 'B+');
	insert into takes values('41299', '561', '1', 'Fall', 2006, 'C+');
	insert into takes values('91569', '476', '1', 'Fall', 2010, 'C ');
	insert into takes values('32119', '642', '1', 'Fall', 2004, 'B+');
	insert into takes values('94766', '158', '1', 'Fall', 2008, 'A+');
	insert into takes values('59290', '443', '2', 'Spring', 2002, 'C-');
	insert into takes values('39204', '692', '1', 'Spring', 2010, 'C ');
	insert into takes values('85746', '468', '1', 'Fall', 2005, 'B ');
	insert into takes values('77588', '349', '1', 'Spring', 2008, 'A ');
	insert into takes values('99268', '760', '1', 'Spring', 2004, 'A-');
	insert into takes values('79170', '626', '1', 'Fall', 2006, 'B ');
	insert into takes values('39254', '603', '1', 'Fall', 2003, 'B ');
	insert into takes values('64155', '338', '1', 'Spring', 2007, 'B ');
	insert into takes values('90381', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('17996', '692', '1', 'Spring', 2010, 'A+');
	insert into takes values('40932', '571', '1', 'Spring', 2004, 'C ');
	insert into takes values('76759', '169', '1', 'Spring', 2007, 'B-');
	insert into takes values('52750', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('82591', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('72521', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('5824', '242', '1', 'Fall', 2009, 'B+');
	insert into takes values('40371', '864', '1', 'Spring', 2006, 'A+');
	insert into takes values('92693', '793', '1', 'Spring', 2002, 'C+');
	insert into takes values('91978', '581', '1', 'Spring', 2005, 'C+');
	insert into takes values('15283', '345', '1', 'Spring', 2008, 'A ');
	insert into takes values('65299', '692', '1', 'Spring', 2010, 'A+');
	insert into takes values('62784', '274', '1', 'Fall', 2002, 'C+');
	insert into takes values('82697', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('70688', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('27662', '696', '1', 'Spring', 2002, 'B ');
	insert into takes values('24116', '105', '1', 'Fall', 2009, 'C ');
	insert into takes values('70061', '105', '2', 'Fall', 2002, 'C-');
	insert into takes values('16405', '237', '2', 'Fall', 2009, 'C ');
	insert into takes values('29959', '496', '1', 'Fall', 2001, 'C-');
	insert into takes values('49450', '270', '1', 'Spring', 2010, 'C-');
	insert into takes values('57156', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('70688', '158', '1', 'Fall', 2008, 'A+');
	insert into takes values('13365', '960', '1', 'Fall', 2009, 'B+');
	insert into takes values('91091', '793', '1', 'Spring', 2002, 'A ');
	insert into takes values('52523', '242', '1', 'Fall', 2009, 'B+');
	insert into takes values('71904', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('89571', '352', '1', 'Spring', 2006, 'B ');
	insert into takes values('93354', '200', '2', 'Fall', 2002, 'A+');
	insert into takes values('52741', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('38712', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('35293', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('42096', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('26102', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('9460', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('18740', '867', '1', 'Fall', 2006, 'B+');
	insert into takes values('77021', '735', '1', 'Spring', 2003, 'C+');
	insert into takes values('7970', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('66494', '591', '1', 'Spring', 2005, 'B ');
	insert into takes values('39157', '313', '1', 'Fall', 2010, 'A-');
	insert into takes values('75878', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('13211', '694', '1', 'Fall', 2002, 'C ');
	insert into takes values('93043', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('90132', '893', '1', 'Fall', 2007, 'A ');
	insert into takes values('17057', '468', '2', 'Fall', 2007, 'C+');
	insert into takes values('99730', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('56499', '408', '2', 'Spring', 2003, 'B ');
	insert into takes values('11195', '239', '1', 'Fall', 2006, 'C+');
	insert into takes values('80651', '239', '1', 'Fall', 2006, 'B ');
	insert into takes values('22620', '461', '1', 'Fall', 2002, 'A-');
	insert into takes values('3693', '258', '1', 'Fall', 2007, 'A+');
	insert into takes values('30188', '867', '2', 'Fall', 2010, 'B-');
	insert into takes values('64550', '612', '1', 'Fall', 2007, 'C ');
	insert into takes values('31080', '400', '1', 'Spring', 2007, 'A+');
	insert into takes values('32490', '237', '2', 'Fall', 2009, 'A-');
	insert into takes values('10917', '704', '1', 'Spring', 2008, 'C-');
	insert into takes values('40738', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('94522', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('25525', '242', '1', 'Fall', 2009, 'A+');
	insert into takes values('47379', '270', '1', 'Spring', 2010, 'A-');
	insert into takes values('28738', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('86736', '105', '1', 'Fall', 2009, 'C ');
	insert into takes values('52866', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('987', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('15086', '468', '1', 'Fall', 2005, 'A ');
	insert into takes values('71426', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('46450', '949', '1', 'Fall', 2007, 'B ');
	insert into takes values('95850', '338', '1', 'Spring', 2007, 'A-');
	insert into takes values('898', '169', '1', 'Spring', 2007, 'C+');
	insert into takes values('1812', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('15328', '959', '1', 'Fall', 2006, 'C+');
	insert into takes values('2178', '345', '1', 'Spring', 2008, 'A+');
	insert into takes values('54296', '972', '1', 'Spring', 2009, 'A-');
	insert into takes values('8853', '581', '1', 'Spring', 2005, 'B+');
	insert into takes values('5208', '476', '1', 'Fall', 2010, 'B+');
	insert into takes values('73165', '239', '1', 'Fall', 2006, 'B-');
	insert into takes values('8457', '991', '1', 'Spring', 2008, 'B ');
	insert into takes values('25611', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('73492', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('45083', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('34770', '270', '1', 'Spring', 2010, 'A+');
	insert into takes values('3739', '362', '2', 'Fall', 2006, 'C-');
	insert into takes values('6712', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('51549', '338', '2', 'Spring', 2006, 'C+');
	insert into takes values('2177', '486', '1', 'Fall', 2009, 'C+');
	insert into takes values('45680', '875', '1', 'Spring', 2005, 'B-');
	insert into takes values('83444', '242', '1', 'Fall', 2009, 'B+');
	insert into takes values('75522', '362', '3', 'Spring', 2008, 'C+');
	insert into takes values('32490', '400', '1', 'Spring', 2007, 'C+');
	insert into takes values('65753', '443', '1', 'Spring', 2010, 'C+');
	insert into takes values('77244', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('78572', '629', '1', 'Spring', 2003, 'B-');
	insert into takes values('69241', '158', '1', 'Fall', 2008, 'B-');
	insert into takes values('35588', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('2419', '747', '1', 'Spring', 2004, 'C ');
	insert into takes values('34502', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('14563', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('13290', '158', '2', 'Spring', 2008, 'C-');
	insert into takes values('33546', '476', '1', 'Fall', 2010, 'C ');
	insert into takes values('35357', '415', '1', 'Fall', 2010, 'C-');
	insert into takes values('4508', '949', '1', 'Fall', 2007, 'C+');
	insert into takes values('10838', '875', '1', 'Spring', 2005, 'B-');
	insert into takes values('23994', '489', '1', 'Fall', 2007, 'C ');
	insert into takes values('5961', '468', '2', 'Fall', 2007, 'B ');
	insert into takes values('1727', '527', '1', 'Fall', 2004, 'C-');
	insert into takes values('82580', '468', '2', 'Fall', 2007, 'A-');
	insert into takes values('58935', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('8986', '362', '1', 'Fall', 2005, 'C ');
	insert into takes values('9114', '421', '1', 'Fall', 2004, 'C+');
	insert into takes values('41211', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('847', '843', '1', 'Fall', 2010, 'C ');
	insert into takes values('43658', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('8347', '338', '1', 'Spring', 2007, 'A ');
	insert into takes values('31560', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('16543', '489', '1', 'Fall', 2007, 'B+');
	insert into takes values('53496', '476', '1', 'Fall', 2010, 'B+');
	insert into takes values('62832', '242', '1', 'Fall', 2009, 'B ');
	insert into takes values('28538', '468', '1', 'Fall', 2005, 'A-');
	insert into takes values('68010', '604', '1', 'Spring', 2009, 'B+');
	insert into takes values('31337', '137', '1', 'Spring', 2002, 'A-');
	insert into takes values('27919', '960', '2', 'Fall', 2006, 'A ');
	insert into takes values('42019', '642', '1', 'Fall', 2004, 'C+');
	insert into takes values('34329', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('43226', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('88801', '400', '2', 'Fall', 2003, 'C+');
	insert into takes values('9947', '735', '2', 'Spring', 2010, 'B ');
	insert into takes values('11095', '461', '1', 'Fall', 2002, 'A-');
	insert into takes values('32490', '443', '1', 'Spring', 2010, 'A+');
	insert into takes values('3487', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('63860', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('17377', '400', '1', 'Spring', 2007, 'C-');
	insert into takes values('43658', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('95631', '604', '1', 'Spring', 2009, 'B ');
	insert into takes values('7970', '408', '1', 'Spring', 2007, 'C-');
	insert into takes values('32464', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('27727', '629', '1', 'Spring', 2003, 'A ');
	insert into takes values('44836', '486', '1', 'Fall', 2009, 'A ');
	insert into takes values('40932', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('83871', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('11855', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('95225', '793', '1', 'Spring', 2002, 'C+');
	insert into takes values('19848', '158', '1', 'Fall', 2008, 'A-');
	insert into takes values('61527', '319', '1', 'Spring', 2003, 'B-');
	insert into takes values('45680', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('88993', '791', '1', 'Spring', 2006, 'A-');
	insert into takes values('25725', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('50664', '793', '1', 'Spring', 2002, 'B+');
	insert into takes values('86981', '760', '1', 'Spring', 2004, 'C-');
	insert into takes values('25718', '313', '1', 'Fall', 2010, 'C+');
	insert into takes values('30845', '603', '1', 'Fall', 2003, 'A+');
	insert into takes values('51579', '735', '2', 'Spring', 2010, 'B-');
	insert into takes values('1954', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('87624', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('69285', '400', '2', 'Fall', 2003, 'A ');
	insert into takes values('6474', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('11453', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('24746', '927', '1', 'Fall', 2002, 'B-');
	insert into takes values('32119', '366', '1', 'Fall', 2005, 'C ');
	insert into takes values('93653', '599', '1', 'Spring', 2003, 'C ');
	insert into takes values('61232', '137', '1', 'Spring', 2002, 'A ');
	insert into takes values('62226', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('36384', '105', '2', 'Fall', 2002, 'B+');
	insert into takes values('44304', '545', '1', 'Fall', 2001, 'A-');
	insert into takes values('48660', '258', '1', 'Fall', 2007, 'C+');
	insert into takes values('93653', '960', '1', 'Fall', 2009, 'C-');
	insert into takes values('43016', '949', '1', 'Fall', 2007, 'C-');
	insert into takes values('56882', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('21102', '443', '2', 'Spring', 2002, 'C+');
	insert into takes values('27950', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('98388', '486', '1', 'Fall', 2009, 'C+');
	insert into takes values('65438', '274', '1', 'Fall', 2002, 'B-');
	insert into takes values('75040', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('63361', '949', '1', 'Fall', 2007, 'C+');
	insert into takes values('17831', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('21086', '843', '1', 'Fall', 2010, 'B-');
	insert into takes values('81150', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('20099', '486', '1', 'Fall', 2009, 'C+');
	insert into takes values('435', '702', '1', 'Spring', 2001, 'A-');
	insert into takes values('827', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('72741', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('33201', '468', '1', 'Fall', 2005, 'B+');
	insert into takes values('35362', '843', '1', 'Fall', 2010, 'A-');
	insert into takes values('12214', '527', '1', 'Fall', 2004, 'C+');
	insert into takes values('43211', '200', '2', 'Fall', 2002, 'B-');
	insert into takes values('1533', '169', '1', 'Spring', 2007, 'A-');
	insert into takes values('77364', '864', '1', 'Spring', 2006, 'C-');
	insert into takes values('75046', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('78892', '972', '1', 'Spring', 2009, 'C ');
	insert into takes values('34404', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('66484', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('85887', '696', '1', 'Spring', 2002, 'C+');
	insert into takes values('81258', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('80799', '408', '2', 'Spring', 2003, 'B-');
	insert into takes values('27662', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('66495', '158', '2', 'Spring', 2008, 'A ');
	insert into takes values('84702', '679', '1', 'Spring', 2010, 'A+');
	insert into takes values('64945', '748', '1', 'Fall', 2003, 'B ');
	insert into takes values('88045', '352', '1', 'Spring', 2006, 'C ');
	insert into takes values('28994', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('99399', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('90353', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('89188', '631', '1', 'Spring', 2007, 'B+');
	insert into takes values('35498', '457', '1', 'Spring', 2001, 'B-');
	insert into takes values('51698', '105', '2', 'Fall', 2002, 'A-');
	insert into takes values('56755', '415', '1', 'Fall', 2010, 'A-');
	insert into takes values('54612', '270', '1', 'Spring', 2010, 'B+');
	insert into takes values('35588', '457', '1', 'Spring', 2001, 'A-');
	insert into takes values('78434', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('50743', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('41299', '962', '1', 'Spring', 2008, 'B ');
	insert into takes values('98388', '496', '1', 'Fall', 2001, 'A-');
	insert into takes values('50873', '704', '1', 'Spring', 2008, 'B ');
	insert into takes values('17769', '748', '1', 'Fall', 2003, 'C ');
	insert into takes values('16907', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('7854', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('94894', '959', '1', 'Fall', 2006, 'C+');
	insert into takes values('36303', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('59397', '376', '1', 'Fall', 2006, 'C+');
	insert into takes values('90372', '366', '1', 'Fall', 2005, 'C-');
	insert into takes values('29091', '545', '1', 'Fall', 2001, 'B ');
	insert into takes values('4015', '893', '1', 'Fall', 2007, 'A ');
	insert into takes values('52669', '345', '1', 'Spring', 2008, 'A-');
	insert into takes values('54620', '581', '1', 'Spring', 2005, 'A ');
	insert into takes values('24442', '571', '1', 'Spring', 2004, 'A+');
	insert into takes values('3639', '852', '1', 'Spring', 2008, 'A ');
	insert into takes values('10454', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('78572', '702', '1', 'Spring', 2001, 'C ');
	insert into takes values('34170', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('52057', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('15883', '760', '1', 'Spring', 2004, 'B+');
	insert into takes values('46155', '313', '1', 'Fall', 2010, 'B+');
	insert into takes values('37946', '338', '2', 'Spring', 2006, 'A+');
	insert into takes values('85910', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('31337', '571', '1', 'Spring', 2004, 'A+');
	insert into takes values('18367', '748', '1', 'Fall', 2003, 'B ');
	insert into takes values('73206', '559', '1', 'Fall', 2002, 'B+');
	insert into takes values('13365', '696', '1', 'Spring', 2002, 'B+');
	insert into takes values('7514', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('62549', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('51538', '808', '1', 'Fall', 2003, 'A-');
	insert into takes values('27528', '893', '1', 'Fall', 2007, 'B ');
	insert into takes values('6710', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('97573', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('27140', '158', '1', 'Fall', 2008, 'B-');
	insert into takes values('90089', '629', '1', 'Spring', 2003, 'A+');
	insert into takes values('57026', '949', '1', 'Fall', 2007, 'B ');
	insert into takes values('66054', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('45359', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('32056', '362', '3', 'Spring', 2008, 'C-');
	insert into takes values('43226', '626', '1', 'Fall', 2006, 'B ');
	insert into takes values('41818', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('56124', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('96206', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('52656', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('67425', '493', '1', 'Spring', 2010, 'C ');
	insert into takes values('25785', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('38371', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('38548', '105', '2', 'Fall', 2002, 'B+');
	insert into takes values('63243', '603', '1', 'Fall', 2003, 'A+');
	insert into takes values('83444', '927', '1', 'Fall', 2002, 'C ');
	insert into takes values('42625', '239', '1', 'Fall', 2006, 'A-');
	insert into takes values('6474', '802', '1', 'Spring', 2003, 'C+');
	insert into takes values('95320', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('58355', '158', '1', 'Fall', 2008, 'B-');
	insert into takes values('25718', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('74911', '400', '1', 'Spring', 2007, 'B+');
	insert into takes values('19861', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('52203', '527', '1', 'Fall', 2004, 'C+');
	insert into takes values('23224', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('73186', '443', '2', 'Spring', 2002, 'C-');
	insert into takes values('59046', '591', '1', 'Spring', 2005, 'A ');
	insert into takes values('27956', '867', '2', 'Fall', 2010, 'A-');
	insert into takes values('65688', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('47677', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('94173', '927', '1', 'Fall', 2002, 'A ');
	insert into takes values('95859', '802', '1', 'Spring', 2003, 'C-');
	insert into takes values('51955', '468', '1', 'Fall', 2005, 'C ');
	insert into takes values('36402', '237', '1', 'Spring', 2008, 'B+');
	insert into takes values('41406', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('62636', '237', '2', 'Fall', 2009, 'B+');
	insert into takes values('53490', '169', '2', 'Fall', 2002, 'B-');
	insert into takes values('4508', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('59530', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('67340', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('21394', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('58172', '338', '2', 'Spring', 2006, 'A+');
	insert into takes values('60748', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('70235', '663', '1', 'Spring', 2005, 'B ');
	insert into takes values('6712', '559', '1', 'Fall', 2002, 'A-');
	insert into takes values('1836', '631', '1', 'Spring', 2007, 'B ');
	insert into takes values('97953', '867', '2', 'Fall', 2010, 'C-');
	insert into takes values('58465', '443', '1', 'Spring', 2010, 'B-');
	insert into takes values('33791', '735', '2', 'Spring', 2010, 'C ');
	insert into takes values('98830', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('67033', '408', '2', 'Spring', 2003, 'A+');
	insert into takes values('68096', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('40992', '334', '1', 'Fall', 2009, 'A-');
	insert into takes values('90914', '349', '1', 'Spring', 2008, 'A-');
	insert into takes values('72014', '527', '1', 'Fall', 2004, 'B-');
	insert into takes values('67725', '748', '1', 'Fall', 2003, 'C ');
	insert into takes values('19220', '875', '1', 'Spring', 2005, 'A+');
	insert into takes values('43123', '962', '1', 'Spring', 2008, 'B ');
	insert into takes values('94257', '694', '1', 'Fall', 2002, 'A ');
	insert into takes values('12941', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('49339', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('3639', '352', '1', 'Spring', 2006, 'A-');
	insert into takes values('88169', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('80248', '445', '1', 'Spring', 2001, 'A-');
	insert into takes values('69853', '960', '1', 'Fall', 2009, 'B-');
	insert into takes values('35220', '445', '1', 'Spring', 2001, 'B+');
	insert into takes values('58081', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('86651', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('85063', '237', '2', 'Fall', 2009, 'B+');
	insert into takes values('76743', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('5250', '795', '1', 'Spring', 2004, 'A-');
	insert into takes values('25785', '702', '1', 'Spring', 2001, 'B-');
	insert into takes values('96227', '313', '1', 'Fall', 2010, 'B+');
	insert into takes values('37734', '313', '1', 'Fall', 2010, 'A-');
	insert into takes values('26473', '604', '1', 'Spring', 2009, 'A ');
	insert into takes values('41406', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('49450', '200', '1', 'Spring', 2007, 'A ');
	insert into takes values('90609', '679', '1', 'Spring', 2010, 'A ');
	insert into takes values('20002', '345', '1', 'Spring', 2008, 'C-');
	insert into takes values('43130', '476', '1', 'Fall', 2010, 'B+');
	insert into takes values('91799', '239', '1', 'Fall', 2006, 'B-');
	insert into takes values('52523', '258', '1', 'Fall', 2007, 'B-');
	insert into takes values('38899', '927', '1', 'Fall', 2002, 'C-');
	insert into takes values('29435', '482', '1', 'Fall', 2005, 'A ');
	insert into takes values('78581', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('48901', '747', '1', 'Spring', 2004, 'C-');
	insert into takes values('22142', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('19293', '468', '2', 'Fall', 2007, 'A-');
	insert into takes values('84239', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('13506', '735', '2', 'Spring', 2010, 'B-');
	insert into takes values('38602', '445', '1', 'Spring', 2001, 'A-');
	insert into takes values('2419', '604', '1', 'Spring', 2009, 'A ');
	insert into takes values('72186', '631', '1', 'Spring', 2007, 'C-');
	insert into takes values('23794', '581', '1', 'Spring', 2005, 'C ');
	insert into takes values('87624', '867', '1', 'Fall', 2006, 'A+');
	insert into takes values('79892', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('68396', '313', '1', 'Fall', 2010, 'C-');
	insert into takes values('69307', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('80057', '200', '2', 'Fall', 2002, 'A ');
	insert into takes values('78758', '852', '1', 'Spring', 2008, 'B+');
	insert into takes values('7149', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('81896', '581', '1', 'Spring', 2005, 'B+');
	insert into takes values('27687', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('55009', '603', '1', 'Fall', 2003, 'A ');
	insert into takes values('56941', '696', '1', 'Spring', 2002, 'C+');
	insert into takes values('72959', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('75513', '642', '1', 'Fall', 2004, 'B-');
	insert into takes values('85451', '802', '1', 'Spring', 2003, 'A+');
	insert into takes values('42991', '663', '1', 'Spring', 2005, 'C-');
	insert into takes values('26730', '735', '2', 'Spring', 2010, 'A-');
	insert into takes values('51008', '200', '1', 'Spring', 2007, 'B-');
	insert into takes values('2501', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('6710', '599', '1', 'Spring', 2003, 'B+');
	insert into takes values('50537', '239', '1', 'Fall', 2006, 'A-');
	insert into takes values('49701', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('12326', '200', '2', 'Fall', 2002, 'C-');
	insert into takes values('16133', '972', '1', 'Spring', 2009, 'B+');
	insert into takes values('28004', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('77898', '527', '1', 'Fall', 2004, 'B+');
	insert into takes values('75423', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('65056', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('84410', '415', '1', 'Fall', 2010, 'C ');
	insert into takes values('94814', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('34331', '400', '1', 'Spring', 2007, 'C+');
	insert into takes values('3005', '408', '2', 'Spring', 2003, 'A+');
	insert into takes values('57377', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('6195', '696', '1', 'Spring', 2002, 'B-');
	insert into takes values('89312', '304', '1', 'Fall', 2009, 'A ');
	insert into takes values('67514', '612', '1', 'Fall', 2007, 'B-');
	insert into takes values('41741', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('15283', '237', '1', 'Spring', 2008, 'C-');
	insert into takes values('91580', '604', '1', 'Spring', 2009, 'A-');
	insert into takes values('83696', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('62832', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('41774', '376', '1', 'Fall', 2006, 'C+');
	insert into takes values('39394', '852', '1', 'Spring', 2008, 'B-');
	insert into takes values('97228', '696', '1', 'Spring', 2002, 'B ');
	insert into takes values('82591', '443', '2', 'Spring', 2002, 'A+');
	insert into takes values('30252', '401', '1', 'Fall', 2003, 'A-');
	insert into takes values('95099', '960', '1', 'Fall', 2009, 'A-');
	insert into takes values('62549', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('2419', '200', '2', 'Fall', 2002, 'A ');
	insert into takes values('69730', '875', '1', 'Spring', 2005, 'A ');
	insert into takes values('51955', '457', '1', 'Spring', 2001, 'A ');
	insert into takes values('99647', '864', '1', 'Spring', 2006, 'A ');
	insert into takes values('95697', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('41674', '158', '1', 'Fall', 2008, 'A-');
	insert into takes values('67657', '169', '1', 'Spring', 2007, 'C ');
	insert into takes values('68712', '400', '1', 'Spring', 2007, 'C-');
	insert into takes values('95175', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('95850', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('16347', '571', '1', 'Spring', 2004, 'C+');
	insert into takes values('37339', '527', '1', 'Fall', 2004, 'C ');
	insert into takes values('88472', '258', '1', 'Fall', 2007, 'C ');
	insert into takes values('40481', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('19245', '591', '1', 'Spring', 2005, 'A ');
	insert into takes values('15726', '200', '2', 'Fall', 2002, 'C+');
	insert into takes values('29260', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('62373', '376', '1', 'Fall', 2006, 'A-');
	insert into takes values('72358', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('28829', '893', '1', 'Fall', 2007, 'A-');
	insert into takes values('847', '735', '1', 'Spring', 2003, 'C-');
	insert into takes values('2848', '401', '1', 'Fall', 2003, 'A+');
	insert into takes values('58595', '629', '1', 'Spring', 2003, 'B ');
	insert into takes values('78116', '362', '1', 'Fall', 2005, 'B ');
	insert into takes values('70098', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('78922', '808', '1', 'Fall', 2003, 'C ');
	insert into takes values('7390', '972', '1', 'Spring', 2009, 'A+');
	insert into takes values('94257', '561', '1', 'Fall', 2006, 'C ');
	insert into takes values('83696', '599', '1', 'Spring', 2003, 'B ');
	insert into takes values('19582', '304', '1', 'Fall', 2009, 'B+');
	insert into takes values('27044', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('83170', '443', '1', 'Spring', 2010, 'B+');
	insert into takes values('22004', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('76672', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('54605', '702', '1', 'Spring', 2001, 'C+');
	insert into takes values('96722', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('63288', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('69758', '581', '1', 'Spring', 2005, 'A+');
	insert into takes values('37449', '352', '1', 'Spring', 2006, 'A+');
	insert into takes values('30858', '237', '2', 'Fall', 2009, 'C-');
	insert into takes values('27556', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('14829', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('90372', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('65681', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('86573', '694', '1', 'Fall', 2002, 'A+');
	insert into takes values('91851', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('64249', '237', '1', 'Spring', 2008, 'A-');
	insert into takes values('22254', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('81884', '559', '1', 'Fall', 2002, 'C-');
	insert into takes values('26802', '401', '1', 'Fall', 2003, 'A ');
	insert into takes values('40189', '735', '1', 'Spring', 2003, 'A-');
	insert into takes values('92864', '457', '1', 'Spring', 2001, 'C-');
	insert into takes values('40044', '352', '1', 'Spring', 2006, 'B ');
	insert into takes values('90779', '476', '1', 'Fall', 2010, 'C-');
	insert into takes values('68278', '493', '1', 'Spring', 2010, 'A ');
	insert into takes values('32881', '604', '1', 'Spring', 2009, 'C ');
	insert into takes values('31690', '468', '1', 'Fall', 2005, 'A ');
	insert into takes values('97629', '694', '1', 'Fall', 2002, 'A ');
	insert into takes values('72165', '603', '1', 'Fall', 2003, 'B ');
	insert into takes values('58355', '137', '1', 'Spring', 2002, 'C-');
	insert into takes values('38336', '791', '1', 'Spring', 2006, 'A-');
	insert into takes values('11095', '843', '1', 'Fall', 2010, 'B-');
	insert into takes values('40677', '545', '1', 'Fall', 2001, 'B-');
	insert into takes values('11152', '808', '1', 'Fall', 2003, 'A+');
	insert into takes values('52076', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('82066', '867', '1', 'Fall', 2006, 'B ');
	insert into takes values('48850', '274', '1', 'Fall', 2002, 'C+');
	insert into takes values('80651', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('96203', '362', '1', 'Fall', 2005, 'C+');
	insert into takes values('95284', '362', '2', 'Fall', 2006, 'A-');
	insert into takes values('86552', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('17665', '626', '1', 'Fall', 2006, 'B ');
	insert into takes values('34170', '158', '2', 'Spring', 2008, 'C+');
	insert into takes values('96178', '408', '2', 'Spring', 2003, 'A+');
	insert into takes values('84189', '457', '1', 'Spring', 2001, 'B ');
	insert into takes values('49391', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('94801', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('91569', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('51008', '875', '1', 'Spring', 2005, 'C ');
	insert into takes values('38902', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('16515', '642', '1', 'Fall', 2004, 'A-');
	insert into takes values('30845', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('23344', '421', '1', 'Fall', 2004, 'A-');
	insert into takes values('65676', '692', '1', 'Spring', 2010, 'A-');
	insert into takes values('24197', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('22618', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('41683', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('57242', '457', '1', 'Spring', 2001, 'B+');
	insert into takes values('14621', '376', '1', 'Fall', 2006, 'C+');
	insert into takes values('18234', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('5336', '158', '1', 'Fall', 2008, 'A+');
	insert into takes values('69225', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('99775', '599', '1', 'Spring', 2003, 'B-');
	insert into takes values('1080', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('17076', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('62754', '489', '1', 'Fall', 2007, 'B ');
	insert into takes values('55354', '169', '1', 'Spring', 2007, 'B ');
	insert into takes values('50038', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('90181', '105', '1', 'Fall', 2009, 'C+');
	insert into takes values('27898', '457', '1', 'Spring', 2001, 'B+');
	insert into takes values('40059', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('25940', '679', '1', 'Spring', 2010, 'C+');
	insert into takes values('96246', '457', '1', 'Spring', 2001, 'B-');
	insert into takes values('29514', '496', '1', 'Fall', 2001, 'B-');
	insert into takes values('12236', '137', '1', 'Spring', 2002, 'A-');
	insert into takes values('93571', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('38602', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('3576', '629', '1', 'Spring', 2003, 'A+');
	insert into takes values('49701', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('11055', '843', '1', 'Fall', 2010, 'A-');
	insert into takes values('18821', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('13749', '692', '1', 'Spring', 2010, 'A-');
	insert into takes values('95284', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('78116', '105', '1', 'Fall', 2009, 'B ');
	insert into takes values('30164', '457', '1', 'Spring', 2001, 'C ');
	insert into takes values('84039', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('81876', '345', '1', 'Spring', 2008, 'B ');
	insert into takes values('36379', '612', '1', 'Fall', 2007, 'B ');
	insert into takes values('50013', '349', '1', 'Spring', 2008, 'B+');
	insert into takes values('97435', '237', '1', 'Spring', 2008, 'C+');
	insert into takes values('23506', '612', '1', 'Fall', 2007, 'A-');
	insert into takes values('11262', '270', '1', 'Spring', 2010, 'C+');
	insert into takes values('44304', '443', '1', 'Spring', 2010, 'B+');
	insert into takes values('21102', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('2201', '747', '1', 'Spring', 2004, 'C-');
	insert into takes values('90372', '843', '1', 'Fall', 2010, 'A ');
	insert into takes values('95626', '362', '1', 'Fall', 2005, 'B ');
	insert into takes values('81175', '694', '1', 'Fall', 2002, 'A+');
	insert into takes values('17996', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('44985', '313', '1', 'Fall', 2010, 'B ');
	insert into takes values('83838', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('9460', '642', '1', 'Fall', 2004, 'B-');
	insert into takes values('73387', '864', '1', 'Spring', 2006, 'C+');
	insert into takes values('70452', '747', '1', 'Spring', 2004, 'C ');
	insert into takes values('1110', '496', '1', 'Fall', 2001, 'A-');
	insert into takes values('56212', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('53496', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('88793', '192', '1', 'Fall', 2002, 'C-');
	insert into takes values('84808', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('68999', '960', '1', 'Fall', 2009, 'B ');
	insert into takes values('70235', '496', '1', 'Fall', 2001, 'B+');
	insert into takes values('14596', '304', '1', 'Fall', 2009, 'A+');
	insert into takes values('69732', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('71287', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('95852', '362', '1', 'Fall', 2005, 'B ');
	insert into takes values('23525', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('67436', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('20002', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('49873', '366', '1', 'Fall', 2005, 'A ');
	insert into takes values('63288', '692', '1', 'Spring', 2010, 'C-');
	insert into takes values('31761', '561', '1', 'Fall', 2006, 'C-');
	insert into takes values('68150', '400', '1', 'Spring', 2007, 'A-');
	insert into takes values('85910', '735', '1', 'Spring', 2003, 'C+');
	insert into takes values('46725', '401', '1', 'Fall', 2003, 'A+');
	insert into takes values('31337', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('69225', '415', '1', 'Fall', 2010, 'B-');
	insert into takes values('48901', '679', '1', 'Spring', 2010, 'B ');
	insert into takes values('83728', '545', '1', 'Fall', 2001, 'B ');
	insert into takes values('68280', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('86969', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('10814', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('44881', '867', '1', 'Fall', 2006, 'A ');
	insert into takes values('58701', '571', '1', 'Spring', 2004, 'A-');
	insert into takes values('56598', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('28316', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('67793', '626', '1', 'Fall', 2006, 'C ');
	insert into takes values('95852', '338', '2', 'Spring', 2006, 'A-');
	insert into takes values('83728', '237', '2', 'Fall', 2009, 'C+');
	insert into takes values('36244', '493', '1', 'Spring', 2010, 'B ');
	insert into takes values('99775', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('40932', '960', '2', 'Fall', 2006, 'A ');
	insert into takes values('15086', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('71630', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('43854', '802', '1', 'Spring', 2003, 'B+');
	insert into takes values('11055', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('86641', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('70395', '591', '1', 'Spring', 2005, 'A+');
	insert into takes values('99647', '304', '1', 'Fall', 2009, 'B+');
	insert into takes values('32744', '105', '1', 'Fall', 2009, 'C-');
	insert into takes values('18859', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('84727', '702', '1', 'Spring', 2001, 'B ');
	insert into takes values('12979', '421', '1', 'Fall', 2004, 'C ');
	insert into takes values('75928', '362', '3', 'Spring', 2008, 'C-');
	insert into takes values('5399', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('40677', '867', '2', 'Fall', 2010, 'A-');
	insert into takes values('21401', '581', '1', 'Spring', 2005, 'C+');
	insert into takes values('84495', '400', '2', 'Fall', 2003, 'A-');
	insert into takes values('54508', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('70522', '960', '1', 'Fall', 2009, 'C-');
	insert into takes values('22268', '692', '1', 'Spring', 2010, 'C-');
	insert into takes values('31690', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('4435', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('82688', '426', '1', 'Spring', 2006, 'B ');
	insert into takes values('82083', '959', '1', 'Fall', 2006, 'A ');
	insert into takes values('67542', '603', '1', 'Fall', 2003, 'C-');
	insert into takes values('94814', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('76604', '974', '1', 'Fall', 2003, 'A-');
	insert into takes values('90220', '158', '2', 'Spring', 2008, 'A-');
	insert into takes values('60224', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('32881', '468', '2', 'Fall', 2007, 'C-');
	insert into takes values('95027', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('26102', '415', '1', 'Fall', 2010, 'C+');
	insert into takes values('64724', '591', '1', 'Spring', 2005, 'B-');
	insert into takes values('25362', '949', '1', 'Fall', 2007, 'C ');
	insert into takes values('66356', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('92839', '421', '1', 'Fall', 2004, 'C-');
	insert into takes values('71287', '663', '1', 'Spring', 2005, 'B ');
	insert into takes values('82707', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('31341', '561', '1', 'Fall', 2006, 'C ');
	insert into takes values('9659', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('42114', '400', '1', 'Spring', 2007, 'C-');
	insert into takes values('77588', '591', '1', 'Spring', 2005, 'C-');
	insert into takes values('66969', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('66495', '313', '1', 'Fall', 2010, 'A+');
	insert into takes values('68070', '959', '1', 'Fall', 2006, 'A ');
	insert into takes values('37521', '338', '1', 'Spring', 2007, 'A+');
	insert into takes values('26102', '642', '1', 'Fall', 2004, 'A+');
	insert into takes values('17076', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('52371', '443', '1', 'Spring', 2010, 'B-');
	insert into takes values('5243', '875', '1', 'Spring', 2005, 'C ');
	insert into takes values('8957', '974', '1', 'Fall', 2003, 'A-');
	insert into takes values('86934', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('89246', '631', '1', 'Spring', 2007, 'C+');
	insert into takes values('50331', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('18675', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('38691', '696', '1', 'Spring', 2002, 'A-');
	insert into takes values('21692', '631', '1', 'Spring', 2007, 'A ');
	insert into takes values('83204', '679', '1', 'Spring', 2010, 'B ');
	insert into takes values('74911', '748', '1', 'Fall', 2003, 'B-');
	insert into takes values('82970', '603', '1', 'Fall', 2003, 'B-');
	insert into takes values('53047', '960', '2', 'Fall', 2006, 'B+');
	insert into takes values('57377', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('65190', '345', '1', 'Spring', 2008, 'A-');
	insert into takes values('94894', '591', '1', 'Spring', 2005, 'B-');
	insert into takes values('67017', '400', '1', 'Spring', 2007, 'A ');
	insert into takes values('41261', '875', '1', 'Spring', 2005, 'B-');
	insert into takes values('52856', '852', '1', 'Spring', 2008, 'A ');
	insert into takes values('68396', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('499', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('81258', '400', '1', 'Spring', 2007, 'C+');
	insert into takes values('16075', '561', '1', 'Fall', 2006, 'A-');
	insert into takes values('97042', '345', '1', 'Spring', 2008, 'B ');
	insert into takes values('64593', '158', '2', 'Spring', 2008, 'C ');
	insert into takes values('288', '468', '1', 'Fall', 2005, 'B-');
	insert into takes values('80227', '559', '1', 'Fall', 2002, 'B+');
	insert into takes values('79352', '137', '1', 'Spring', 2002, 'B+');
	insert into takes values('54460', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('95366', '679', '1', 'Spring', 2010, 'A ');
	insert into takes values('63860', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('32881', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('70235', '486', '1', 'Fall', 2009, 'B ');
	insert into takes values('80113', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('8347', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('45200', '200', '2', 'Fall', 2002, 'A ');
	insert into takes values('75423', '604', '1', 'Spring', 2009, 'B+');
	insert into takes values('40937', '852', '1', 'Spring', 2008, 'C ');
	insert into takes values('64820', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('69853', '486', '1', 'Fall', 2009, 'C ');
	insert into takes values('65438', '468', '1', 'Fall', 2005, 'C+');
	insert into takes values('68999', '852', '1', 'Spring', 2008, 'A-');
	insert into takes values('79772', '760', '1', 'Spring', 2004, 'A-');
	insert into takes values('81396', '496', '1', 'Fall', 2001, 'B+');
	insert into takes values('38271', '893', '1', 'Fall', 2007, 'B ');
	insert into takes values('70965', '599', '1', 'Spring', 2003, 'C ');
	insert into takes values('98019', '408', '1', 'Spring', 2007, 'C ');
	insert into takes values('41674', '270', '1', 'Spring', 2010, 'C ');
	insert into takes values('59848', '843', '1', 'Fall', 2010, 'C+');
	insert into takes values('57135', '493', '1', 'Spring', 2010, 'A+');
	insert into takes values('42565', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('69230', '486', '1', 'Fall', 2009, 'A ');
	insert into takes values('90779', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('18775', '313', '1', 'Fall', 2010, 'C ');
	insert into takes values('85451', '571', '1', 'Spring', 2004, 'C-');
	insert into takes values('75273', '591', '1', 'Spring', 2005, 'C+');
	insert into takes values('69581', '642', '1', 'Fall', 2004, 'A+');
	insert into takes values('17924', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('21086', '867', '2', 'Fall', 2010, 'C-');
	insert into takes values('9440', '334', '1', 'Fall', 2009, 'A-');
	insert into takes values('92442', '852', '1', 'Spring', 2008, 'C+');
	insert into takes values('42956', '408', '2', 'Spring', 2003, 'A ');
	insert into takes values('58701', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('78782', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('78314', '960', '2', 'Fall', 2006, 'B+');
	insert into takes values('17769', '493', '1', 'Spring', 2010, 'A ');
	insert into takes values('70688', '735', '1', 'Spring', 2003, 'C ');
	insert into takes values('57123', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('67425', '893', '1', 'Fall', 2007, 'C ');
	insert into takes values('12173', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('50013', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('96895', '561', '1', 'Fall', 2006, 'B+');
	insert into takes values('80912', '274', '1', 'Fall', 2002, 'A+');
	insert into takes values('36881', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('82126', '974', '1', 'Fall', 2003, 'B-');
	insert into takes values('80742', '338', '1', 'Spring', 2007, 'B-');
	insert into takes values('98870', '735', '2', 'Spring', 2010, 'C ');
	insert into takes values('98690', '760', '1', 'Spring', 2004, 'A ');
	insert into takes values('20099', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('16311', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('47824', '735', '1', 'Spring', 2003, 'C ');
	insert into takes values('86833', '237', '2', 'Fall', 2009, 'A-');
	insert into takes values('91569', '959', '1', 'Fall', 2006, 'B+');
	insert into takes values('1080', '493', '1', 'Spring', 2010, 'A-');
	insert into takes values('46980', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('15249', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('32506', '274', '1', 'Fall', 2002, 'B ');
	insert into takes values('83728', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('71904', '696', '1', 'Spring', 2002, 'B-');
	insert into takes values('1812', '362', '1', 'Fall', 2005, 'C ');
	insert into takes values('29192', '105', '2', 'Fall', 2002, 'B+');
	insert into takes values('61998', '735', '1', 'Spring', 2003, 'A ');
	insert into takes values('43130', '793', '1', 'Spring', 2002, 'C+');
	insert into takes values('47670', '105', '2', 'Fall', 2002, 'C+');
	insert into takes values('19735', '694', '1', 'Fall', 2002, 'B-');
	insert into takes values('24865', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('66008', '482', '1', 'Fall', 2005, 'A ');
	insert into takes values('37101', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('23457', '334', '1', 'Fall', 2009, 'A-');
	insert into takes values('45720', '694', '1', 'Fall', 2002, 'A ');
	insert into takes values('96117', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('69853', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('88085', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('72165', '545', '1', 'Fall', 2001, 'A ');
	insert into takes values('40178', '338', '1', 'Spring', 2007, 'A ');
	insert into takes values('64820', '679', '1', 'Spring', 2010, 'C-');
	insert into takes values('57026', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('95175', '169', '1', 'Spring', 2007, 'C+');
	insert into takes values('37038', '591', '1', 'Spring', 2005, 'B ');
	insert into takes values('88577', '696', '1', 'Spring', 2002, 'C+');
	insert into takes values('42843', '415', '1', 'Fall', 2010, 'C-');
	insert into takes values('40937', '694', '1', 'Fall', 2002, 'A ');
	insert into takes values('31820', '319', '1', 'Spring', 2003, 'C+');
	insert into takes values('66356', '604', '1', 'Spring', 2009, 'B+');
	insert into takes values('92849', '443', '2', 'Spring', 2002, 'A+');
	insert into takes values('29462', '696', '1', 'Spring', 2002, 'B+');
	insert into takes values('29260', '486', '1', 'Fall', 2009, 'C+');
	insert into takes values('69581', '362', '1', 'Fall', 2005, 'C+');
	insert into takes values('82082', '696', '1', 'Spring', 2002, 'A ');
	insert into takes values('27044', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('21692', '334', '1', 'Fall', 2009, 'A ');
	insert into takes values('31080', '242', '1', 'Fall', 2009, 'C ');
	insert into takes values('83573', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('57238', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('38476', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('56', '400', '2', 'Fall', 2003, 'C+');
	insert into takes values('10204', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('99949', '604', '1', 'Spring', 2009, 'C ');
	insert into takes values('94990', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('27094', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('82974', '867', '2', 'Fall', 2010, 'A+');
	insert into takes values('499', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('36263', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('11126', '626', '1', 'Fall', 2006, 'C+');
	insert into takes values('75241', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('645', '679', '1', 'Spring', 2010, 'B ');
	insert into takes values('7973', '612', '1', 'Fall', 2007, 'A-');
	insert into takes values('91370', '421', '1', 'Fall', 2004, 'A-');
	insert into takes values('19048', '443', '2', 'Spring', 2002, 'B ');
	insert into takes values('2133', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('52203', '158', '2', 'Spring', 2008, 'C+');
	insert into takes values('48861', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('40481', '482', '1', 'Fall', 2005, 'A-');
	insert into takes values('17911', '559', '1', 'Fall', 2002, 'A-');
	insert into takes values('64169', '400', '2', 'Fall', 2003, 'B+');
	insert into takes values('78481', '581', '1', 'Spring', 2005, 'A+');
	insert into takes values('11195', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('80057', '962', '1', 'Spring', 2008, 'B ');
	insert into takes values('77898', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('3576', '426', '1', 'Spring', 2006, 'A-');
	insert into takes values('19245', '334', '1', 'Fall', 2009, 'B-');
	insert into takes values('993', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('67514', '735', '1', 'Spring', 2003, 'A-');
	insert into takes values('97551', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('46066', '571', '1', 'Spring', 2004, 'A+');
	insert into takes values('64249', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('18775', '949', '1', 'Fall', 2007, 'C ');
	insert into takes values('463', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('57941', '200', '1', 'Spring', 2007, 'B+');
	insert into takes values('38602', '972', '1', 'Spring', 2009, 'B+');
	insert into takes values('46106', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('68516', '158', '2', 'Spring', 2008, 'C+');
	insert into takes values('81175', '158', '2', 'Spring', 2008, 'B-');
	insert into takes values('64249', '457', '1', 'Spring', 2001, 'C+');
	insert into takes values('86753', '663', '1', 'Spring', 2005, 'C-');
	insert into takes values('50537', '704', '1', 'Spring', 2008, 'C-');
	insert into takes values('75547', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('80113', '581', '1', 'Spring', 2005, 'C-');
	insert into takes values('87785', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('98563', '362', '2', 'Fall', 2006, 'C-');
	insert into takes values('75791', '169', '2', 'Fall', 2002, 'B-');
	insert into takes values('22179', '169', '1', 'Spring', 2007, 'C+');
	insert into takes values('37818', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('27556', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('19791', '313', '1', 'Fall', 2010, 'A+');
	insert into takes values('58081', '974', '1', 'Fall', 2003, 'C ');
	insert into takes values('90814', '626', '1', 'Fall', 2006, 'A-');
	insert into takes values('15613', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('66229', '704', '1', 'Spring', 2008, 'C-');
	insert into takes values('83871', '376', '1', 'Fall', 2006, 'B ');
	insert into takes values('9084', '457', '1', 'Spring', 2001, 'B ');
	insert into takes values('24387', '376', '1', 'Fall', 2006, 'C ');
	insert into takes values('23439', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('43016', '445', '1', 'Spring', 2001, 'B-');
	insert into takes values('46769', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('66054', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('65703', '400', '2', 'Fall', 2003, 'B+');
	insert into takes values('95205', '748', '1', 'Fall', 2003, 'A-');
	insert into takes values('86552', '415', '1', 'Fall', 2010, 'B+');
	insert into takes values('35687', '960', '1', 'Fall', 2009, 'C-');
	insert into takes values('40937', '599', '1', 'Spring', 2003, 'C ');
	insert into takes values('41938', '400', '2', 'Fall', 2003, 'C-');
	insert into takes values('70965', '443', '2', 'Spring', 2002, 'A ');
	insert into takes values('66484', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('6673', '679', '1', 'Spring', 2010, 'B+');
	insert into takes values('28128', '793', '1', 'Spring', 2002, 'A-');
	insert into takes values('56212', '559', '1', 'Fall', 2002, 'B ');
	insert into takes values('66484', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('76250', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('30164', '581', '1', 'Spring', 2005, 'C ');
	insert into takes values('36244', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('89132', '604', '1', 'Spring', 2009, 'B+');
	insert into takes values('32130', '468', '2', 'Fall', 2007, 'A+');
	insert into takes values('86969', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('16523', '158', '1', 'Fall', 2008, 'A+');
	insert into takes values('30341', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('39472', '991', '1', 'Spring', 2008, 'C-');
	insert into takes values('62784', '457', '1', 'Spring', 2001, 'C ');
	insert into takes values('18499', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('51923', '791', '1', 'Spring', 2006, 'A-');
	insert into takes values('62054', '105', '2', 'Fall', 2002, 'A+');
	insert into takes values('8192', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('1000', '493', '1', 'Spring', 2010, 'A-');
	insert into takes values('37038', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('79210', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('108', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('31560', '735', '1', 'Spring', 2003, 'C+');
	insert into takes values('94766', '443', '1', 'Spring', 2010, 'B+');
	insert into takes values('94814', '702', '1', 'Spring', 2001, 'B-');
	insert into takes values('83953', '974', '1', 'Fall', 2003, 'B-');
	insert into takes values('97065', '612', '1', 'Fall', 2007, 'A+');
	insert into takes values('91132', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('55286', '527', '1', 'Fall', 2004, 'B-');
	insert into takes values('79210', '960', '1', 'Fall', 2009, 'A+');
	insert into takes values('74840', '237', '1', 'Spring', 2008, 'A+');
	insert into takes values('33460', '867', '1', 'Fall', 2006, 'C+');
	insert into takes values('5617', '237', '2', 'Fall', 2009, 'A-');
	insert into takes values('55857', '237', '2', 'Fall', 2009, 'C+');
	insert into takes values('14554', '237', '1', 'Spring', 2008, 'B ');
	insert into takes values('77289', '559', '1', 'Fall', 2002, 'C-');
	insert into takes values('68150', '408', '2', 'Spring', 2003, 'A+');
	insert into takes values('75794', '893', '1', 'Fall', 2007, 'B ');
	insert into takes values('5414', '457', '1', 'Spring', 2001, 'B ');
	insert into takes values('98423', '791', '1', 'Spring', 2006, 'C+');
	insert into takes values('95320', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('51817', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('43505', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('18821', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('45436', '457', '1', 'Spring', 2001, 'A-');
	insert into takes values('46928', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('32490', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('30858', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('2795', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('4860', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('89140', '893', '1', 'Fall', 2007, 'C+');
	insert into takes values('44551', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('52187', '704', '1', 'Spring', 2008, 'B ');
	insert into takes values('99949', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('78787', '362', '2', 'Fall', 2006, 'A ');
	insert into takes values('28952', '242', '1', 'Fall', 2009, 'B ');
	insert into takes values('32772', '242', '1', 'Fall', 2009, 'C ');
	insert into takes values('28989', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('72006', '376', '1', 'Fall', 2006, 'A-');
	insert into takes values('68554', '362', '1', 'Fall', 2005, 'B ');
	insert into takes values('14432', '545', '1', 'Fall', 2001, 'B ');
	insert into takes values('80610', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('29435', '694', '1', 'Fall', 2002, 'C+');
	insert into takes values('931', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('36845', '791', '1', 'Spring', 2006, 'A-');
	insert into takes values('38895', '747', '1', 'Spring', 2004, 'B+');
	insert into takes values('62749', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('13211', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('52371', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('45680', '960', '2', 'Fall', 2006, 'B-');
	insert into takes values('11237', '559', '1', 'Fall', 2002, 'C+');
	insert into takes values('79772', '242', '1', 'Fall', 2009, 'C+');
	insert into takes values('68999', '612', '1', 'Fall', 2007, 'B-');
	insert into takes values('93125', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('86641', '486', '1', 'Fall', 2009, 'C+');
	insert into takes values('71287', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('95626', '704', '1', 'Spring', 2008, 'C-');
	insert into takes values('59673', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('35175', '242', '1', 'Fall', 2009, 'A ');
	insert into takes values('39978', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('95320', '852', '1', 'Spring', 2008, 'C ');
	insert into takes values('71025', '795', '1', 'Spring', 2004, 'A-');
	insert into takes values('94620', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('88287', '468', '1', 'Fall', 2005, 'B-');
	insert into takes values('98359', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('931', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('14596', '239', '1', 'Fall', 2006, 'B ');
	insert into takes values('16480', '927', '1', 'Fall', 2002, 'C ');
	insert into takes values('792', '362', '3', 'Spring', 2008, 'A+');
	insert into takes values('78116', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('68712', '793', '1', 'Spring', 2002, 'C-');
	insert into takes values('95201', '571', '1', 'Spring', 2004, 'C ');
	insert into takes values('84495', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('78911', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('67293', '626', '1', 'Fall', 2006, 'B+');
	insert into takes values('33401', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('73394', '692', '1', 'Spring', 2010, 'C+');
	insert into takes values('62716', '313', '1', 'Fall', 2010, 'B+');
	insert into takes values('16528', '338', '2', 'Spring', 2006, 'A ');
	insert into takes values('52750', '242', '1', 'Fall', 2009, 'A-');
	insert into takes values('3039', '561', '1', 'Fall', 2006, 'A ');
	insert into takes values('23500', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('63243', '200', '1', 'Spring', 2007, 'C ');
	insert into takes values('45650', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('68150', '169', '2', 'Fall', 2002, 'B-');
	insert into takes values('7602', '242', '1', 'Fall', 2009, 'A-');
	insert into takes values('49450', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('47627', '304', '1', 'Fall', 2009, 'A+');
	insert into takes values('14065', '867', '1', 'Fall', 2006, 'A+');
	insert into takes values('92417', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('65205', '843', '1', 'Fall', 2010, 'C-');
	insert into takes values('1533', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('40738', '735', '2', 'Spring', 2010, 'B ');
	insert into takes values('21008', '604', '1', 'Spring', 2009, 'B-');
	insert into takes values('11855', '599', '1', 'Spring', 2003, 'C ');
	insert into takes values('7854', '445', '1', 'Spring', 2001, 'C ');
	insert into takes values('88389', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('57156', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('38548', '313', '1', 'Fall', 2010, 'C+');
	insert into takes values('24630', '237', '2', 'Fall', 2009, 'C ');
	insert into takes values('80420', '603', '1', 'Fall', 2003, 'C-');
	insert into takes values('59673', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('70061', '137', '1', 'Spring', 2002, 'A-');
	insert into takes values('94311', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('86674', '959', '1', 'Fall', 2006, 'A-');
	insert into takes values('38288', '334', '1', 'Fall', 2009, 'C ');
	insert into takes values('17924', '105', '2', 'Fall', 2002, 'A+');
	insert into takes values('37653', '270', '1', 'Spring', 2010, 'B-');
	insert into takes values('82591', '400', '1', 'Spring', 2007, 'A-');
	insert into takes values('94535', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('79911', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('52187', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('858', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('32385', '893', '1', 'Fall', 2007, 'B-');
	insert into takes values('82688', '612', '1', 'Fall', 2007, 'A ');
	insert into takes values('11195', '591', '1', 'Spring', 2005, 'A-');
	insert into takes values('41280', '334', '1', 'Fall', 2009, 'B+');
	insert into takes values('95225', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('64642', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('36881', '468', '2', 'Fall', 2007, 'C+');
	insert into takes values('26494', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('53172', '527', '1', 'Fall', 2004, 'B-');
	insert into takes values('13365', '663', '1', 'Spring', 2005, 'B ');
	insert into takes values('68330', '747', '1', 'Spring', 2004, 'C ');
	insert into takes values('30474', '200', '2', 'Fall', 2002, 'C-');
	insert into takes values('38668', '747', '1', 'Spring', 2004, 'A ');
	insert into takes values('13921', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('14639', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('70924', '400', '2', 'Fall', 2003, 'C-');
	insert into takes values('7973', '867', '1', 'Fall', 2006, 'B+');
	insert into takes values('24002', '237', '2', 'Fall', 2009, 'A-');
	insert into takes values('507', '735', '1', 'Spring', 2003, 'C ');
	insert into takes values('65703', '401', '1', 'Fall', 2003, 'A+');
	insert into takes values('39704', '237', '1', 'Spring', 2008, 'C+');
	insert into takes values('43912', '239', '1', 'Fall', 2006, 'C-');
	insert into takes values('58846', '927', '1', 'Fall', 2002, 'A+');
	insert into takes values('49982', '599', '1', 'Spring', 2003, 'A+');
	insert into takes values('14563', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('76246', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('79329', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('7149', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('65753', '192', '1', 'Fall', 2002, 'A+');
	insert into takes values('15283', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('65715', '791', '1', 'Spring', 2006, 'B+');
	insert into takes values('27727', '793', '1', 'Spring', 2002, 'A ');
	insert into takes values('72643', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('15249', '239', '1', 'Fall', 2006, 'C-');
	insert into takes values('68096', '192', '1', 'Fall', 2002, 'C ');
	insert into takes values('39204', '258', '1', 'Fall', 2007, 'B+');
	insert into takes values('90234', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('46260', '401', '1', 'Fall', 2003, 'B+');
	insert into takes values('41671', '258', '1', 'Fall', 2007, 'B-');
	insert into takes values('75547', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('40738', '313', '1', 'Fall', 2010, 'A+');
	insert into takes values('99754', '237', '2', 'Fall', 2009, 'B+');
	insert into takes values('43032', '793', '1', 'Spring', 2002, 'C+');
	insert into takes values('70384', '735', '2', 'Spring', 2010, 'A+');
	insert into takes values('88525', '496', '1', 'Fall', 2001, 'B+');
	insert into takes values('73807', '852', '1', 'Spring', 2008, 'B+');
	insert into takes values('36881', '791', '1', 'Spring', 2006, 'B+');
	insert into takes values('69758', '304', '1', 'Fall', 2009, 'B+');
	insert into takes values('72014', '760', '1', 'Spring', 2004, 'C-');
	insert into takes values('12666', '545', '1', 'Fall', 2001, 'A ');
	insert into takes values('83728', '972', '1', 'Spring', 2009, 'C-');
	insert into takes values('4248', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('34195', '927', '1', 'Fall', 2002, 'B-');
	insert into takes values('61414', '629', '1', 'Spring', 2003, 'A ');
	insert into takes values('86934', '960', '2', 'Fall', 2006, 'A ');
	insert into takes values('94815', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('18809', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('46441', '599', '1', 'Spring', 2003, 'B+');
	insert into takes values('56124', '591', '1', 'Spring', 2005, 'B ');
	insert into takes values('92864', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('35220', '867', '1', 'Fall', 2006, 'A ');
	insert into takes values('29091', '604', '1', 'Spring', 2009, 'B+');
	insert into takes values('92864', '105', '2', 'Fall', 2002, 'A ');
	insert into takes values('81150', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('77664', '237', '2', 'Fall', 2009, 'C+');
	insert into takes values('64249', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('75522', '927', '1', 'Fall', 2002, 'C-');
	insert into takes values('64550', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('66495', '415', '1', 'Fall', 2010, 'A+');
	insert into takes values('92849', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('19917', '345', '1', 'Spring', 2008, 'C ');
	insert into takes values('25068', '867', '2', 'Fall', 2010, 'C-');
	insert into takes values('96988', '468', '1', 'Fall', 2005, 'C ');
	insert into takes values('65753', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('99647', '612', '1', 'Fall', 2007, 'C ');
	insert into takes values('66495', '270', '1', 'Spring', 2010, 'C ');
	insert into takes values('99730', '137', '1', 'Spring', 2002, 'A ');
	insert into takes values('82688', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('10814', '527', '1', 'Fall', 2004, 'C+');
	insert into takes values('38895', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('25077', '400', '1', 'Spring', 2007, 'A+');
	insert into takes values('15144', '642', '1', 'Fall', 2004, 'B+');
	insert into takes values('90132', '875', '1', 'Spring', 2005, 'A+');
	insert into takes values('41261', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('58326', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('58889', '105', '2', 'Fall', 2002, 'A-');
	insert into takes values('24746', '559', '1', 'Fall', 2002, 'B ');
	insert into takes values('19321', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('57456', '468', '1', 'Fall', 2005, 'A ');
	insert into takes values('27043', '443', '1', 'Spring', 2010, 'B ');
	insert into takes values('98140', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('92693', '274', '1', 'Fall', 2002, 'B-');
	insert into takes values('163', '169', '2', 'Fall', 2002, 'B+');
	insert into takes values('15578', '349', '1', 'Spring', 2008, 'A ');
	insert into takes values('16969', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('68096', '802', '1', 'Spring', 2003, 'B+');
	insert into takes values('5250', '927', '1', 'Fall', 2002, 'A+');
	insert into takes values('78454', '270', '1', 'Spring', 2010, 'A+');
	insert into takes values('82083', '457', '1', 'Spring', 2001, 'B-');
	insert into takes values('61414', '362', '1', 'Fall', 2005, 'B ');
	insert into takes values('64155', '426', '1', 'Spring', 2006, 'C ');
	insert into takes values('95225', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('16523', '239', '1', 'Fall', 2006, 'B-');
	insert into takes values('61920', '338', '1', 'Spring', 2007, 'C ');
	insert into takes values('67017', '493', '1', 'Spring', 2010, 'C ');
	insert into takes values('85602', '972', '1', 'Spring', 2009, 'B-');
	insert into takes values('62429', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('43348', '545', '1', 'Fall', 2001, 'A+');
	insert into takes values('46337', '591', '1', 'Spring', 2005, 'C+');
	insert into takes values('28989', '338', '2', 'Spring', 2006, 'A ');
	insert into takes values('28994', '401', '1', 'Fall', 2003, 'A-');
	insert into takes values('25068', '137', '1', 'Spring', 2002, 'A ');
	insert into takes values('35462', '242', '1', 'Fall', 2009, 'C+');
	insert into takes values('59553', '200', '1', 'Spring', 2007, 'C ');
	insert into takes values('61444', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('53805', '457', '1', 'Spring', 2001, 'B+');
	insert into takes values('26147', '313', '1', 'Fall', 2010, 'B ');
	insert into takes values('28019', '864', '1', 'Spring', 2006, 'C-');
	insert into takes values('21395', '629', '1', 'Spring', 2003, 'A ');
	insert into takes values('89196', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('90181', '591', '1', 'Spring', 2005, 'A ');
	insert into takes values('5399', '581', '1', 'Spring', 2005, 'A ');
	insert into takes values('37734', '959', '1', 'Fall', 2006, 'C+');
	insert into takes values('40457', '270', '1', 'Spring', 2010, 'B-');
	insert into takes values('8957', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('73908', '927', '1', 'Fall', 2002, 'A-');
	insert into takes values('5243', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('91091', '400', '1', 'Spring', 2007, 'C ');
	insert into takes values('34158', '169', '2', 'Fall', 2002, 'C ');
	insert into takes values('17600', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('33791', '200', '2', 'Fall', 2002, 'B+');
	insert into takes values('93061', '237', '1', 'Spring', 2008, 'A+');
	insert into takes values('28361', '400', '2', 'Fall', 2003, 'A ');
	insert into takes values('89140', '482', '1', 'Fall', 2005, 'C ');
	insert into takes values('50267', '366', '1', 'Fall', 2005, 'C ');
	insert into takes values('50873', '696', '1', 'Spring', 2002, 'B ');
	insert into takes values('25525', '400', '2', 'Fall', 2003, 'A-');
	insert into takes values('51698', '808', '1', 'Fall', 2003, 'B ');
	insert into takes values('16075', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('6195', '476', '1', 'Fall', 2010, 'A ');
	insert into takes values('18740', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('5393', '476', '1', 'Fall', 2010, 'B+');
	insert into takes values('60688', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('78481', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('52371', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('14214', '760', '1', 'Spring', 2004, 'B+');
	insert into takes values('9514', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('86661', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('7020', '760', '1', 'Spring', 2004, 'C ');
	insert into takes values('34170', '457', '1', 'Spring', 2001, 'B ');
	insert into takes values('58469', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('64222', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('92442', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('53485', '591', '1', 'Spring', 2005, 'C-');
	insert into takes values('69471', '612', '1', 'Fall', 2007, 'B ');
	insert into takes values('57985', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('88287', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('45570', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('8912', '559', '1', 'Fall', 2002, 'C-');
	insert into takes values('43912', '457', '1', 'Spring', 2001, 'A+');
	insert into takes values('24796', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('57511', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('10834', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('10727', '802', '1', 'Spring', 2003, 'C-');
	insert into takes values('35462', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('89140', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('28989', '599', '1', 'Spring', 2003, 'A+');
	insert into takes values('2501', '334', '1', 'Fall', 2009, 'B-');
	insert into takes values('54875', '489', '1', 'Fall', 2007, 'C ');
	insert into takes values('31337', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('47630', '376', '1', 'Fall', 2006, 'B ');
	insert into takes values('1827', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('83728', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('16133', '468', '2', 'Fall', 2007, 'A-');
	insert into takes values('19220', '679', '1', 'Spring', 2010, 'A+');
	insert into takes values('16969', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('59290', '362', '2', 'Fall', 2006, 'C-');
	insert into takes values('20180', '631', '1', 'Spring', 2007, 'B+');
	insert into takes values('46970', '960', '2', 'Fall', 2006, 'C+');
	insert into takes values('2201', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('11262', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('18675', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('83686', '105', '1', 'Fall', 2009, 'C-');
	insert into takes values('43505', '793', '1', 'Spring', 2002, 'A+');
	insert into takes values('61737', '893', '1', 'Fall', 2007, 'A+');
	insert into takes values('41345', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('54728', '338', '1', 'Spring', 2007, 'A+');
	insert into takes values('61414', '875', '1', 'Spring', 2005, 'C-');
	insert into takes values('55859', '493', '1', 'Spring', 2010, 'A-');
	insert into takes values('85746', '893', '1', 'Fall', 2007, 'B-');
	insert into takes values('97953', '791', '1', 'Spring', 2006, 'A-');
	insert into takes values('19321', '476', '1', 'Fall', 2010, 'A+');
	insert into takes values('7620', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('71085', '802', '1', 'Spring', 2003, 'C-');
	insert into takes values('21692', '482', '1', 'Fall', 2005, 'A ');
	insert into takes values('93491', '237', '2', 'Fall', 2009, 'A ');
	insert into takes values('23794', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('81028', '875', '1', 'Spring', 2005, 'B+');
	insert into takes values('22260', '527', '1', 'Fall', 2004, 'B-');
	insert into takes values('21009', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('64259', '158', '2', 'Spring', 2008, 'C+');
	insert into takes values('36384', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('43505', '960', '2', 'Fall', 2006, 'B-');
	insert into takes values('68010', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('34392', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('34158', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('40897', '493', '1', 'Spring', 2010, 'C+');
	insert into takes values('74840', '527', '1', 'Fall', 2004, 'C-');
	insert into takes values('34331', '875', '1', 'Spring', 2005, 'B+');
	insert into takes values('76911', '362', '2', 'Fall', 2006, 'B-');
	insert into takes values('4582', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('79772', '696', '1', 'Spring', 2002, 'A ');
	insert into takes values('67660', '694', '1', 'Fall', 2002, 'C+');
	insert into takes values('67425', '629', '1', 'Spring', 2003, 'A ');
	insert into takes values('99977', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('76895', '443', '1', 'Spring', 2010, 'A ');
	insert into takes values('8843', '927', '1', 'Fall', 2002, 'A-');
	insert into takes values('13741', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('99719', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('69632', '599', '1', 'Spring', 2003, 'A ');
	insert into takes values('20378', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('1402', '476', '1', 'Fall', 2010, 'B ');
	insert into takes values('82039', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('78756', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('9256', '362', '1', 'Fall', 2005, 'C-');
	insert into takes values('8860', '679', '1', 'Spring', 2010, 'B+');
	insert into takes values('15487', '400', '2', 'Fall', 2003, 'B-');
	insert into takes values('58355', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('39927', '571', '1', 'Spring', 2004, 'C+');
	insert into takes values('96206', '972', '1', 'Spring', 2009, 'A ');
	insert into takes values('66279', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('92464', '493', '1', 'Spring', 2010, 'C ');
	insert into takes values('51008', '843', '1', 'Fall', 2010, 'A+');
	insert into takes values('9114', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('25552', '237', '1', 'Spring', 2008, 'C-');
	insert into takes values('97590', '893', '1', 'Fall', 2007, 'B+');
	insert into takes values('83511', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('62487', '735', '1', 'Spring', 2003, 'B-');
	insert into takes values('67660', '960', '1', 'Fall', 2009, 'A-');
	insert into takes values('41450', '376', '1', 'Fall', 2006, 'A ');
	insert into takes values('15144', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('5824', '468', '1', 'Fall', 2005, 'A-');
	insert into takes values('51549', '415', '1', 'Fall', 2010, 'C ');
	insert into takes values('27430', '735', '1', 'Spring', 2003, 'B-');
	insert into takes values('30334', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('97953', '468', '1', 'Fall', 2005, 'A+');
	insert into takes values('25528', '461', '1', 'Fall', 2002, 'C+');
	insert into takes values('57055', '366', '1', 'Fall', 2005, 'C ');
	insert into takes values('68395', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('83511', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('27044', '242', '1', 'Fall', 2009, 'B ');
	insert into takes values('91799', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('32483', '795', '1', 'Spring', 2004, 'B ');
	insert into takes values('79772', '875', '1', 'Spring', 2005, 'B-');
	insert into takes values('4034', '843', '1', 'Fall', 2010, 'A+');
	insert into takes values('78314', '270', '1', 'Spring', 2010, 'A+');
	insert into takes values('9514', '468', '2', 'Fall', 2007, 'C-');
	insert into takes values('42991', '679', '1', 'Spring', 2010, 'B-');
	insert into takes values('11855', '443', '2', 'Spring', 2002, 'A ');
	insert into takes values('32368', '443', '1', 'Spring', 2010, 'A+');
	insert into takes values('88993', '408', '2', 'Spring', 2003, 'C-');
	insert into takes values('22467', '421', '1', 'Fall', 2004, 'B+');
	insert into takes values('86375', '626', '1', 'Fall', 2006, 'C+');
	insert into takes values('25068', '158', '2', 'Spring', 2008, 'C ');
	insert into takes values('86707', '974', '1', 'Fall', 2003, 'A+');
	insert into takes values('64082', '408', '1', 'Spring', 2007, 'C ');
	insert into takes values('27556', '808', '1', 'Fall', 2003, 'B-');
	insert into takes values('16753', '972', '1', 'Spring', 2009, 'C-');
	insert into takes values('24374', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('92385', '476', '1', 'Fall', 2010, 'B+');
	insert into takes values('57156', '559', '1', 'Fall', 2002, 'B ');
	insert into takes values('81789', '679', '1', 'Spring', 2010, 'C+');
	insert into takes values('88525', '696', '1', 'Spring', 2002, 'B ');
	insert into takes values('82697', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('31079', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('19603', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('17339', '200', '2', 'Fall', 2002, 'C-');
	insert into takes values('4435', '545', '1', 'Fall', 2001, 'A-');
	insert into takes values('71287', '486', '1', 'Fall', 2009, 'B-');
	insert into takes values('25780', '105', '1', 'Fall', 2009, 'C+');
	insert into takes values('16907', '599', '1', 'Spring', 2003, 'A ');
	insert into takes values('20974', '362', '3', 'Spring', 2008, 'C-');
	insert into takes values('55859', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('43854', '237', '1', 'Spring', 2008, 'B-');
	insert into takes values('35685', '991', '1', 'Spring', 2008, 'B-');
	insert into takes values('63560', '972', '1', 'Spring', 2009, 'B ');
	insert into takes values('47379', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('31266', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('89551', '631', '1', 'Spring', 2007, 'C+');
	insert into takes values('9114', '962', '1', 'Spring', 2008, 'A+');
	insert into takes values('93171', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('95046', '972', '1', 'Spring', 2009, 'B-');
	insert into takes values('1110', '313', '1', 'Fall', 2010, 'A-');
	insert into takes values('2970', '692', '1', 'Spring', 2010, 'A-');
	insert into takes values('89106', '960', '2', 'Fall', 2006, 'B+');
	insert into takes values('31690', '626', '1', 'Fall', 2006, 'B-');
	insert into takes values('7732', '352', '1', 'Spring', 2006, 'C ');
	insert into takes values('33791', '352', '1', 'Spring', 2006, 'A-');
	insert into takes values('74070', '421', '1', 'Fall', 2004, 'A-');
	insert into takes values('27687', '169', '1', 'Spring', 2007, 'A ');
	insert into takes values('50206', '960', '1', 'Fall', 2009, 'B+');
	insert into takes values('58326', '408', '2', 'Spring', 2003, 'B-');
	insert into takes values('54622', '735', '2', 'Spring', 2010, 'C ');
	insert into takes values('15030', '591', '1', 'Spring', 2005, 'C+');
	insert into takes values('68096', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('47627', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('85614', '694', '1', 'Fall', 2002, 'B ');
	insert into takes values('87439', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('25780', '443', '2', 'Spring', 2002, 'A-');
	insert into takes values('65443', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('49611', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('336', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('71287', '169', '1', 'Spring', 2007, 'C+');
	insert into takes values('50719', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('7035', '345', '1', 'Spring', 2008, 'C+');
	insert into takes values('92849', '415', '1', 'Fall', 2010, 'C+');
	insert into takes values('42991', '169', '1', 'Spring', 2007, 'C ');
	insert into takes values('50719', '612', '1', 'Fall', 2007, 'C ');
	insert into takes values('53152', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('40481', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('96741', '760', '1', 'Spring', 2004, 'C-');
	insert into takes values('57123', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('15613', '237', '1', 'Spring', 2008, 'A-');
	insert into takes values('85445', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('19245', '603', '1', 'Fall', 2003, 'A ');
	insert into takes values('81785', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('48901', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('83462', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('70564', '960', '1', 'Fall', 2009, 'B+');
	insert into takes values('20002', '972', '1', 'Spring', 2009, 'A-');
	insert into takes values('57941', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('11419', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('32376', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('19861', '927', '1', 'Fall', 2002, 'C+');
	insert into takes values('29514', '258', '1', 'Fall', 2007, 'B-');
	insert into takes values('67657', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('88045', '696', '1', 'Spring', 2002, 'B-');
	insert into takes values('88993', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('32886', '493', '1', 'Spring', 2010, 'A+');
	insert into takes values('23457', '304', '1', 'Fall', 2009, 'A ');
	insert into takes values('22226', '599', '1', 'Spring', 2003, 'A ');
	insert into takes values('98619', '105', '1', 'Fall', 2009, 'C ');
	insert into takes values('65208', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('99348', '457', '1', 'Spring', 2001, 'C-');
	insert into takes values('64164', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('37339', '696', '1', 'Spring', 2002, 'B ');
	insert into takes values('76759', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('73492', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('75252', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('85754', '338', '1', 'Spring', 2007, 'B-');
	insert into takes values('57985', '626', '1', 'Fall', 2006, 'B+');
	insert into takes values('58307', '962', '1', 'Spring', 2008, 'A+');
	insert into takes values('72669', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('59539', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('463', '793', '1', 'Spring', 2002, 'A ');
	insert into takes values('39514', '875', '1', 'Spring', 2005, 'B+');
	insert into takes values('61354', '457', '1', 'Spring', 2001, 'A+');
	insert into takes values('16528', '527', '1', 'Fall', 2004, 'C-');
	insert into takes values('28352', '604', '1', 'Spring', 2009, 'B ');
	insert into takes values('45300', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('99760', '679', '1', 'Spring', 2010, 'A ');
	insert into takes values('6304', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('14499', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('78767', '962', '1', 'Spring', 2008, 'C-');
	insert into takes values('50013', '735', '2', 'Spring', 2010, 'C ');
	insert into takes values('5393', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('12666', '313', '1', 'Fall', 2010, 'B-');
	insert into takes values('59848', '105', '2', 'Fall', 2002, 'B-');
	insert into takes values('33791', '169', '2', 'Fall', 2002, 'B-');
	insert into takes values('89551', '972', '1', 'Spring', 2009, 'B-');
	insert into takes values('5243', '972', '1', 'Spring', 2009, 'A-');
	insert into takes values('25187', '631', '1', 'Spring', 2007, 'A ');
	insert into takes values('99451', '461', '1', 'Fall', 2002, 'C-');
	insert into takes values('35357', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('23449', '400', '1', 'Spring', 2007, 'A ');
	insert into takes values('62549', '158', '2', 'Spring', 2008, 'C+');
	insert into takes values('97953', '561', '1', 'Fall', 2006, 'C+');
	insert into takes values('36402', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('34502', '242', '1', 'Fall', 2009, 'C+');
	insert into takes values('29462', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('99268', '476', '1', 'Fall', 2010, 'A ');
	insert into takes values('68554', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('10693', '642', '1', 'Fall', 2004, 'B-');
	insert into takes values('57780', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('40178', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('1922', '972', '1', 'Spring', 2009, 'A+');
	insert into takes values('93508', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('85602', '843', '1', 'Fall', 2010, 'A+');
	insert into takes values('85575', '692', '1', 'Spring', 2010, 'C ');
	insert into takes values('90814', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('68999', '631', '1', 'Spring', 2007, 'A ');
	insert into takes values('64259', '482', '1', 'Fall', 2005, 'A ');
	insert into takes values('73165', '476', '1', 'Fall', 2010, 'A+');
	insert into takes values('8251', '421', '1', 'Fall', 2004, 'A-');
	insert into takes values('18859', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('77364', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('1018', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('64192', '334', '1', 'Fall', 2009, 'B ');
	insert into takes values('44551', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('987', '400', '1', 'Spring', 2007, 'A-');
	insert into takes values('66269', '893', '1', 'Fall', 2007, 'B-');
	insert into takes values('37449', '864', '1', 'Spring', 2006, 'B+');
	insert into takes values('85505', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('64039', '486', '1', 'Fall', 2009, 'B ');
	insert into takes values('77130', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('13826', '960', '1', 'Fall', 2009, 'B+');
	insert into takes values('92949', '274', '1', 'Fall', 2002, 'A+');
	insert into takes values('5617', '599', '1', 'Spring', 2003, 'A+');
	insert into takes values('89312', '735', '2', 'Spring', 2010, 'A ');
	insert into takes values('36303', '561', '1', 'Fall', 2006, 'C-');
	insert into takes values('13921', '663', '1', 'Spring', 2005, 'C ');
	insert into takes values('98563', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('70828', '867', '2', 'Fall', 2010, 'A-');
	insert into takes values('73908', '702', '1', 'Spring', 2001, 'B ');
	insert into takes values('69581', '242', '1', 'Fall', 2009, 'A+');
	insert into takes values('68396', '599', '1', 'Spring', 2003, 'B+');
	insert into takes values('13081', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('90181', '349', '1', 'Spring', 2008, 'A-');
	insert into takes values('51975', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('8343', '927', '1', 'Fall', 2002, 'A ');
	insert into takes values('53048', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('58081', '137', '1', 'Spring', 2002, 'A ');
	insert into takes values('36102', '852', '1', 'Spring', 2008, 'B-');
	insert into takes values('21337', '192', '1', 'Fall', 2002, 'B+');
	insert into takes values('39394', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('95175', '960', '2', 'Fall', 2006, 'A-');
	insert into takes values('77580', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('51549', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('52523', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('84704', '603', '1', 'Fall', 2003, 'C-');
	insert into takes values('56276', '599', '1', 'Spring', 2003, 'C ');
	insert into takes values('75231', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('78758', '974', '1', 'Fall', 2003, 'B-');
	insert into takes values('92274', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('37103', '338', '1', 'Spring', 2007, 'A+');
	insert into takes values('5617', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('24796', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('57538', '457', '1', 'Spring', 2001, 'A ');
	insert into takes values('25331', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('74460', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('34542', '338', '1', 'Spring', 2007, 'C-');
	insert into takes values('18367', '694', '1', 'Fall', 2002, 'A ');
	insert into takes values('75772', '468', '2', 'Fall', 2007, 'B ');
	insert into takes values('8140', '313', '1', 'Fall', 2010, 'B-');
	insert into takes values('37350', '960', '2', 'Fall', 2006, 'C ');
	insert into takes values('12216', '793', '1', 'Spring', 2002, 'A+');
	insert into takes values('50537', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('4383', '468', '1', 'Fall', 2005, 'B ');
	insert into takes values('39241', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('91799', '421', '1', 'Fall', 2004, 'B+');
	insert into takes values('69850', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('75794', '169', '2', 'Fall', 2002, 'C ');
	insert into takes values('93366', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('70384', '974', '1', 'Fall', 2003, 'A-');
	insert into takes values('22396', '313', '1', 'Fall', 2010, 'A ');
	insert into takes values('98690', '237', '1', 'Spring', 2008, 'A-');
	insert into takes values('86969', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('94311', '334', '1', 'Fall', 2009, 'B+');
	insert into takes values('95205', '991', '1', 'Spring', 2008, 'A ');
	insert into takes values('20985', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('98690', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('36657', '408', '2', 'Spring', 2003, 'C ');
	insert into takes values('64121', '735', '2', 'Spring', 2010, 'B-');
	insert into takes values('31476', '760', '1', 'Spring', 2004, 'C ');
	insert into takes values('45720', '192', '1', 'Fall', 2002, 'C ');
	insert into takes values('58846', '443', '1', 'Spring', 2010, 'B-');
	insert into takes values('64140', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('67660', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('56598', '864', '1', 'Spring', 2006, 'C+');
	insert into takes values('59908', '604', '1', 'Spring', 2009, 'A ');
	insert into takes values('34018', '426', '1', 'Spring', 2006, 'A-');
	insert into takes values('4015', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('88418', '362', '2', 'Fall', 2006, 'B-');
	insert into takes values('35257', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('92040', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('73908', '258', '1', 'Fall', 2007, 'C-');
	insert into takes values('84792', '105', '2', 'Fall', 2002, 'C-');
	insert into takes values('66090', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('29399', '960', '2', 'Fall', 2006, 'A ');
	insert into takes values('87048', '237', '2', 'Fall', 2009, 'C ');
	insert into takes values('86833', '692', '1', 'Spring', 2010, 'B-');
	insert into takes values('16480', '599', '1', 'Spring', 2003, 'B+');
	insert into takes values('40992', '795', '1', 'Spring', 2004, 'B+');
	insert into takes values('95859', '408', '1', 'Spring', 2007, 'C+');
	insert into takes values('75362', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('48471', '400', '1', 'Spring', 2007, 'A ');
	insert into takes values('75299', '158', '1', 'Fall', 2008, 'C ');
	insert into takes values('22142', '200', '2', 'Fall', 2002, 'B-');
	insert into takes values('54620', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('34322', '747', '1', 'Spring', 2004, 'C-');
	insert into takes values('21086', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('27919', '629', '1', 'Spring', 2003, 'B ');
	insert into takes values('80742', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('56882', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('35362', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('45720', '362', '1', 'Fall', 2005, 'C ');
	insert into takes values('36494', '581', '1', 'Spring', 2005, 'C-');
	insert into takes values('73807', '319', '1', 'Spring', 2003, 'B ');
	insert into takes values('52741', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('44304', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('96615', '864', '1', 'Spring', 2006, 'A ');
	insert into takes values('17339', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('33349', '631', '1', 'Spring', 2007, 'C-');
	insert into takes values('36494', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('36384', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('23457', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('5703', '476', '1', 'Fall', 2010, 'A ');
	insert into takes values('2629', '158', '1', 'Fall', 2008, 'A ');
	insert into takes values('61354', '604', '1', 'Spring', 2009, 'B-');
	insert into takes values('90082', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('88525', '158', '1', 'Fall', 2008, 'B+');
	insert into takes values('65715', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('14639', '334', '1', 'Fall', 2009, 'B+');
	insert into takes values('99694', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('17339', '137', '1', 'Spring', 2002, 'B+');
	insert into takes values('66753', '443', '1', 'Spring', 2010, 'B-');
	insert into takes values('31101', '443', '1', 'Spring', 2010, 'C+');
	insert into takes values('29959', '927', '1', 'Fall', 2002, 'C-');
	insert into takes values('827', '581', '1', 'Spring', 2005, 'A-');
	insert into takes values('54296', '802', '1', 'Spring', 2003, 'C-');
	insert into takes values('14639', '626', '1', 'Fall', 2006, 'B-');
	insert into takes values('31341', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('17665', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('56057', '400', '1', 'Spring', 2007, 'C ');
	insert into takes values('22345', '612', '1', 'Fall', 2007, 'B-');
	insert into takes values('83022', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('37521', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('62795', '599', '1', 'Spring', 2003, 'A ');
	insert into takes values('68395', '696', '1', 'Spring', 2002, 'A+');
	insert into takes values('75046', '591', '1', 'Spring', 2005, 'C+');
	insert into takes values('46980', '489', '1', 'Fall', 2007, 'C ');
	insert into takes values('41741', '679', '1', 'Spring', 2010, 'B+');
	insert into takes values('83573', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('87044', '313', '1', 'Fall', 2010, 'A ');
	insert into takes values('45720', '795', '1', 'Spring', 2004, 'A-');
	insert into takes values('66356', '696', '1', 'Spring', 2002, 'C-');
	insert into takes values('7498', '852', '1', 'Spring', 2008, 'B+');
	insert into takes values('93043', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('99553', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('93366', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('7732', '400', '1', 'Spring', 2007, 'B ');
	insert into takes values('89000', '545', '1', 'Fall', 2001, 'C ');
	insert into takes values('43123', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('5898', '642', '1', 'Fall', 2004, 'C+');
	insert into takes values('52157', '338', '1', 'Spring', 2007, 'A-');
	insert into takes values('2423', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('98047', '158', '2', 'Spring', 2008, 'A-');
	insert into takes values('43989', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('14094', '867', '1', 'Fall', 2006, 'B ');
	insert into takes values('17424', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('16885', '200', '2', 'Fall', 2002, 'A+');
	insert into takes values('73394', '334', '1', 'Fall', 2009, 'A-');
	insert into takes values('22226', '959', '1', 'Fall', 2006, 'A-');
	insert into takes values('19917', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('75547', '561', '1', 'Fall', 2006, 'B+');
	insert into takes values('34542', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('18675', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('68712', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('11419', '237', '1', 'Spring', 2008, 'B-');
	insert into takes values('1827', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('37653', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('1812', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('40080', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('61998', '612', '1', 'Fall', 2007, 'B ');
	insert into takes values('59908', '270', '1', 'Spring', 2010, 'A ');
	insert into takes values('41491', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('6895', '408', '2', 'Spring', 2003, 'B ');
	insert into takes values('19582', '401', '1', 'Fall', 2003, 'C-');
	insert into takes values('978', '629', '1', 'Spring', 2003, 'B ');
	insert into takes values('5243', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('90181', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('71768', '603', '1', 'Fall', 2003, 'B-');
	insert into takes values('16250', '735', '2', 'Spring', 2010, 'A-');
	insert into takes values('75123', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('15613', '468', '2', 'Fall', 2007, 'A+');
	insert into takes values('52076', '313', '1', 'Fall', 2010, 'C-');
	insert into takes values('23392', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('24325', '338', '1', 'Spring', 2007, 'A-');
	insert into takes values('79446', '603', '1', 'Fall', 2003, 'A ');
	insert into takes values('44703', '338', '2', 'Spring', 2006, 'A-');
	insert into takes values('29665', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('43016', '793', '1', 'Spring', 2002, 'C-');
	insert into takes values('23525', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('92464', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('53225', '169', '1', 'Spring', 2007, 'B-');
	insert into takes values('82974', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('32130', '169', '1', 'Spring', 2007, 'B ');
	insert into takes values('19450', '443', '2', 'Spring', 2002, 'B ');
	insert into takes values('65121', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('17339', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('18338', '200', '1', 'Spring', 2007, 'C-');
	insert into takes values('17997', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('16297', '237', '1', 'Spring', 2008, 'A+');
	insert into takes values('67146', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('90234', '237', '1', 'Spring', 2008, 'B-');
	insert into takes values('98120', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('96772', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('16885', '258', '1', 'Fall', 2007, 'C-');
	insert into takes values('70389', '105', '1', 'Fall', 2009, 'B ');
	insert into takes values('47379', '949', '1', 'Fall', 2007, 'C ');
	insert into takes values('34392', '486', '1', 'Fall', 2009, 'C ');
	insert into takes values('46155', '603', '1', 'Fall', 2003, 'B+');
	insert into takes values('80912', '603', '1', 'Fall', 2003, 'B-');
	insert into takes values('16907', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('28352', '445', '1', 'Spring', 2001, 'C+');
	insert into takes values('42688', '875', '1', 'Spring', 2005, 'A-');
	insert into takes values('99271', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('52385', '893', '1', 'Fall', 2007, 'A ');
	insert into takes values('98315', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('3576', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('59117', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('64550', '626', '1', 'Fall', 2006, 'B ');
	insert into takes values('14829', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('69850', '443', '2', 'Spring', 2002, 'A-');
	insert into takes values('81294', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('29863', '443', '2', 'Spring', 2002, 'A ');
	insert into takes values('35588', '169', '2', 'Fall', 2002, 'B ');
	insert into takes values('847', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('82688', '599', '1', 'Spring', 2003, 'B-');
	insert into takes values('16311', '468', '1', 'Fall', 2005, 'A ');
	insert into takes values('97551', '400', '2', 'Fall', 2003, 'B+');
	insert into takes values('83557', '694', '1', 'Fall', 2002, 'B-');
	insert into takes values('64039', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('86404', '493', '1', 'Spring', 2010, 'A ');
	insert into takes values('38973', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('94178', '443', '2', 'Spring', 2002, 'B-');
	insert into takes values('90082', '400', '1', 'Spring', 2007, 'C+');
	insert into takes values('84167', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('914', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('88045', '791', '1', 'Spring', 2006, 'A ');
	insert into takes values('58170', '105', '1', 'Fall', 2009, 'A+');
	insert into takes values('57238', '960', '1', 'Fall', 2009, 'B+');
	insert into takes values('8252', '962', '1', 'Spring', 2008, 'B-');
	insert into takes values('87222', '461', '1', 'Fall', 2002, 'C-');
	insert into takes values('78892', '237', '1', 'Spring', 2008, 'A-');
	insert into takes values('64164', '791', '1', 'Spring', 2006, 'C-');
	insert into takes values('94815', '443', '1', 'Spring', 2010, 'A-');
	insert into takes values('2419', '408', '1', 'Spring', 2007, 'B ');
	insert into takes values('3005', '795', '1', 'Spring', 2004, 'B+');
	insert into takes values('2139', '334', '1', 'Fall', 2009, 'A-');
	insert into takes values('2848', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('78481', '747', '1', 'Spring', 2004, 'C ');
	insert into takes values('10527', '843', '1', 'Fall', 2010, 'B+');
	insert into takes values('55940', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('29920', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('33651', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('62429', '692', '1', 'Spring', 2010, 'C-');
	insert into takes values('98315', '748', '1', 'Fall', 2003, 'B-');
	insert into takes values('96772', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('89140', '843', '1', 'Fall', 2010, 'A ');
	insert into takes values('69952', '408', '2', 'Spring', 2003, 'B ');
	insert into takes values('37449', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('41818', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('5414', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('914', '242', '1', 'Fall', 2009, 'C+');
	insert into takes values('21692', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('62487', '400', '1', 'Spring', 2007, 'A-');
	insert into takes values('29645', '200', '2', 'Fall', 2002, 'A-');
	insert into takes values('19638', '415', '1', 'Fall', 2010, 'C ');
	insert into takes values('18675', '795', '1', 'Spring', 2004, 'B-');
	insert into takes values('56', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('46436', '735', '1', 'Spring', 2003, 'C+');
	insert into takes values('58170', '561', '1', 'Fall', 2006, 'C+');
	insert into takes values('54296', '631', '1', 'Spring', 2007, 'A ');
	insert into takes values('51975', '604', '1', 'Spring', 2009, 'B-');
	insert into takes values('60040', '991', '1', 'Spring', 2008, 'A ');
	insert into takes values('28004', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('86375', '612', '1', 'Fall', 2007, 'B-');
	insert into takes values('16885', '366', '1', 'Fall', 2005, 'C-');
	insert into takes values('2178', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('41674', '169', '2', 'Fall', 2002, 'B+');
	insert into takes values('44881', '760', '1', 'Spring', 2004, 'B+');
	insert into takes values('67293', '400', '2', 'Fall', 2003, 'A-');
	insert into takes values('66356', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('87785', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('68453', '338', '1', 'Spring', 2007, 'A-');
	insert into takes values('86375', '927', '1', 'Fall', 2002, 'C+');
	insert into takes values('35198', '631', '1', 'Spring', 2007, 'B ');
	insert into takes values('99647', '626', '1', 'Fall', 2006, 'C ');
	insert into takes values('31079', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('62429', '334', '1', 'Fall', 2009, 'C-');
	insert into takes values('4182', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('58469', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('93571', '443', '2', 'Spring', 2002, 'C-');
	insert into takes values('93708', '747', '1', 'Spring', 2004, 'C-');
	insert into takes values('59553', '443', '1', 'Spring', 2010, 'B ');
	insert into takes values('19917', '443', '2', 'Spring', 2002, 'B-');
	insert into takes values('85910', '599', '1', 'Spring', 2003, 'B+');
	insert into takes values('64297', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('95089', '313', '1', 'Fall', 2010, 'B-');
	insert into takes values('91442', '349', '1', 'Spring', 2008, 'A-');
	insert into takes values('11152', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('48678', '345', '1', 'Spring', 2008, 'A+');
	insert into takes values('65121', '612', '1', 'Fall', 2007, 'B ');
	insert into takes values('52707', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('80227', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('74070', '991', '1', 'Spring', 2008, 'A ');
	insert into takes values('25256', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('94620', '345', '1', 'Spring', 2008, 'B ');
	insert into takes values('79502', '612', '1', 'Fall', 2007, 'B ');
	insert into takes values('5336', '972', '1', 'Spring', 2009, 'C-');
	insert into takes values('58874', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('92464', '237', '1', 'Spring', 2008, 'C+');
	insert into takes values('39552', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('69225', '237', '1', 'Spring', 2008, 'B-');
	insert into takes values('12979', '867', '2', 'Fall', 2010, 'A-');
	insert into takes values('57985', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('58081', '559', '1', 'Fall', 2002, 'C+');
	insert into takes values('58701', '258', '1', 'Fall', 2007, 'C+');
	insert into takes values('90448', '493', '1', 'Spring', 2010, 'A-');
	insert into takes values('95027', '400', '2', 'Fall', 2003, 'B-');
	insert into takes values('32506', '735', '1', 'Spring', 2003, 'C+');
	insert into takes values('50467', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('41299', '426', '1', 'Spring', 2006, 'C ');
	insert into takes values('22142', '702', '1', 'Spring', 2001, 'C+');
	insert into takes values('7035', '313', '1', 'Fall', 2010, 'C-');
	insert into takes values('1968', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('66495', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('34322', '496', '1', 'Fall', 2001, 'C ');
	insert into takes values('65329', '972', '1', 'Spring', 2009, 'C-');
	insert into takes values('37430', '239', '1', 'Fall', 2006, 'C+');
	insert into takes values('61356', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('20803', '599', '1', 'Spring', 2003, 'A ');
	insert into takes values('66293', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('68453', '242', '1', 'Fall', 2009, 'C+');
	insert into takes values('94697', '748', '1', 'Fall', 2003, 'C-');
	insert into takes values('50702', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('65056', '169', '2', 'Fall', 2002, 'B-');
	insert into takes values('93631', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('18234', '696', '1', 'Spring', 2002, 'A-');
	insert into takes values('76911', '457', '1', 'Spring', 2001, 'A+');
	insert into takes values('64164', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('8819', '527', '1', 'Fall', 2004, 'B+');
	insert into takes values('56486', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('89759', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('7854', '748', '1', 'Fall', 2003, 'A-');
	insert into takes values('83002', '972', '1', 'Spring', 2009, 'C-');
	insert into takes values('64013', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('80285', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('90381', '559', '1', 'Fall', 2002, 'A-');
	insert into takes values('31266', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('11966', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('21789', '702', '1', 'Spring', 2001, 'B ');
	insert into takes values('79589', '169', '2', 'Fall', 2002, 'A ');
	insert into takes values('29705', '362', '2', 'Fall', 2006, 'A-');
	insert into takes values('68516', '338', '2', 'Spring', 2006, 'B+');
	insert into takes values('94766', '735', '2', 'Spring', 2010, 'A-');
	insert into takes values('30397', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('15086', '426', '1', 'Spring', 2006, 'A-');
	insert into takes values('27140', '559', '1', 'Fall', 2002, 'A ');
	insert into takes values('56058', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('25068', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('18338', '545', '1', 'Fall', 2001, 'A+');
	insert into takes values('81984', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('17076', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('38555', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('74473', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('63449', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('41406', '334', '1', 'Fall', 2009, 'C-');
	insert into takes values('54620', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('85063', '400', '1', 'Spring', 2007, 'B+');
	insert into takes values('80285', '482', '1', 'Fall', 2005, 'A-');
	insert into takes values('3127', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('32369', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('71025', '408', '1', 'Spring', 2007, 'B ');
	insert into takes values('72177', '791', '1', 'Spring', 2006, 'B+');
	insert into takes values('89246', '642', '1', 'Fall', 2004, 'A-');
	insert into takes values('2177', '468', '2', 'Fall', 2007, 'C-');
	insert into takes values('40178', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('86674', '581', '1', 'Spring', 2005, 'A-');
	insert into takes values('65205', '239', '1', 'Fall', 2006, 'A-');
	insert into takes values('24197', '476', '1', 'Fall', 2010, 'A ');
	insert into takes values('42991', '747', '1', 'Spring', 2004, 'C ');
	insert into takes values('90082', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('81883', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('14639', '258', '1', 'Fall', 2007, 'B+');
	insert into takes values('14214', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('55915', '158', '2', 'Spring', 2008, 'B+');
	insert into takes values('57055', '626', '1', 'Fall', 2006, 'B-');
	insert into takes values('15883', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('59553', '237', '2', 'Fall', 2009, 'C ');
	insert into takes values('53803', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('69285', '959', '1', 'Fall', 2006, 'A ');
	insert into takes values('44206', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('52385', '493', '1', 'Spring', 2010, 'B+');
	insert into takes values('83686', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('71287', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('41261', '927', '1', 'Fall', 2002, 'B+');
	insert into takes values('70395', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('22226', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('57238', '239', '1', 'Fall', 2006, 'B-');
	insert into takes values('99780', '258', '1', 'Fall', 2007, 'C ');
	insert into takes values('62152', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('11152', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('89234', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('5381', '457', '1', 'Spring', 2001, 'A ');
	insert into takes values('35685', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('12078', '663', '1', 'Spring', 2005, 'A ');
	insert into takes values('35198', '747', '1', 'Spring', 2004, 'C ');
	insert into takes values('50873', '791', '1', 'Spring', 2006, 'C+');
	insert into takes values('23224', '603', '1', 'Fall', 2003, 'B ');
	insert into takes values('74639', '959', '1', 'Fall', 2006, 'B ');
	insert into takes values('40932', '489', '1', 'Fall', 2007, 'A-');
	insert into takes values('46725', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('67655', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('1533', '443', '2', 'Spring', 2002, 'B+');
	insert into takes values('83444', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('67018', '200', '2', 'Fall', 2002, 'A+');
	insert into takes values('29192', '599', '1', 'Spring', 2003, 'B+');
	insert into takes values('43016', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('31516', '496', '1', 'Fall', 2001, 'B-');
	insert into takes values('61783', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('49759', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('67146', '400', '1', 'Spring', 2007, 'A+');
	insert into takes values('44304', '704', '1', 'Spring', 2008, 'C ');
	insert into takes values('80057', '352', '1', 'Spring', 2006, 'A+');
	insert into takes values('50977', '443', '1', 'Spring', 2010, 'C+');
	insert into takes values('12615', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('90004', '345', '1', 'Spring', 2008, 'C-');
	insert into takes values('97953', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('94726', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('27804', '304', '1', 'Fall', 2009, 'B+');
	insert into takes values('2795', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('87280', '735', '1', 'Spring', 2003, 'B-');
	insert into takes values('50598', '867', '2', 'Fall', 2010, 'C ');
	insert into takes values('7498', '408', '1', 'Spring', 2007, 'C ');
	insert into takes values('74464', '663', '1', 'Spring', 2005, 'A-');
	insert into takes values('31560', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('49701', '362', '1', 'Fall', 2005, 'C ');
	insert into takes values('55170', '959', '1', 'Fall', 2006, 'A-');
	insert into takes values('30222', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('66106', '270', '1', 'Spring', 2010, 'C+');
	insert into takes values('13921', '867', '1', 'Fall', 2006, 'B ');
	insert into takes values('97435', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('18859', '468', '1', 'Fall', 2005, 'A ');
	insert into takes values('82082', '852', '1', 'Spring', 2008, 'B-');
	insert into takes values('32954', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('23992', '795', '1', 'Spring', 2004, 'B+');
	insert into takes values('37284', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('37946', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('71628', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('73186', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('18740', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('38476', '852', '1', 'Spring', 2008, 'B ');
	insert into takes values('5208', '105', '2', 'Fall', 2002, 'C-');
	insert into takes values('56058', '482', '1', 'Fall', 2005, 'C ');
	insert into takes values('6523', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('8457', '237', '2', 'Fall', 2009, 'C-');
	insert into takes values('41299', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('58469', '591', '1', 'Spring', 2005, 'A+');
	insert into takes values('9256', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('50944', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('10454', '679', '1', 'Spring', 2010, 'A ');
	insert into takes values('65901', '581', '1', 'Spring', 2005, 'A-');
	insert into takes values('83953', '559', '1', 'Fall', 2002, 'C+');
	insert into takes values('28004', '663', '1', 'Spring', 2005, 'B-');
	insert into takes values('26881', '591', '1', 'Spring', 2005, 'A+');
	insert into takes values('91799', '242', '1', 'Fall', 2009, 'A ');
	insert into takes values('78758', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('35198', '642', '1', 'Fall', 2004, 'B+');
	insert into takes values('36513', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('67310', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('27094', '561', '1', 'Fall', 2006, 'C ');
	insert into takes values('79352', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('544', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('21102', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('4645', '626', '1', 'Fall', 2006, 'B-');
	insert into takes values('50414', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('58307', '893', '1', 'Fall', 2007, 'A-');
	insert into takes values('9256', '352', '1', 'Spring', 2006, 'C ');
	insert into takes values('39521', '105', '2', 'Fall', 2002, 'A-');
	insert into takes values('34197', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('22618', '376', '1', 'Fall', 2006, 'A-');
	insert into takes values('99754', '692', '1', 'Spring', 2010, 'A ');
	insert into takes values('2561', '200', '2', 'Fall', 2002, 'C-');
	insert into takes values('97551', '612', '1', 'Fall', 2007, 'C ');
	insert into takes values('26080', '972', '1', 'Spring', 2009, 'A ');
	insert into takes values('5943', '468', '2', 'Fall', 2007, 'B ');
	insert into takes values('89000', '760', '1', 'Spring', 2004, 'B ');
	insert into takes values('9183', '679', '1', 'Spring', 2010, 'B-');
	insert into takes values('93653', '421', '1', 'Fall', 2004, 'A ');
	insert into takes values('9514', '345', '1', 'Spring', 2008, 'C-');
	insert into takes values('21126', '105', '1', 'Fall', 2009, 'A+');
	insert into takes values('88993', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('6710', '445', '1', 'Spring', 2001, 'B+');
	insert into takes values('47379', '748', '1', 'Fall', 2003, 'B-');
	insert into takes values('79352', '443', '2', 'Spring', 2002, 'A ');
	insert into takes values('11095', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('4682', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('30650', '338', '1', 'Spring', 2007, 'C+');
	insert into takes values('83398', '603', '1', 'Fall', 2003, 'B+');
	insert into takes values('44998', '338', '2', 'Spring', 2006, 'C ');
	insert into takes values('64259', '426', '1', 'Spring', 2006, 'A-');
	insert into takes values('282', '457', '1', 'Spring', 2001, 'B+');
	insert into takes values('29260', '802', '1', 'Spring', 2003, 'B+');
	insert into takes values('11095', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('12236', '679', '1', 'Spring', 2010, 'C-');
	insert into takes values('52385', '334', '1', 'Fall', 2009, 'C ');
	insert into takes values('39394', '599', '1', 'Spring', 2003, 'A+');
	insert into takes values('56057', '626', '1', 'Fall', 2006, 'A-');
	insert into takes values('23373', '735', '1', 'Spring', 2003, 'A-');
	insert into takes values('22345', '237', '2', 'Fall', 2009, 'B+');
	insert into takes values('34770', '421', '1', 'Fall', 2004, 'C+');
	insert into takes values('10663', '527', '1', 'Fall', 2004, 'C+');
	insert into takes values('26802', '304', '1', 'Fall', 2009, 'B+');
	insert into takes values('19917', '694', '1', 'Fall', 2002, 'A+');
	insert into takes values('19342', '239', '1', 'Fall', 2006, 'B-');
	insert into takes values('97953', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('86344', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('81884', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('18752', '376', '1', 'Fall', 2006, 'B-');
	insert into takes values('39514', '962', '1', 'Spring', 2008, 'A+');
	insert into takes values('19321', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('60984', '735', '1', 'Spring', 2003, 'A+');
	insert into takes values('65681', '631', '1', 'Spring', 2007, 'C-');
	insert into takes values('83204', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('51549', '468', '1', 'Fall', 2005, 'A ');
	insert into takes values('28352', '274', '1', 'Fall', 2002, 'B ');
	insert into takes values('19824', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('68263', '581', '1', 'Spring', 2005, 'C+');
	insert into takes values('16057', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('80285', '571', '1', 'Spring', 2004, 'C-');
	insert into takes values('24010', '443', '2', 'Spring', 2002, 'C+');
	insert into takes values('34018', '200', '2', 'Fall', 2002, 'A-');
	insert into takes values('3039', '158', '2', 'Spring', 2008, 'C+');
	insert into takes values('85234', '362', '1', 'Fall', 2005, 'C-');
	insert into takes values('75082', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('20002', '443', '2', 'Spring', 2002, 'B+');
	insert into takes values('41988', '169', '2', 'Fall', 2002, 'C ');
	insert into takes values('12214', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('30341', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('70572', '366', '1', 'Fall', 2005, 'A ');
	insert into takes values('50365', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('47126', '200', '1', 'Spring', 2007, 'C-');
	insert into takes values('23311', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('69960', '200', '2', 'Fall', 2002, 'A+');
	insert into takes values('89132', '591', '1', 'Spring', 2005, 'A+');
	insert into takes values('89188', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('94998', '376', '1', 'Fall', 2006, 'B ');
	insert into takes values('7149', '663', '1', 'Spring', 2005, 'C-');
	insert into takes values('98056', '482', '1', 'Fall', 2005, 'A ');
	insert into takes values('96710', '927', '1', 'Fall', 2002, 'C+');
	insert into takes values('72643', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('86641', '362', '3', 'Spring', 2008, 'C-');
	insert into takes values('39514', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('79589', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('34236', '962', '1', 'Spring', 2008, 'C+');
	insert into takes values('20099', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('1367', '352', '1', 'Spring', 2006, 'C+');
	insert into takes values('46769', '663', '1', 'Spring', 2005, 'B-');
	insert into takes values('87624', '239', '1', 'Fall', 2006, 'C-');
	insert into takes values('33201', '735', '1', 'Spring', 2003, 'C ');
	insert into takes values('64067', '237', '2', 'Fall', 2009, 'A ');
	insert into takes values('50664', '489', '1', 'Fall', 2007, 'C ');
	insert into takes values('31560', '599', '1', 'Spring', 2003, 'A-');
	insert into takes values('13511', '604', '1', 'Spring', 2009, 'B-');
	insert into takes values('83170', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('89393', '486', '1', 'Fall', 2009, 'A ');
	insert into takes values('1460', '493', '1', 'Spring', 2010, 'C-');
	insert into takes values('11194', '559', '1', 'Fall', 2002, 'A ');
	insert into takes values('27094', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('26080', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('5961', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('36263', '239', '1', 'Fall', 2006, 'C-');
	insert into takes values('69230', '274', '1', 'Fall', 2002, 'B ');
	insert into takes values('8957', '352', '1', 'Spring', 2006, 'C-');
	insert into takes values('68150', '642', '1', 'Fall', 2004, 'A-');
	insert into takes values('59172', '496', '1', 'Fall', 2001, 'B+');
	insert into takes values('68242', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('3335', '581', '1', 'Spring', 2005, 'C ');
	insert into takes values('45826', '468', '1', 'Fall', 2005, 'A-');
	insert into takes values('29849', '696', '1', 'Spring', 2002, 'A ');
	insert into takes values('38668', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('18286', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('74911', '561', '1', 'Fall', 2006, 'C ');
	insert into takes values('38973', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('78143', '400', '2', 'Fall', 2003, 'A+');
	insert into takes values('80047', '604', '1', 'Spring', 2009, 'A-');
	insert into takes values('11530', '476', '1', 'Fall', 2010, 'C ');
	insert into takes values('24442', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('7204', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('70918', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('28019', '852', '1', 'Spring', 2008, 'A-');
	insert into takes values('92867', '169', '1', 'Spring', 2007, 'B ');
	insert into takes values('17607', '105', '2', 'Fall', 2002, 'A+');
	insert into takes values('70452', '603', '1', 'Fall', 2003, 'C-');
	insert into takes values('31486', '319', '1', 'Spring', 2003, 'C+');
	insert into takes values('31266', '692', '1', 'Spring', 2010, 'A ');
	insert into takes values('48165', '468', '2', 'Fall', 2007, 'A-');
	insert into takes values('62487', '852', '1', 'Spring', 2008, 'B+');
	insert into takes values('88389', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('34170', '791', '1', 'Spring', 2006, 'A-');
	insert into takes values('28361', '158', '1', 'Fall', 2008, 'B-');
	insert into takes values('51549', '476', '1', 'Fall', 2010, 'A+');
	insert into takes values('59117', '962', '1', 'Spring', 2008, 'A ');
	insert into takes values('36052', '400', '1', 'Spring', 2007, 'B ');
	insert into takes values('77148', '559', '1', 'Fall', 2002, 'B+');
	insert into takes values('22620', '867', '1', 'Fall', 2006, 'A-');
	insert into takes values('16405', '345', '1', 'Spring', 2008, 'B-');
	insert into takes values('73908', '960', '2', 'Fall', 2006, 'A ');
	insert into takes values('67310', '626', '1', 'Fall', 2006, 'B-');
	insert into takes values('61065', '242', '1', 'Fall', 2009, 'B+');
	insert into takes values('53077', '237', '2', 'Fall', 2009, 'C ');
	insert into takes values('26473', '401', '1', 'Fall', 2003, 'C-');
	insert into takes values('26147', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('77580', '443', '1', 'Spring', 2010, 'A+');
	insert into takes values('73328', '793', '1', 'Spring', 2002, 'A-');
	insert into takes values('55531', '237', '1', 'Spring', 2008, 'C-');
	insert into takes values('80990', '631', '1', 'Spring', 2007, 'B ');
	insert into takes values('67021', '443', '2', 'Spring', 2002, 'C ');
	insert into takes values('30474', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('8251', '864', '1', 'Spring', 2006, 'C+');
	insert into takes values('4940', '692', '1', 'Spring', 2010, 'C+');
	insert into takes values('75241', '468', '1', 'Fall', 2005, 'B+');
	insert into takes values('85809', '696', '1', 'Spring', 2002, 'C-');
	insert into takes values('41261', '400', '2', 'Fall', 2003, 'A-');
	insert into takes values('16057', '959', '1', 'Fall', 2006, 'B+');
	insert into takes values('64820', '443', '2', 'Spring', 2002, 'B ');
	insert into takes values('80821', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('27043', '421', '1', 'Fall', 2004, 'B+');
	insert into takes values('87439', '663', '1', 'Spring', 2005, 'C-');
	insert into takes values('64138', '626', '1', 'Fall', 2006, 'C+');
	insert into takes values('13290', '893', '1', 'Fall', 2007, 'B ');
	insert into takes values('51817', '603', '1', 'Fall', 2003, 'B ');
	insert into takes values('86806', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('62749', '599', '1', 'Spring', 2003, 'B-');
	insert into takes values('58935', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('16297', '527', '1', 'Fall', 2004, 'B+');
	insert into takes values('8192', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('44038', '561', '1', 'Fall', 2006, 'C-');
	insert into takes values('31079', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('74070', '352', '1', 'Spring', 2006, 'A-');
	insert into takes values('32369', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('6729', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('58300', '468', '2', 'Fall', 2007, 'C-');
	insert into takes values('64945', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('7514', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('5144', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('13506', '679', '1', 'Spring', 2010, 'B-');
	insert into takes values('90353', '468', '2', 'Fall', 2007, 'A+');
	insert into takes values('58326', '242', '1', 'Fall', 2009, 'A-');
	insert into takes values('46074', '482', '1', 'Fall', 2005, 'B ');
	insert into takes values('30222', '105', '2', 'Fall', 2002, 'A+');
	insert into takes values('4582', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('463', '362', '1', 'Fall', 2005, 'C-');
	insert into takes values('34197', '457', '1', 'Spring', 2001, 'B-');
	insert into takes values('37586', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('44206', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('1884', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('27950', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('38712', '304', '1', 'Fall', 2009, 'C-');
	insert into takes values('87439', '927', '1', 'Fall', 2002, 'C ');
	insert into takes values('66090', '962', '1', 'Spring', 2008, 'B-');
	insert into takes values('12615', '408', '1', 'Spring', 2007, 'C ');
	insert into takes values('85849', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('67407', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('3335', '960', '1', 'Fall', 2009, 'B-');
	insert into takes values('86981', '421', '1', 'Fall', 2004, 'C ');
	insert into takes values('94846', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('78911', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('37219', '468', '2', 'Fall', 2007, 'A+');
	insert into takes values('55170', '258', '1', 'Fall', 2007, 'A+');
	insert into takes values('91370', '959', '1', 'Fall', 2006, 'B+');
	insert into takes values('47670', '105', '1', 'Fall', 2009, 'C ');
	insert into takes values('71543', '468', '2', 'Fall', 2007, 'A-');
	insert into takes values('30164', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('53077', '864', '1', 'Spring', 2006, 'B ');
	insert into takes values('4449', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('68453', '401', '1', 'Fall', 2003, 'C ');
	insert into takes values('21102', '843', '1', 'Fall', 2010, 'C+');
	insert into takes values('14869', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('61003', '443', '2', 'Spring', 2002, 'B ');
	insert into takes values('52750', '631', '1', 'Spring', 2007, 'A+');
	insert into takes values('63288', '793', '1', 'Spring', 2002, 'C ');
	insert into takes values('42092', '581', '1', 'Spring', 2005, 'C ');
	insert into takes values('33882', '571', '1', 'Spring', 2004, 'B+');
	insert into takes values('46694', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('46970', '493', '1', 'Spring', 2010, 'C-');
	insert into takes values('86934', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('2967', '457', '1', 'Spring', 2001, 'A+');
	insert into takes values('3639', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('37734', '169', '1', 'Spring', 2007, 'A-');
	insert into takes values('7043', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('71529', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('65901', '237', '2', 'Fall', 2009, 'C ');
	insert into takes values('96052', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('14499', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('62487', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('56143', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('66469', '237', '1', 'Spring', 2008, 'B ');
	insert into takes values('31079', '401', '1', 'Fall', 2003, 'C-');
	insert into takes values('53165', '137', '1', 'Spring', 2002, 'B ');
	insert into takes values('27430', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('18859', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('5336', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('37101', '400', '1', 'Spring', 2007, 'A ');
	insert into takes values('66259', '200', '2', 'Fall', 2002, 'A+');
	insert into takes values('30341', '158', '2', 'Spring', 2008, 'C-');
	insert into takes values('11201', '760', '1', 'Spring', 2004, 'B-');
	insert into takes values('4248', '476', '1', 'Fall', 2010, 'B ');
	insert into takes values('5824', '735', '1', 'Spring', 2003, 'C ');
	insert into takes values('33791', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('37581', '158', '2', 'Spring', 2008, 'B+');
	insert into takes values('34158', '482', '1', 'Fall', 2005, 'A+');
	insert into takes values('65433', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('82688', '496', '1', 'Fall', 2001, 'C ');
	insert into takes values('51084', '679', '1', 'Spring', 2010, 'C-');
	insert into takes values('9114', '852', '1', 'Spring', 2008, 'A ');
	insert into takes values('34404', '443', '2', 'Spring', 2002, 'A-');
	insert into takes values('50583', '105', '1', 'Fall', 2009, 'B ');
	insert into takes values('20489', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('5871', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('4508', '461', '1', 'Fall', 2002, 'B-');
	insert into takes values('94697', '489', '1', 'Fall', 2007, 'B+');
	insert into takes values('17397', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('95089', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('51862', '702', '1', 'Spring', 2001, 'B ');
	insert into takes values('49813', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('288', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('65901', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('67810', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('25331', '158', '1', 'Fall', 2008, 'C-');
	insert into takes values('53469', '461', '1', 'Fall', 2002, 'B ');
	insert into takes values('57538', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('16993', '408', '1', 'Spring', 2007, 'C ');
	insert into takes values('90814', '242', '1', 'Fall', 2009, 'C ');
	insert into takes values('77021', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('99268', '362', '1', 'Fall', 2005, 'C+');
	insert into takes values('66212', '443', '2', 'Spring', 2002, 'B+');
	insert into takes values('20803', '408', '1', 'Spring', 2007, 'C-');
	insert into takes values('70572', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('91799', '489', '1', 'Fall', 2007, 'C+');
	insert into takes values('93631', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('92659', '791', '1', 'Spring', 2006, 'B+');
	insert into takes values('75123', '629', '1', 'Spring', 2003, 'A ');
	insert into takes values('80651', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('19766', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('19048', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('27043', '242', '1', 'Fall', 2009, 'B+');
	insert into takes values('68720', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('66763', '137', '1', 'Spring', 2002, 'A+');
	insert into takes values('80821', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('76768', '604', '1', 'Spring', 2009, 'B ');
	insert into takes values('89234', '612', '1', 'Fall', 2007, 'A+');
	insert into takes values('96911', '401', '1', 'Fall', 2003, 'B+');
	insert into takes values('66281', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('35935', '893', '1', 'Fall', 2007, 'C ');
	insert into takes values('54508', '408', '1', 'Spring', 2007, 'C-');
	insert into takes values('68278', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('61414', '258', '1', 'Fall', 2007, 'B-');
	insert into takes values('58465', '875', '1', 'Spring', 2005, 'C-');
	insert into takes values('1836', '679', '1', 'Spring', 2010, 'B ');
	insert into takes values('97658', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('75547', '443', '2', 'Spring', 2002, 'A ');
	insert into takes values('66008', '237', '2', 'Fall', 2009, 'A-');
	insert into takes values('12069', '949', '1', 'Fall', 2007, 'C-');
	insert into takes values('78758', '258', '1', 'Fall', 2007, 'C+');
	insert into takes values('6195', '105', '1', 'Fall', 2009, 'B ');
	insert into takes values('96741', '486', '1', 'Fall', 2009, 'A-');
	insert into takes values('68263', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('8140', '591', '1', 'Spring', 2005, 'B ');
	insert into takes values('57026', '105', '2', 'Fall', 2002, 'A-');
	insert into takes values('60040', '702', '1', 'Spring', 2001, 'B-');
	insert into takes values('86736', '663', '1', 'Spring', 2005, 'C-');
	insert into takes values('4940', '242', '1', 'Fall', 2009, 'A-');
	insert into takes values('34502', '366', '1', 'Fall', 2005, 'B ');
	insert into takes values('65443', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('89759', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('4438', '867', '1', 'Fall', 2006, 'B ');
	insert into takes values('74163', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('6712', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('82039', '493', '1', 'Spring', 2010, 'C ');
	insert into takes values('97629', '599', '1', 'Spring', 2003, 'A-');
	insert into takes values('68779', '237', '1', 'Spring', 2008, 'B+');
	insert into takes values('61737', '793', '1', 'Spring', 2002, 'B ');
	insert into takes values('22057', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('69732', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('32217', '545', '1', 'Fall', 2001, 'C ');
	insert into takes values('20084', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('92839', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('63390', '468', '1', 'Fall', 2005, 'B ');
	insert into takes values('12326', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('10454', '496', '1', 'Fall', 2001, 'B ');
	insert into takes values('31516', '400', '1', 'Spring', 2007, 'A-');
	insert into takes values('48009', '808', '1', 'Fall', 2003, 'C ');
	insert into takes values('85234', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('17911', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('78332', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('80247', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('3833', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('25528', '408', '1', 'Spring', 2007, 'C+');
	insert into takes values('94620', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('69783', '852', '1', 'Spring', 2008, 'C+');
	insert into takes values('29031', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('87268', '735', '1', 'Spring', 2003, 'C-');
	insert into takes values('21692', '692', '1', 'Spring', 2010, 'A-');
	insert into takes values('33206', '591', '1', 'Spring', 2005, 'A-');
	insert into takes values('52120', '642', '1', 'Fall', 2004, 'C+');
	insert into takes values('48053', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('1220', '334', '1', 'Fall', 2009, 'A ');
	insert into takes values('95366', '974', '1', 'Fall', 2003, 'A-');
	insert into takes values('31554', '486', '1', 'Fall', 2009, 'B ');
	insert into takes values('46928', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('89196', '476', '1', 'Fall', 2010, 'C-');
	insert into takes values('72165', '612', '1', 'Fall', 2007, 'B-');
	insert into takes values('27043', '408', '2', 'Spring', 2003, 'A+');
	insert into takes values('62226', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('16480', '443', '2', 'Spring', 2002, 'A ');
	insert into takes values('25942', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('16057', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('15024', '692', '1', 'Spring', 2010, 'B+');
	insert into takes values('80248', '760', '1', 'Spring', 2004, 'B+');
	insert into takes values('83838', '239', '1', 'Fall', 2006, 'B-');
	insert into takes values('41741', '545', '1', 'Fall', 2001, 'A ');
	insert into takes values('10527', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('78787', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('29665', '345', '1', 'Spring', 2008, 'C ');
	insert into takes values('56', '443', '1', 'Spring', 2010, 'A+');
	insert into takes values('94324', '875', '1', 'Spring', 2005, 'A-');
	insert into takes values('88472', '408', '1', 'Spring', 2007, 'A+');
	insert into takes values('97590', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('89393', '735', '1', 'Spring', 2003, 'C+');
	insert into takes values('17086', '200', '2', 'Fall', 2002, 'A-');
	insert into takes values('79892', '631', '1', 'Spring', 2007, 'C-');
	insert into takes values('61065', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('46970', '352', '1', 'Spring', 2006, 'C-');
	insert into takes values('40059', '735', '2', 'Spring', 2010, 'A+');
	insert into takes values('88887', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('13880', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('19342', '415', '1', 'Fall', 2010, 'A-');
	insert into takes values('25940', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('18108', '760', '1', 'Spring', 2004, 'C-');
	insert into takes values('7861', '445', '1', 'Spring', 2001, 'C ');
	insert into takes values('62754', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('44206', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('56486', '400', '1', 'Spring', 2007, 'C+');
	insert into takes values('91442', '105', '2', 'Fall', 2002, 'A-');
	insert into takes values('26028', '864', '1', 'Spring', 2006, 'B+');
	insert into takes values('69752', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('19245', '169', '1', 'Spring', 2007, 'B-');
	insert into takes values('27236', '421', '1', 'Fall', 2004, 'B-');
	insert into takes values('93814', '200', '2', 'Fall', 2002, 'C+');
	insert into takes values('34392', '959', '1', 'Fall', 2006, 'A+');
	insert into takes values('92776', '702', '1', 'Spring', 2001, 'A-');
	insert into takes values('55915', '893', '1', 'Fall', 2007, 'C ');
	insert into takes values('47487', '696', '1', 'Spring', 2002, 'A ');
	insert into takes values('17057', '274', '1', 'Fall', 2002, 'C+');
	insert into takes values('99226', '991', '1', 'Spring', 2008, 'C-');
	insert into takes values('76743', '545', '1', 'Fall', 2001, 'A ');
	insert into takes values('67657', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('70061', '843', '1', 'Fall', 2010, 'A+');
	insert into takes values('36657', '927', '1', 'Fall', 2002, 'B-');
	insert into takes values('46066', '747', '1', 'Spring', 2004, 'A ');
	insert into takes values('67146', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('6673', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('80976', '237', '1', 'Spring', 2008, 'C-');
	insert into takes values('12711', '642', '1', 'Fall', 2004, 'A+');
	insert into takes values('39876', '349', '1', 'Spring', 2008, 'A-');
	insert into takes values('75513', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('17769', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('72055', '239', '1', 'Fall', 2006, 'C-');
	insert into takes values('42565', '408', '2', 'Spring', 2003, 'C ');
	insert into takes values('29514', '415', '1', 'Fall', 2010, 'C ');
	insert into takes values('85534', '468', '2', 'Fall', 2007, 'C-');
	insert into takes values('8022', '237', '1', 'Spring', 2008, 'A+');
	insert into takes values('70235', '875', '1', 'Spring', 2005, 'A+');
	insert into takes values('26080', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('58594', '461', '1', 'Fall', 2002, 'B-');
	insert into takes values('48589', '200', '1', 'Spring', 2007, 'B-');
	insert into takes values('85809', '960', '2', 'Fall', 2006, 'C+');
	insert into takes values('35175', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('54622', '704', '1', 'Spring', 2008, 'A+');
	insert into takes values('65038', '105', '2', 'Fall', 2002, 'B+');
	insert into takes values('8986', '867', '2', 'Fall', 2010, 'C-');
	insert into takes values('69730', '270', '1', 'Spring', 2010, 'C-');
	insert into takes values('41890', '867', '1', 'Fall', 2006, 'A+');
	insert into takes values('64401', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('3739', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('37454', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('21552', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('23392', '760', '1', 'Spring', 2004, 'B-');
	insert into takes values('14668', '237', '2', 'Fall', 2009, 'A-');
	insert into takes values('38602', '893', '1', 'Fall', 2007, 'A ');
	insert into takes values('1232', '489', '1', 'Fall', 2007, 'A-');
	insert into takes values('78332', '875', '1', 'Spring', 2005, 'C ');
	insert into takes values('435', '679', '1', 'Spring', 2010, 'C-');
	insert into takes values('83953', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('61356', '105', '2', 'Fall', 2002, 'A+');
	insert into takes values('85226', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('17944', '482', '1', 'Fall', 2005, 'A ');
	insert into takes values('8843', '642', '1', 'Fall', 2004, 'C+');
	insert into takes values('96911', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('78481', '443', '1', 'Spring', 2010, 'B+');
	insert into takes values('21394', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('76057', '258', '1', 'Fall', 2007, 'C-');
	insert into takes values('34055', '461', '1', 'Fall', 2002, 'C-');
	insert into takes values('99977', '362', '2', 'Fall', 2006, 'B-');
	insert into takes values('65438', '158', '1', 'Fall', 2008, 'C-');
	insert into takes values('26147', '137', '1', 'Spring', 2002, 'C-');
	insert into takes values('65987', '105', '1', 'Fall', 2009, 'B+');
	insert into takes values('80254', '169', '2', 'Fall', 2002, 'C ');
	insert into takes values('81245', '642', '1', 'Fall', 2004, 'A+');
	insert into takes values('6895', '852', '1', 'Spring', 2008, 'C ');
	insert into takes values('95366', '642', '1', 'Fall', 2004, 'A-');
	insert into takes values('28133', '875', '1', 'Spring', 2005, 'B-');
	insert into takes values('32506', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('40738', '748', '1', 'Fall', 2003, 'C ');
	insert into takes values('12941', '795', '1', 'Spring', 2004, 'A-');
	insert into takes values('52471', '362', '1', 'Fall', 2005, 'C-');
	insert into takes values('259', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('77364', '408', '2', 'Spring', 2003, 'B ');
	insert into takes values('5005', '527', '1', 'Fall', 2004, 'A-');
	insert into takes values('31442', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('99977', '270', '1', 'Spring', 2010, 'B-');
	insert into takes values('11682', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('29645', '192', '1', 'Fall', 2002, 'A+');
	insert into takes values('59117', '960', '2', 'Fall', 2006, 'C+');
	insert into takes values('4582', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('88085', '362', '3', 'Spring', 2008, 'B ');
	insert into takes values('54296', '760', '1', 'Spring', 2004, 'A ');
	insert into takes values('57538', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('2561', '313', '1', 'Fall', 2010, 'C+');
	insert into takes values('63310', '694', '1', 'Fall', 2002, 'A+');
	insert into takes values('56124', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('35462', '400', '2', 'Fall', 2003, 'C-');
	insert into takes values('21246', '443', '1', 'Spring', 2010, 'B+');
	insert into takes values('53451', '242', '1', 'Fall', 2009, 'B+');
	insert into takes values('96134', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('38696', '867', '2', 'Fall', 2010, 'C-');
	insert into takes values('67017', '426', '1', 'Spring', 2006, 'C ');
	insert into takes values('93814', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('73213', '362', '3', 'Spring', 2008, 'C+');
	insert into takes values('10204', '408', '2', 'Spring', 2003, 'C ');
	insert into takes values('22325', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('42991', '200', '1', 'Spring', 2007, 'A-');
	insert into takes values('29140', '242', '1', 'Fall', 2009, 'A+');
	insert into takes values('62636', '366', '1', 'Fall', 2005, 'C-');
	insert into takes values('72501', '482', '1', 'Fall', 2005, 'B ');
	insert into takes values('70235', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('32056', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('46970', '864', '1', 'Spring', 2006, 'C ');
	insert into takes values('66008', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('8517', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('98870', '599', '1', 'Spring', 2003, 'B ');
	insert into takes values('16631', '599', '1', 'Spring', 2003, 'C ');
	insert into takes values('1000', '972', '1', 'Spring', 2009, 'B+');
	insert into takes values('68395', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('18338', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('62749', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('33645', '415', '1', 'Fall', 2010, 'C ');
	insert into takes values('21337', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('108', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('20540', '421', '1', 'Fall', 2004, 'A ');
	insert into takes values('73206', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('94324', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('64820', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('45817', '338', '2', 'Spring', 2006, 'A-');
	insert into takes values('41091', '642', '1', 'Fall', 2004, 'A-');
	insert into takes values('7956', '962', '1', 'Spring', 2008, 'C-');
	insert into takes values('88887', '426', '1', 'Spring', 2006, 'C ');
	insert into takes values('99369', '408', '1', 'Spring', 2007, 'A ');
	insert into takes values('37946', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('76169', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('29002', '692', '1', 'Spring', 2010, 'C+');
	insert into takes values('5943', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('5703', '319', '1', 'Spring', 2003, 'B-');
	insert into takes values('58606', '696', '1', 'Spring', 2002, 'A+');
	insert into takes values('68554', '338', '2', 'Spring', 2006, 'A-');
	insert into takes values('73807', '612', '1', 'Fall', 2007, 'A ');
	insert into takes values('19791', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('75522', '421', '1', 'Fall', 2004, 'C ');
	insert into takes values('29260', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('78332', '200', '2', 'Fall', 2002, 'B-');
	insert into takes values('847', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('18554', '338', '1', 'Spring', 2007, 'C+');
	insert into takes values('15487', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('79487', '864', '1', 'Spring', 2006, 'B ');
	insert into takes values('85211', '663', '1', 'Spring', 2005, 'C+');
	insert into takes values('96772', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('12979', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('7498', '791', '1', 'Spring', 2006, 'B+');
	insert into takes values('90814', '461', '1', 'Fall', 2002, 'A-');
	insert into takes values('20985', '270', '1', 'Spring', 2010, 'C+');
	insert into takes values('41450', '443', '1', 'Spring', 2010, 'A-');
	insert into takes values('14621', '237', '2', 'Fall', 2009, 'C+');
	insert into takes values('97023', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('51203', '642', '1', 'Fall', 2004, 'B+');
	insert into takes values('10727', '400', '2', 'Fall', 2003, 'C-');
	insert into takes values('72485', '972', '1', 'Spring', 2009, 'C ');
	insert into takes values('88140', '545', '1', 'Fall', 2001, 'A+');
	insert into takes values('42565', '457', '1', 'Spring', 2001, 'A+');
	insert into takes values('85234', '692', '1', 'Spring', 2010, 'A-');
	insert into takes values('2561', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('3487', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('42956', '258', '1', 'Fall', 2007, 'C+');
	insert into takes values('49280', '242', '1', 'Fall', 2009, 'B ');
	insert into takes values('6523', '793', '1', 'Spring', 2002, 'A-');
	insert into takes values('77580', '192', '1', 'Fall', 2002, 'C ');
	insert into takes values('39619', '421', '1', 'Fall', 2004, 'C-');
	insert into takes values('60249', '959', '1', 'Fall', 2006, 'C+');
	insert into takes values('41261', '408', '1', 'Spring', 2007, 'C+');
	insert into takes values('85234', '242', '1', 'Fall', 2009, 'A+');
	insert into takes values('4004', '599', '1', 'Spring', 2003, 'B+');
	insert into takes values('34158', '338', '2', 'Spring', 2006, 'B+');
	insert into takes values('96324', '415', '1', 'Fall', 2010, 'C-');
	insert into takes values('51862', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('28538', '791', '1', 'Spring', 2006, 'A ');
	insert into takes values('32065', '493', '1', 'Spring', 2010, 'C-');
	insert into takes values('50969', '972', '1', 'Spring', 2009, 'B+');
	insert into takes values('31086', '274', '1', 'Fall', 2002, 'B ');
	insert into takes values('32245', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('25528', '421', '1', 'Fall', 2004, 'C ');
	insert into takes values('49244', '105', '1', 'Fall', 2009, 'C-');
	insert into takes values('40897', '400', '2', 'Fall', 2003, 'A-');
	insert into takes values('84039', '559', '1', 'Fall', 2002, 'B+');
	insert into takes values('62520', '679', '1', 'Spring', 2010, 'B+');
	insert into takes values('99710', '603', '1', 'Fall', 2003, 'B+');
	insert into takes values('81150', '486', '1', 'Fall', 2009, 'B-');
	insert into takes values('25718', '959', '1', 'Fall', 2006, 'B ');
	insert into takes values('65190', '867', '1', 'Fall', 2006, 'C+');
	insert into takes values('58326', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('25187', '735', '2', 'Spring', 2010, 'A+');
	insert into takes values('11101', '376', '1', 'Fall', 2006, 'C+');
	insert into takes values('20084', '242', '1', 'Fall', 2009, 'C ');
	insert into takes values('18809', '959', '1', 'Fall', 2006, 'B+');
	insert into takes values('53496', '962', '1', 'Spring', 2008, 'A+');
	insert into takes values('48901', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('90041', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('87054', '581', '1', 'Spring', 2005, 'B+');
	insert into takes values('3639', '408', '2', 'Spring', 2003, 'C+');
	insert into takes values('19293', '237', '1', 'Spring', 2008, 'B ');
	insert into takes values('90234', '960', '2', 'Fall', 2006, 'C+');
	insert into takes values('30177', '457', '1', 'Spring', 2001, 'C+');
	insert into takes values('77000', '496', '1', 'Fall', 2001, 'B ');
	insert into takes values('27727', '270', '1', 'Spring', 2010, 'A+');
	insert into takes values('69732', '242', '1', 'Fall', 2009, 'A+');
	insert into takes values('69581', '461', '1', 'Fall', 2002, 'B+');
	insert into takes values('68242', '735', '1', 'Spring', 2003, 'C ');
	insert into takes values('74070', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('43981', '415', '1', 'Fall', 2010, 'B-');
	insert into takes values('57334', '415', '1', 'Fall', 2010, 'B-');
	insert into takes values('70061', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('50743', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('60249', '867', '1', 'Fall', 2006, 'B ');
	insert into takes values('10076', '237', '1', 'Spring', 2008, 'A-');
	insert into takes values('37818', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('5017', '694', '1', 'Fall', 2002, 'C+');
	insert into takes values('31101', '603', '1', 'Fall', 2003, 'B+');
	insert into takes values('45436', '158', '1', 'Fall', 2008, 'C ');
	insert into takes values('64082', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('64082', '443', '2', 'Spring', 2002, 'C-');
	insert into takes values('71630', '137', '1', 'Spring', 2002, 'B+');
	insert into takes values('34788', '571', '1', 'Spring', 2004, 'A+');
	insert into takes values('91569', '457', '1', 'Spring', 2001, 'A+');
	insert into takes values('61065', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('2419', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('92442', '421', '1', 'Fall', 2004, 'C+');
	insert into takes values('98359', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('90663', '443', '1', 'Spring', 2010, 'C ');
	insert into takes values('43505', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('42960', '366', '1', 'Fall', 2005, 'C ');
	insert into takes values('41751', '489', '1', 'Fall', 2007, 'B ');
	insert into takes values('65714', '400', '1', 'Spring', 2007, 'C ');
	insert into takes values('79772', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('83136', '581', '1', 'Spring', 2005, 'A ');
	insert into takes values('82970', '352', '1', 'Spring', 2006, 'C ');
	insert into takes values('96246', '105', '2', 'Fall', 2002, 'C-');
	insert into takes values('30188', '927', '1', 'Fall', 2002, 'A ');
	insert into takes values('7620', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('21789', '408', '1', 'Spring', 2007, 'A ');
	insert into takes values('46260', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('74672', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('91992', '158', '1', 'Fall', 2008, 'C ');
	insert into takes values('12173', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('45359', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('28738', '366', '1', 'Fall', 2005, 'A ');
	insert into takes values('42625', '401', '1', 'Fall', 2003, 'A+');
	insert into takes values('19848', '482', '1', 'Fall', 2005, 'A-');
	insert into takes values('32483', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('52057', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('82066', '735', '2', 'Spring', 2010, 'A ');
	insert into takes values('16528', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('83398', '401', '1', 'Fall', 2003, 'A ');
	insert into takes values('79210', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('58634', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('41675', '626', '1', 'Fall', 2006, 'A-');
	insert into takes values('18367', '334', '1', 'Fall', 2009, 'A-');
	insert into takes values('75231', '808', '1', 'Fall', 2003, 'B-');
	insert into takes values('1402', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('10527', '426', '1', 'Spring', 2006, 'A-');
	insert into takes values('56276', '702', '1', 'Spring', 2001, 'B ');
	insert into takes values('90004', '313', '1', 'Fall', 2010, 'B+');
	insert into takes values('80610', '270', '1', 'Spring', 2010, 'C+');
	insert into takes values('99780', '696', '1', 'Spring', 2002, 'B ');
	insert into takes values('23224', '694', '1', 'Fall', 2002, 'B ');
	insert into takes values('52707', '496', '1', 'Fall', 2001, 'C ');
	insert into takes values('27236', '334', '1', 'Fall', 2009, 'B ');
	insert into takes values('35721', '476', '1', 'Fall', 2010, 'A-');
	insert into takes values('48776', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('73542', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('90609', '974', '1', 'Fall', 2003, 'C-');
	insert into takes values('108', '105', '2', 'Fall', 2002, 'B+');
	insert into takes values('16250', '345', '1', 'Spring', 2008, 'B-');
	insert into takes values('92949', '400', '1', 'Spring', 2007, 'B ');
	insert into takes values('48589', '443', '1', 'Spring', 2010, 'B-');
	insert into takes values('6367', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('5393', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('43130', '421', '1', 'Fall', 2004, 'A-');
	insert into takes values('63860', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('92703', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('8603', '802', '1', 'Spring', 2003, 'C+');
	insert into takes values('61527', '960', '1', 'Fall', 2009, 'A-');
	insert into takes values('49073', '791', '1', 'Spring', 2006, 'C-');
	insert into takes values('67293', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('52076', '631', '1', 'Spring', 2007, 'B+');
	insert into takes values('14484', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('14032', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('66106', '169', '2', 'Fall', 2002, 'A-');
	insert into takes values('10454', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('77244', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('35905', '702', '1', 'Spring', 2001, 'C+');
	insert into takes values('65056', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('95953', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('24197', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('90609', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('52750', '559', '1', 'Fall', 2002, 'C-');
	insert into takes values('92659', '545', '1', 'Fall', 2001, 'A+');
	insert into takes values('51008', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('41751', '258', '1', 'Fall', 2007, 'C-');
	insert into takes values('90372', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('44881', '493', '1', 'Spring', 2010, 'A ');
	insert into takes values('13749', '258', '1', 'Fall', 2007, 'A-');
	insert into takes values('18752', '493', '1', 'Spring', 2010, 'C-');
	insert into takes values('31993', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('51238', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('23500', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('68999', '864', '1', 'Spring', 2006, 'C-');
	insert into takes values('10481', '696', '1', 'Spring', 2002, 'C ');
	insert into takes values('18675', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('55000', '591', '1', 'Spring', 2005, 'A-');
	insert into takes values('78454', '642', '1', 'Fall', 2004, 'C+');
	insert into takes values('8603', '843', '1', 'Fall', 2010, 'A ');
	insert into takes values('3335', '561', '1', 'Fall', 2006, 'C-');
	insert into takes values('22057', '400', '1', 'Spring', 2007, 'B+');
	insert into takes values('2561', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('82970', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('72528', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('48611', '461', '1', 'Fall', 2002, 'A-');
	insert into takes values('55238', '362', '2', 'Fall', 2006, 'A-');
	insert into takes values('98120', '642', '1', 'Fall', 2004, 'B-');
	insert into takes values('2848', '735', '2', 'Spring', 2010, 'B-');
	insert into takes values('63860', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('35905', '443', '2', 'Spring', 2002, 'C-');
	insert into takes values('45570', '626', '1', 'Fall', 2006, 'B-');
	insert into takes values('59517', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('61065', '962', '1', 'Spring', 2008, 'C+');
	insert into takes values('52187', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('90089', '843', '1', 'Fall', 2010, 'A+');
	insert into takes values('74974', '401', '1', 'Fall', 2003, 'B+');
	insert into takes values('64938', '893', '1', 'Fall', 2007, 'C+');
	insert into takes values('42114', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('72669', '400', '1', 'Spring', 2007, 'A ');
	insert into takes values('25528', '875', '1', 'Spring', 2005, 'B-');
	insert into takes values('90234', '527', '1', 'Fall', 2004, 'C ');
	insert into takes values('1087', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('898', '468', '1', 'Fall', 2005, 'A+');
	insert into takes values('26473', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('91442', '401', '1', 'Fall', 2003, 'A+');
	insert into takes values('10904', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('11966', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('11530', '864', '1', 'Spring', 2006, 'C-');
	insert into takes values('58170', '461', '1', 'Fall', 2002, 'C+');
	insert into takes values('95626', '927', '1', 'Fall', 2002, 'B-');
	insert into takes values('83557', '468', '2', 'Fall', 2007, 'B ');
	insert into takes values('9993', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('57538', '200', '1', 'Spring', 2007, 'A ');
	insert into takes values('59848', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('42565', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('1018', '158', '1', 'Fall', 2008, 'A-');
	insert into takes values('5703', '468', '2', 'Fall', 2007, 'A+');
	insert into takes values('89051', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('65715', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('98940', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('8819', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('63289', '793', '1', 'Spring', 2002, 'C+');
	insert into takes values('8192', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('85981', '867', '1', 'Fall', 2006, 'C+');
	insert into takes values('163', '443', '1', 'Spring', 2010, 'C ');
	insert into takes values('5393', '612', '1', 'Fall', 2007, 'B ');
	insert into takes values('56212', '760', '1', 'Spring', 2004, 'A-');
	insert into takes values('28361', '415', '1', 'Fall', 2010, 'C+');
	insert into takes values('36402', '561', '1', 'Fall', 2006, 'A ');
	insert into takes values('842', '169', '2', 'Fall', 2002, 'B+');
	insert into takes values('66259', '972', '1', 'Spring', 2009, 'C-');
	insert into takes values('51416', '274', '1', 'Fall', 2002, 'B ');
	insert into takes values('44836', '415', '1', 'Fall', 2010, 'B-');
	insert into takes values('82687', '200', '1', 'Spring', 2007, 'A+');
	insert into takes values('65433', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('17676', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('61364', '795', '1', 'Spring', 2004, 'A-');
	insert into takes values('1812', '237', '1', 'Spring', 2008, 'B+');
	insert into takes values('48247', '489', '1', 'Fall', 2007, 'B+');
	insert into takes values('66281', '581', '1', 'Spring', 2005, 'A-');
	insert into takes values('91569', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('10705', '959', '1', 'Fall', 2006, 'A-');
	insert into takes values('73186', '571', '1', 'Spring', 2004, 'A+');
	insert into takes values('14874', '457', '1', 'Spring', 2001, 'A+');
	insert into takes values('67017', '599', '1', 'Spring', 2003, 'A+');
	insert into takes values('59908', '991', '1', 'Spring', 2008, 'B ');
	insert into takes values('5208', '237', '1', 'Spring', 2008, 'A-');
	insert into takes values('70807', '927', '1', 'Fall', 2002, 'B-');
	insert into takes values('82868', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('65038', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('61403', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('74796', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('35685', '629', '1', 'Spring', 2003, 'B-');
	insert into takes values('76743', '599', '1', 'Spring', 2003, 'B ');
	insert into takes values('8252', '415', '1', 'Fall', 2010, 'B-');
	insert into takes values('32772', '663', '1', 'Spring', 2005, 'A ');
	insert into takes values('78911', '599', '1', 'Spring', 2003, 'A+');
	insert into takes values('90041', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('68330', '258', '1', 'Fall', 2007, 'A+');
	insert into takes values('60762', '169', '2', 'Fall', 2002, 'A+');
	insert into takes values('39521', '679', '1', 'Spring', 2010, 'C+');
	insert into takes values('38973', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('83686', '760', '1', 'Spring', 2004, 'C+');
	insert into takes values('64820', '476', '1', 'Fall', 2010, 'A+');
	insert into takes values('17600', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('30943', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('15249', '192', '1', 'Fall', 2002, 'A+');
	insert into takes values('70359', '702', '1', 'Spring', 2001, 'C-');
	insert into takes values('19861', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('30164', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('87651', '443', '2', 'Spring', 2002, 'B+');
	insert into takes values('60249', '239', '1', 'Fall', 2006, 'A-');
	insert into takes values('26080', '527', '1', 'Fall', 2004, 'A-');
	insert into takes values('58170', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('2139', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('74796', '893', '1', 'Fall', 2007, 'A-');
	insert into takes values('66229', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('94311', '493', '1', 'Spring', 2010, 'B ');
	insert into takes values('53803', '791', '1', 'Spring', 2006, 'A ');
	insert into takes values('7970', '338', '1', 'Spring', 2007, 'C+');
	insert into takes values('7620', '972', '1', 'Spring', 2009, 'A ');
	insert into takes values('11202', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('3833', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('99780', '401', '1', 'Fall', 2003, 'A-');
	insert into takes values('21008', '237', '2', 'Fall', 2009, 'C-');
	insert into takes values('14869', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('32419', '960', '1', 'Fall', 2009, 'A+');
	insert into takes values('23311', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('80698', '443', '1', 'Spring', 2010, 'B+');
	insert into takes values('39978', '629', '1', 'Spring', 2003, 'A ');
	insert into takes values('82591', '696', '1', 'Spring', 2002, 'C-');
	insert into takes values('34331', '338', '1', 'Spring', 2007, 'B ');
	insert into takes values('97023', '527', '1', 'Fall', 2004, 'B-');
	insert into takes values('76953', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('10917', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('827', '319', '1', 'Spring', 2003, 'C+');
	insert into takes values('1727', '927', '1', 'Fall', 2002, 'B-');
	insert into takes values('9256', '599', '1', 'Spring', 2003, 'B-');
	insert into takes values('39521', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('65714', '974', '1', 'Fall', 2003, 'C-');
	insert into takes values('4355', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('2970', '867', '1', 'Fall', 2006, 'A ');
	insert into takes values('77898', '802', '1', 'Spring', 2003, 'A+');
	insert into takes values('58081', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('13290', '408', '1', 'Spring', 2007, 'A-');
	insert into takes values('72669', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('99754', '760', '1', 'Spring', 2004, 'C+');
	insert into takes values('59530', '559', '1', 'Fall', 2002, 'A ');
	insert into takes values('507', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('67793', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('16849', '959', '1', 'Fall', 2006, 'C+');
	insert into takes values('87831', '599', '1', 'Spring', 2003, 'B-');
	insert into takes values('50331', '696', '1', 'Spring', 2002, 'B-');
	insert into takes values('69285', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('84704', '626', '1', 'Fall', 2006, 'A ');
	insert into takes values('45436', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('7020', '735', '1', 'Spring', 2003, 'A ');
	insert into takes values('92693', '760', '1', 'Spring', 2004, 'B+');
	insert into takes values('53424', '591', '1', 'Spring', 2005, 'A-');
	insert into takes values('70310', '426', '1', 'Spring', 2006, 'C ');
	insert into takes values('89140', '169', '1', 'Spring', 2007, 'A ');
	insert into takes values('21395', '242', '1', 'Fall', 2009, 'A ');
	insert into takes values('56212', '679', '1', 'Spring', 2010, 'A ');
	insert into takes values('20445', '748', '1', 'Fall', 2003, 'B ');
	insert into takes values('931', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('6990', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('71630', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('22532', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('83557', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('94142', '482', '1', 'Fall', 2005, 'A-');
	insert into takes values('19917', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('15430', '270', '1', 'Spring', 2010, 'C-');
	insert into takes values('63860', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('19848', '642', '1', 'Fall', 2004, 'B-');
	insert into takes values('41211', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('760', '581', '1', 'Spring', 2005, 'C ');
	insert into takes values('42565', '366', '1', 'Fall', 2005, 'C-');
	insert into takes values('5336', '457', '1', 'Spring', 2001, 'C+');
	insert into takes values('32954', '559', '1', 'Fall', 2002, 'B ');
	insert into takes values('75938', '105', '1', 'Fall', 2009, 'B-');
	insert into takes values('463', '631', '1', 'Spring', 2007, 'C-');
	insert into takes values('78581', '482', '1', 'Fall', 2005, 'A-');
	insert into takes values('61003', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('71426', '629', '1', 'Spring', 2003, 'C ');
	insert into takes values('21101', '415', '1', 'Fall', 2010, 'A-');
	insert into takes values('26080', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('77172', '972', '1', 'Spring', 2009, 'A ');
	insert into takes values('46155', '270', '1', 'Spring', 2010, 'C+');
	insert into takes values('16347', '793', '1', 'Spring', 2002, 'B+');
	insert into takes values('81566', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('96968', '696', '1', 'Spring', 2002, 'A-');
	insert into takes values('1110', '581', '1', 'Spring', 2005, 'A ');
	insert into takes values('13352', '696', '1', 'Spring', 2002, 'A-');
	insert into takes values('99730', '105', '2', 'Fall', 2002, 'B+');
	insert into takes values('27017', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('7620', '489', '1', 'Fall', 2007, 'A ');
	insert into takes values('43211', '893', '1', 'Fall', 2007, 'B-');
	insert into takes values('28994', '482', '1', 'Fall', 2005, 'A ');
	insert into takes values('78454', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('64550', '599', '1', 'Spring', 2003, 'A+');
	insert into takes values('11966', '599', '1', 'Spring', 2003, 'C ');
	insert into takes values('35042', '631', '1', 'Spring', 2007, 'B+');
	insert into takes values('30110', '735', '1', 'Spring', 2003, 'C-');
	insert into takes values('95046', '974', '1', 'Fall', 2003, 'C ');
	insert into takes values('93508', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('31442', '793', '1', 'Spring', 2002, 'C-');
	insert into takes values('13741', '793', '1', 'Spring', 2002, 'C ');
	insert into takes values('15083', '443', '1', 'Spring', 2010, 'A+');
	insert into takes values('87222', '421', '1', 'Fall', 2004, 'C ');
	insert into takes values('77218', '408', '2', 'Spring', 2003, 'B ');
	insert into takes values('20195', '793', '1', 'Spring', 2002, 'C+');
	insert into takes values('46155', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('55238', '991', '1', 'Spring', 2008, 'A-');
	insert into takes values('52750', '974', '1', 'Fall', 2003, 'B ');
	insert into takes values('93125', '237', '1', 'Spring', 2008, 'C-');
	insert into takes values('99719', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('47126', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('51817', '415', '1', 'Fall', 2010, 'C-');
	insert into takes values('5898', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('52187', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('87784', '105', '1', 'Fall', 2009, 'C-');
	insert into takes values('31266', '362', '2', 'Fall', 2006, 'C-');
	insert into takes values('10481', '960', '1', 'Fall', 2009, 'A+');
	insert into takes values('63361', '612', '1', 'Fall', 2007, 'C ');
	insert into takes values('58355', '408', '1', 'Spring', 2007, 'C-');
	insert into takes values('44703', '793', '1', 'Spring', 2002, 'A+');
	insert into takes values('81566', '421', '1', 'Fall', 2004, 'A+');
	insert into takes values('62716', '200', '1', 'Spring', 2007, 'A+');
	insert into takes values('91370', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('77415', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('78858', '169', '1', 'Spring', 2007, 'B+');
	insert into takes values('20445', '493', '1', 'Spring', 2010, 'A-');
	insert into takes values('66106', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('44584', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('64642', '843', '1', 'Fall', 2010, 'A-');
	insert into takes values('13506', '559', '1', 'Fall', 2002, 'C+');
	insert into takes values('28316', '258', '1', 'Fall', 2007, 'C-');
	insert into takes values('29002', '604', '1', 'Spring', 2009, 'A+');
	insert into takes values('2177', '313', '1', 'Fall', 2010, 'C ');
	insert into takes values('12683', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('24442', '426', '1', 'Spring', 2006, 'A+');
	insert into takes values('50658', '376', '1', 'Fall', 2006, 'C+');
	insert into takes values('16297', '400', '2', 'Fall', 2003, 'C-');
	insert into takes values('9953', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('94726', '400', '2', 'Fall', 2003, 'B+');
	insert into takes values('59397', '527', '1', 'Fall', 2004, 'B+');
	insert into takes values('35905', '239', '1', 'Fall', 2006, 'B ');
	insert into takes values('95099', '443', '1', 'Spring', 2010, 'C ');
	insert into takes values('1110', '561', '1', 'Fall', 2006, 'A ');
	insert into takes values('59673', '760', '1', 'Spring', 2004, 'B ');
	insert into takes values('84865', '679', '1', 'Spring', 2010, 'C-');
	insert into takes values('88140', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('31137', '974', '1', 'Fall', 2003, 'A-');
	insert into takes values('27662', '893', '1', 'Fall', 2007, 'B+');
	insert into takes values('9947', '345', '1', 'Spring', 2008, 'B-');
	insert into takes values('28738', '604', '1', 'Spring', 2009, 'C+');
	insert into takes values('53152', '626', '1', 'Fall', 2006, 'C ');
	insert into takes values('29091', '362', '3', 'Spring', 2008, 'C+');
	insert into takes values('52187', '482', '1', 'Fall', 2005, 'A+');
	insert into takes values('45570', '352', '1', 'Spring', 2006, 'B+');
	insert into takes values('48469', '679', '1', 'Spring', 2010, 'C-');
	insert into takes values('29920', '482', '1', 'Fall', 2005, 'A-');
	insert into takes values('77234', '352', '1', 'Spring', 2006, 'B ');
	insert into takes values('19582', '972', '1', 'Spring', 2009, 'B-');
	insert into takes values('94815', '457', '1', 'Spring', 2001, 'A-');
	insert into takes values('19220', '545', '1', 'Fall', 2001, 'B-');
	insert into takes values('36791', '482', '1', 'Fall', 2005, 'B ');
	insert into takes values('19362', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('86674', '559', '1', 'Fall', 2002, 'A-');
	insert into takes values('87048', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('45680', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('20099', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('98563', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('97042', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('99647', '949', '1', 'Fall', 2007, 'C-');
	insert into takes values('50039', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('42843', '400', '2', 'Fall', 2003, 'B+');
	insert into takes values('42114', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('15613', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('17607', '400', '2', 'Fall', 2003, 'A ');
	insert into takes values('66753', '702', '1', 'Spring', 2001, 'B ');
	insert into takes values('38668', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('59290', '791', '1', 'Spring', 2006, 'C+');
	insert into takes values('81883', '561', '1', 'Fall', 2006, 'A+');
	insert into takes values('94815', '927', '1', 'Fall', 2002, 'A+');
	insert into takes values('23270', '679', '1', 'Spring', 2010, 'C+');
	insert into takes values('63361', '270', '1', 'Spring', 2010, 'A-');
	insert into takes values('45817', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('17831', '760', '1', 'Spring', 2004, 'C-');
	insert into takes values('88302', '274', '1', 'Fall', 2002, 'A+');
	insert into takes values('82402', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('80651', '274', '1', 'Fall', 2002, 'B ');
	insert into takes values('13081', '867', '2', 'Fall', 2010, 'A+');
	insert into takes values('10663', '974', '1', 'Fall', 2003, 'C ');
	insert into takes values('75513', '591', '1', 'Spring', 2005, 'A-');
	insert into takes values('45200', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('26028', '795', '1', 'Spring', 2004, 'B ');
	insert into takes values('57511', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('11057', '237', '2', 'Fall', 2009, 'A ');
	insert into takes values('57160', '496', '1', 'Fall', 2001, 'B-');
	insert into takes values('84189', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('75547', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('21552', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('88553', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('95953', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('73606', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('77898', '735', '1', 'Spring', 2003, 'A+');
	insert into takes values('842', '864', '1', 'Spring', 2006, 'C+');
	insert into takes values('71878', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('75116', '137', '1', 'Spring', 2002, 'B+');
	insert into takes values('67583', '274', '1', 'Fall', 2002, 'A-');
	insert into takes values('73602', '960', '2', 'Fall', 2006, 'A ');
	insert into takes values('68516', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('10481', '169', '1', 'Spring', 2007, 'A ');
	insert into takes values('30943', '791', '1', 'Spring', 2006, 'C-');
	insert into takes values('11422', '591', '1', 'Spring', 2005, 'C+');
	insert into takes values('59530', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('82646', '445', '1', 'Spring', 2001, 'B+');
	insert into takes values('99271', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('38902', '313', '1', 'Fall', 2010, 'C+');
	insert into takes values('63612', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('18286', '158', '1', 'Fall', 2008, 'A+');
	insert into takes values('33094', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('22532', '169', '2', 'Fall', 2002, 'A-');
	insert into takes values('86075', '200', '1', 'Spring', 2007, 'C ');
	insert into takes values('23934', '242', '1', 'Fall', 2009, 'A+');
	insert into takes values('19541', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('93354', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('84167', '603', '1', 'Fall', 2003, 'A+');
	insert into takes values('557', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('65901', '599', '1', 'Spring', 2003, 'A+');
	insert into takes values('72521', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('18808', '962', '1', 'Spring', 2008, 'B ');
	insert into takes values('74796', '443', '2', 'Spring', 2002, 'A+');
	insert into takes values('90009', '793', '1', 'Spring', 2002, 'B+');
	insert into takes values('64155', '415', '1', 'Fall', 2010, 'C ');
	insert into takes values('65901', '345', '1', 'Spring', 2008, 'A-');
	insert into takes values('94990', '599', '1', 'Spring', 2003, 'B-');
	insert into takes values('30845', '426', '1', 'Spring', 2006, 'C ');
	insert into takes values('22254', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('17665', '496', '1', 'Fall', 2001, 'C-');
	insert into takes values('16347', '604', '1', 'Spring', 2009, 'B+');
	insert into takes values('57083', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('88169', '696', '1', 'Spring', 2002, 'C+');
	insert into takes values('78787', '158', '2', 'Spring', 2008, 'B-');
	insert into takes values('80610', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('33882', '334', '1', 'Fall', 2009, 'C-');
	insert into takes values('52076', '362', '3', 'Spring', 2008, 'C-');
	insert into takes values('83314', '137', '1', 'Spring', 2002, 'A ');
	insert into takes values('45494', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('86934', '972', '1', 'Spring', 2009, 'A+');
	insert into takes values('83314', '793', '1', 'Spring', 2002, 'A ');
	insert into takes values('1000', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('83686', '960', '1', 'Fall', 2009, 'A+');
	insert into takes values('86806', '545', '1', 'Fall', 2001, 'C+');
	insert into takes values('47265', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('86552', '443', '1', 'Spring', 2010, 'A-');
	insert into takes values('16347', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('99268', '694', '1', 'Fall', 2002, 'A+');
	insert into takes values('85614', '735', '2', 'Spring', 2010, 'A-');
	insert into takes values('59539', '476', '1', 'Fall', 2010, 'B ');
	insert into takes values('69307', '760', '1', 'Spring', 2004, 'B ');
	insert into takes values('98830', '795', '1', 'Spring', 2004, 'A-');
	insert into takes values('92040', '137', '1', 'Spring', 2002, 'B ');
	insert into takes values('84727', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('86753', '408', '1', 'Spring', 2007, 'A ');
	insert into takes values('56089', '581', '1', 'Spring', 2005, 'A-');
	insert into takes values('62549', '338', '2', 'Spring', 2006, 'B+');
	insert into takes values('60688', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('60688', '200', '1', 'Spring', 2007, 'A+');
	insert into takes values('61003', '493', '1', 'Spring', 2010, 'C+');
	insert into takes values('33817', '559', '1', 'Fall', 2002, 'B ');
	insert into takes values('74016', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('61783', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('39114', '843', '1', 'Fall', 2010, 'B+');
	insert into takes values('64138', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('18367', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('75362', '400', '1', 'Spring', 2007, 'A-');
	insert into takes values('81610', '362', '1', 'Fall', 2005, 'C ');
	insert into takes values('77289', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('65433', '867', '2', 'Fall', 2010, 'C ');
	insert into takes values('57242', '415', '1', 'Fall', 2010, 'B-');
	insert into takes values('47824', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('11083', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('30222', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('92040', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('6474', '482', '1', 'Fall', 2005, 'A+');
	insert into takes values('12078', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('30177', '376', '1', 'Fall', 2006, 'B+');
	insert into takes values('87706', '960', '2', 'Fall', 2006, 'C+');
	insert into takes values('41894', '304', '1', 'Fall', 2009, 'B ');
	insert into takes values('63860', '468', '1', 'Fall', 2005, 'A-');
	insert into takes values('40932', '239', '1', 'Fall', 2006, 'A-');
	insert into takes values('83170', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('30124', '747', '1', 'Spring', 2004, 'B+');
	insert into takes values('10693', '692', '1', 'Spring', 2010, 'C+');
	insert into takes values('29091', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('74911', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('50743', '376', '1', 'Fall', 2006, 'C ');
	insert into takes values('58874', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('95099', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('69632', '408', '2', 'Spring', 2003, 'B-');
	insert into takes values('74530', '400', '2', 'Fall', 2003, 'A+');
	insert into takes values('48009', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('25611', '242', '1', 'Fall', 2009, 'C-');
	insert into takes values('50658', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('5243', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('1826', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('52057', '443', '2', 'Spring', 2002, 'B+');
	insert into takes values('96117', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('1836', '748', '1', 'Fall', 2003, 'A-');
	insert into takes values('14628', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('32483', '274', '1', 'Fall', 2002, 'C+');
	insert into takes values('2286', '791', '1', 'Spring', 2006, 'A-');
	insert into takes values('2286', '603', '1', 'Fall', 2003, 'C-');
	insert into takes values('87222', '362', '1', 'Fall', 2005, 'C ');
	insert into takes values('75510', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('65443', '362', '1', 'Fall', 2005, 'C+');
	insert into takes values('18808', '581', '1', 'Spring', 2005, 'C-');
	insert into takes values('14596', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('29260', '468', '2', 'Fall', 2007, 'A-');
	insert into takes values('29863', '760', '1', 'Spring', 2004, 'A-');
	insert into takes values('88358', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('16885', '482', '1', 'Fall', 2005, 'A+');
	insert into takes values('57156', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('75928', '468', '2', 'Fall', 2007, 'B ');
	insert into takes values('60267', '642', '1', 'Fall', 2004, 'C+');
	insert into takes values('50743', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('43854', '270', '1', 'Spring', 2010, 'B-');
	insert into takes values('84410', '493', '1', 'Spring', 2010, 'A-');
	insert into takes values('39254', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('56276', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('96085', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('24374', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('56499', '192', '1', 'Fall', 2002, 'C ');
	insert into takes values('85575', '791', '1', 'Spring', 2006, 'B+');
	insert into takes values('60224', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('1836', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('82687', '338', '2', 'Spring', 2006, 'B+');
	insert into takes values('61527', '760', '1', 'Spring', 2004, 'A-');
	insert into takes values('3005', '137', '1', 'Spring', 2002, 'B ');
	insert into takes values('8022', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('25552', '192', '1', 'Fall', 2002, 'C ');
	insert into takes values('22179', '808', '1', 'Fall', 2003, 'C ');
	insert into takes values('19766', '631', '1', 'Spring', 2007, 'A+');
	insert into takes values('81984', '270', '1', 'Spring', 2010, 'C+');
	insert into takes values('1826', '400', '1', 'Spring', 2007, 'A+');
	insert into takes values('48640', '795', '1', 'Spring', 2004, 'C+');
	insert into takes values('79170', '962', '1', 'Spring', 2008, 'A ');
	insert into takes values('71529', '486', '1', 'Fall', 2009, 'A-');
	insert into takes values('45300', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('14032', '893', '1', 'Fall', 2007, 'B+');
	insert into takes values('26695', '694', '1', 'Fall', 2002, 'B ');
	insert into takes values('37449', '591', '1', 'Spring', 2005, 'B ');
	insert into takes values('25077', '960', '2', 'Fall', 2006, 'B+');
	insert into takes values('10663', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('67407', '169', '1', 'Spring', 2007, 'B-');
	insert into takes values('84727', '200', '1', 'Spring', 2007, 'B+');
	insert into takes values('93366', '735', '2', 'Spring', 2010, 'B-');
	insert into takes values('96178', '105', '1', 'Fall', 2009, 'C+');
	insert into takes values('14621', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('39612', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('61166', '400', '1', 'Spring', 2007, 'C ');
	insert into takes values('40303', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('94998', '875', '1', 'Spring', 2005, 'C ');
	insert into takes values('66813', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('9460', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('87268', '493', '1', 'Spring', 2010, 'B ');
	insert into takes values('38691', '631', '1', 'Spring', 2007, 'B ');
	insert into takes values('30124', '702', '1', 'Spring', 2001, 'B ');
	insert into takes values('45720', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('89234', '352', '1', 'Spring', 2006, 'B+');
	insert into takes values('96968', '612', '1', 'Fall', 2007, 'B-');
	insert into takes values('93043', '362', '3', 'Spring', 2008, 'C-');
	insert into takes values('11578', '692', '1', 'Spring', 2010, 'A ');
	insert into takes values('32376', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('80610', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('38691', '893', '1', 'Fall', 2007, 'C+');
	insert into takes values('5399', '476', '1', 'Fall', 2010, 'A+');
	insert into takes values('9953', '237', '2', 'Fall', 2009, 'A ');
	insert into takes values('79763', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('70098', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('81538', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('97694', '735', '1', 'Spring', 2003, 'B+');
	insert into takes values('56003', '352', '1', 'Spring', 2006, 'A-');
	insert into takes values('67657', '747', '1', 'Spring', 2004, 'B-');
	insert into takes values('80821', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('35462', '105', '2', 'Fall', 2002, 'B-');
	insert into takes values('13023', '486', '1', 'Fall', 2009, 'A ');
	insert into takes values('41741', '468', '1', 'Fall', 2005, 'B ');
	insert into takes values('87246', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('35462', '319', '1', 'Spring', 2003, 'C-');
	insert into takes values('43658', '702', '1', 'Spring', 2001, 'C-');
	insert into takes values('72657', '702', '1', 'Spring', 2001, 'C ');
	insert into takes values('92464', '527', '1', 'Fall', 2004, 'A ');
	insert into takes values('1285', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('18775', '158', '2', 'Spring', 2008, 'B-');
	insert into takes values('24784', '421', '1', 'Fall', 2004, 'B-');
	insert into takes values('34404', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('13826', '760', '1', 'Spring', 2004, 'A-');
	insert into takes values('45650', '626', '1', 'Fall', 2006, 'B ');
	insert into takes values('29871', '338', '1', 'Spring', 2007, 'C+');
	insert into takes values('56139', '468', '1', 'Fall', 2005, 'C+');
	insert into takes values('35220', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('65144', '486', '1', 'Fall', 2009, 'B ');
	insert into takes values('85602', '694', '1', 'Fall', 2002, 'A ');
	insert into takes values('66008', '408', '1', 'Spring', 2007, 'B ');
	insert into takes values('6287', '604', '1', 'Spring', 2009, 'B-');
	insert into takes values('89297', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('7204', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('78116', '421', '1', 'Fall', 2004, 'A ');
	insert into takes values('63538', '867', '1', 'Fall', 2006, 'A ');
	insert into takes values('57190', '793', '1', 'Spring', 2002, 'C+');
	insert into takes values('34957', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('17057', '457', '1', 'Spring', 2001, 'C ');
	insert into takes values('10527', '599', '1', 'Spring', 2003, 'A+');
	insert into takes values('64138', '408', '1', 'Spring', 2007, 'A+');
	insert into takes values('67655', '875', '1', 'Spring', 2005, 'B-');
	insert into takes values('58465', '352', '1', 'Spring', 2006, 'C+');
	insert into takes values('44816', '604', '1', 'Spring', 2009, 'A ');
	insert into takes values('17676', '158', '2', 'Spring', 2008, 'A ');
	insert into takes values('58594', '864', '1', 'Spring', 2006, 'A ');
	insert into takes values('39881', '735', '1', 'Spring', 2003, 'C ');
	insert into takes values('29260', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('35198', '679', '1', 'Spring', 2010, 'C+');
	insert into takes values('79534', '468', '2', 'Fall', 2007, 'A-');
	insert into takes values('23475', '242', '1', 'Fall', 2009, 'A+');
	insert into takes values('67655', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('38691', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('36102', '421', '1', 'Fall', 2004, 'C-');
	insert into takes values('56755', '972', '1', 'Spring', 2009, 'B+');
	insert into takes values('11201', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('55286', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('64067', '795', '1', 'Spring', 2004, 'A ');
	insert into takes values('90089', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('71529', '313', '1', 'Fall', 2010, 'C+');
	insert into takes values('76270', '927', '1', 'Fall', 2002, 'A-');
	insert into takes values('67657', '319', '1', 'Spring', 2003, 'C+');
	insert into takes values('60366', '612', '1', 'Fall', 2007, 'A ');
	insert into takes values('62754', '852', '1', 'Spring', 2008, 'B ');
	insert into takes values('32954', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('12615', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('38691', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('8252', '581', '1', 'Spring', 2005, 'A+');
	insert into takes values('20378', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('86674', '401', '1', 'Fall', 2003, 'B+');
	insert into takes values('10076', '482', '1', 'Fall', 2005, 'A+');
	insert into takes values('77415', '852', '1', 'Spring', 2008, 'A-');
	insert into takes values('64192', '482', '1', 'Fall', 2005, 'B-');
	insert into takes values('92965', '604', '1', 'Spring', 2009, 'A-');
	insert into takes values('94766', '468', '1', 'Fall', 2005, 'C+');
	insert into takes values('65681', '791', '1', 'Spring', 2006, 'A ');
	insert into takes values('37219', '362', '2', 'Fall', 2006, 'C-');
	insert into takes values('87015', '362', '2', 'Fall', 2006, 'B-');
	insert into takes values('65703', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('53077', '591', '1', 'Spring', 2005, 'B-');
	insert into takes values('36791', '313', '1', 'Fall', 2010, 'B-');
	insert into takes values('93043', '443', '1', 'Spring', 2010, 'C ');
	insert into takes values('62226', '663', '1', 'Spring', 2005, 'A ');
	insert into takes values('51868', '604', '1', 'Spring', 2009, 'B+');
	insert into takes values('96895', '626', '1', 'Fall', 2006, 'B ');
	insert into takes values('69952', '735', '2', 'Spring', 2010, 'A+');
	insert into takes values('53588', '527', '1', 'Fall', 2004, 'C ');
	insert into takes values('82063', '468', '2', 'Fall', 2007, 'A+');
	insert into takes values('14432', '313', '1', 'Fall', 2010, 'A ');
	insert into takes values('53496', '599', '1', 'Spring', 2003, 'A-');
	insert into takes values('50331', '692', '1', 'Spring', 2010, 'C+');
	insert into takes values('52707', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('72186', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('65987', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('32744', '735', '2', 'Spring', 2010, 'C ');
	insert into takes values('87624', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('24387', '629', '1', 'Spring', 2003, 'A ');
	insert into takes values('80610', '400', '2', 'Fall', 2003, 'A ');
	insert into takes values('32130', '476', '1', 'Fall', 2010, 'B ');
	insert into takes values('63502', '545', '1', 'Fall', 2001, 'B+');
	insert into takes values('57511', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('23373', '808', '1', 'Fall', 2003, 'A-');
	insert into takes values('90779', '599', '1', 'Spring', 2003, 'B+');
	insert into takes values('29849', '663', '1', 'Spring', 2005, 'A-');
	insert into takes values('88389', '545', '1', 'Fall', 2001, 'A ');
	insert into takes values('16453', '105', '2', 'Fall', 2002, 'C-');
	insert into takes values('34170', '334', '1', 'Fall', 2009, 'B-');
	insert into takes values('72186', '629', '1', 'Spring', 2003, 'A ');
	insert into takes values('49759', '362', '2', 'Fall', 2006, 'B-');
	insert into takes values('89106', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('7020', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('75878', '476', '1', 'Fall', 2010, 'B+');
	insert into takes values('83214', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('88140', '468', '1', 'Fall', 2005, 'A-');
	insert into takes values('50386', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('1087', '561', '1', 'Fall', 2006, 'A-');
	insert into takes values('69679', '415', '1', 'Fall', 2010, 'A-');
	insert into takes values('71904', '864', '1', 'Spring', 2006, 'A ');
	insert into takes values('59848', '443', '2', 'Spring', 2002, 'A ');
	insert into takes values('17911', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('49391', '493', '1', 'Spring', 2010, 'B+');
	insert into takes values('67810', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('76250', '400', '2', 'Fall', 2003, 'A ');
	insert into takes values('43130', '443', '2', 'Spring', 2002, 'C ');
	insert into takes values('8251', '338', '2', 'Spring', 2006, 'A+');
	insert into takes values('10838', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('87268', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('34197', '408', '2', 'Spring', 2003, 'C-');
	insert into takes values('27528', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('70572', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('20084', '482', '1', 'Fall', 2005, 'A-');
	insert into takes values('69758', '599', '1', 'Spring', 2003, 'B+');
	insert into takes values('38973', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('93491', '443', '2', 'Spring', 2002, 'B ');
	insert into takes values('83398', '960', '1', 'Fall', 2009, 'A+');
	insert into takes values('41345', '400', '1', 'Spring', 2007, 'A ');
	insert into takes values('8343', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('53728', '366', '1', 'Fall', 2005, 'C-');
	insert into takes values('48471', '158', '2', 'Spring', 2008, 'A ');
	insert into takes values('24374', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('85356', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('163', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('98940', '313', '1', 'Fall', 2010, 'A-');
	insert into takes values('20814', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('19450', '747', '1', 'Spring', 2004, 'C ');
	insert into takes values('2967', '169', '1', 'Spring', 2007, 'C ');
	insert into takes values('58413', '486', '1', 'Fall', 2009, 'A ');
	insert into takes values('22004', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('27094', '599', '1', 'Spring', 2003, 'A+');
	insert into takes values('34957', '760', '1', 'Spring', 2004, 'B+');
	insert into takes values('43854', '702', '1', 'Spring', 2001, 'C+');
	insert into takes values('86674', '242', '1', 'Fall', 2009, 'B+');
	insert into takes values('96772', '258', '1', 'Fall', 2007, 'A-');
	insert into takes values('47265', '631', '1', 'Spring', 2007, 'A ');
	insert into takes values('3335', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('43495', '237', '2', 'Fall', 2009, 'C-');
	insert into takes values('87831', '496', '1', 'Fall', 2001, 'C-');
	insert into takes values('90234', '200', '2', 'Fall', 2002, 'B+');
	insert into takes values('23475', '362', '1', 'Fall', 2005, 'A+');
	insert into takes values('19048', '362', '3', 'Spring', 2008, 'C-');
	insert into takes values('96206', '338', '1', 'Spring', 2007, 'A+');
	insert into takes values('69853', '457', '1', 'Spring', 2001, 'B ');
	insert into takes values('99289', '242', '1', 'Fall', 2009, 'A+');
	insert into takes values('20985', '760', '1', 'Spring', 2004, 'B-');
	insert into takes values('90181', '400', '1', 'Spring', 2007, 'C-');
	insert into takes values('50944', '169', '2', 'Fall', 2002, 'A ');
	insert into takes values('19638', '960', '2', 'Fall', 2006, 'B-');
	insert into takes values('98019', '704', '1', 'Spring', 2008, 'C-');
	insert into takes values('79170', '591', '1', 'Spring', 2005, 'C+');
	insert into takes values('84808', '974', '1', 'Fall', 2003, 'A-');
	insert into takes values('39580', '875', '1', 'Spring', 2005, 'A ');
	insert into takes values('25380', '476', '1', 'Fall', 2010, 'C-');
	insert into takes values('61354', '843', '1', 'Fall', 2010, 'A+');
	insert into takes values('27919', '366', '1', 'Fall', 2005, 'A+');
	insert into takes values('14023', '493', '1', 'Spring', 2010, 'B ');
	insert into takes values('70061', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('91442', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('47677', '561', '1', 'Fall', 2006, 'B-');
	insert into takes values('18469', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('931', '415', '1', 'Fall', 2010, 'B ');
	insert into takes values('25187', '258', '1', 'Fall', 2007, 'A ');
	insert into takes values('73602', '972', '1', 'Spring', 2009, 'A-');
	insert into takes values('36402', '559', '1', 'Fall', 2002, 'A-');
	insert into takes values('28352', '791', '1', 'Spring', 2006, 'B+');
	insert into takes values('75938', '270', '1', 'Spring', 2010, 'C ');
	insert into takes values('13211', '408', '2', 'Spring', 2003, 'B-');
	insert into takes values('41674', '200', '1', 'Spring', 2007, 'C ');
	insert into takes values('25611', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('97023', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('53089', '200', '2', 'Fall', 2002, 'A ');
	insert into takes values('14596', '612', '1', 'Fall', 2007, 'B-');
	insert into takes values('49684', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('17133', '795', '1', 'Spring', 2004, 'B-');
	insert into takes values('792', '445', '1', 'Spring', 2001, 'C ');
	insert into takes values('24746', '400', '1', 'Spring', 2007, 'B+');
	insert into takes values('2795', '408', '1', 'Spring', 2007, 'C+');
	insert into takes values('70395', '852', '1', 'Spring', 2008, 'B-');
	insert into takes values('84702', '893', '1', 'Fall', 2007, 'C ');
	insert into takes values('18469', '200', '1', 'Spring', 2007, 'B+');
	insert into takes values('86981', '400', '1', 'Spring', 2007, 'C-');
	insert into takes values('82591', '192', '1', 'Fall', 2002, 'C ');
	insert into takes values('76799', '760', '1', 'Spring', 2004, 'B+');
	insert into takes values('46450', '352', '1', 'Spring', 2006, 'C+');
	insert into takes values('94620', '760', '1', 'Spring', 2004, 'C+');
	insert into takes values('19203', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('21394', '748', '1', 'Fall', 2003, 'B-');
	insert into takes values('5336', '366', '1', 'Fall', 2005, 'C-');
	insert into takes values('69679', '304', '1', 'Fall', 2009, 'A+');
	insert into takes values('57213', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('18108', '696', '1', 'Spring', 2002, 'C ');
	insert into takes values('72006', '747', '1', 'Spring', 2004, 'A ');
	insert into takes values('72741', '893', '1', 'Fall', 2007, 'B-');
	insert into takes values('35685', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('57123', '795', '1', 'Spring', 2004, 'B ');
	insert into takes values('1460', '401', '1', 'Fall', 2003, 'A-');
	insert into takes values('30845', '704', '1', 'Spring', 2008, 'C-');
	insert into takes values('38973', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('3640', '468', '1', 'Fall', 2005, 'C+');
	insert into takes values('72768', '629', '1', 'Spring', 2003, 'B ');
	insert into takes values('34404', '704', '1', 'Spring', 2008, 'B ');
	insert into takes values('81031', '237', '1', 'Spring', 2008, 'B+');
	insert into takes values('71287', '158', '2', 'Spring', 2008, 'B-');
	insert into takes values('99730', '319', '1', 'Spring', 2003, 'C ');
	insert into takes values('95089', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('93004', '237', '2', 'Fall', 2009, 'C ');
	insert into takes values('557', '366', '1', 'Fall', 2005, 'B ');
	insert into takes values('22003', '408', '1', 'Spring', 2007, 'A ');
	insert into takes values('90082', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('47025', '612', '1', 'Fall', 2007, 'B+');
	insert into takes values('94836', '313', '1', 'Fall', 2010, 'C+');
	insert into takes values('53803', '445', '1', 'Spring', 2001, 'C ');
	insert into takes values('62832', '158', '1', 'Fall', 2008, 'A ');
	insert into takes values('99073', '545', '1', 'Fall', 2001, 'A-');
	insert into takes values('93061', '802', '1', 'Spring', 2003, 'B+');
	insert into takes values('78858', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('32130', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('63560', '362', '2', 'Fall', 2006, 'C-');
	insert into takes values('75173', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('28977', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('5871', '376', '1', 'Fall', 2006, 'B ');
	insert into takes values('57190', '760', '1', 'Spring', 2004, 'B ');
	insert into takes values('75560', '875', '1', 'Spring', 2005, 'A-');
	insert into takes values('59530', '962', '1', 'Spring', 2008, 'B-');
	insert into takes values('59908', '313', '1', 'Fall', 2010, 'A-');
	insert into takes values('93508', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('88169', '158', '1', 'Fall', 2008, 'A+');
	insert into takes values('41491', '561', '1', 'Fall', 2006, 'B-');
	insert into takes values('29514', '408', '1', 'Spring', 2007, 'B ');
	insert into takes values('94766', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('66293', '603', '1', 'Fall', 2003, 'B ');
	insert into takes values('44584', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('25046', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('22086', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('31554', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('45002', '599', '1', 'Spring', 2003, 'A+');
	insert into takes values('56849', '960', '2', 'Fall', 2006, 'C ');
	insert into takes values('72959', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('15283', '629', '1', 'Spring', 2003, 'B-');
	insert into takes values('75231', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('4015', '376', '1', 'Fall', 2006, 'B+');
	insert into takes values('16035', '694', '1', 'Fall', 2002, 'B-');
	insert into takes values('94836', '960', '1', 'Fall', 2009, 'B+');
	insert into takes values('6209', '496', '1', 'Fall', 2001, 'B+');
	insert into takes values('66484', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('70918', '960', '2', 'Fall', 2006, 'A-');
	insert into takes values('1737', '362', '1', 'Fall', 2005, 'B ');
	insert into takes values('8517', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('42843', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('74473', '482', '1', 'Fall', 2005, 'B ');
	insert into takes values('98423', '663', '1', 'Spring', 2005, 'C-');
	insert into takes values('11195', '875', '1', 'Spring', 2005, 'B+');
	insert into takes values('95225', '482', '1', 'Fall', 2005, 'C ');
	insert into takes values('72657', '482', '1', 'Fall', 2005, 'A ');
	insert into takes values('16453', '960', '2', 'Fall', 2006, 'C-');
	insert into takes values('50267', '457', '1', 'Spring', 2001, 'B-');
	insert into takes values('40178', '631', '1', 'Spring', 2007, 'C+');
	insert into takes values('41299', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('64138', '304', '1', 'Fall', 2009, 'C-');
	insert into takes values('99775', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('84515', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('18809', '421', '1', 'Fall', 2004, 'B-');
	insert into takes values('48660', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('86981', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('14065', '893', '1', 'Fall', 2007, 'A-');
	insert into takes values('41491', '748', '1', 'Fall', 2003, 'B+');
	insert into takes values('89000', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('23457', '239', '1', 'Fall', 2006, 'B ');
	insert into takes values('84727', '875', '1', 'Spring', 2005, 'A-');
	insert into takes values('90194', '962', '1', 'Spring', 2008, 'B-');
	insert into takes values('76672', '482', '1', 'Fall', 2005, 'C+');
	insert into takes values('75878', '400', '2', 'Fall', 2003, 'A-');
	insert into takes values('18108', '702', '1', 'Spring', 2001, 'A-');
	insert into takes values('4345', '270', '1', 'Spring', 2010, 'B+');
	insert into takes values('8343', '421', '1', 'Fall', 2004, 'A-');
	insert into takes values('9993', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('83204', '400', '1', 'Spring', 2007, 'C ');
	insert into takes values('8912', '237', '1', 'Spring', 2008, 'A ');
	insert into takes values('11201', '875', '1', 'Spring', 2005, 'C-');
	insert into takes values('38696', '362', '3', 'Spring', 2008, 'C+');
	insert into takes values('11578', '791', '1', 'Spring', 2006, 'B+');
	insert into takes values('68516', '604', '1', 'Spring', 2009, 'C ');
	insert into takes values('75772', '366', '1', 'Fall', 2005, 'B ');
	insert into takes values('15578', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('4345', '415', '1', 'Fall', 2010, 'C ');
	insert into takes values('48462', '362', '3', 'Spring', 2008, 'C+');
	insert into takes values('91915', '192', '1', 'Fall', 2002, 'A-');
	insert into takes values('30161', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('41751', '445', '1', 'Spring', 2001, 'A ');
	insert into takes values('11202', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('52523', '376', '1', 'Fall', 2006, 'C ');
	insert into takes values('15487', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('71944', '629', '1', 'Spring', 2003, 'B-');
	insert into takes values('56499', '791', '1', 'Spring', 2006, 'B+');
	insert into takes values('8819', '319', '1', 'Spring', 2003, 'B ');
	insert into takes values('49611', '704', '1', 'Spring', 2008, 'C ');
	insert into takes values('37103', '443', '2', 'Spring', 2002, 'A+');
	insert into takes values('91091', '105', '2', 'Fall', 2002, 'B+');
	insert into takes values('32368', '735', '2', 'Spring', 2010, 'B+');
	insert into takes values('90009', '559', '1', 'Fall', 2002, 'A ');
	insert into takes values('83838', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('59172', '527', '1', 'Fall', 2004, 'B-');
	insert into takes values('55329', '334', '1', 'Fall', 2009, 'C-');
	insert into takes values('34322', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('32056', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('75547', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('42556', '527', '1', 'Fall', 2004, 'C+');
	insert into takes values('17831', '795', '1', 'Spring', 2004, 'B-');
	insert into takes values('87054', '304', '1', 'Fall', 2009, 'C+');
	insert into takes values('59172', '867', '1', 'Fall', 2006, 'C+');
	insert into takes values('10481', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('73492', '702', '1', 'Spring', 2001, 'A ');
	insert into takes values('8483', '338', '1', 'Spring', 2007, 'B-');
	insert into takes values('83398', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('48462', '482', '1', 'Fall', 2005, 'C ');
	insert into takes values('56598', '486', '1', 'Fall', 2009, 'C+');
	insert into takes values('32954', '893', '1', 'Fall', 2007, 'B ');
	insert into takes values('14182', '158', '2', 'Spring', 2008, 'A-');
	insert into takes values('20244', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('6367', '561', '1', 'Fall', 2006, 'B-');
	insert into takes values('69285', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('54296', '349', '1', 'Spring', 2008, 'A-');
	insert into takes values('10736', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('79589', '696', '1', 'Spring', 2002, 'A+');
	insert into takes values('85680', '274', '1', 'Fall', 2002, 'C+');
	insert into takes values('50267', '237', '2', 'Fall', 2009, 'C ');
	insert into takes values('41599', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('86981', '808', '1', 'Fall', 2003, 'B-');
	insert into takes values('13511', '421', '1', 'Fall', 2004, 'B-');
	insert into takes values('81984', '400', '1', 'Spring', 2007, 'C ');
	insert into takes values('79469', '200', '1', 'Spring', 2007, 'A+');
	insert into takes values('21395', '158', '1', 'Fall', 2008, 'A+');
	insert into takes values('14182', '408', '2', 'Spring', 2003, 'B-');
	insert into takes values('84189', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('23457', '959', '1', 'Fall', 2006, 'A-');
	insert into takes values('10481', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('73165', '400', '2', 'Fall', 2003, 'C-');
	insert into takes values('54460', '559', '1', 'Fall', 2002, 'C+');
	insert into takes values('10917', '158', '2', 'Spring', 2008, 'A+');
	insert into takes values('65056', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('83622', '338', '2', 'Spring', 2006, 'C+');
	insert into takes values('60748', '457', '1', 'Spring', 2001, 'A ');
	insert into takes values('15538', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('82974', '604', '1', 'Spring', 2009, 'C ');
	insert into takes values('44352', '867', '1', 'Fall', 2006, 'B+');
	insert into takes values('98830', '960', '2', 'Fall', 2006, 'A ');
	insert into takes values('71628', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('34392', '345', '1', 'Spring', 2008, 'B-');
	insert into takes values('7861', '443', '2', 'Spring', 2002, 'B-');
	insert into takes values('31554', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('60366', '486', '1', 'Fall', 2009, 'B-');
	insert into takes values('58935', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('41973', '704', '1', 'Spring', 2008, 'A+');
	insert into takes values('83003', '421', '1', 'Fall', 2004, 'C-');
	insert into takes values('42560', '105', '2', 'Fall', 2002, 'A-');
	insert into takes values('59117', '105', '2', 'Fall', 2002, 'B+');
	insert into takes values('61854', '760', '1', 'Spring', 2004, 'B ');
	insert into takes values('53077', '960', '2', 'Fall', 2006, 'B-');
	insert into takes values('4004', '991', '1', 'Spring', 2008, 'C+');
	insert into takes values('19220', '400', '2', 'Fall', 2003, 'C+');
	insert into takes values('21552', '274', '1', 'Fall', 2002, 'A ');
	insert into takes values('7043', '237', '1', 'Spring', 2008, 'C ');
	insert into takes values('9495', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('50966', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('58170', '408', '1', 'Spring', 2007, 'B ');
	insert into takes values('44836', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('64945', '972', '1', 'Spring', 2009, 'A+');
	insert into takes values('72979', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('1402', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('11194', '489', '1', 'Fall', 2007, 'A ');
	insert into takes values('75791', '696', '1', 'Spring', 2002, 'A ');
	insert into takes values('98726', '760', '1', 'Spring', 2004, 'A+');
	insert into takes values('76057', '791', '1', 'Spring', 2006, 'B+');
	insert into takes values('36926', '493', '1', 'Spring', 2010, 'B+');
	insert into takes values('72177', '338', '2', 'Spring', 2006, 'B ');
	insert into takes values('30182', '443', '1', 'Spring', 2010, 'A-');
	insert into takes values('9114', '581', '1', 'Spring', 2005, 'C+');
	insert into takes values('83204', '960', '2', 'Fall', 2006, 'C ');
	insert into takes values('36244', '959', '1', 'Fall', 2006, 'A ');
	insert into takes values('83953', '169', '2', 'Fall', 2002, 'A-');
	insert into takes values('1884', '489', '1', 'Fall', 2007, 'A-');
	insert into takes values('858', '663', '1', 'Spring', 2005, 'A ');
	insert into takes values('86404', '629', '1', 'Spring', 2003, 'B+');
	insert into takes values('86001', '735', '1', 'Spring', 2003, 'C+');
	insert into takes values('85746', '760', '1', 'Spring', 2004, 'C-');
	insert into takes values('89734', '192', '1', 'Fall', 2002, 'C ');
	insert into takes values('75082', '694', '1', 'Fall', 2002, 'A+');
	insert into takes values('87785', '591', '1', 'Spring', 2005, 'A-');
	insert into takes values('28738', '962', '1', 'Spring', 2008, 'A ');
	insert into takes values('92949', '612', '1', 'Fall', 2007, 'A ');
	insert into takes values('17128', '338', '1', 'Spring', 2007, 'A-');
	insert into takes values('11578', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('51923', '527', '1', 'Fall', 2004, 'C-');
	insert into takes values('71768', '408', '2', 'Spring', 2003, 'A-');
	insert into takes values('56078', '408', '1', 'Spring', 2007, 'C ');
	insert into takes values('97065', '476', '1', 'Fall', 2010, 'C-');
	insert into takes values('390', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('73542', '192', '1', 'Fall', 2002, 'C-');
	insert into takes values('92867', '679', '1', 'Spring', 2010, 'A ');
	insert into takes values('43854', '468', '1', 'Fall', 2005, 'A-');
	insert into takes values('70099', '457', '1', 'Spring', 2001, 'C-');
	insert into takes values('46035', '843', '1', 'Fall', 2010, 'A+');
	insert into takes values('96722', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('76953', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('7020', '443', '1', 'Spring', 2010, 'C ');
	insert into takes values('76173', '242', '1', 'Fall', 2009, 'A-');
	insert into takes values('28409', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('21337', '735', '1', 'Spring', 2003, 'A+');
	insert into takes values('67793', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('15024', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('18007', '408', '1', 'Spring', 2007, 'C+');
	insert into takes values('6209', '200', '1', 'Spring', 2007, 'A-');
	insert into takes values('27950', '401', '1', 'Fall', 2003, 'A ');
	insert into takes values('48901', '735', '1', 'Spring', 2003, 'B-');
	insert into takes values('18808', '626', '1', 'Fall', 2006, 'B-');
	insert into takes values('53225', '242', '1', 'Fall', 2009, 'A-');
	insert into takes values('18499', '893', '1', 'Fall', 2007, 'A+');
	insert into takes values('4004', '169', '2', 'Fall', 2002, 'B+');
	insert into takes values('84432', '105', '1', 'Fall', 2009, 'B+');
	insert into takes values('68712', '400', '2', 'Fall', 2003, 'A ');
	insert into takes values('60762', '362', '1', 'Fall', 2005, 'C ');
	insert into takes values('78454', '400', '1', 'Spring', 2007, 'C-');
	insert into takes values('96193', '927', '1', 'Fall', 2002, 'A-');
	insert into takes values('97023', '694', '1', 'Fall', 2002, 'C+');
	insert into takes values('49813', '338', '1', 'Spring', 2007, 'B-');
	insert into takes values('17076', '169', '1', 'Spring', 2007, 'A ');
	insert into takes values('58085', '760', '1', 'Spring', 2004, 'A-');
	insert into takes values('83836', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('64121', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('54620', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('35257', '545', '1', 'Fall', 2001, 'C ');
	insert into takes values('16885', '893', '1', 'Fall', 2007, 'C+');
	insert into takes values('31079', '694', '1', 'Fall', 2002, 'A+');
	insert into takes values('82868', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('71944', '200', '1', 'Spring', 2007, 'C ');
	insert into takes values('53728', '603', '1', 'Fall', 2003, 'B+');
	insert into takes values('43989', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('72177', '571', '1', 'Spring', 2004, 'B+');
	insert into takes values('33206', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('37715', '408', '1', 'Spring', 2007, 'B+');
	insert into takes values('78552', '793', '1', 'Spring', 2002, 'A+');
	insert into takes values('38676', '496', '1', 'Fall', 2001, 'B ');
	insert into takes values('11578', '631', '1', 'Spring', 2007, 'A-');
	insert into takes values('888', '237', '2', 'Fall', 2009, 'B+');
	insert into takes values('87965', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('6304', '237', '2', 'Fall', 2009, 'C ');
	insert into takes values('16543', '561', '1', 'Fall', 2006, 'B ');
	insert into takes values('29435', '875', '1', 'Spring', 2005, 'C-');
	insert into takes values('43981', '242', '1', 'Fall', 2009, 'C-');
	insert into takes values('53547', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('85887', '960', '1', 'Fall', 2009, 'B ');
	insert into takes values('46769', '591', '1', 'Spring', 2005, 'B ');
	insert into takes values('62520', '843', '1', 'Fall', 2010, 'B-');
	insert into takes values('39978', '258', '1', 'Fall', 2007, 'A+');
	insert into takes values('47824', '345', '1', 'Spring', 2008, 'B-');
	insert into takes values('49611', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('10705', '200', '1', 'Spring', 2007, 'C-');
	insert into takes values('34957', '561', '1', 'Fall', 2006, 'A+');
	insert into takes values('74639', '445', '1', 'Spring', 2001, 'C+');
	insert into takes values('72055', '960', '1', 'Fall', 2009, 'A-');
	insert into takes values('62832', '867', '2', 'Fall', 2010, 'A-');
	insert into takes values('19050', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('43616', '461', '1', 'Fall', 2002, 'C+');
	insert into takes values('66753', '105', '2', 'Fall', 2002, 'C-');
	insert into takes values('39238', '599', '1', 'Spring', 2003, 'B ');
	insert into takes values('27950', '692', '1', 'Spring', 2010, 'A+');
	insert into takes values('80420', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('51768', '704', '1', 'Spring', 2008, 'A ');
	insert into takes values('58469', '843', '1', 'Fall', 2010, 'A ');
	insert into takes values('76270', '200', '2', 'Fall', 2002, 'A ');
	insert into takes values('84792', '496', '1', 'Fall', 2001, 'C-');
	insert into takes values('2177', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('36303', '408', '1', 'Spring', 2007, 'A-');
	insert into takes values('41827', '867', '1', 'Fall', 2006, 'B ');
	insert into takes values('17424', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('8957', '962', '1', 'Spring', 2008, 'C+');
	insert into takes values('80799', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('53805', '735', '2', 'Spring', 2010, 'B-');
	insert into takes values('11855', '362', '1', 'Fall', 2005, 'C-');
	insert into takes values('21009', '808', '1', 'Fall', 2003, 'B-');
	insert into takes values('83557', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('32886', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('49339', '461', '1', 'Fall', 2002, 'B+');
	insert into takes values('21692', '843', '1', 'Fall', 2010, 'B-');
	insert into takes values('13757', '237', '2', 'Fall', 2009, 'C-');
	insert into takes values('35138', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('2423', '408', '2', 'Spring', 2003, 'C ');
	insert into takes values('9933', '875', '1', 'Spring', 2005, 'B+');
	insert into takes values('19536', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('72741', '972', '1', 'Spring', 2009, 'A+');
	insert into takes values('55531', '867', '2', 'Fall', 2010, 'B ');
	insert into takes values('42556', '401', '1', 'Fall', 2003, 'C ');
	insert into takes values('26028', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('65438', '581', '1', 'Spring', 2005, 'A+');
	insert into takes values('67407', '338', '1', 'Spring', 2007, 'B-');
	insert into takes values('79446', '366', '1', 'Fall', 2005, 'C ');
	insert into takes values('17996', '867', '2', 'Fall', 2010, 'B-');
	insert into takes values('79469', '457', '1', 'Spring', 2001, 'B-');
	insert into takes values('31137', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('82082', '599', '1', 'Spring', 2003, 'C+');
	insert into takes values('38271', '461', '1', 'Fall', 2002, 'B ');
	insert into takes values('81884', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('86529', '200', '2', 'Fall', 2002, 'B-');
	insert into takes values('7514', '604', '1', 'Spring', 2009, 'A ');
	insert into takes values('63560', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('1018', '421', '1', 'Fall', 2004, 'C-');
	insert into takes values('61527', '545', '1', 'Fall', 2001, 'A+');
	insert into takes values('81031', '960', '1', 'Fall', 2009, 'C-');
	insert into takes values('28128', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('75173', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('18367', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('19245', '795', '1', 'Spring', 2004, 'B ');
	insert into takes values('1727', '496', '1', 'Fall', 2001, 'A+');
	insert into takes values('8457', '349', '1', 'Spring', 2008, 'B+');
	insert into takes values('82126', '304', '1', 'Fall', 2009, 'C ');
	insert into takes values('53469', '760', '1', 'Spring', 2004, 'C-');
	insert into takes values('29239', '362', '1', 'Fall', 2005, 'B ');
	insert into takes values('1232', '482', '1', 'Fall', 2005, 'A+');
	insert into takes values('98843', '949', '1', 'Fall', 2007, 'C ');
	insert into takes values('86707', '362', '2', 'Fall', 2006, 'A-');
	insert into takes values('39204', '482', '1', 'Fall', 2005, 'A ');
	insert into takes values('92839', '704', '1', 'Spring', 2008, 'B ');
	insert into takes values('37219', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('81638', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('30021', '443', '2', 'Spring', 2002, 'B ');
	insert into takes values('65144', '493', '1', 'Spring', 2010, 'A-');
	insert into takes values('22912', '875', '1', 'Spring', 2005, 'B ');
	insert into takes values('1954', '604', '1', 'Spring', 2009, 'B+');
	insert into takes values('30188', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('31250', '376', '1', 'Fall', 2006, 'B-');
	insert into takes values('32130', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('63449', '962', '1', 'Spring', 2008, 'A-');
	insert into takes values('17600', '962', '1', 'Spring', 2008, 'C ');
	insert into takes values('88169', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('23311', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('36881', '631', '1', 'Spring', 2007, 'C+');
	insert into takes values('60249', '169', '1', 'Spring', 2007, 'B ');
	insert into takes values('84189', '362', '2', 'Fall', 2006, 'B ');
	insert into takes values('74163', '496', '1', 'Fall', 2001, 'B+');
	insert into takes values('93004', '415', '1', 'Fall', 2010, 'B-');
	insert into takes values('73387', '843', '1', 'Fall', 2010, 'C ');
	insert into takes values('85226', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('17607', '702', '1', 'Spring', 2001, 'B-');
	insert into takes values('48678', '571', '1', 'Spring', 2004, 'C ');
	insert into takes values('80912', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('50386', '962', '1', 'Spring', 2008, 'B-');
	insert into takes values('90448', '468', '1', 'Fall', 2005, 'B+');
	insert into takes values('17924', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('65329', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('28952', '927', '1', 'Fall', 2002, 'A+');
	insert into takes values('66212', '972', '1', 'Spring', 2009, 'A-');
	insert into takes values('72669', '270', '1', 'Spring', 2010, 'C+');
	insert into takes values('67051', '603', '1', 'Fall', 2003, 'A ');
	insert into takes values('96003', '270', '1', 'Spring', 2010, 'B ');
	insert into takes values('75362', '960', '2', 'Fall', 2006, 'B+');
	insert into takes values('92332', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('14869', '545', '1', 'Fall', 2001, 'B ');
	insert into takes values('15030', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('63288', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('51923', '352', '1', 'Spring', 2006, 'A+');
	insert into takes values('8022', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('898', '843', '1', 'Fall', 2010, 'B+');
	insert into takes values('86641', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('53451', '795', '1', 'Spring', 2004, 'C+');
	insert into takes values('16885', '692', '1', 'Spring', 2010, 'A+');
	insert into takes values('67293', '974', '1', 'Fall', 2003, 'A-');
	insert into takes values('65681', '629', '1', 'Spring', 2003, 'B-');
	insert into takes values('7123', '808', '1', 'Fall', 2003, 'B+');
	insert into takes values('88993', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('15517', '426', '1', 'Spring', 2006, 'C ');
	insert into takes values('22179', '258', '1', 'Fall', 2007, 'A ');
	insert into takes values('94836', '415', '1', 'Fall', 2010, 'C+');
	insert into takes values('53788', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('10663', '852', '1', 'Spring', 2008, 'A ');
	insert into takes values('22254', '561', '1', 'Fall', 2006, 'C-');
	insert into takes values('76799', '795', '1', 'Spring', 2004, 'B+');
	insert into takes values('2178', '793', '1', 'Spring', 2002, 'C+');
	insert into takes values('59908', '415', '1', 'Fall', 2010, 'C ');
	insert into takes values('4355', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('92864', '468', '1', 'Fall', 2005, 'B ');
	insert into takes values('29435', '274', '1', 'Fall', 2002, 'C-');
	insert into takes values('57985', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('37284', '489', '1', 'Fall', 2007, 'A ');
	insert into takes values('82301', '747', '1', 'Spring', 2004, 'B+');
	insert into takes values('78922', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('90567', '274', '1', 'Fall', 2002, 'B-');
	insert into takes values('13511', '748', '1', 'Fall', 2003, 'B ');
	insert into takes values('36881', '974', '1', 'Fall', 2003, 'C-');
	insert into takes values('3693', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('56755', '545', '1', 'Fall', 2001, 'B ');
	insert into takes values('31080', '694', '1', 'Fall', 2002, 'A+');
	insert into takes values('63860', '692', '1', 'Spring', 2010, 'A+');
	insert into takes values('66229', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('11101', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('63243', '702', '1', 'Spring', 2001, 'C ');
	insert into takes values('15083', '545', '1', 'Fall', 2001, 'B-');
	insert into takes values('93004', '258', '1', 'Fall', 2007, 'B ');
	insert into takes values('49982', '362', '1', 'Fall', 2005, 'C ');
	insert into takes values('41827', '457', '1', 'Spring', 2001, 'C ');
	insert into takes values('51768', '443', '2', 'Spring', 2002, 'B-');
	insert into takes values('89297', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('35362', '408', '1', 'Spring', 2007, 'C ');
	insert into takes values('5703', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('93043', '561', '1', 'Fall', 2006, 'A+');
	insert into takes values('39472', '443', '1', 'Spring', 2010, 'B ');
	insert into takes values('58634', '362', '1', 'Fall', 2005, 'C-');
	insert into takes values('1460', '489', '1', 'Fall', 2007, 'C ');
	insert into takes values('86552', '400', '2', 'Fall', 2003, 'C ');
	insert into takes values('75878', '158', '1', 'Fall', 2008, 'C-');
	insert into takes values('17076', '338', '1', 'Spring', 2007, 'B ');
	insert into takes values('56078', '137', '1', 'Spring', 2002, 'B+');
	insert into takes values('21008', '893', '1', 'Fall', 2007, 'A+');
	insert into takes values('59673', '852', '1', 'Spring', 2008, 'C-');
	insert into takes values('82063', '237', '2', 'Fall', 2009, 'C ');
	insert into takes values('9993', '242', '1', 'Fall', 2009, 'A-');
	insert into takes values('43616', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('58846', '366', '1', 'Fall', 2005, 'A ');
	insert into takes values('23500', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('8347', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('94726', '960', '1', 'Fall', 2009, 'C-');
	insert into takes values('79170', '867', '1', 'Fall', 2006, 'B ');
	insert into takes values('12941', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('645', '496', '1', 'Fall', 2001, 'B ');
	insert into takes values('11455', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('86001', '457', '1', 'Spring', 2001, 'A+');
	insert into takes values('65190', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('75938', '376', '1', 'Fall', 2006, 'C ');
	insert into takes values('52385', '105', '1', 'Fall', 2009, 'B+');
	insert into takes values('50703', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('99780', '760', '1', 'Spring', 2004, 'C-');
	insert into takes values('282', '345', '1', 'Spring', 2008, 'B ');
	insert into takes values('86344', '476', '1', 'Fall', 2010, 'B ');
	insert into takes values('42388', '748', '1', 'Fall', 2003, 'B ');
	insert into takes values('39310', '760', '1', 'Spring', 2004, 'A-');
	insert into takes values('37219', '960', '1', 'Fall', 2009, 'B-');
	insert into takes values('48053', '105', '2', 'Fall', 2002, 'A-');
	insert into takes values('30772', '352', '1', 'Spring', 2006, 'C-');
	insert into takes values('80742', '319', '1', 'Spring', 2003, 'C-');
	insert into takes values('58085', '237', '1', 'Spring', 2008, 'C+');
	insert into takes values('6523', '304', '1', 'Fall', 2009, 'B+');
	insert into takes values('95852', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('67725', '400', '1', 'Spring', 2007, 'B+');
	insert into takes values('1727', '747', '1', 'Spring', 2004, 'A ');
	insert into takes values('94522', '362', '3', 'Spring', 2008, 'C-');
	insert into takes values('74672', '468', '2', 'Fall', 2007, 'A+');
	insert into takes values('43495', '604', '1', 'Spring', 2009, 'C ');
	insert into takes values('99348', '366', '1', 'Fall', 2005, 'A+');
	insert into takes values('28316', '400', '2', 'Fall', 2003, 'B-');
	insert into takes values('96206', '867', '1', 'Fall', 2006, 'A-');
	insert into takes values('42019', '443', '1', 'Spring', 2010, 'C ');
	insert into takes values('8140', '158', '1', 'Fall', 2008, 'A-');
	insert into takes values('46035', '443', '1', 'Spring', 2010, 'B-');
	insert into takes values('46155', '626', '1', 'Fall', 2006, 'A-');
	insert into takes values('78922', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('62549', '599', '1', 'Spring', 2003, 'B ');
	insert into takes values('87054', '421', '1', 'Fall', 2004, 'A ');
	insert into takes values('84432', '702', '1', 'Spring', 2001, 'A+');
	insert into takes values('36126', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('48053', '408', '2', 'Spring', 2003, 'C-');
	insert into takes values('3693', '192', '1', 'Fall', 2002, 'A+');
	insert into takes values('77244', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('1922', '704', '1', 'Spring', 2008, 'C ');
	insert into takes values('18583', '793', '1', 'Spring', 2002, 'B ');
	insert into takes values('23525', '527', '1', 'Fall', 2004, 'C ');
	insert into takes values('95574', '559', '1', 'Fall', 2002, 'B-');
	insert into takes values('45359', '735', '2', 'Spring', 2010, 'B ');
	insert into takes values('76057', '793', '1', 'Spring', 2002, 'B+');
	insert into takes values('92693', '631', '1', 'Spring', 2007, 'C-');
	insert into takes values('92464', '376', '1', 'Fall', 2006, 'C-');
	insert into takes values('96153', '443', '2', 'Spring', 2002, 'A ');
	insert into takes values('78922', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('67051', '972', '1', 'Spring', 2009, 'B-');
	insert into takes values('80285', '631', '1', 'Spring', 2007, 'B-');
	insert into takes values('11201', '626', '1', 'Fall', 2006, 'A-');
	insert into takes values('10454', '270', '1', 'Spring', 2010, 'B-');
	insert into takes values('46442', '457', '1', 'Spring', 2001, 'C ');
	insert into takes values('28409', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('29462', '748', '1', 'Fall', 2003, 'C-');
	insert into takes values('46337', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('23506', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('10033', '679', '1', 'Spring', 2010, 'A+');
	insert into takes values('78792', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('58846', '493', '1', 'Spring', 2010, 'A ');
	insert into takes values('81294', '991', '1', 'Spring', 2008, 'A ');
	insert into takes values('54612', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('75534', '334', '1', 'Fall', 2009, 'B ');
	insert into takes values('82039', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('37521', '561', '1', 'Fall', 2006, 'C+');
	insert into takes values('19848', '476', '1', 'Fall', 2010, 'A+');
	insert into takes values('64164', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('94257', '334', '1', 'Fall', 2009, 'A ');
	insert into takes values('48778', '808', '1', 'Fall', 2003, 'A+');
	insert into takes values('39881', '571', '1', 'Spring', 2004, 'A+');
	insert into takes values('41894', '760', '1', 'Spring', 2004, 'B+');
	insert into takes values('52187', '137', '1', 'Spring', 2002, 'A-');
	insert into takes values('7123', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('30222', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('56755', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('69679', '200', '1', 'Spring', 2007, 'C ');
	insert into takes values('49701', '962', '1', 'Spring', 2008, 'B-');
	insert into takes values('86934', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('51997', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('59920', '443', '2', 'Spring', 2002, 'C-');
	insert into takes values('44816', '960', '2', 'Fall', 2006, 'C ');
	insert into takes values('2201', '808', '1', 'Fall', 2003, 'B-');
	insert into takes values('68395', '974', '1', 'Fall', 2003, 'A-');
	insert into takes values('64297', '663', '1', 'Spring', 2005, 'B-');
	insert into takes values('83204', '692', '1', 'Spring', 2010, 'C+');
	insert into takes values('23311', '802', '1', 'Spring', 2003, 'B ');
	insert into takes values('85849', '604', '1', 'Spring', 2009, 'C ');
	insert into takes values('5017', '237', '1', 'Spring', 2008, 'A+');
	insert into takes values('99710', '692', '1', 'Spring', 2010, 'A+');
	insert into takes values('90132', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('91569', '486', '1', 'Fall', 2009, 'C+');
	insert into takes values('69581', '486', '1', 'Fall', 2009, 'A-');
	insert into takes values('64121', '408', '1', 'Spring', 2007, 'C ');
	insert into takes values('85809', '408', '1', 'Spring', 2007, 'C+');
	insert into takes values('51768', '867', '2', 'Fall', 2010, 'A+');
	insert into takes values('52876', '468', '2', 'Fall', 2007, 'B+');
	insert into takes values('14639', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('84808', '571', '1', 'Spring', 2004, 'B+');
	insert into takes values('19824', '400', '2', 'Fall', 2003, 'B-');
	insert into takes values('84167', '679', '1', 'Spring', 2010, 'B ');
	insert into takes values('83511', '400', '2', 'Fall', 2003, 'A ');
	insert into takes values('41675', '694', '1', 'Fall', 2002, 'C ');
	insert into takes values('42388', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('99289', '581', '1', 'Spring', 2005, 'A+');
	insert into takes values('9495', '760', '1', 'Spring', 2004, 'A ');
	insert into takes values('69679', '239', '1', 'Fall', 2006, 'B ');
	insert into takes values('59530', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('27043', '105', '2', 'Fall', 2002, 'A-');
	insert into takes values('56089', '604', '1', 'Spring', 2009, 'B-');
	insert into takes values('78332', '612', '1', 'Fall', 2007, 'C-');
	insert into takes values('74464', '702', '1', 'Spring', 2001, 'A-');
	insert into takes values('52371', '237', '2', 'Fall', 2009, 'A ');
	insert into takes values('9360', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('86344', '571', '1', 'Spring', 2004, 'B+');
	insert into takes values('72669', '242', '1', 'Fall', 2009, 'C-');
	insert into takes values('62429', '735', '2', 'Spring', 2010, 'C ');
	insert into takes values('26102', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('29803', '612', '1', 'Fall', 2007, 'C ');
	insert into takes values('22086', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('88308', '319', '1', 'Spring', 2003, 'B-');
	insert into takes values('42092', '270', '1', 'Spring', 2010, 'B-');
	insert into takes values('45720', '415', '1', 'Fall', 2010, 'C ');
	insert into takes values('40897', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('61166', '482', '1', 'Fall', 2005, 'C ');
	insert into takes values('36657', '959', '1', 'Fall', 2006, 'A+');
	insert into takes values('64945', '493', '1', 'Spring', 2010, 'C+');
	insert into takes values('37809', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('19220', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('61332', '591', '1', 'Spring', 2005, 'B+');
	insert into takes values('71944', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('78314', '158', '1', 'Fall', 2008, 'B-');
	insert into takes values('58355', '468', '1', 'Fall', 2005, 'A+');
	insert into takes values('31250', '747', '1', 'Spring', 2004, 'B+');
	insert into takes values('85981', '591', '1', 'Spring', 2005, 'B+');
	insert into takes values('2133', '991', '1', 'Spring', 2008, 'A ');
	insert into takes values('83557', '735', '2', 'Spring', 2010, 'A+');
	insert into takes values('87054', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('35881', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('8022', '338', '1', 'Spring', 2007, 'C+');
	insert into takes values('5617', '415', '1', 'Fall', 2010, 'B ');
	insert into takes values('37350', '559', '1', 'Fall', 2002, 'B+');
	insert into takes values('26427', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('57135', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('85063', '735', '1', 'Spring', 2003, 'B-');
	insert into takes values('39310', '345', '1', 'Spring', 2008, 'C-');
	insert into takes values('95201', '604', '1', 'Spring', 2009, 'C-');
	insert into takes values('47379', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('65144', '960', '1', 'Fall', 2009, 'A-');
	insert into takes values('36494', '408', '2', 'Spring', 2003, 'C-');
	insert into takes values('39241', '496', '1', 'Fall', 2001, 'C ');
	insert into takes values('37284', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('30161', '400', '1', 'Spring', 2007, 'C-');
	insert into takes values('77003', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('20244', '631', '1', 'Spring', 2007, 'C-');
	insert into takes values('95225', '972', '1', 'Spring', 2009, 'A+');
	insert into takes values('57156', '461', '1', 'Fall', 2002, 'B ');
	insert into takes values('30397', '960', '2', 'Fall', 2006, 'B-');
	insert into takes values('66763', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('87651', '867', '1', 'Fall', 2006, 'B ');
	insert into takes values('38712', '802', '1', 'Spring', 2003, 'C-');
	insert into takes values('4435', '599', '1', 'Spring', 2003, 'B ');
	insert into takes values('39552', '239', '1', 'Fall', 2006, 'B-');
	insert into takes values('80254', '612', '1', 'Fall', 2007, 'B ');
	insert into takes values('36995', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('46442', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('53165', '468', '1', 'Fall', 2005, 'B+');
	insert into takes values('67293', '169', '2', 'Fall', 2002, 'A+');
	insert into takes values('52471', '679', '1', 'Spring', 2010, 'B-');
	insert into takes values('32119', '864', '1', 'Spring', 2006, 'B ');
	insert into takes values('44206', '852', '1', 'Spring', 2008, 'B ');
	insert into takes values('65241', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('54605', '270', '1', 'Spring', 2010, 'A-');
	insert into takes values('25940', '461', '1', 'Fall', 2002, 'C ');
	insert into takes values('89059', '852', '1', 'Spring', 2008, 'A ');
	insert into takes values('44836', '200', '2', 'Fall', 2002, 'C-');
	insert into takes values('32130', '338', '1', 'Spring', 2007, 'C-');
	insert into takes values('5017', '105', '1', 'Fall', 2009, 'C ');
	insert into takes values('44352', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('76895', '376', '1', 'Fall', 2006, 'B+');
	insert into takes values('81876', '461', '1', 'Fall', 2002, 'A-');
	insert into takes values('75513', '702', '1', 'Spring', 2001, 'B ');
	insert into takes values('99647', '200', '2', 'Fall', 2002, 'C+');
	insert into takes values('51084', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('83728', '443', '2', 'Spring', 2002, 'B-');
	insert into takes values('12563', '629', '1', 'Spring', 2003, 'B-');
	insert into takes values('51553', '200', '1', 'Spring', 2007, 'C ');
	insert into takes values('88169', '571', '1', 'Spring', 2004, 'A-');
	insert into takes values('92332', '105', '1', 'Fall', 2009, 'B+');
	insert into takes values('14596', '200', '1', 'Spring', 2007, 'B+');
	insert into takes values('31302', '802', '1', 'Spring', 2003, 'B+');
	insert into takes values('14182', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('91978', '304', '1', 'Fall', 2009, 'B ');
	insert into takes values('21100', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('52750', '527', '1', 'Fall', 2004, 'A ');
	insert into takes values('32130', '242', '1', 'Fall', 2009, 'C+');
	insert into takes values('17057', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('85226', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('38712', '476', '1', 'Fall', 2010, 'B-');
	insert into takes values('53048', '401', '1', 'Fall', 2003, 'A ');
	insert into takes values('6729', '482', '1', 'Fall', 2005, 'B ');
	insert into takes values('1968', '313', '1', 'Fall', 2010, 'A ');
	insert into takes values('38899', '400', '1', 'Spring', 2007, 'C ');
	insert into takes values('98690', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('8912', '795', '1', 'Spring', 2004, 'B+');
	insert into takes values('44584', '545', '1', 'Fall', 2001, 'A ');
	insert into takes values('73186', '626', '1', 'Fall', 2006, 'C-');
	insert into takes values('31476', '927', '1', 'Fall', 2002, 'A-');
	insert into takes values('50013', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('68010', '486', '1', 'Fall', 2009, 'C ');
	insert into takes values('46980', '694', '1', 'Fall', 2002, 'C ');
	insert into takes values('83691', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('65753', '338', '1', 'Spring', 2007, 'A+');
	insert into takes values('86934', '748', '1', 'Fall', 2003, 'B ');
	insert into takes values('39394', '527', '1', 'Fall', 2004, 'B-');
	insert into takes values('99189', '408', '1', 'Spring', 2007, 'A+');
	insert into takes values('98690', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('91132', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('65299', '239', '1', 'Fall', 2006, 'B ');
	insert into takes values('18675', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('5925', '843', '1', 'Fall', 2010, 'C-');
	insert into takes values('52187', '237', '2', 'Fall', 2009, 'B-');
	insert into takes values('88793', '443', '1', 'Spring', 2010, 'B ');
	insert into takes values('21766', '692', '1', 'Spring', 2010, 'A-');
	insert into takes values('11202', '105', '1', 'Fall', 2009, 'C-');
	insert into takes values('85308', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('30161', '760', '1', 'Spring', 2004, 'B ');
	insert into takes values('49450', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('29920', '443', '2', 'Spring', 2002, 'B-');
	insert into takes values('28316', '443', '1', 'Spring', 2010, 'C ');
	insert into takes values('99754', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('25780', '852', '1', 'Spring', 2008, 'C+');
	insert into takes values('52866', '486', '1', 'Fall', 2009, 'B+');
	insert into takes values('9460', '200', '1', 'Spring', 2007, 'A ');
	insert into takes values('94173', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('50966', '960', '2', 'Fall', 2006, 'A-');
	insert into takes values('62832', '581', '1', 'Spring', 2005, 'B+');
	insert into takes values('41988', '105', '1', 'Fall', 2009, 'B+');
	insert into takes values('89414', '527', '1', 'Fall', 2004, 'A ');
	insert into takes values('92864', '864', '1', 'Spring', 2006, 'B+');
	insert into takes values('19735', '612', '1', 'Fall', 2007, 'A ');
	insert into takes values('914', '591', '1', 'Spring', 2005, 'C-');
	insert into takes values('70359', '242', '1', 'Fall', 2009, 'B+');
	insert into takes values('37734', '893', '1', 'Fall', 2007, 'A ');
	insert into takes values('50664', '345', '1', 'Spring', 2008, 'A+');
	insert into takes values('37581', '169', '1', 'Spring', 2007, 'C ');
	insert into takes values('10454', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('163', '603', '1', 'Fall', 2003, 'A ');
	insert into takes values('38548', '408', '1', 'Spring', 2007, 'A+');
	insert into takes values('95099', '105', '1', 'Fall', 2009, 'C ');
	insert into takes values('77364', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('53152', '679', '1', 'Spring', 2010, 'A+');
	insert into takes values('95205', '959', '1', 'Fall', 2006, 'C ');
	insert into takes values('21246', '461', '1', 'Fall', 2002, 'B+');
	insert into takes values('43032', '137', '1', 'Spring', 2002, 'A ');
	insert into takes values('66090', '426', '1', 'Spring', 2006, 'C ');
	insert into takes values('63449', '793', '1', 'Spring', 2002, 'B-');
	insert into takes values('50267', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('63645', '852', '1', 'Spring', 2008, 'C ');
	insert into takes values('33094', '270', '1', 'Spring', 2010, 'C ');
	insert into takes values('73492', '493', '1', 'Spring', 2010, 'C-');
	insert into takes values('80248', '852', '1', 'Spring', 2008, 'A-');
	insert into takes values('5824', '338', '2', 'Spring', 2006, 'A-');
	insert into takes values('14668', '561', '1', 'Fall', 2006, 'B-');
	insert into takes values('42625', '443', '1', 'Spring', 2010, 'B-');
	insert into takes values('50039', '561', '1', 'Fall', 2006, 'B+');
	insert into takes values('18286', '735', '1', 'Spring', 2003, 'B ');
	insert into takes values('46436', '274', '1', 'Fall', 2002, 'C+');
	insert into takes values('20378', '802', '1', 'Spring', 2003, 'C-');
	insert into takes values('73072', '642', '1', 'Fall', 2004, 'C-');
	insert into takes values('94894', '679', '1', 'Spring', 2010, 'B-');
	insert into takes values('64169', '960', '2', 'Fall', 2006, 'A-');
	insert into takes values('32056', '545', '1', 'Fall', 2001, 'A ');
	insert into takes values('80057', '415', '1', 'Fall', 2010, 'A+');
	insert into takes values('75547', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('10705', '702', '1', 'Spring', 2001, 'B-');
	insert into takes values('35293', '527', '1', 'Fall', 2004, 'A-');
	insert into takes values('66229', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('7970', '972', '1', 'Spring', 2009, 'A ');
	insert into takes values('78581', '408', '2', 'Spring', 2003, 'B+');
	insert into takes values('74796', '192', '1', 'Fall', 2002, 'B-');
	insert into takes values('56057', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('64914', '468', '1', 'Fall', 2005, 'C-');
	insert into takes values('5824', '237', '1', 'Spring', 2008, 'B-');
	insert into takes values('99760', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('63449', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('35721', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('79469', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('37339', '629', '1', 'Spring', 2003, 'B+');
	insert into takes values('82301', '304', '1', 'Fall', 2009, 'A+');
	insert into takes values('95029', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('35687', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('99711', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('75423', '974', '1', 'Fall', 2003, 'B-');
	insert into takes values('95850', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('67560', '304', '1', 'Fall', 2009, 'B-');
	insert into takes values('4015', '443', '2', 'Spring', 2002, 'C ');
	insert into takes values('75534', '626', '1', 'Fall', 2006, 'A ');
	insert into takes values('84792', '415', '1', 'Fall', 2010, 'B ');
	insert into takes values('24116', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('59538', '748', '1', 'Fall', 2003, 'A ');
	insert into takes values('92776', '795', '1', 'Spring', 2004, 'B+');
	insert into takes values('89414', '626', '1', 'Fall', 2006, 'B-');
	insert into takes values('94990', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('23934', '443', '1', 'Spring', 2010, 'A+');
	insert into takes values('77021', '200', '1', 'Spring', 2007, 'C ');
	insert into takes values('62784', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('32056', '421', '1', 'Fall', 2004, 'B-');
	insert into takes values('45300', '496', '1', 'Fall', 2001, 'C ');
	insert into takes values('95205', '559', '1', 'Fall', 2002, 'A-');
	insert into takes values('23994', '158', '2', 'Spring', 2008, 'C ');
	insert into takes values('80247', '795', '1', 'Spring', 2004, 'C+');
	insert into takes values('72643', '960', '1', 'Fall', 2009, 'B ');
	insert into takes values('86404', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('22254', '696', '1', 'Spring', 2002, 'C-');
	insert into takes values('61444', '105', '2', 'Fall', 2002, 'A+');
	insert into takes values('21101', '493', '1', 'Spring', 2010, 'C ');
	insert into takes values('53699', '486', '1', 'Fall', 2009, 'A-');
	insert into takes values('5250', '239', '1', 'Fall', 2006, 'C+');
	insert into takes values('33401', '366', '1', 'Fall', 2005, 'A ');
	insert into takes values('78314', '629', '1', 'Spring', 2003, 'B ');
	insert into takes values('65396', '679', '1', 'Spring', 2010, 'C-');
	insert into takes values('85366', '258', '1', 'Fall', 2007, 'C+');
	insert into takes values('23344', '735', '2', 'Spring', 2010, 'A+');
	insert into takes values('16480', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('84865', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('28004', '867', '2', 'Fall', 2010, 'C+');
	insert into takes values('57538', '443', '2', 'Spring', 2002, 'A ');
	insert into takes values('48778', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('44551', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('78782', '345', '1', 'Spring', 2008, 'A-');
	insert into takes values('59908', '400', '2', 'Fall', 2003, 'A+');
	insert into takes values('52741', '258', '1', 'Fall', 2007, 'A ');
	insert into takes values('69628', '875', '1', 'Spring', 2005, 'A-');
	insert into takes values('61414', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('34404', '258', '1', 'Fall', 2007, 'A+');
	insert into takes values('85308', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('85849', '493', '1', 'Spring', 2010, 'B+');
	insert into takes values('80799', '927', '1', 'Fall', 2002, 'A ');
	insert into takes values('60867', '962', '1', 'Spring', 2008, 'A ');
	insert into takes values('95850', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('48009', '489', '1', 'Fall', 2007, 'A ');
	insert into takes values('37809', '581', '1', 'Spring', 2005, 'A+');
	insert into takes values('5898', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('7123', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('32369', '612', '1', 'Fall', 2007, 'A ');
	insert into takes values('14668', '408', '2', 'Spring', 2003, 'C-');
	insert into takes values('5843', '489', '1', 'Fall', 2007, 'C+');
	insert into takes values('82591', '599', '1', 'Spring', 2003, 'B ');
	insert into takes values('80799', '105', '1', 'Fall', 2009, 'B ');
	insert into takes values('37869', '200', '2', 'Fall', 2002, 'A ');
	insert into takes values('69225', '319', '1', 'Spring', 2003, 'A ');
	insert into takes values('67371', '802', '1', 'Spring', 2003, 'B+');
	insert into takes values('90372', '445', '1', 'Spring', 2001, 'C ');
	insert into takes values('50664', '137', '1', 'Spring', 2002, 'C ');
	insert into takes values('14668', '400', '2', 'Fall', 2003, 'C+');
	insert into takes values('38013', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('63489', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('10904', '735', '1', 'Spring', 2003, 'A+');
	insert into takes values('87651', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('68396', '867', '2', 'Fall', 2010, 'B+');
	insert into takes values('66090', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('94311', '527', '1', 'Fall', 2004, 'C-');
	insert into takes values('22179', '867', '2', 'Fall', 2010, 'C-');
	insert into takes values('13757', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('63039', '362', '1', 'Fall', 2005, 'B+');
	insert into takes values('34569', '457', '1', 'Spring', 2001, 'C ');
	insert into takes values('96227', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('95099', '893', '1', 'Fall', 2007, 'B-');
	insert into takes values('43495', '443', '2', 'Spring', 2002, 'A-');
	insert into takes values('63612', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('82082', '362', '3', 'Spring', 2008, 'C+');
	insert into takes values('65258', '612', '1', 'Fall', 2007, 'A-');
	insert into takes values('63288', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('56882', '629', '1', 'Spring', 2003, 'B ');
	insert into takes values('91978', '362', '3', 'Spring', 2008, 'A-');
	insert into takes values('83314', '663', '1', 'Spring', 2005, 'B+');
	insert into takes values('44881', '362', '1', 'Fall', 2005, 'A-');
	insert into takes values('15249', '415', '1', 'Fall', 2010, 'A+');
	insert into takes values('31079', '443', '2', 'Spring', 2002, 'A-');
	insert into takes values('77415', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('61402', '527', '1', 'Fall', 2004, 'A+');
	insert into takes values('32368', '486', '1', 'Fall', 2009, 'C ');
	insert into takes values('92839', '349', '1', 'Spring', 2008, 'A-');
	insert into takes values('72165', '415', '1', 'Fall', 2010, 'A-');
	insert into takes values('99399', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('88308', '696', '1', 'Spring', 2002, 'C ');
	insert into takes values('88577', '443', '2', 'Spring', 2002, 'B-');
	insert into takes values('41261', '408', '2', 'Spring', 2003, 'C ');
	insert into takes values('94535', '192', '1', 'Fall', 2002, 'C-');
	insert into takes values('99719', '561', '1', 'Fall', 2006, 'B-');
	insert into takes values('10527', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('22198', '843', '1', 'Fall', 2010, 'A+');
	insert into takes values('97629', '527', '1', 'Fall', 2004, 'A ');
	insert into takes values('81258', '443', '2', 'Spring', 2002, 'C ');
	insert into takes values('62636', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('81884', '679', '1', 'Spring', 2010, 'B ');
	insert into takes values('76799', '352', '1', 'Spring', 2006, 'A-');
	insert into takes values('64138', '349', '1', 'Spring', 2008, 'C+');
	insert into takes values('10076', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('42625', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('17133', '457', '1', 'Spring', 2001, 'B+');
	insert into takes values('42388', '612', '1', 'Fall', 2007, 'A ');
	insert into takes values('20084', '960', '2', 'Fall', 2006, 'A ');
	insert into takes values('57135', '400', '1', 'Spring', 2007, 'A+');
	insert into takes values('58172', '334', '1', 'Fall', 2009, 'A-');
	insert into takes values('78782', '802', '1', 'Spring', 2003, 'C+');
	insert into takes values('65038', '408', '2', 'Spring', 2003, 'B-');
	insert into takes values('85981', '408', '2', 'Spring', 2003, 'B-');
	insert into takes values('53799', '338', '2', 'Spring', 2006, 'B ');
	insert into takes values('52203', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('40481', '612', '1', 'Fall', 2007, 'A-');
	insert into takes values('21246', '408', '2', 'Spring', 2003, 'A ');
	insert into takes values('34018', '864', '1', 'Spring', 2006, 'C-');
	insert into takes values('96246', '496', '1', 'Fall', 2001, 'B ');
	insert into takes values('5298', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('50598', '158', '1', 'Fall', 2008, 'B ');
	insert into takes values('40178', '735', '1', 'Spring', 2003, 'C-');
	insert into takes values('20814', '626', '1', 'Fall', 2006, 'C ');
	insert into takes values('68280', '237', '1', 'Spring', 2008, 'B+');
	insert into takes values('9183', '401', '1', 'Fall', 2003, 'B ');
	insert into takes values('53803', '760', '1', 'Spring', 2004, 'B-');
	insert into takes values('4860', '959', '1', 'Fall', 2006, 'C+');
	insert into takes values('16035', '875', '1', 'Spring', 2005, 'C-');
	insert into takes values('91992', '200', '1', 'Spring', 2007, 'A-');
	insert into takes values('90181', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('86802', '468', '1', 'Fall', 2005, 'B ');
	insert into takes values('88472', '843', '1', 'Fall', 2010, 'B-');
	insert into takes values('52385', '415', '1', 'Fall', 2010, 'C+');
	insert into takes values('11682', '949', '1', 'Fall', 2007, 'C-');
	insert into takes values('83691', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('53118', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('81031', '843', '1', 'Fall', 2010, 'B ');
	insert into takes values('80976', '421', '1', 'Fall', 2004, 'B+');
	insert into takes values('52371', '795', '1', 'Spring', 2004, 'B ');
	insert into takes values('96246', '559', '1', 'Fall', 2002, 'B+');
	insert into takes values('49450', '239', '1', 'Fall', 2006, 'C ');
	insert into takes values('64067', '274', '1', 'Fall', 2002, 'B ');
	insert into takes values('5463', '158', '1', 'Fall', 2008, 'C ');
	insert into takes values('30650', '408', '1', 'Spring', 2007, 'C-');
	insert into takes values('92693', '352', '1', 'Spring', 2006, 'A ');
	insert into takes values('38371', '893', '1', 'Fall', 2007, 'B ');
	insert into takes values('93125', '352', '1', 'Spring', 2006, 'B+');
	insert into takes values('24201', '629', '1', 'Spring', 2003, 'A ');
	insert into takes values('20084', '345', '1', 'Spring', 2008, 'A+');
	insert into takes values('37038', '604', '1', 'Spring', 2009, 'C ');
	insert into takes values('75299', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('81984', '599', '1', 'Spring', 2003, 'C+');
	insert into takes values('30164', '962', '1', 'Spring', 2008, 'C-');
	insert into takes values('94801', '401', '1', 'Fall', 2003, 'C+');
	insert into takes values('65987', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('83444', '793', '1', 'Spring', 2002, 'A ');
	insert into takes values('5017', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('41596', '852', '1', 'Spring', 2008, 'C-');
	insert into takes values('66753', '791', '1', 'Spring', 2006, 'C-');
	insert into takes values('9993', '791', '1', 'Spring', 2006, 'A-');
	insert into takes values('18675', '468', '1', 'Fall', 2005, 'B-');
	insert into takes values('27919', '421', '1', 'Fall', 2004, 'A-');
	insert into takes values('46655', '158', '2', 'Spring', 2008, 'B+');
	insert into takes values('77364', '991', '1', 'Spring', 2008, 'C-');
	insert into takes values('12683', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('16311', '802', '1', 'Spring', 2003, 'A+');
	insert into takes values('7970', '852', '1', 'Spring', 2008, 'A ');
	insert into takes values('5871', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('74464', '237', '1', 'Spring', 2008, 'B-');
	insert into takes values('21789', '476', '1', 'Fall', 2010, 'A ');
	insert into takes values('72014', '893', '1', 'Fall', 2007, 'C+');
	insert into takes values('19245', '760', '1', 'Spring', 2004, 'A-');
	insert into takes values('41741', '962', '1', 'Spring', 2008, 'C+');
	insert into takes values('57083', '735', '2', 'Spring', 2010, 'B-');
	insert into takes values('10814', '581', '1', 'Spring', 2005, 'C ');
	insert into takes values('69730', '591', '1', 'Spring', 2005, 'B-');
	insert into takes values('32464', '642', '1', 'Fall', 2004, 'B-');
	insert into takes values('68242', '349', '1', 'Spring', 2008, 'C-');
	insert into takes values('77244', '415', '1', 'Fall', 2010, 'C ');
	insert into takes values('78756', '808', '1', 'Fall', 2003, 'B ');
	insert into takes values('77898', '408', '1', 'Spring', 2007, 'A ');
	insert into takes values('5208', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('81175', '875', '1', 'Spring', 2005, 'A ');
	insert into takes values('70572', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('18234', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('69241', '631', '1', 'Spring', 2007, 'C+');
	insert into takes values('68242', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('25068', '663', '1', 'Spring', 2005, 'A-');
	insert into takes values('68779', '795', '1', 'Spring', 2004, 'B+');
	insert into takes values('68010', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('76057', '319', '1', 'Spring', 2003, 'A+');
	insert into takes values('7390', '239', '1', 'Fall', 2006, 'B-');
	insert into takes values('85445', '808', '1', 'Fall', 2003, 'C-');
	insert into takes values('87048', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('38336', '561', '1', 'Fall', 2006, 'A ');
	insert into takes values('18636', '352', '1', 'Spring', 2006, 'A+');
	insert into takes values('91992', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('858', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('18809', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('82580', '545', '1', 'Fall', 2001, 'C ');
	insert into takes values('41751', '603', '1', 'Fall', 2003, 'A-');
	insert into takes values('95320', '345', '1', 'Spring', 2008, 'A+');
	insert into takes values('10204', '696', '1', 'Spring', 2002, 'B-');
	insert into takes values('24796', '791', '1', 'Spring', 2006, 'B+');
	insert into takes values('123', '169', '2', 'Fall', 2002, 'B-');
	insert into takes values('10663', '237', '1', 'Spring', 2008, 'B+');
	insert into takes values('93039', '169', '2', 'Fall', 2002, 'B-');
	insert into takes values('23934', '791', '1', 'Spring', 2006, 'B-');
	insert into takes values('69850', '105', '1', 'Fall', 2009, 'C-');
	insert into takes values('39521', '559', '1', 'Fall', 2002, 'C+');
	insert into takes values('73602', '612', '1', 'Fall', 2007, 'C ');
	insert into takes values('94535', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('85849', '949', '1', 'Fall', 2007, 'B ');
	insert into takes values('92040', '105', '1', 'Fall', 2009, 'C+');
	insert into takes values('66269', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('81876', '599', '1', 'Spring', 2003, 'B ');
	insert into takes values('42114', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('48901', '237', '2', 'Fall', 2009, 'C+');
	insert into takes values('5617', '972', '1', 'Spring', 2009, 'C ');
	insert into takes values('85308', '960', '2', 'Fall', 2006, 'C ');
	insert into takes values('86552', '692', '1', 'Spring', 2010, 'A-');
	insert into takes values('64192', '445', '1', 'Spring', 2001, 'C ');
	insert into takes values('44985', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('93571', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('86651', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('14182', '476', '1', 'Fall', 2010, 'C+');
	insert into takes values('46769', '704', '1', 'Spring', 2008, 'B-');
	insert into takes values('81028', '626', '1', 'Fall', 2006, 'A ');
	insert into takes values('9953', '735', '2', 'Spring', 2010, 'A ');
	insert into takes values('2201', '461', '1', 'Fall', 2002, 'B ');
	insert into takes values('56058', '974', '1', 'Fall', 2003, 'C ');
	insert into takes values('12683', '445', '1', 'Spring', 2001, 'C+');
	insert into takes values('56089', '496', '1', 'Fall', 2001, 'B+');
	insert into takes values('56212', '867', '2', 'Fall', 2010, 'A+');
	insert into takes values('99268', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('88887', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('32886', '875', '1', 'Spring', 2005, 'A ');
	insert into takes values('99271', '338', '2', 'Spring', 2006, 'A-');
	insert into takes values('63582', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('66229', '791', '1', 'Spring', 2006, 'C+');
	insert into takes values('64724', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('5414', '421', '1', 'Fall', 2004, 'C-');
	insert into takes values('24442', '338', '2', 'Spring', 2006, 'C ');
	insert into takes values('71944', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('33107', '852', '1', 'Spring', 2008, 'B-');
	insert into takes values('59920', '960', '2', 'Fall', 2006, 'A ');
	insert into takes values('59046', '401', '1', 'Fall', 2003, 'A ');
	insert into takes values('93061', '362', '3', 'Spring', 2008, 'C-');
	insert into takes values('53118', '949', '1', 'Fall', 2007, 'C-');
	insert into takes values('62705', '927', '1', 'Fall', 2002, 'C-');
	insert into takes values('95205', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('85226', '875', '1', 'Spring', 2005, 'C ');
	insert into takes values('97065', '972', '1', 'Spring', 2009, 'A+');
	insert into takes values('35687', '421', '1', 'Fall', 2004, 'A ');
	insert into takes values('107', '366', '1', 'Fall', 2005, 'B-');
	insert into takes values('54612', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('27044', '443', '2', 'Spring', 2002, 'A-');
	insert into takes values('61854', '599', '1', 'Spring', 2003, 'B+');
	insert into takes values('72358', '631', '1', 'Spring', 2007, 'C ');
	insert into takes values('95953', '704', '1', 'Spring', 2008, 'C-');
	insert into takes values('28252', '400', '1', 'Spring', 2007, 'C ');
	insert into takes values('14563', '349', '1', 'Spring', 2008, 'B+');
	insert into takes values('90009', '867', '1', 'Fall', 2006, 'B+');
	insert into takes values('2139', '158', '2', 'Spring', 2008, 'B ');
	insert into takes values('30845', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('35362', '443', '1', 'Spring', 2010, 'A+');
	insert into takes values('33645', '468', '2', 'Fall', 2007, 'B ');
	insert into takes values('85754', '760', '1', 'Spring', 2004, 'A ');
	insert into takes values('95027', '581', '1', 'Spring', 2005, 'B+');
	insert into takes values('22620', '679', '1', 'Spring', 2010, 'A ');
	insert into takes values('87651', '962', '1', 'Spring', 2008, 'B ');
	insert into takes values('62705', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('87439', '237', '2', 'Fall', 2009, 'C-');
	insert into takes values('23475', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('59117', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('12069', '663', '1', 'Spring', 2005, 'A ');
	insert into takes values('44271', '692', '1', 'Spring', 2010, 'C+');
	insert into takes values('51238', '105', '1', 'Fall', 2009, 'B ');
	insert into takes values('34422', '545', '1', 'Fall', 2001, 'C ');
	insert into takes values('10033', '457', '1', 'Spring', 2001, 'C-');
	insert into takes values('86806', '242', '1', 'Fall', 2009, 'C-');
	insert into takes values('19293', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('49280', '489', '1', 'Fall', 2007, 'B ');
	insert into takes values('9360', '493', '1', 'Spring', 2010, 'C ');
	insert into takes values('40677', '461', '1', 'Fall', 2002, 'A-');
	insert into takes values('22260', '631', '1', 'Spring', 2007, 'C-');
	insert into takes values('8517', '362', '3', 'Spring', 2008, 'C+');
	insert into takes values('74163', '105', '1', 'Fall', 2009, 'A+');
	insert into takes values('79892', '748', '1', 'Fall', 2003, 'C-');
	insert into takes values('12711', '400', '1', 'Spring', 2007, 'C-');
	insert into takes values('78143', '631', '1', 'Spring', 2007, 'A-');
	insert into takes values('97400', '237', '1', 'Spring', 2008, 'B ');
	insert into takes values('37101', '362', '1', 'Fall', 2005, 'C+');
	insert into takes values('67514', '867', '2', 'Fall', 2010, 'A-');
	insert into takes values('43432', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('74473', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('26730', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('8912', '408', '1', 'Spring', 2007, 'A-');
	insert into takes values('46450', '663', '1', 'Spring', 2005, 'A-');
	insert into takes values('21394', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('90353', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('77664', '304', '1', 'Fall', 2009, 'A ');
	insert into takes values('85981', '338', '1', 'Spring', 2007, 'B+');
	insert into takes values('31554', '694', '1', 'Fall', 2002, 'A-');
	insert into takes values('81294', '867', '1', 'Fall', 2006, 'B ');
	insert into takes values('59539', '559', '1', 'Fall', 2002, 'C ');
	insert into takes values('13365', '239', '1', 'Fall', 2006, 'B+');
	insert into takes values('82687', '304', '1', 'Fall', 2009, 'C-');
	insert into takes values('70395', '612', '1', 'Fall', 2007, 'A+');
	insert into takes values('15024', '237', '1', 'Spring', 2008, 'C-');
	insert into takes values('82868', '962', '1', 'Spring', 2008, 'B+');
	insert into takes values('99399', '366', '1', 'Fall', 2005, 'B ');
	insert into takes values('92849', '747', '1', 'Spring', 2004, 'C ');
	insert into takes values('63489', '629', '1', 'Spring', 2003, 'A+');
	insert into takes values('57238', '864', '1', 'Spring', 2006, 'A-');
	insert into takes values('72528', '421', '1', 'Fall', 2004, 'C-');
	insert into takes values('62705', '808', '1', 'Fall', 2003, 'C ');
	insert into takes values('28352', '599', '1', 'Spring', 2003, 'B ');
	insert into takes values('40371', '400', '1', 'Spring', 2007, 'C+');
	insert into takes values('32772', '137', '1', 'Spring', 2002, 'C-');
	insert into takes values('43032', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('93043', '603', '1', 'Fall', 2003, 'C ');
	insert into takes values('96206', '702', '1', 'Spring', 2001, 'C-');
	insert into takes values('77003', '962', '1', 'Spring', 2008, 'C-');
	insert into takes values('41938', '408', '2', 'Spring', 2003, 'B ');
	insert into takes values('13757', '581', '1', 'Spring', 2005, 'C-');
	insert into takes values('10033', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('67222', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('99754', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('90082', '679', '1', 'Spring', 2010, 'B ');
	insert into takes values('2201', '545', '1', 'Fall', 2001, 'B ');
	insert into takes values('37734', '304', '1', 'Fall', 2009, 'C+');
	insert into takes values('97658', '274', '1', 'Fall', 2002, 'B ');
	insert into takes values('56299', '808', '1', 'Fall', 2003, 'C+');
	insert into takes values('72521', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('51238', '561', '1', 'Fall', 2006, 'A ');
	insert into takes values('77588', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('99451', '476', '1', 'Fall', 2010, 'C ');
	insert into takes values('78434', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('74911', '663', '1', 'Spring', 2005, 'B ');
	insert into takes values('70235', '461', '1', 'Fall', 2002, 'C-');
	insert into takes values('41832', '802', '1', 'Spring', 2003, 'C-');
	insert into takes values('42114', '313', '1', 'Fall', 2010, 'C-');
	insert into takes values('57456', '631', '1', 'Spring', 2007, 'C-');
	insert into takes values('64297', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('78572', '852', '1', 'Spring', 2008, 'A ');
	insert into takes values('51553', '334', '1', 'Fall', 2009, 'C ');
	insert into takes values('80057', '793', '1', 'Spring', 2002, 'A+');
	insert into takes values('36402', '362', '3', 'Spring', 2008, 'C+');
	insert into takes values('53788', '237', '1', 'Spring', 2008, 'C-');
	insert into takes values('1087', '864', '1', 'Spring', 2006, 'A ');
	insert into takes values('35198', '663', '1', 'Spring', 2005, 'B-');
	insert into takes values('59172', '192', '1', 'Fall', 2002, 'B ');
	insert into takes values('73213', '974', '1', 'Fall', 2003, 'A-');
	insert into takes values('77580', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('10834', '489', '1', 'Fall', 2007, 'B-');
	insert into takes values('81294', '443', '1', 'Spring', 2010, 'C ');
	insert into takes values('2133', '105', '2', 'Fall', 2002, 'C ');
	insert into takes values('2201', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('96772', '972', '1', 'Spring', 2009, 'A-');
	insert into takes values('19293', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('24796', '559', '1', 'Fall', 2002, 'A+');
	insert into takes values('75596', '158', '1', 'Fall', 2008, 'B+');
	insert into takes values('12971', '875', '1', 'Spring', 2005, 'A+');
	insert into takes values('39612', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('61166', '581', '1', 'Spring', 2005, 'A ');
	insert into takes values('22258', '158', '2', 'Spring', 2008, 'C+');
	insert into takes values('76049', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('33651', '949', '1', 'Fall', 2007, 'B-');
	insert into takes values('46337', '443', '1', 'Spring', 2010, 'C+');
	insert into takes values('47126', '362', '2', 'Fall', 2006, 'C+');
	insert into takes values('10556', '603', '1', 'Fall', 2003, 'A ');
	insert into takes values('88472', '612', '1', 'Fall', 2007, 'B-');
	insert into takes values('15538', '959', '1', 'Fall', 2006, 'C-');
	insert into takes values('2419', '591', '1', 'Spring', 2005, 'B-');
	insert into takes values('31560', '457', '1', 'Spring', 2001, 'A+');
	insert into takes values('53699', '571', '1', 'Spring', 2004, 'C-');
	insert into takes values('88287', '949', '1', 'Fall', 2007, 'B ');
	insert into takes values('29959', '704', '1', 'Spring', 2008, 'C-');
	insert into takes values('27950', '169', '2', 'Fall', 2002, 'C ');
	insert into takes values('4173', '489', '1', 'Fall', 2007, 'A+');
	insert into takes values('16347', '457', '1', 'Spring', 2001, 'B-');
	insert into takes values('69222', '612', '1', 'Fall', 2007, 'B ');
	insert into takes values('92965', '702', '1', 'Spring', 2001, 'B ');
	insert into takes values('56003', '793', '1', 'Spring', 2002, 'C-');
	insert into takes values('36384', '867', '2', 'Fall', 2010, 'A-');
	insert into takes values('38902', '893', '1', 'Fall', 2007, 'B ');
	insert into takes values('90009', '875', '1', 'Spring', 2005, 'B-');
	insert into takes values('83002', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('16311', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('53165', '421', '1', 'Fall', 2004, 'B ');
	insert into takes values('41299', '400', '1', 'Spring', 2007, 'B+');
	insert into takes values('645', '991', '1', 'Spring', 2008, 'C ');
	insert into takes values('2561', '694', '1', 'Fall', 2002, 'C-');
	insert into takes values('33338', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('96206', '696', '1', 'Spring', 2002, 'C ');
	insert into takes values('20489', '408', '1', 'Spring', 2007, 'B-');
	insert into takes values('83003', '760', '1', 'Spring', 2004, 'B+');
	insert into takes values('78552', '960', '2', 'Fall', 2006, 'C+');
	insert into takes values('28128', '795', '1', 'Spring', 2004, 'B+');
	insert into takes values('46725', '169', '2', 'Fall', 2002, 'A ');
	insert into takes values('1836', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('41683', '366', '1', 'Fall', 2005, 'A-');
	insert into takes values('75772', '747', '1', 'Spring', 2004, 'C ');
	insert into takes values('58935', '972', '1', 'Spring', 2009, 'C ');
	insert into takes values('39204', '426', '1', 'Spring', 2006, 'B+');
	insert into takes values('19321', '692', '1', 'Spring', 2010, 'C-');
	insert into takes values('91197', '137', '1', 'Spring', 2002, 'B ');
	insert into takes values('87193', '875', '1', 'Spring', 2005, 'C ');
	insert into takes values('30182', '445', '1', 'Spring', 2001, 'C-');
	insert into takes values('41973', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('85904', '319', '1', 'Spring', 2003, 'B ');
	insert into takes values('89196', '960', '1', 'Fall', 2009, 'B ');
	insert into takes values('29435', '959', '1', 'Fall', 2006, 'C+');
	insert into takes values('2286', '972', '1', 'Spring', 2009, 'C-');
	insert into takes values('78143', '242', '1', 'Fall', 2009, 'B-');
	insert into takes values('82066', '239', '1', 'Fall', 2006, 'C+');
	insert into takes values('58307', '468', '1', 'Fall', 2005, 'C ');
	insert into takes values('29849', '200', '2', 'Fall', 2002, 'C+');
	insert into takes values('42556', '352', '1', 'Spring', 2006, 'A+');
	insert into takes values('68248', '875', '1', 'Spring', 2005, 'B+');
	insert into takes values('13211', '158', '2', 'Spring', 2008, 'C ');
	insert into takes values('57538', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('5898', '461', '1', 'Fall', 2002, 'A+');
	insert into takes values('50365', '362', '3', 'Spring', 2008, 'A+');
	insert into takes values('67542', '493', '1', 'Spring', 2010, 'C+');
	insert into takes values('14484', '626', '1', 'Fall', 2006, 'B+');
	insert into takes values('17207', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('22396', '400', '1', 'Spring', 2007, 'A+');
	insert into takes values('99250', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('80976', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('19862', '443', '1', 'Spring', 2010, 'B ');
	insert into takes values('11095', '626', '1', 'Fall', 2006, 'A ');
	insert into takes values('24932', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('11152', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('43981', '867', '2', 'Fall', 2010, 'A-');
	insert into takes values('3651', '493', '1', 'Spring', 2010, 'A-');
	insert into takes values('91569', '137', '1', 'Spring', 2002, 'B+');
	insert into takes values('47487', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('51093', '626', '1', 'Fall', 2006, 'A-');
	insert into takes values('11057', '795', '1', 'Spring', 2004, 'A-');
	insert into takes values('87831', '400', '2', 'Fall', 2003, 'C-');
	insert into takes values('61166', '496', '1', 'Fall', 2001, 'A ');
	insert into takes values('41599', '349', '1', 'Spring', 2008, 'A+');
	insert into takes values('77234', '426', '1', 'Spring', 2006, 'C+');
	insert into takes values('29803', '559', '1', 'Fall', 2002, 'C-');
	insert into takes values('37350', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('86736', '612', '1', 'Fall', 2007, 'B ');
	insert into takes values('48611', '626', '1', 'Fall', 2006, 'A+');
	insert into takes values('40303', '629', '1', 'Spring', 2003, 'A ');
	insert into takes values('85211', '334', '1', 'Fall', 2009, 'A ');
	insert into takes values('3651', '237', '2', 'Fall', 2009, 'C+');
	insert into takes values('90372', '591', '1', 'Spring', 2005, 'C+');
	insert into takes values('35905', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('11453', '334', '1', 'Fall', 2009, 'A-');
	insert into takes values('93491', '304', '1', 'Fall', 2009, 'B ');
	insert into takes values('10556', '105', '1', 'Fall', 2009, 'B+');
	insert into takes values('58935', '362', '1', 'Fall', 2005, 'C-');
	insert into takes values('75046', '974', '1', 'Fall', 2003, 'C+');
	insert into takes values('59290', '960', '1', 'Fall', 2009, 'C ');
	insert into takes values('56499', '663', '1', 'Spring', 2005, 'A+');
	insert into takes values('40178', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('37350', '415', '1', 'Fall', 2010, 'A+');
	insert into takes values('28538', '345', '1', 'Spring', 2008, 'C+');
	insert into takes values('66356', '400', '2', 'Fall', 2003, 'C+');
	insert into takes values('47487', '489', '1', 'Fall', 2007, 'A ');
	insert into takes values('20814', '401', '1', 'Fall', 2003, 'A ');
	insert into takes values('75510', '704', '1', 'Spring', 2008, 'C+');
	insert into takes values('44352', '376', '1', 'Fall', 2006, 'C ');
	insert into takes values('22050', '843', '1', 'Fall', 2010, 'A+');
	insert into takes values('20985', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('35905', '349', '1', 'Spring', 2008, 'C ');
	insert into takes values('58170', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('5898', '581', '1', 'Spring', 2005, 'C ');
	insert into takes values('67583', '561', '1', 'Fall', 2006, 'C+');
	insert into takes values('29192', '319', '1', 'Spring', 2003, 'B+');
	insert into takes values('6673', '642', '1', 'Fall', 2004, 'A ');
	insert into takes values('11083', '960', '1', 'Fall', 2009, 'C+');
	insert into takes values('463', '401', '1', 'Fall', 2003, 'C-');
	insert into takes values('66753', '972', '1', 'Spring', 2009, 'B+');
	insert into takes values('57055', '843', '1', 'Fall', 2010, 'A-');
	insert into takes values('20974', '493', '1', 'Spring', 2010, 'A-');
	insert into takes values('39310', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('31820', '960', '1', 'Fall', 2009, 'B ');
	insert into takes values('81031', '599', '1', 'Spring', 2003, 'B+');
	insert into takes values('23224', '949', '1', 'Fall', 2007, 'B+');
	insert into takes values('43989', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('898', '581', '1', 'Spring', 2005, 'B+');
	insert into takes values('32881', '304', '1', 'Fall', 2009, 'C+');
	insert into takes values('64938', '852', '1', 'Spring', 2008, 'B+');
	insert into takes values('53490', '319', '1', 'Spring', 2003, 'B ');
	insert into takes values('73268', '631', '1', 'Spring', 2007, 'A-');
	insert into takes values('16467', '200', '1', 'Spring', 2007, 'B ');
	insert into takes values('99073', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('76049', '319', '1', 'Spring', 2003, 'B-');
	insert into takes values('37818', '169', '1', 'Spring', 2007, 'B+');
	insert into takes values('75116', '760', '1', 'Spring', 2004, 'C ');
	insert into takes values('27952', '200', '1', 'Spring', 2007, 'A+');
	insert into takes values('88887', '604', '1', 'Spring', 2009, 'A ');
	insert into takes values('58594', '843', '1', 'Fall', 2010, 'C ');
	insert into takes values('3005', '200', '2', 'Fall', 2002, 'C+');
	insert into takes values('62429', '760', '1', 'Spring', 2004, 'C+');
	insert into takes values('50267', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('32464', '867', '1', 'Fall', 2006, 'A+');
	insert into takes values('35042', '489', '1', 'Fall', 2007, 'A-');
	insert into takes values('47670', '334', '1', 'Fall', 2009, 'C+');
	insert into takes values('30845', '352', '1', 'Spring', 2006, 'B ');
	insert into takes values('85981', '748', '1', 'Fall', 2003, 'C-');
	insert into takes values('54296', '158', '1', 'Fall', 2008, 'C ');
	insert into takes values('84189', '401', '1', 'Fall', 2003, 'A+');
	insert into takes values('85754', '959', '1', 'Fall', 2006, 'A-');
	insert into takes values('34236', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('81028', '192', '1', 'Fall', 2002, 'C+');
	insert into takes values('10454', '334', '1', 'Fall', 2009, 'B-');
	insert into takes values('10076', '105', '1', 'Fall', 2009, 'C-');
	insert into takes values('22620', '496', '1', 'Fall', 2001, 'B-');
	insert into takes values('18808', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('30164', '415', '1', 'Fall', 2010, 'C-');
	insert into takes values('45570', '960', '1', 'Fall', 2009, 'B-');
	insert into takes values('49813', '258', '1', 'Fall', 2007, 'C ');
	insert into takes values('59046', '626', '1', 'Fall', 2006, 'A ');
	insert into takes values('20002', '192', '1', 'Fall', 2002, 'A ');
	insert into takes values('52019', '808', '1', 'Fall', 2003, 'A ');
	insert into takes values('89104', '158', '2', 'Spring', 2008, 'B-');
	insert into takes values('51579', '237', '1', 'Spring', 2008, 'A+');
	insert into takes values('23794', '443', '1', 'Spring', 2010, 'A+');
	insert into takes values('96615', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('70098', '696', '1', 'Spring', 2002, 'A+');
	insert into takes values('97868', '748', '1', 'Fall', 2003, 'B ');
	insert into takes values('18286', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('19766', '461', '1', 'Fall', 2002, 'C+');
	insert into takes values('99226', '493', '1', 'Spring', 2010, 'C-');
	insert into takes values('99780', '169', '2', 'Fall', 2002, 'C-');
	insert into takes values('17076', '362', '1', 'Fall', 2005, 'B-');
	insert into takes values('26619', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('2501', '468', '2', 'Fall', 2007, 'B-');
	insert into takes values('13880', '426', '1', 'Spring', 2006, 'C-');
	insert into takes values('2501', '400', '1', 'Spring', 2007, 'A ');
	insert into takes values('33817', '960', '1', 'Fall', 2009, 'A ');
	insert into takes values('85614', '559', '1', 'Fall', 2002, 'B+');
	insert into takes values('51538', '345', '1', 'Spring', 2008, 'C ');
	insert into takes values('75938', '169', '1', 'Spring', 2007, 'A+');
	insert into takes values('37219', '795', '1', 'Spring', 2004, 'B-');
	insert into takes values('73542', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('27727', '581', '1', 'Spring', 2005, 'A ');
	insert into takes values('10269', '421', '1', 'Fall', 2004, 'B-');
	insert into takes values('13217', '443', '1', 'Spring', 2010, 'A ');
	insert into takes values('45494', '959', '1', 'Fall', 2006, 'A-');
	insert into takes values('44271', '105', '1', 'Fall', 2009, 'C+');
	insert into takes values('64138', '748', '1', 'Fall', 2003, 'B ');
	insert into takes values('39114', '237', '1', 'Spring', 2008, 'C-');
	insert into takes values('19582', '443', '1', 'Spring', 2010, 'B-');
	insert into takes values('72521', '461', '1', 'Fall', 2002, 'A-');
	insert into takes values('78572', '169', '1', 'Spring', 2007, 'A ');
	insert into takes values('46155', '338', '1', 'Spring', 2007, 'C+');
	insert into takes values('80420', '893', '1', 'Fall', 2007, 'C+');
	insert into takes values('43130', '237', '1', 'Spring', 2008, 'B-');
	insert into takes values('65681', '352', '1', 'Spring', 2006, 'C+');
	insert into takes values('49073', '949', '1', 'Fall', 2007, 'A ');
	insert into takes values('71543', '960', '2', 'Fall', 2006, 'B ');
	insert into takes values('83039', '692', '1', 'Spring', 2010, 'B-');
	insert into takes values('62054', '561', '1', 'Fall', 2006, 'C-');
	insert into takes values('1827', '400', '1', 'Spring', 2007, 'C+');
	insert into takes values('33817', '581', '1', 'Spring', 2005, 'A-');
	insert into takes values('16885', '426', '1', 'Spring', 2006, 'C ');
	insert into takes values('898', '545', '1', 'Fall', 2001, 'A+');
	insert into takes values('87784', '959', '1', 'Fall', 2006, 'A+');
	insert into takes values('21789', '468', '1', 'Fall', 2005, 'A ');
	insert into takes values('21556', '192', '1', 'Fall', 2002, 'C-');
	insert into takes values('69758', '169', '2', 'Fall', 2002, 'B-');
	insert into takes values('7490', '795', '1', 'Spring', 2004, 'A-');
	insert into takes values('49339', '493', '1', 'Spring', 2010, 'A ');
	insert into takes values('76250', '258', '1', 'Fall', 2007, 'A+');
	insert into takes values('92949', '338', '2', 'Spring', 2006, 'B+');
	insert into takes values('69122', '571', '1', 'Spring', 2004, 'A-');
	insert into takes values('1968', '631', '1', 'Spring', 2007, 'A-');
	insert into takes values('64259', '304', '1', 'Fall', 2009, 'A-');
	insert into takes values('82970', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('463', '843', '1', 'Fall', 2010, 'A ');
	insert into takes values('75273', '408', '1', 'Spring', 2007, 'C ');
	insert into takes values('59539', '696', '1', 'Spring', 2002, 'C+');
	insert into takes values('87651', '338', '2', 'Spring', 2006, 'A+');
	insert into takes values('73387', '974', '1', 'Fall', 2003, 'A ');
	insert into takes values('55857', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('74639', '408', '1', 'Spring', 2007, 'B ');
	insert into takes values('92849', '642', '1', 'Fall', 2004, 'C ');
	insert into takes values('29192', '482', '1', 'Fall', 2005, 'B ');
	insert into takes values('61081', '200', '2', 'Fall', 2002, 'C ');
	insert into takes values('95089', '527', '1', 'Fall', 2004, 'C+');
	insert into takes values('59172', '345', '1', 'Spring', 2008, 'C+');
	insert into takes values('15883', '604', '1', 'Spring', 2009, 'A-');
	insert into takes values('81031', '362', '1', 'Fall', 2005, 'C-');
	insert into takes values('46066', '400', '1', 'Spring', 2007, 'B-');
	insert into takes values('7490', '663', '1', 'Spring', 2005, 'C ');
	insert into takes values('46442', '626', '1', 'Fall', 2006, 'B-');
	insert into takes values('13495', '867', '2', 'Fall', 2010, 'A ');
	insert into takes values('4582', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('38555', '663', '1', 'Spring', 2005, 'A-');
	insert into takes values('27140', '158', '2', 'Spring', 2008, 'B-');
	insert into takes values('83002', '629', '1', 'Spring', 2003, 'A ');
	insert into takes values('91442', '599', '1', 'Spring', 2003, 'C+');
	insert into takes values('41675', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('96911', '426', '1', 'Spring', 2006, 'A-');
	insert into takes values('19848', '704', '1', 'Spring', 2008, 'B ');
	insert into takes values('41683', '875', '1', 'Spring', 2005, 'B-');
	insert into takes values('57242', '270', '1', 'Spring', 2010, 'C+');
	insert into takes values('11441', '629', '1', 'Spring', 2003, 'A+');
	insert into takes values('1232', '349', '1', 'Spring', 2008, 'B+');
	insert into takes values('81550', '893', '1', 'Fall', 2007, 'B+');
	insert into takes values('73186', '137', '1', 'Spring', 2002, 'C+');
	insert into takes values('18775', '400', '1', 'Spring', 2007, 'B ');
	insert into takes values('94535', '415', '1', 'Fall', 2010, 'C ');
	insert into takes values('14554', '893', '1', 'Fall', 2007, 'B+');
	insert into takes values('34404', '366', '1', 'Fall', 2005, 'A ');
	insert into takes values('20244', '852', '1', 'Spring', 2008, 'B+');
	insert into takes values('14432', '200', '2', 'Fall', 2002, 'A+');
	insert into takes values('84654', '603', '1', 'Fall', 2003, 'A+');
	insert into takes values('69730', '496', '1', 'Fall', 2001, 'C+');
	insert into takes values('87054', '702', '1', 'Spring', 2001, 'B+');
	insert into takes values('27430', '362', '1', 'Fall', 2005, 'A ');
	insert into takes values('76169', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('22268', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('87193', '702', '1', 'Spring', 2001, 'B-');
	insert into takes values('31250', '696', '1', 'Spring', 2002, 'B+');
	insert into takes values('79589', '237', '1', 'Spring', 2008, 'B+');
	insert into takes values('28977', '642', '1', 'Fall', 2004, 'A-');
	insert into takes values('57962', '974', '1', 'Fall', 2003, 'A+');
	insert into takes values('23994', '795', '1', 'Spring', 2004, 'C-');
	insert into takes values('57083', '200', '2', 'Fall', 2002, 'A ');
	insert into takes values('31364', '169', '2', 'Fall', 2002, 'C ');
	insert into takes values('78581', '864', '1', 'Spring', 2006, 'B-');
	insert into takes values('64550', '603', '1', 'Fall', 2003, 'C+');
	insert into takes values('64401', '629', '1', 'Spring', 2003, 'A-');
	insert into takes values('94324', '400', '1', 'Spring', 2007, 'C ');
	insert into takes values('81789', '629', '1', 'Spring', 2003, 'B-');
	insert into takes values('42092', '489', '1', 'Fall', 2007, 'B ');
	insert into takes values('69081', '559', '1', 'Fall', 2002, 'A ');
	insert into takes values('78469', '468', '2', 'Fall', 2007, 'B ');
	insert into takes values('36126', '571', '1', 'Spring', 2004, 'B ');
	insert into takes values('40080', '972', '1', 'Spring', 2009, 'A-');
	insert into takes values('32772', '468', '1', 'Fall', 2005, 'A-');
	insert into takes values('57431', '604', '1', 'Spring', 2009, 'A-');
	insert into takes values('67293', '735', '2', 'Spring', 2010, 'A-');
	insert into takes values('97228', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('29002', '457', '1', 'Spring', 2001, 'C-');
	insert into takes values('99730', '802', '1', 'Spring', 2003, 'C ');
	insert into takes values('69679', '599', '1', 'Spring', 2003, 'B ');
	insert into takes values('99710', '949', '1', 'Fall', 2007, 'B ');
	insert into takes values('9256', '105', '2', 'Fall', 2002, 'B-');
	insert into takes values('34404', '376', '1', 'Fall', 2006, 'A+');
	insert into takes values('73542', '875', '1', 'Spring', 2005, 'A ');
	insert into takes values('79911', '445', '1', 'Spring', 2001, 'B ');
	insert into takes values('51955', '496', '1', 'Fall', 2001, 'A+');
	insert into takes values('88472', '581', '1', 'Spring', 2005, 'B-');
	insert into takes values('75299', '991', '1', 'Spring', 2008, 'B+');
	insert into takes values('62705', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('48778', '362', '3', 'Spring', 2008, 'B-');
	insert into takes values('79502', '482', '1', 'Fall', 2005, 'B+');
	insert into takes values('17507', '258', '1', 'Fall', 2007, 'A ');
	insert into takes values('18636', '692', '1', 'Spring', 2010, 'B ');
	insert into takes values('52385', '960', '2', 'Fall', 2006, 'A-');
	insert into takes values('98056', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('3163', '400', '1', 'Spring', 2007, 'A-');
	insert into takes values('19766', '791', '1', 'Spring', 2006, 'B ');
	insert into takes values('23110', '793', '1', 'Spring', 2002, 'B ');
	insert into takes values('89000', '366', '1', 'Fall', 2005, 'C-');
	insert into takes values('36244', '426', '1', 'Spring', 2006, 'A ');
	insert into takes values('28977', '274', '1', 'Fall', 2002, 'C ');
	insert into takes values('19603', '692', '1', 'Spring', 2010, 'C-');
	insert into takes values('914', '319', '1', 'Spring', 2003, 'A-');
	insert into takes values('35498', '599', '1', 'Spring', 2003, 'C-');
	insert into takes values('64138', '319', '1', 'Spring', 2003, 'A-');
	insert into takes values('85505', '581', '1', 'Spring', 2005, 'B ');
	insert into takes values('65101', '468', '2', 'Fall', 2007, 'B ');
	insert into takes values('31761', '366', '1', 'Fall', 2005, 'B+');
	insert into takes values('83170', '169', '1', 'Spring', 2007, 'B-');
	insert into takes values('898', '443', '1', 'Spring', 2010, 'C-');
	insert into takes values('29920', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('56941', '599', '1', 'Spring', 2003, 'A+');
	insert into takes values('81984', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('97042', '443', '2', 'Spring', 2002, 'C-');
	insert into takes values('27804', '137', '1', 'Spring', 2002, 'B-');
	insert into takes values('30021', '679', '1', 'Spring', 2010, 'B ');
	insert into takes values('68150', '747', '1', 'Spring', 2004, 'C-');
	insert into takes values('89000', '242', '1', 'Fall', 2009, 'A ');
	insert into takes values('70299', '237', '2', 'Fall', 2009, 'C-');
	insert into takes values('94801', '791', '1', 'Spring', 2006, 'C ');
	insert into takes values('43854', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('95626', '338', '2', 'Spring', 2006, 'B+');
	insert into takes values('30858', '338', '2', 'Spring', 2006, 'C ');
	insert into takes values('17207', '237', '1', 'Spring', 2008, 'B+');
	insert into takes values('26695', '629', '1', 'Spring', 2003, 'B-');
	insert into takes values('13753', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('20084', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('75878', '802', '1', 'Spring', 2003, 'A-');
	insert into takes values('25068', '338', '2', 'Spring', 2006, 'C-');
	insert into takes values('22258', '843', '1', 'Fall', 2010, 'C-');
	insert into takes values('53588', '949', '1', 'Fall', 2007, 'A+');
	insert into takes values('66212', '400', '1', 'Spring', 2007, 'C+');
	insert into takes values('36494', '696', '1', 'Spring', 2002, 'A ');
	insert into takes values('20489', '599', '1', 'Spring', 2003, 'C+');
	insert into takes values('24387', '468', '2', 'Fall', 2007, 'C-');
	insert into takes values('46442', '747', '1', 'Spring', 2004, 'B ');
	insert into takes values('31137', '642', '1', 'Fall', 2004, 'B ');
	insert into takes values('2177', '493', '1', 'Spring', 2010, 'C ');
	insert into takes values('99369', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('66269', '867', '1', 'Fall', 2006, 'A-');
	insert into takes values('6367', '949', '1', 'Fall', 2007, 'C-');
	insert into takes values('22254', '426', '1', 'Spring', 2006, 'B-');
	insert into takes values('64550', '334', '1', 'Fall', 2009, 'A+');
	insert into takes values('45680', '599', '1', 'Spring', 2003, 'A+');
	insert into takes values('7020', '105', '2', 'Fall', 2002, 'A+');
	insert into takes values('1460', '949', '1', 'Fall', 2007, 'C ');
	insert into takes values('78116', '581', '1', 'Spring', 2005, 'C+');
	insert into takes values('61444', '192', '1', 'Fall', 2002, 'A+');
	insert into takes values('15024', '237', '2', 'Fall', 2009, 'B+');
	insert into takes values('51678', '893', '1', 'Fall', 2007, 'A+');
	insert into takes values('32483', '408', '1', 'Spring', 2007, 'A+');
	insert into takes values('60406', '270', '1', 'Spring', 2010, 'A-');
	insert into takes values('26080', '445', '1', 'Spring', 2001, 'B-');
	insert into takes values('68720', '362', '3', 'Spring', 2008, 'C ');
	insert into takes values('85809', '599', '1', 'Spring', 2003, 'A ');
	insert into takes values('77289', '493', '1', 'Spring', 2010, 'B ');
	insert into takes values('83214', '591', '1', 'Spring', 2005, 'A+');
	insert into takes values('81610', '694', '1', 'Fall', 2002, 'B+');
	insert into takes values('77415', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('85746', '408', '2', 'Spring', 2003, 'B-');
	insert into takes values('95046', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('15726', '334', '1', 'Fall', 2009, 'A ');
	insert into takes values('6990', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('39204', '793', '1', 'Spring', 2002, 'C ');
	insert into takes values('70452', '313', '1', 'Fall', 2010, 'A+');
	insert into takes values('73602', '482', '1', 'Fall', 2005, 'B ');
	insert into takes values('75395', '426', '1', 'Spring', 2006, 'A+');
	insert into takes values('9933', '362', '3', 'Spring', 2008, 'A ');
	insert into takes values('80990', '843', '1', 'Fall', 2010, 'B+');
	insert into takes values('1727', '852', '1', 'Spring', 2008, 'B+');
	insert into takes values('26695', '927', '1', 'Fall', 2002, 'C+');
	insert into takes values('84845', '747', '1', 'Spring', 2004, 'A ');
	insert into takes values('64192', '258', '1', 'Fall', 2007, 'B-');
	insert into takes values('97953', '489', '1', 'Fall', 2007, 'A ');
	insert into takes values('42388', '747', '1', 'Spring', 2004, 'A+');
	insert into takes values('63502', '591', '1', 'Spring', 2005, 'C ');
	insert into takes values('23270', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('15283', '927', '1', 'Fall', 2002, 'B-');
	insert into takes values('63645', '426', '1', 'Spring', 2006, 'A ');
	insert into takes values('89051', '408', '2', 'Spring', 2003, 'A ');
	insert into takes values('89414', '482', '1', 'Fall', 2005, 'C ');
	insert into takes values('30943', '629', '1', 'Spring', 2003, 'B-');
	insert into takes values('63645', '345', '1', 'Spring', 2008, 'A ');
	insert into takes values('86753', '362', '2', 'Fall', 2006, 'B+');
	insert into takes values('40738', '105', '2', 'Fall', 2002, 'A+');
	insert into takes values('26473', '612', '1', 'Fall', 2007, 'C ');
	insert into takes values('69732', '735', '1', 'Spring', 2003, 'A-');
	insert into takes values('50966', '468', '2', 'Fall', 2007, 'C ');
	insert into takes values('73328', '972', '1', 'Spring', 2009, 'B+');
	insert into takes values('85063', '345', '1', 'Spring', 2008, 'C-');
	insert into takes values('11578', '959', '1', 'Fall', 2006, 'A-');
	insert into takes values('49684', '747', '1', 'Spring', 2004, 'C+');
	insert into takes values('66259', '319', '1', 'Spring', 2003, 'A-');
	insert into takes values('84808', '158', '1', 'Fall', 2008, 'C+');
	insert into takes values('49759', '489', '1', 'Fall', 2007, 'B ');
	insert into takes values('31101', '692', '1', 'Spring', 2010, 'B-');
	insert into takes values('40303', '972', '1', 'Spring', 2009, 'C-');
	insert into takes values('11195', '960', '2', 'Fall', 2006, 'A-');
	insert into takes values('29091', '158', '1', 'Fall', 2008, 'B+');
	insert into takes values('51997', '200', '2', 'Fall', 2002, 'B ');
	insert into takes values('336', '443', '1', 'Spring', 2010, 'B ');
	insert into takes values('21225', '704', '1', 'Spring', 2008, 'B+');
	insert into takes values('40992', '457', '1', 'Spring', 2001, 'C ');
	insert into takes values('15980', '591', '1', 'Spring', 2005, 'C-');
	insert into takes values('23392', '991', '1', 'Spring', 2008, 'A+');
	insert into takes values('57026', '486', '1', 'Fall', 2009, 'A-');
	insert into takes values('38336', '852', '1', 'Spring', 2008, 'C-');
	insert into takes values('95366', '457', '1', 'Spring', 2001, 'B ');
	insert into takes values('58355', '793', '1', 'Spring', 2002, 'C ');
	insert into takes values('76672', '352', '1', 'Spring', 2006, 'B-');
	insert into takes values('99226', '258', '1', 'Fall', 2007, 'C-');
	insert into takes values('55915', '875', '1', 'Spring', 2005, 'C-');
	insert into takes values('50414', '486', '1', 'Fall', 2009, 'C-');
	insert into takes values('80047', '401', '1', 'Fall', 2003, 'B-');
	insert into takes values('53172', '362', '2', 'Fall', 2006, 'A+');
	insert into takes values('29920', '489', '1', 'Fall', 2007, 'C+');
	insert into takes values('15086', '242', '1', 'Fall', 2009, 'C-');
	insert into takes values('34502', '875', '1', 'Spring', 2005, 'B-');
	insert into takes values('20489', '974', '1', 'Fall', 2003, 'C ');
	insert into takes values('1884', '345', '1', 'Spring', 2008, 'C+');
	insert into takes values('7602', '663', '1', 'Spring', 2005, 'A-');
	insert into takes values('73186', '400', '2', 'Fall', 2003, 'B ');
	insert into takes values('18808', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('61783', '362', '3', 'Spring', 2008, 'C+');
	insert into takes values('23506', '694', '1', 'Fall', 2002, 'C+');
	insert into takes values('64196', '443', '2', 'Spring', 2002, 'A ');
	insert into takes values('53152', '629', '1', 'Spring', 2003, 'C-');
	insert into takes values('11530', '603', '1', 'Fall', 2003, 'B-');
	insert into takes values('23110', '237', '1', 'Spring', 2008, 'A-');
	insert into takes values('83136', '338', '2', 'Spring', 2006, 'B-');
	insert into takes values('15517', '274', '1', 'Fall', 2002, 'B+');
	insert into takes values('88308', '893', '1', 'Fall', 2007, 'C-');
	insert into takes values('69122', '747', '1', 'Spring', 2004, 'A-');
	insert into takes values('20002', '352', '1', 'Spring', 2006, 'C+');
	insert into takes values('31554', '169', '2', 'Fall', 2002, 'C+');
	insert into takes values('82083', '445', '1', 'Spring', 2001, 'A+');
	insert into takes values('75547', '527', '1', 'Fall', 2004, 'B ');
	insert into takes values('72055', '366', '1', 'Fall', 2005, 'C+');
	insert into takes values('16593', '270', '1', 'Spring', 2010, 'A+');
	insert into takes values('57456', '561', '1', 'Fall', 2006, 'B-');
	insert into takes values('39892', '489', '1', 'Fall', 2007, 'A-');
	insert into takes values('81150', '408', '2', 'Spring', 2003, 'B ');
	insert into takes values('85754', '875', '1', 'Spring', 2005, 'C+');
	insert into takes values('49214', '795', '1', 'Spring', 2004, 'A+');
	insert into takes values('65753', '748', '1', 'Fall', 2003, 'A+');
	insert into takes values('84239', '959', '1', 'Fall', 2006, 'B-');
	insert into takes values('17397', '270', '1', 'Spring', 2010, 'C+');
	insert into takes values('81396', '489', '1', 'Fall', 2007, 'C-');
	insert into takes values('86661', '105', '1', 'Fall', 2009, 'A ');
	insert into takes values('31337', '735', '1', 'Spring', 2003, 'C-');
	insert into takes values('95631', '362', '3', 'Spring', 2008, 'B+');
	insert into takes values('83696', '612', '1', 'Fall', 2007, 'B-');
	insert into takes values('5898', '443', '2', 'Spring', 2002, 'B+');
	insert into takes values('4182', '468', '1', 'Fall', 2005, 'C+');
	insert into takes values('21101', '702', '1', 'Spring', 2001, 'C ');
	insert into takes values('85746', '867', '2', 'Fall', 2010, 'A-');
	insert into takes values('50331', '400', '1', 'Spring', 2007, 'A+');
	insert into takes values('40371', '345', '1', 'Spring', 2008, 'B ');
	insert into takes values('48165', '239', '1', 'Fall', 2006, 'A+');
	insert into takes values('64934', '270', '1', 'Spring', 2010, 'C ');
	insert into takes values('3487', '629', '1', 'Spring', 2003, 'C+');
	insert into takes values('18636', '795', '1', 'Spring', 2004, 'C ');
	insert into takes values('13211', '242', '1', 'Fall', 2009, 'B+');
	insert into takes values('99977', '867', '1', 'Fall', 2006, 'A+');
	insert into takes values('7043', '679', '1', 'Spring', 2010, 'C-');
	insert into takes values('61003', '802', '1', 'Spring', 2003, 'B-');
	insert into takes values('96206', '200', '1', 'Spring', 2007, 'B-');
	insert into takes values('94814', '493', '1', 'Spring', 2010, 'B-');
	insert into takes values('89104', '242', '1', 'Fall', 2009, 'A-');
	insert into takes values('16885', '415', '1', 'Fall', 2010, 'A ');
	insert into takes values('8957', '603', '1', 'Fall', 2003, 'B ');
	insert into takes values('40276', '893', '1', 'Fall', 2007, 'C ');
	insert into takes values('41774', '696', '1', 'Spring', 2002, 'A+');
	insert into takes values('66484', '747', '1', 'Spring', 2004, 'C ');
	insert into takes values('45300', '237', '1', 'Spring', 2008, 'B ');
	insert into takes values('97629', '735', '2', 'Spring', 2010, 'C-');
	insert into takes values('71631', '604', '1', 'Spring', 2009, 'A-');
	insert into takes values('23224', '735', '1', 'Spring', 2003, 'A ');
	insert into takes values('38121', '867', '2', 'Fall', 2010, 'C-');
	insert into takes values('11201', '476', '1', 'Fall', 2010, 'C-');
	insert into takes values('63502', '867', '1', 'Fall', 2006, 'C-');
	insert into takes values('30845', '735', '2', 'Spring', 2010, 'C+');
	insert into takes values('71631', '581', '1', 'Spring', 2005, 'A ');
	insert into takes values('31820', '237', '2', 'Fall', 2009, 'A+');
	insert into takes values('62124', '927', '1', 'Fall', 2002, 'B ');
	insert into takes values('94569', '362', '2', 'Fall', 2006, 'A-');
	insert into takes values('41890', '571', '1', 'Spring', 2004, 'A ');
	insert into takes values('97590', '867', '1', 'Fall', 2006, 'B-');
	insert into takes values('99226', '237', '2', 'Fall', 2009, 'B ');
	insert into takes values('94535', '679', '1', 'Spring', 2010, 'A ');
	insert into takes values('52876', '169', '2', 'Fall', 2002, 'A-');
	insert into takes values('71631', '200', '2', 'Fall', 2002, 'A-');
	insert into takes values('16347', '629', '1', 'Spring', 2003, 'B+');
	insert into takes values('77130', '591', '1', 'Spring', 2005, 'C+');
	insert into takes values('53490', '334', '1', 'Fall', 2009, 'B ');
	insert into takes values('19766', '482', '1', 'Fall', 2005, 'C-');
	insert into takes values('60984', '468', '1', 'Fall', 2005, 'A-');
	insert into takes values('65714', '457', '1', 'Spring', 2001, 'B-');
	insert into takes values('52929', '338', '1', 'Spring', 2007, 'A ');
	insert into takes values('31086', '319', '1', 'Spring', 2003, 'C-');
	insert into takes values('75794', '338', '1', 'Spring', 2007, 'A ');
	insert into takes values('48165', '105', '2', 'Fall', 2002, 'A ');
	insert into takes values('79911', '239', '1', 'Fall', 2006, 'A ');
	insert into takes values('12078', '972', '1', 'Spring', 2009, 'C+');
	insert into takes values('760', '972', '1', 'Spring', 2009, 'C-');
	insert into takes values('16035', '338', '2', 'Spring', 2006, 'C+');
	insert into takes values('35498', '545', '1', 'Fall', 2001, 'C-');
	insert into takes values('60406', '852', '1', 'Spring', 2008, 'A-');
	insert into takes values('40178', '612', '1', 'Fall', 2007, 'C+');
	insert into takes values('36995', '991', '1', 'Spring', 2008, 'B ');
	insert into takes values('34542', '960', '2', 'Fall', 2006, 'B+');
	insert into takes values('68096', '169', '2', 'Fall', 2002, 'B-');
	insert into takes values('41596', '349', '1', 'Spring', 2008, 'B ');
	insert into takes values('96741', '867', '1', 'Fall', 2006, 'C ');
	insert into takes values('3833', '972', '1', 'Spring', 2009, 'A+');
	insert into takes values('74974', '791', '1', 'Spring', 2006, 'A+');
	insert into takes values('99764', '105', '2', 'Fall', 2002, 'A ');
	insert into takes values('645', '105', '1', 'Fall', 2009, 'A-');
	insert into takes values('85308', '242', '1', 'Fall', 2009, 'A ');
	insert into takes values('25331', '852', '1', 'Spring', 2008, 'A+');
	insert into takes values('18740', '527', '1', 'Fall', 2004, 'C+');
	insert into takes values('85063', '338', '2', 'Spring', 2006, 'B ');
	insert into takes values('32506', '443', '1', 'Spring', 2010, 'B-');
	insert into takes values('70522', '864', '1', 'Spring', 2006, 'A+');
	insert into takes values('73542', '802', '1', 'Spring', 2003, 'A ');
	insert into takes values('56089', '169', '1', 'Spring', 2007, 'C-');
	insert into takes values('51868', '486', '1', 'Fall', 2009, 'A+');
	insert into takes values('53165', '192', '1', 'Fall', 2002, 'C-');
	insert into takes values('7498', '642', '1', 'Fall', 2004, 'A-');
	insert into takes values('81550', '426', '1', 'Spring', 2006, 'A+');
	insert into takes values('17128', '401', '1', 'Fall', 2003, 'B+');
	insert into takes values('43616', '974', '1', 'Fall', 2003, 'B+');
	insert into takes values('53165', '200', '1', 'Spring', 2007, 'C+');
	insert into takes values('44551', '962', '1', 'Spring', 2008, 'B-');
	insert into takes values('50537', '169', '1', 'Spring', 2007, 'B-');
	insert into takes values('38712', '345', '1', 'Spring', 2008, 'B+');
	insert into takes values('34331', '362', '2', 'Fall', 2006, 'C ');
	insert into takes values('96153', '400', '1', 'Spring', 2007, 'A+');
	insert into takes values('94257', '270', '1', 'Spring', 2010, 'B+');
	insert into takes values('97694', '694', '1', 'Fall', 2002, 'C+');
	insert into takes values('36845', '571', '1', 'Spring', 2004, 'B-');
	insert into takes values('41674', '545', '1', 'Fall', 2001, 'A+');
	insert into takes values('36685', '457', '1', 'Spring', 2001, 'C-');
	insert into takes values('36265', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('7854', '735', '1', 'Spring', 2003, 'A ');
	insert into takes values('49611', '468', '2', 'Fall', 2007, 'A ');
	insert into takes values('37946', '972', '1', 'Spring', 2009, 'B+');
	insert into takes values('49339', '599', '1', 'Spring', 2003, 'B-');
	insert into takes values('35588', '679', '1', 'Spring', 2010, 'A-');
	insert into takes values('858', '962', '1', 'Spring', 2008, 'C-');
	insert into takes values('43016', '421', '1', 'Fall', 2004, 'A ');
	insert into takes values('52019', '200', '2', 'Fall', 2002, 'A+');
	insert into takes values('90448', '158', '1', 'Fall', 2008, 'B-');
	insert into takes values('73213', '626', '1', 'Fall', 2006, 'A-');
	insert into takes values('26494', '960', '2', 'Fall', 2006, 'A+');
	insert into takes values('7973', '349', '1', 'Spring', 2008, 'B-');
	insert into takes values('24010', '105', '2', 'Fall', 2002, 'B ');
	insert into takes values('30650', '679', '1', 'Spring', 2010, 'C ');
	insert into takes values('90089', '169', '1', 'Spring', 2007, 'C+');
	insert into takes values('19321', '200', '2', 'Fall', 2002, 'A+');
	insert into takes values('60688', '960', '2', 'Fall', 2006, 'C-');
	insert into takes values('29192', '748', '1', 'Fall', 2003, 'C+');
	insert into takes values('87785', '461', '1', 'Fall', 2002, 'A ');
	insert into takes values('70359', '927', '1', 'Fall', 2002, 'C ');
	insert into takes values('11201', '319', '1', 'Spring', 2003, 'B ');
	insert into takes values('89132', '875', '1', 'Spring', 2005, 'C ');
	insert into advisor values('24746', '19368');
	insert into advisor values('79352', '95030');
	insert into advisor values('76672', '22591');
	insert into advisor values('14182', '77346');
	insert into advisor values('44985', '31955');
	insert into advisor values('96052', '73623');
	insert into advisor values('35175', '90643');
	insert into advisor values('44271', '58558');
	insert into advisor values('40897', '73623');
	insert into advisor values('92839', '25946');
	insert into advisor values('79329', '58558');
	insert into advisor values('97101', '48570');
	insert into advisor values('24865', '6569');
	insert into advisor values('36052', '31955');
	insert into advisor values('98940', '99052');
	insert into advisor values('21395', '58558');
	insert into advisor values('55859', '28097');
	insert into advisor values('74016', '74420');
	insert into advisor values('93061', '64871');
	insert into advisor values('94998', '50330');
	insert into advisor values('30772', '57180');
	insert into advisor values('1968', '3335');
	insert into advisor values('90567', '48507');
	insert into advisor values('49611', '58558');
	insert into advisor values('81538', '59795');
	insert into advisor values('68999', '6569');
	insert into advisor values('74639', '41930');
	insert into advisor values('66054', '25946');
	insert into advisor values('792', '48507');
	insert into advisor values('60267', '81991');
	insert into advisor values('17769', '36897');
	insert into advisor values('39580', '3199');
	insert into advisor values('89106', '15347');
	insert into advisor values('37856', '25946');
	insert into advisor values('58307', '48507');
	insert into advisor values('57985', '52647');
	insert into advisor values('72014', '22591');
	insert into advisor values('2795', '28400');
	insert into advisor values('89000', '58558');
	insert into advisor values('46442', '48570');
	insert into advisor values('60040', '15347');
	insert into advisor values('19791', '59795');
	insert into advisor values('4582', '64871');
	insert into advisor values('108', '77346');
	insert into advisor values('1533', '50885');
	insert into advisor values('7123', '65931');
	insert into advisor values('44584', '64871');
	insert into advisor values('32954', '90376');
	insert into advisor values('98056', '73623');
	insert into advisor values('76953', '79081');
	insert into advisor values('81884', '3199');
	insert into advisor values('22057', '48507');
	insert into advisor values('21126', '52647');
	insert into advisor values('82918', '81991');
	insert into advisor values('4173', '25946');
	insert into advisor values('83022', '64871');
	insert into advisor values('25525', '96895');
	insert into advisor values('75040', '80759');
	insert into advisor values('31624', '41930');
	insert into advisor values('64893', '96895');
	insert into advisor values('59920', '72553');
	insert into advisor values('38602', '77346');
	insert into advisor values('21401', '79081');
	insert into advisor values('93004', '15347');
	insert into advisor values('38899', '37687');
	insert into advisor values('75241', '28097');
	insert into advisor values('98830', '80759');
	insert into advisor values('37101', '80759');
	insert into advisor values('4508', '28097');
	insert into advisor values('32130', '16807');
	insert into advisor values('56755', '79653');
	insert into advisor values('11510', '95709');
	insert into advisor values('3335', '74420');
	insert into advisor values('61081', '80759');
	insert into advisor values('33651', '96895');
	insert into advisor values('8251', '73623');
	insert into advisor values('10705', '6569');
	insert into advisor values('64082', '74426');
	insert into advisor values('59517', '34175');
	insert into advisor values('91569', '14365');
	insert into advisor values('88085', '28400');
	insert into advisor values('96722', '58558');
	insert into advisor values('36379', '42782');
	insert into advisor values('69581', '25946');
	insert into advisor values('65329', '3335');
	insert into advisor values('49214', '4034');
	insert into advisor values('64155', '36897');
	insert into advisor values('58594', '74420');
	insert into advisor values('71904', '95030');
	insert into advisor values('69241', '72553');
	insert into advisor values('58889', '3335');
	insert into advisor values('30341', '79081');
	insert into advisor values('70688', '97302');
	insert into advisor values('81258', '58558');
	insert into advisor values('63090', '25946');
	insert into advisor values('70572', '35579');
	insert into advisor values('58413', '28400');
	insert into advisor values('93171', '6569');
	insert into advisor values('35138', '41930');
	insert into advisor values('77289', '59795');
	insert into advisor values('93571', '57180');
	insert into advisor values('14554', '22591');
	insert into advisor values('46725', '90376');
	insert into advisor values('99730', '3199');
	insert into advisor values('10527', '36897');
	insert into advisor values('898', '22591');
	insert into advisor values('64297', '43779');
	insert into advisor values('10204', '65931');
	insert into advisor values('36926', '43779');
	insert into advisor values('49618', '74426');
	insert into advisor values('34329', '81991');
	insert into advisor values('84410', '81991');
	insert into advisor values('29435', '77346');
	insert into advisor values('62636', '79081');
	insert into advisor values('8483', '74426');
	insert into advisor values('2177', '50330');
	insert into advisor values('43348', '81991');
	insert into advisor values('37430', '41930');
	insert into advisor values('37586', '81991');
	insert into advisor values('55238', '35579');
	insert into advisor values('34404', '74426');
	insert into advisor values('59539', '28400');
	insert into advisor values('43123', '95030');
	insert into advisor values('19582', '96895');
	insert into advisor values('88553', '31955');
	insert into advisor values('5898', '34175');
	insert into advisor values('2419', '73623');
	insert into advisor values('31516', '95030');
	insert into advisor values('3487', '4034');
	insert into advisor values('66269', '58558');
	insert into advisor values('54622', '4034');
	insert into advisor values('19638', '4034');
	insert into advisor values('88418', '57180');
	insert into advisor values('86802', '35579');
	insert into advisor values('63361', '90643');
	insert into advisor values('6367', '14365');
	insert into advisor values('84239', '22591');
	insert into advisor values('4940', '15347');
	insert into advisor values('90663', '77346');
	insert into advisor values('38476', '95030');
	insert into advisor values('96003', '3335');
	insert into advisor values('64914', '14365');
	insert into advisor values('41599', '48507');
	insert into advisor values('22226', '64871');
	insert into advisor values('96153', '28097');
	insert into advisor values('44998', '36897');
	insert into advisor values('74163', '80759');
	insert into advisor values('75046', '16807');
	insert into advisor values('97679', '43779');
	insert into advisor values('94894', '78699');
	insert into advisor values('44881', '22591');
	insert into advisor values('98619', '77346');
	insert into advisor values('86753', '22591');
	insert into advisor values('87054', '35579');
	insert into advisor values('39046', '19368');
	insert into advisor values('29031', '78699');
	insert into advisor values('97355', '28400');
	insert into advisor values('24010', '80759');
	insert into advisor values('21789', '63395');
	insert into advisor values('52157', '65931');
	insert into advisor values('64938', '52647');
	insert into advisor values('94535', '50885');
	insert into advisor values('58595', '31955');
	insert into advisor values('72979', '41930');
	insert into advisor values('32506', '28097');
	insert into advisor values('31690', '14365');
	insert into advisor values('87044', '36897');
	insert into advisor values('34236', '57180');
	insert into advisor values('18808', '77346');
	insert into advisor values('91063', '52647');
	insert into advisor values('48462', '52647');
	insert into advisor values('41965', '65931');
	insert into advisor values('31137', '50330');
	insert into advisor values('7602', '63287');
	insert into advisor values('84845', '6569');
	insert into advisor values('28252', '90643');
	insert into advisor values('10736', '90643');
	insert into advisor values('58465', '59795');
	insert into advisor values('64140', '52647');
	insert into advisor values('6523', '43779');
	insert into advisor values('64067', '77346');
	insert into advisor values('99399', '4034');
	insert into advisor values('21337', '43779');
	insert into advisor values('15457', '95709');
	insert into advisor values('26102', '99052');
	insert into advisor values('31337', '50330');
	insert into advisor values('67425', '42782');
	insert into advisor values('48640', '3335');
	insert into advisor values('72741', '80759');
	insert into advisor values('29803', '3199');
	insert into advisor values('38895', '15347');
	insert into advisor values('49391', '16807');
	insert into advisor values('13741', '4034');
	insert into advisor values('59538', '42782');
	insert into advisor values('9360', '28097');
	insert into advisor values('53728', '57180');
	insert into advisor values('77898', '15347');
	insert into advisor values('32419', '95030');
	insert into advisor values('37521', '4034');
	insert into advisor values('97065', '79653');
	insert into advisor values('80057', '90376');
	insert into advisor values('1826', '64871');
	insert into advisor values('80285', '73623');
	insert into advisor values('72959', '90643');
	insert into advisor values('41751', '34175');
	insert into advisor values('11604', '43779');
	insert into advisor values('41827', '35579');
	insert into advisor values('8853', '99052');
	insert into advisor values('9440', '4233');
	insert into advisor values('1884', '72553');
	insert into advisor values('41774', '37687');
	insert into advisor values('32385', '72553');
	insert into advisor values('336', '28097');
	insert into advisor values('82688', '79081');
	insert into advisor values('66090', '35579');
	insert into advisor values('4182', '63287');
	insert into advisor values('20099', '95709');
	insert into advisor values('81028', '78699');
	insert into advisor values('27556', '28400');
	insert into advisor values('65258', '6569');
	insert into advisor values('29239', '65931');
	insert into advisor values('54508', '80759');
	insert into advisor values('37449', '63287');
	insert into advisor values('16753', '96895');
	insert into advisor values('82697', '63287');
	insert into advisor values('11422', '37687');
	insert into advisor values('59046', '19368');
	insert into advisor values('89246', '35579');
	insert into advisor values('95859', '6569');
	insert into advisor values('94173', '43779');
	insert into advisor values('70021', '96895');
	insert into advisor values('92040', '19368');
	insert into advisor values('36019', '96895');
	insert into advisor values('40558', '79653');
	insert into advisor values('62549', '77346');
	insert into advisor values('92385', '50885');
	insert into advisor values('14214', '22591');
	insert into advisor values('32245', '15347');
	insert into advisor values('13506', '90643');
	insert into advisor values('26080', '6569');
	insert into advisor values('52872', '28400');
	insert into advisor values('28952', '74420');
	insert into advisor values('1080', '25946');
	insert into advisor values('11095', '48570');
	insert into advisor values('33460', '95709');
	insert into advisor values('99226', '79081');
	insert into advisor values('52707', '64871');
	insert into advisor values('40189', '22591');
	insert into advisor values('35721', '43779');
	insert into advisor values('6400', '80759');
	insert into advisor values('60688', '73623');
	insert into advisor values('18821', '59795');
	insert into advisor values('65443', '95709');
	insert into advisor values('71630', '48570');
	insert into advisor values('46956', '48570');
	insert into advisor values('64259', '64871');
	insert into advisor values('77021', '73623');
	insert into advisor values('41450', '77346');
	insert into advisor values('13028', '78699');
	insert into advisor values('90381', '16807');
	insert into advisor values('9460', '3199');
	insert into advisor values('98423', '64871');
	insert into advisor values('38691', '28400');
	insert into advisor values('86806', '48570');
	insert into advisor values('18469', '97302');
	insert into advisor values('11194', '16807');
	insert into advisor values('19862', '48507');
	insert into advisor values('24116', '16807');
	insert into advisor values('67021', '65931');
	insert into advisor values('69752', '16807');
	insert into advisor values('69225', '50330');
	insert into advisor values('1018', '79653');
	insert into advisor values('7656', '63287');
	insert into advisor values('35220', '80759');
	insert into advisor values('79210', '34175');
	insert into advisor values('10814', '4034');
	insert into advisor values('55698', '25946');
	insert into advisor values('49684', '95030');
	insert into advisor values('59908', '15347');
	insert into advisor values('64724', '35579');
	insert into advisor values('19048', '73623');
	insert into advisor values('62716', '90376');
	insert into advisor values('95205', '25946');
	insert into advisor values('40303', '99052');
	insert into advisor values('27430', '48570');
	insert into advisor values('83953', '50885');
	insert into advisor values('4248', '15347');
	insert into advisor values('21766', '22591');
	insert into advisor values('39657', '28400');
	insert into advisor values('85366', '48570');
	insert into advisor values('93354', '52647');
	insert into advisor values('77580', '41930');
	insert into advisor values('92864', '74420');
	insert into advisor values('57135', '50330');
	insert into advisor values('1727', '77346');
	insert into advisor values('91788', '15347');
	insert into advisor values('80420', '3199');
	insert into advisor values('67810', '79653');
	insert into advisor values('86404', '43779');
	insert into advisor values('16907', '78699');
	insert into advisor values('46928', '3199');
	insert into advisor values('84702', '14365');
	insert into advisor values('91343', '15347');
	insert into advisor values('83686', '90376');
	insert into advisor values('83462', '97302');
	insert into advisor values('67725', '74426');
	insert into advisor values('5393', '41930');
	insert into advisor values('34422', '79653');
	insert into advisor values('17128', '4034');
	insert into advisor values('81883', '50885');
	insert into advisor values('87965', '74426');
	insert into advisor values('93653', '15347');
	insert into advisor values('70522', '50330');
	insert into advisor values('48850', '36897');
	insert into advisor values('68070', '73623');
	insert into advisor values('50206', '81991');
	insert into advisor values('80254', '79081');
	insert into advisor values('22396', '48507');
	insert into advisor values('19293', '73623');
	insert into advisor values('67660', '42782');
	insert into advisor values('85910', '79653');
	insert into advisor values('10917', '77346');
	insert into advisor values('95574', '95030');
	insert into advisor values('13081', '96895');
	insert into advisor values('33349', '78699');
	insert into advisor values('19861', '25946');
	insert into advisor values('30723', '74420');
	insert into advisor values('83039', '74420');
	insert into advisor values('41741', '43779');
	insert into advisor values('97400', '90376');
	insert into advisor values('81207', '43779');
	insert into advisor values('23994', '57180');
	insert into advisor values('54672', '77346');
	insert into advisor values('47001', '50330');
	insert into advisor values('26147', '78699');
	insert into advisor values('65987', '36897');
	insert into advisor values('99250', '73623');
	insert into advisor values('13826', '31955');
	insert into advisor values('3739', '99052');
	insert into advisor values('10454', '37687');
	insert into advisor values('48053', '35579');
	insert into advisor values('66813', '95709');
	insert into advisor values('16593', '80759');
	insert into advisor values('14668', '80759');
	insert into advisor values('33338', '95030');
	insert into advisor values('45300', '37687');
	insert into advisor values('3127', '35579');
	insert into advisor values('40992', '63395');
	insert into advisor values('70310', '90376');
	insert into advisor values('46451', '90643');
	insert into advisor values('288', '41930');
	insert into advisor values('557', '63287');
	insert into advisor values('22170', '73623');
	insert into advisor values('64164', '72553');
	insert into advisor values('74911', '59795');
	insert into advisor values('7020', '31955');
	insert into advisor values('78552', '4233');
	insert into advisor values('50386', '48507');
	insert into advisor values('48678', '6569');
	insert into advisor values('24442', '74426');
	insert into advisor values('89188', '80759');
	insert into advisor values('390', '4233');
	insert into advisor values('10663', '28097');
	insert into advisor values('97551', '50330');
	insert into advisor values('76895', '43779');
	insert into advisor values('85451', '99052');
	insert into advisor values('43989', '74426');
	insert into advisor values('99719', '58558');
	insert into advisor values('19245', '80759');
	insert into advisor values('36685', '4034');
	insert into advisor values('57123', '73623');
	insert into advisor values('51997', '48570');
	insert into advisor values('95631', '48507');
	insert into advisor values('70452', '95030');
	insert into advisor values('37219', '72553');
	insert into advisor values('59530', '50885');
	insert into advisor values('61737', '36897');
	insert into advisor values('33645', '81991');
	insert into advisor values('3143', '63395');
	insert into advisor values('78792', '72553');
	insert into advisor values('10076', '6569');
	insert into advisor values('59553', '80759');
	insert into advisor values('57666', '48507');
	insert into advisor values('22004', '78699');
	insert into advisor values('38668', '97302');
	insert into advisor values('43130', '4034');
	insert into advisor values('36263', '4034');
	insert into advisor values('99271', '28400');
	insert into advisor values('69850', '3335');
	insert into advisor values('59397', '16807');
	insert into advisor values('61127', '48507');
	insert into advisor values('30299', '50330');
	insert into advisor values('57962', '81991');
	insert into advisor values('88169', '6569');
	insert into advisor values('27094', '77346');
	insert into advisor values('39115', '6569');
	insert into advisor values('84189', '28097');
	insert into advisor values('79892', '99052');
	insert into advisor values('95046', '96895');
	insert into advisor values('34386', '74426');
	insert into advisor values('82646', '34175');
	insert into advisor values('31086', '48570');
	insert into advisor values('85226', '3199');
	insert into advisor values('32490', '35579');
	insert into advisor values('39704', '73623');
	insert into advisor values('80610', '97302');
	insert into advisor values('18675', '22591');
	insert into advisor values('47630', '72553');
	insert into advisor values('36102', '35579');
	insert into advisor values('22620', '3335');
	insert into advisor values('39157', '36897');
	insert into advisor values('86327', '25946');
	insert into advisor values('84865', '74420');
	insert into advisor values('83557', '48570');
	insert into advisor values('7490', '80759');
	insert into advisor values('94178', '80759');
	insert into advisor values('99660', '42782');
	insert into advisor values('57511', '37687');
	insert into advisor values('56941', '41930');
	insert into advisor values('77415', '64871');
	insert into advisor values('99754', '4233');
	insert into advisor values('81550', '72553');
	insert into advisor values('79911', '64871');
	insert into advisor values('82082', '4233');
	insert into advisor values('58846', '79081');
	insert into advisor values('11076', '95030');
	insert into advisor values('7204', '14365');
	insert into advisor values('73165', '57180');
	insert into advisor values('1737', '41930');
	insert into advisor values('12979', '37687');
	insert into advisor values('57334', '90643');
	insert into advisor values('1827', '14365');
	insert into advisor values('29390', '52647');
	insert into advisor values('31302', '95709');
	insert into advisor values('77231', '90376');
	insert into advisor values('36126', '63287');
	insert into advisor values('45200', '37687');
	insert into advisor values('99463', '97302');
	insert into advisor values('79170', '73623');
	insert into advisor values('12216', '34175');
	insert into advisor values('64593', '96895');
	insert into advisor values('30177', '4233');
	insert into advisor values('15074', '4233');
	insert into advisor values('5005', '4233');
	insert into advisor values('99348', '99052');
	insert into advisor values('82591', '4034');
	insert into advisor values('53089', '78699');
	insert into advisor values('24630', '63395');
	insert into advisor values('71387', '35579');
	insert into advisor values('61354', '42782');
	insert into advisor values('10481', '19368');
	insert into advisor values('39310', '63395');
	insert into advisor values('16297', '16807');
	insert into advisor values('72622', '90643');
	insert into advisor values('92965', '64871');
	insert into advisor values('89104', '6569');
	insert into advisor values('13408', '63287');
	insert into advisor values('66229', '36897');
	insert into advisor values('87280', '63287');
	insert into advisor values('73206', '4034');
	insert into advisor values('24387', '19368');
	insert into advisor values('32744', '37687');
	insert into advisor values('39204', '74426');
	insert into advisor values('42298', '52647');
	insert into advisor values('53588', '81991');
	insert into advisor values('90004', '16807');
	insert into advisor values('12563', '36897');
	insert into advisor values('55000', '64871');
	insert into advisor values('1110', '3335');
	insert into advisor values('55170', '4034');
	insert into advisor values('56080', '90376');
	insert into advisor values('61065', '99052');
	insert into advisor values('107', '15347');
	insert into advisor values('11453', '97302');
	insert into advisor values('53805', '74420');
	insert into advisor values('39241', '95030');
	insert into advisor values('32886', '57180');
	insert into advisor values('40080', '95709');
	insert into advisor values('22142', '79653');
	insert into advisor values('94257', '48570');
	insert into advisor values('75513', '74420');
	insert into advisor values('99268', '95030');
	insert into advisor values('20084', '16807');
	insert into advisor values('51868', '52647');
	insert into advisor values('7287', '14365');
	insert into advisor values('35588', '48570');
	insert into advisor values('83170', '15347');
	insert into advisor values('14596', '79081');
	insert into advisor values('23794', '90376');
	insert into advisor values('78332', '41930');
	insert into advisor values('49339', '41930');
	insert into advisor values('40677', '95030');
	insert into advisor values('90220', '95709');
	insert into advisor values('95029', '48570');
	insert into advisor values('83728', '3335');
	insert into advisor values('67033', '63287');
	insert into advisor values('87785', '15347');
	insert into advisor values('4345', '28400');
	insert into advisor values('96085', '59795');
	insert into advisor values('64249', '52647');
	insert into advisor values('53803', '15347');
	insert into advisor values('27956', '79081');
	insert into advisor values('24796', '35579');
	insert into advisor values('4449', '37687');
	insert into advisor values('77364', '4233');
	insert into advisor values('70384', '37687');
	insert into advisor values('18007', '16807');
	insert into advisor values('51723', '42782');
	insert into advisor values('56486', '22591');
	insert into advisor values('70359', '6569');
	insert into advisor values('18234', '34175');
	insert into advisor values('34322', '41930');
	insert into advisor values('24325', '79653');
	insert into advisor values('83444', '64871');
	insert into advisor values('93814', '35579');
	insert into advisor values('80912', '74420');
	insert into advisor values('70099', '3335');
	insert into advisor values('64945', '97302');
	insert into advisor values('81789', '48570');
	insert into advisor values('38271', '79081');
	insert into advisor values('87784', '57180');
	insert into advisor values('46436', '50885');
	insert into advisor values('20195', '96895');
	insert into advisor values('31080', '31955');
	insert into advisor values('85887', '74426');
	insert into advisor values('85234', '4233');
	insert into advisor values('1460', '43779');
	insert into advisor values('30650', '43779');
	insert into advisor values('6474', '78699');
	insert into advisor values('67051', '95709');
	insert into advisor values('58300', '31955');
	insert into advisor values('64192', '50330');
	insert into advisor values('84727', '96895');
	insert into advisor values('39881', '72553');
	insert into advisor values('3163', '72553');
	insert into advisor values('72643', '37687');
	insert into advisor values('66008', '74426');
	insert into advisor values('76291', '25946');
	insert into advisor values('92274', '37687');
	insert into advisor values('16075', '73623');
	insert into advisor values('30334', '6569');
	insert into advisor values('75123', '48570');
	insert into advisor values('35042', '97302');
	insert into advisor values('99073', '37687');
	insert into advisor values('68280', '35579');
	insert into advisor values('80976', '19368');
	insert into advisor values('68554', '72553');
	insert into advisor values('99949', '16807');
	insert into advisor values('71287', '52647');
	insert into advisor values('73268', '74420');
	insert into advisor values('93708', '58558');
	insert into advisor values('29399', '50330');
	insert into advisor values('14284', '80759');
	insert into advisor values('80247', '3199');
	insert into advisor values('86344', '4233');
	insert into advisor values('54728', '6569');
	insert into advisor values('86375', '22591');
	insert into advisor values('64401', '48507');
	insert into advisor values('9183', '63287');
	insert into advisor values('71529', '15347');
	insert into advisor values('65433', '58558');
	insert into advisor values('89051', '81991');
	insert into advisor values('90448', '31955');
	insert into advisor values('90082', '90643');
	insert into advisor values('25362', '48570');
	insert into advisor values('74509', '79081');
	insert into advisor values('20445', '74426');
	insert into advisor values('40059', '4034');
	insert into advisor values('60867', '63287');
	insert into advisor values('28128', '74420');
	insert into advisor values('28518', '97302');
	insert into advisor values('17086', '16807');
	insert into advisor values('91132', '63287');
	insert into advisor values('29260', '57180');
	insert into advisor values('29707', '59795');
	insert into advisor values('85746', '4034');
	insert into advisor values('54605', '4034');
	insert into advisor values('78922', '79653');
	insert into advisor values('76173', '3335');
	insert into advisor values('6304', '22591');
	insert into advisor values('98120', '16807');
	insert into advisor values('6195', '37687');
	insert into advisor values('33837', '78699');
	insert into advisor values('86833', '95030');
	insert into advisor values('28829', '6569');
	insert into advisor values('82974', '95709');
	insert into advisor values('39114', '96895');
	insert into advisor values('53485', '15347');
	insert into advisor values('8603', '65931');
	insert into advisor values('7973', '58558');
	insert into advisor values('34502', '31955');
	insert into advisor values('69853', '28400');
	insert into advisor values('70389', '37687');
	insert into advisor values('75423', '6569');
	insert into advisor values('26881', '59795');
	insert into advisor values('19848', '28097');
	insert into advisor values('5017', '37687');
	insert into advisor values('33094', '14365');
	insert into advisor values('25468', '4233');
	insert into advisor values('75928', '6569');
	insert into advisor values('94522', '79653');
	insert into advisor values('30289', '35579');
	insert into advisor values('54296', '97302');
	insert into advisor values('12069', '65931');
	insert into advisor values('89059', '95709');
	insert into advisor values('38336', '36897');
	insert into advisor values('98563', '65931');
	insert into advisor values('19541', '72553');
	insert into advisor values('95366', '65931');
	insert into advisor values('69758', '16807');
	insert into advisor values('98690', '79653');
	insert into advisor values('66494', '28400');
	insert into advisor values('65205', '28097');
	insert into advisor values('11682', '59795');
	insert into advisor values('36265', '96895');
	insert into advisor values('14432', '79653');
	insert into advisor values('63860', '57180');
	insert into advisor values('50969', '77346');
	insert into advisor values('95089', '36897');
	insert into advisor values('74840', '22591');
	insert into advisor values('29002', '63395');
	insert into advisor values('37809', '28400');
	insert into advisor values('27727', '52647');
	insert into advisor values('66469', '81991');
	insert into advisor values('31486', '95030');
	insert into advisor values('95099', '73623');
	insert into advisor values('57083', '36897');
	insert into advisor values('83622', '74420');
	insert into advisor values('68278', '57180');
	insert into advisor values('87651', '4034');
	insert into advisor values('8426', '34175');
	insert into advisor values('88793', '97302');
	insert into advisor values('60249', '95709');
	insert into advisor values('65144', '28097');
	insert into advisor values('91091', '74420');
	insert into advisor values('8252', '15347');
	insert into advisor values('82126', '4233');
	insert into advisor values('13290', '77346');
	insert into advisor values('85356', '95030');
	insert into advisor values('5871', '41930');
	insert into advisor values('59290', '72553');
	insert into advisor values('5414', '63395');
	insert into advisor values('30124', '48570');
	insert into advisor values('21008', '95709');
	insert into advisor values('69732', '58558');
	insert into advisor values('19450', '25946');
	insert into advisor values('55915', '95030');
	insert into advisor values('14621', '74426');
	insert into advisor values('22003', '57180');
	insert into advisor values('16631', '19368');
	insert into advisor values('51549', '63395');
	insert into advisor values('95284', '74426');
	insert into advisor values('60366', '3199');
	insert into advisor values('99369', '52647');
	insert into advisor values('50873', '19368');
	insert into advisor values('36244', '58558');
	insert into advisor values('58874', '3199');
	insert into advisor values('82687', '79081');
	insert into advisor values('2423', '34175');
	insert into advisor values('62429', '50330');
	insert into advisor values('93631', '95709');
	insert into advisor values('29705', '80759');
	insert into advisor values('52076', '48570');
	insert into advisor values('53451', '4233');
	insert into advisor values('69730', '3199');
	insert into advisor values('56276', '48507');
	insert into advisor values('23311', '73623');
	insert into advisor values('21086', '42782');
	insert into advisor values('61003', '79081');
	insert into advisor values('27950', '22591');
	insert into advisor values('50583', '41930');
	insert into advisor values('40276', '77346');
	insert into advisor values('15487', '28400');
	insert into advisor values('83592', '48570');
	insert into advisor values('46970', '81991');
	insert into advisor values('30188', '19368');
	insert into advisor values('64934', '31955');
	insert into advisor values('99694', '15347');
	insert into advisor values('79534', '4233');
	insert into advisor values('57156', '73623');
	insert into advisor values('41894', '63287');
	insert into advisor values('69679', '35579');
	insert into advisor values('62795', '96895');
	insert into advisor values('34331', '52647');
	insert into advisor values('4645', '28400');
	insert into advisor values('70395', '97302');
	insert into advisor values('69222', '81991');
	insert into advisor values('22254', '64871');
	insert into advisor values('51817', '4233');
	insert into advisor values('66495', '95709');
	insert into advisor values('72501', '79653');
	insert into advisor values('7390', '19368');
	insert into advisor values('28538', '99052');
	insert into advisor values('68649', '65931');
	insert into advisor values('15249', '64871');
	insert into advisor values('98984', '36897');
	insert into advisor values('35198', '22591');
	insert into advisor values('67017', '50330');
	insert into advisor values('27919', '3335');
	insert into advisor values('46762', '22591');
	insert into advisor values('98843', '19368');
	insert into advisor values('14094', '95030');
	insert into advisor values('79589', '41930');
	insert into advisor values('94371', '6569');
	insert into advisor values('25528', '3335');
	insert into advisor values('7620', '31955');
	insert into advisor values('43658', '79653');
	insert into advisor values('65714', '57180');
	insert into advisor values('37339', '3199');
	insert into advisor values('38555', '74426');
	insert into advisor values('73908', '43779');
	insert into advisor values('4438', '25946');
	insert into advisor values('15883', '22591');
	insert into advisor values('41890', '35579');
	insert into advisor values('75547', '52647');
	insert into advisor values('89196', '72553');
	insert into advisor values('52494', '97302');
	insert into advisor values('44551', '74420');
	insert into advisor values('61332', '19368');
	insert into advisor values('37715', '35579');
	insert into advisor values('68779', '79653');
	insert into advisor values('71768', '3199');
	insert into advisor values('72055', '95709');
	insert into advisor values('29514', '4034');
	insert into advisor values('62152', '64871');
	insert into advisor values('66212', '31955');
	insert into advisor values('53048', '57180');
	insert into advisor values('4015', '96895');
	insert into advisor values('67340', '6569');
	insert into advisor values('2970', '42782');
	insert into advisor values('27952', '57180');
	insert into advisor values('51008', '16807');
	insert into advisor values('97629', '3199');
	insert into advisor values('31079', '65931');
	insert into advisor values('57941', '34175');
	insert into advisor values('30397', '65931');
	insert into advisor values('45826', '14365');
	insert into advisor values('70299', '22591');
	insert into advisor values('9084', '63287');
	insert into advisor values('78116', '97302');
	insert into advisor values('5250', '48570');
	insert into advisor values('93508', '50330');
	insert into advisor values('30845', '48507');
	insert into advisor values('91442', '90643');
	insert into advisor values('75938', '50330');
	insert into advisor values('74672', '3335');
	insert into advisor values('12078', '35579');
	insert into advisor values('94311', '48507');
	insert into advisor values('94697', '28400');
	insert into advisor values('50702', '77346');
	insert into advisor values('35462', '28097');
	insert into advisor values('34018', '28097');
	insert into advisor values('99775', '77346');
	insert into advisor values('88140', '16807');
	insert into advisor values('46106', '28097');
	insert into advisor values('68096', '63395');
	insert into advisor values('84808', '22591');
	insert into advisor values('97658', '34175');
	insert into advisor values('73186', '22591');
	insert into advisor values('50944', '58558');
	insert into advisor values('53165', '35579');
	insert into advisor values('86981', '77346');
	insert into advisor values('16885', '35579');
	insert into advisor values('2561', '52647');
	insert into advisor values('96178', '42782');
	insert into advisor values('64731', '65931');
	insert into advisor values('14023', '73623');
	insert into advisor values('47265', '63287');
	insert into advisor values('84704', '90376');
	insert into advisor values('69132', '77346');
	insert into advisor values('49073', '80759');
	insert into advisor values('44703', '28400');
	insert into advisor values('41211', '6569');
	insert into advisor values('61414', '77346');
	insert into advisor values('38696', '50885');
	insert into advisor values('90009', '95030');
	insert into advisor values('97868', '99052');
	insert into advisor values('17944', '64871');
	insert into advisor values('25380', '96895');
	insert into advisor values('85614', '72553');
	insert into advisor values('60984', '77346');
	insert into advisor values('84495', '63395');
	insert into advisor values('19321', '57180');
	insert into advisor values('99611', '4034');
	insert into advisor values('72485', '41930');
	insert into advisor values('50267', '43779');
	insert into advisor values('544', '78699');
	insert into advisor values('55009', '48570');
	insert into advisor values('45083', '74426');
	insert into advisor values('67018', '35579');
	insert into advisor values('93039', '74426');
	insert into advisor values('75772', '48570');
	insert into advisor values('60224', '50330');
	insert into advisor values('41674', '3199');
	insert into advisor values('97435', '80759');
	insert into advisor values('21101', '96895');
	insert into advisor values('76250', '41930');
	insert into advisor values('40682', '36897');
	insert into advisor values('39612', '14365');
	insert into advisor values('14032', '34175');
	insert into advisor values('75791', '37687');
	insert into advisor values('5208', '36897');
	insert into advisor values('43432', '63287');
	insert into advisor values('68453', '57180');
	insert into advisor values('12711', '58558');
	insert into advisor values('40932', '34175');
	insert into advisor values('6710', '77346');
	insert into advisor values('91370', '63287');
	insert into advisor values('43912', '80759');
	insert into advisor values('12666', '74420');
	insert into advisor values('74460', '81991');
	insert into advisor values('99422', '14365');
	insert into advisor values('95320', '80759');
	insert into advisor values('56299', '58558');
	insert into advisor values('84432', '79081');
	insert into advisor values('75231', '63287');
	insert into advisor values('94846', '25946');
	insert into advisor values('4004', '50330');
	insert into advisor values('28361', '96895');
	insert into advisor values('97228', '42782');
	insert into advisor values('39552', '63395');
	insert into advisor values('38676', '3199');
	insert into advisor values('94814', '57180');
	insert into advisor values('16035', '81991');
	insert into advisor values('79205', '43779');
	insert into advisor values('4682', '35579');
	insert into advisor values('5925', '4034');
	insert into advisor values('25187', '41930');
	insert into advisor values('19603', '48570');
	insert into advisor values('41491', '37687');
	insert into advisor values('99764', '63287');
	insert into advisor values('50537', '95709');
	insert into advisor values('67793', '36897');
	insert into advisor values('47487', '41930');
	insert into advisor values('19362', '14365');
	insert into advisor values('25942', '96895');
	insert into advisor values('39238', '72553');
	insert into advisor values('65979', '6569');
	insert into advisor values('22086', '19368');
	insert into advisor values('37734', '31955');
	insert into advisor values('17911', '28097');
	insert into advisor values('87831', '79081');
	insert into advisor values('12214', '25946');
	insert into advisor values('20378', '78699');
	insert into advisor values('11083', '96895');
	insert into advisor values('57377', '50885');
	insert into advisor values('35881', '78699');
	insert into advisor values('34542', '79081');
	insert into advisor values('91978', '48570');
	insert into advisor values('87048', '59795');
	insert into advisor values('64820', '14365');
	insert into advisor values('57474', '41930');
	insert into advisor values('53496', '3199');
	insert into advisor values('87193', '4233');
	insert into advisor values('847', '65931');
	insert into advisor values('42388', '97302');
	insert into advisor values('62749', '15347');
	insert into advisor values('41988', '28097');
	insert into advisor values('85680', '97302');
	insert into advisor values('82083', '63287');
	insert into advisor values('65056', '72553');
	insert into advisor values('3639', '59795');
	insert into advisor values('37038', '79653');
	insert into advisor values('9933', '64871');
	insert into advisor values('65190', '52647');
	insert into advisor values('15328', '37687');
	insert into advisor values('59455', '14365');
	insert into advisor values('49873', '22591');
	insert into advisor values('82039', '48570');
	insert into advisor values('20974', '28400');
	insert into advisor values('56089', '48507');
	insert into advisor values('86573', '72553');
	insert into advisor values('38712', '97302');
	insert into advisor values('42991', '6569');
	insert into advisor values('28019', '15347');
	insert into advisor values('13023', '58558');
	insert into advisor values('31761', '72553');
	insert into advisor values('56882', '25946');
	insert into advisor values('34788', '37687');
	insert into advisor values('17607', '52647');
	insert into advisor values('48776', '58558');
	insert into advisor values('78758', '59795');
	insert into advisor values('77218', '77346');
	insert into advisor values('4034', '97302');
	insert into advisor values('50658', '81991');
	insert into advisor values('76057', '37687');
	insert into advisor values('96067', '99052');
	insert into advisor values('24784', '4034');
	insert into advisor values('31560', '36897');
	insert into advisor values('32345', '74426');
	insert into advisor values('76799', '58558');
	insert into advisor values('37454', '96895');
	insert into advisor values('30943', '63287');
	insert into advisor values('16405', '73623');
	insert into advisor values('95850', '4233');
	insert into advisor values('26619', '35579');
	insert into advisor values('17997', '65931');
	insert into advisor values('26427', '80759');
	insert into advisor values('73213', '90376');
	insert into advisor values('93366', '58558');
	insert into advisor values('33882', '74426');
	insert into advisor values('37818', '43779');
	insert into advisor values('21102', '74426');
	insert into advisor values('76798', '52647');
	insert into advisor values('31820', '90376');
	insert into advisor values('63489', '50885');
	insert into advisor values('51955', '81991');
	insert into advisor values('71631', '72553');
	insert into advisor values('48009', '16807');
	insert into advisor values('51678', '65931');
	insert into advisor values('73602', '31955');
	insert into advisor values('11530', '4034');
	insert into advisor values('32376', '4233');
	insert into advisor values('80799', '74420');
	insert into advisor values('40178', '99052');
	insert into advisor values('58701', '42782');
	insert into advisor values('46655', '81991');
	insert into advisor values('93043', '72553');
	insert into advisor values('1402', '37687');
	insert into advisor values('29462', '3199');
	insert into advisor values('49701', '42782');
	insert into advisor values('96968', '3199');
	insert into advisor values('89551', '16807');
	insert into advisor values('32483', '72553');
	insert into advisor values('39472', '77346');
	insert into advisor values('88045', '34175');
	insert into advisor values('30474', '65931');
	insert into advisor values('31476', '36897');
	insert into advisor values('95175', '57180');
	insert into advisor values('95697', '50330');
	insert into advisor values('37759', '95030');
	insert into advisor values('96134', '95709');
	insert into advisor values('92464', '4034');
	insert into advisor values('78434', '80759');
	insert into advisor values('44038', '63395');
	insert into advisor values('43993', '95030');
	insert into advisor values('914', '95030');
	insert into advisor values('19342', '78699');
	insert into advisor values('13749', '79653');
	insert into advisor values('33546', '72553');
	insert into advisor values('40116', '42782');
	insert into advisor values('46980', '3199');
	insert into advisor values('31266', '81991');
	insert into advisor values('65688', '73623');
	insert into advisor values('65563', '35579');
	insert into advisor values('83314', '57180');
	insert into advisor values('39876', '72553');
	insert into advisor values('44706', '43779');
	insert into advisor values('15086', '48570');
	insert into advisor values('12615', '34175');
	insert into advisor values('63538', '25946');
	insert into advisor values('17831', '22591');
	insert into advisor values('96117', '15347');
	insert into advisor values('82066', '31955');
	insert into advisor values('28738', '79653');
	insert into advisor values('84515', '97302');
	insert into advisor values('90132', '90643');
	insert into advisor values('8192', '22591');
	insert into advisor values('25611', '63395');
	insert into advisor values('50743', '52647');
	insert into advisor values('41683', '28097');
	insert into advisor values('99553', '48507');
	insert into advisor values('22179', '22591');
	insert into advisor values('65121', '72553');
	insert into advisor values('52057', '81991');
	insert into advisor values('931', '95709');
	insert into advisor values('23392', '59795');
	insert into advisor values('33759', '15347');
	insert into advisor values('52203', '4233');
	insert into advisor values('78581', '74426');
	insert into advisor values('65241', '25946');
	insert into advisor values('45359', '80759');
	insert into advisor values('86001', '64871');
	insert into advisor values('22532', '50330');
	insert into advisor values('97573', '22591');
	insert into advisor values('90609', '6569');
	insert into advisor values('16528', '48507');
	insert into advisor values('61920', '28400');
	insert into advisor values('282', '28400');
	insert into advisor values('85602', '58558');
	insert into advisor values('62832', '95709');
	insert into advisor values('78454', '34175');
	insert into advisor values('30222', '90376');
	insert into advisor values('28994', '4233');
	insert into advisor values('39927', '77346');
	insert into advisor values('74070', '90376');
	insert into advisor values('65208', '59795');
	insert into advisor values('2286', '31955');
	insert into advisor values('49450', '59795');
	insert into advisor values('83214', '73623');
	insert into advisor values('6287', '99052');
	insert into advisor values('86661', '90376');
	insert into advisor values('68242', '28400');
	insert into advisor values('42092', '74420');
	insert into advisor values('9993', '96895');
	insert into advisor values('89734', '73623');
	insert into advisor values('7732', '16807');
	insert into advisor values('89312', '3335');
	insert into advisor values('35357', '50330');
	insert into advisor values('86127', '58558');
	insert into advisor values('18775', '37687');
	insert into advisor values('24374', '4034');
	insert into advisor values('2848', '57180');
	insert into advisor values('78143', '3199');
	insert into advisor values('50977', '3335');
	insert into advisor values('96895', '65931');
	insert into advisor values('95626', '50885');
	insert into advisor values('22260', '42782');
	insert into advisor values('23224', '36897');
	insert into advisor values('27528', '80759');
	insert into advisor values('71025', '74426');
	insert into advisor values('36845', '72553');
	insert into advisor values('17924', '97302');
	insert into advisor values('69632', '59795');
	insert into advisor values('70828', '97302');
	insert into advisor values('27687', '4034');
	insert into advisor values('28299', '63395');
	insert into advisor values('14869', '22591');
	insert into advisor values('11152', '6569');
	insert into advisor values('17507', '65931');
	insert into advisor values('57107', '31955');
	insert into advisor values('47670', '95030');
	insert into advisor values('25718', '6569');
	insert into advisor values('67293', '74426');
	insert into advisor values('41091', '96895');
	insert into advisor values('86674', '65931');
	insert into advisor values('23506', '52647');
	insert into advisor values('8022', '77346');
	insert into advisor values('97953', '4233');
	insert into advisor values('86934', '36897');
	insert into advisor values('58172', '28400');
	insert into advisor values('81610', '78699');
	insert into advisor values('77172', '64871');
	insert into advisor values('499', '35579');
	insert into advisor values('94730', '3199');
	insert into advisor values('40371', '31955');
	insert into advisor values('3651', '41930');
	insert into advisor values('85904', '34175');
	insert into advisor values('73394', '99052');
	insert into advisor values('8807', '96895');
	insert into advisor values('62705', '48570');
	insert into advisor values('11578', '90376');
	insert into advisor values('68248', '50330');
	insert into advisor values('98315', '6569');
	insert into advisor values('62754', '95030');
	insert into advisor values('41406', '95030');
	insert into advisor values('82063', '57180');
	insert into advisor values('87706', '34175');
	insert into advisor values('20540', '41930');
	insert into advisor values('69960', '14365');
	insert into advisor values('30252', '65931');
	insert into advisor values('70098', '37687');
	insert into advisor values('93986', '14365');
	insert into advisor values('35685', '97302');
	insert into advisor values('31364', '34175');
	insert into advisor values('36494', '4034');
	insert into advisor values('32217', '4233');
	insert into advisor values('69952', '79081');
	insert into advisor values('52523', '31955');
	insert into advisor values('7149', '97302');
	insert into advisor values('71878', '57180');
	insert into advisor values('29192', '48570');
	insert into advisor values('79446', '48507');
	insert into advisor values('77000', '22591');
	insert into advisor values('1836', '35579');
	insert into advisor values('84167', '95709');
	insert into advisor values('81785', '78699');
	insert into advisor values('1087', '35579');
	insert into advisor values('5617', '73623');
	insert into advisor values('53547', '73623');
	insert into advisor values('39978', '31955');
	insert into advisor values('60748', '6569');
	insert into advisor values('23449', '81991');
	insert into advisor values('52385', '63287');
	insert into advisor values('2139', '4233');
	insert into advisor values('12941', '37687');
	insert into advisor values('72521', '80759');
	insert into advisor values('82580', '65931');
	insert into advisor values('39394', '14365');
	insert into advisor values('39901', '43779');
	insert into advisor values('3493', '74426');
	insert into advisor values('90353', '81991');
	insert into advisor values('69747', '28400');
	insert into advisor values('39514', '14365');
	insert into advisor values('36995', '16807');
	insert into advisor values('12971', '50330');
	insert into advisor values('76768', '19368');
	insert into advisor values('79502', '90376');
	insert into advisor values('63390', '50885');
	insert into advisor values('19824', '77346');
	insert into advisor values('46769', '52647');
	insert into advisor values('65400', '4034');
	insert into advisor values('44258', '96895');
	insert into advisor values('81896', '16807');
	insert into advisor values('79772', '90643');
	insert into advisor values('46155', '78699');
	insert into advisor values('18709', '52647');
	insert into advisor values('63502', '16807');
	insert into advisor values('39521', '97302');
	insert into advisor values('51203', '78699');
	insert into advisor values('96741', '48507');
	insert into advisor values('38371', '48570');
	insert into advisor values('59673', '79081');
	insert into advisor values('13365', '95030');
	insert into advisor values('1000', '16807');
	insert into advisor values('19735', '90643');
	insert into advisor values('34126', '95709');
	insert into advisor values('16467', '50330');
	insert into advisor values('80248', '3199');
	insert into advisor values('58634', '28400');
	insert into advisor values('51975', '16807');
	insert into advisor values('77548', '90643');
	insert into advisor values('74796', '36897');
	insert into advisor values('85981', '28400');
	insert into advisor values('29645', '37687');
	insert into advisor values('89234', '57180');
	insert into advisor values('94142', '16807');
	insert into advisor values('79697', '42782');
	insert into advisor values('90089', '48570');
	insert into advisor values('20244', '25946');
	insert into advisor values('37350', '99052');
	insert into advisor values('81638', '63395');
	insert into advisor values('90914', '28400');
	insert into advisor values('75395', '95709');
	insert into advisor values('42556', '28400');
	insert into advisor values('10556', '3199');
	insert into advisor values('39619', '74426');
	insert into advisor values('38288', '3199');
	insert into advisor values('20985', '79653');
	insert into advisor values('38548', '74420');
	insert into advisor values('15698', '41930');
	insert into advisor values('23500', '79653');
	insert into advisor values('70965', '22591');
	insert into advisor values('76911', '63395');
	insert into advisor values('3545', '74420');
	insert into advisor values('46694', '28400');
	insert into advisor values('99977', '28400');
	insert into advisor values('90124', '57180');
	insert into advisor values('95840', '48570');
	insert into advisor values('56143', '52647');
	insert into advisor values('79469', '50330');
	insert into advisor values('3693', '73623');
	insert into advisor values('42096', '4233');
	insert into advisor values('88472', '90643');
	insert into advisor values('14874', '79081');
	insert into advisor values('978', '36897');
	insert into advisor values('33201', '81991');
	insert into advisor values('30161', '63287');
	insert into advisor values('46441', '14365');
	insert into advisor values('31035', '19368');
	insert into advisor values('67371', '3335');
	insert into advisor values('80651', '4233');
	insert into advisor values('43505', '72553');
	insert into advisor values('35498', '80759');
	insert into advisor values('48423', '95709');
	insert into advisor values('51093', '15347');
	insert into advisor values('78572', '37687');
	insert into advisor values('52669', '37687');
	insert into advisor values('87246', '28400');
	insert into advisor values('69122', '79081');
	insert into advisor values('52945', '48570');
	insert into advisor values('52471', '4233');
	insert into advisor values('62728', '97302');
	insert into advisor values('52929', '43779');
	insert into advisor values('85754', '19368');
	insert into advisor values('18583', '50330');
	insert into advisor values('74974', '77346');
	insert into advisor values('48611', '77346');
	insert into advisor values('63582', '81991');
	insert into advisor values('53118', '79081');
	insert into advisor values('88887', '48570');
	insert into advisor values('81175', '19368');
	insert into advisor values('69783', '31955');
	insert into advisor values('14829', '52647');
	insert into advisor values('53469', '80759');
	insert into advisor values('44304', '22591');
	insert into advisor values('48861', '52647');
	insert into advisor values('73411', '77346');
	insert into advisor values('95225', '48570');
	insert into advisor values('53788', '77346');
	insert into advisor values('68712', '57180');
	insert into advisor values('52866', '35579');
	insert into advisor values('5298', '90376');
	insert into advisor values('58606', '59795');
	insert into advisor values('76049', '14365');
	insert into advisor values('78858', '99052');
	insert into advisor values('97041', '28400');
	insert into advisor values('98388', '63287');
	insert into advisor values('15024', '77346');
	insert into advisor values('5243', '58558');
	insert into advisor values('80990', '90376');
	insert into advisor values('77664', '35579');
	insert into advisor values('49982', '77346');
	insert into advisor values('87222', '57180');
	insert into advisor values('35523', '25946');
	insert into advisor values('14499', '97302');
	insert into advisor values('33107', '77346');
	insert into advisor values('18108', '34175');
	insert into advisor values('67655', '4233');
	insert into advisor values('95852', '79081');
	insert into advisor values('50664', '36897');
	insert into advisor values('59117', '37687');
	insert into advisor values('435', '4233');
	insert into advisor values('75596', '6569');
	insert into advisor values('34197', '73623');
	insert into advisor values('66281', '79653');
	insert into advisor values('86736', '90643');
	insert into advisor values('14484', '48507');
	insert into advisor values('88308', '25946');
	insert into advisor values('36657', '96895');
	insert into advisor values('93125', '78699');
	insert into advisor values('29140', '48570');
	insert into advisor values('85211', '15347');
	insert into advisor values('23525', '50330');
	insert into advisor values('3005', '31955');
	insert into advisor values('91197', '35579');
	insert into advisor values('1285', '4034');
	insert into advisor values('29863', '16807');
	insert into advisor values('15070', '97302');
	insert into advisor values('98047', '57180');
	insert into advisor values('87624', '28097');
	insert into advisor values('38902', '65931');
	insert into advisor values('15538', '59795');
	insert into advisor values('83691', '79653');
	insert into advisor values('89759', '42782');
	insert into advisor values('34770', '64871');
	insert into advisor values('11202', '90376');
	insert into advisor values('65681', '3199');
	insert into advisor values('17665', '74426');
	insert into advisor values('11966', '79653');
	insert into advisor values('21556', '42782');
	insert into advisor values('24002', '19368');
	insert into advisor values('75878', '22591');
	insert into advisor values('52120', '34175');
	insert into advisor values('93491', '64871');
	insert into advisor values('78637', '90643');
	insert into advisor values('9256', '72553');
	insert into advisor values('41345', '50330');
	insert into advisor values('98726', '52647');
	insert into advisor values('5381', '77346');
	insert into advisor values('99647', '37687');
	insert into advisor values('50331', '78699');
	insert into advisor values('48247', '28400');
	insert into advisor values('65753', '73623');
	insert into advisor values('29091', '63287');
	insert into advisor values('72165', '99052');
	insert into advisor values('43981', '48507');
	insert into advisor values('16057', '42782');
	insert into advisor values('88525', '48507');
	insert into advisor values('16480', '41930');
	insert into advisor values('92849', '90376');
	insert into advisor values('9495', '77346');
	insert into advisor values('14581', '50885');
	insert into advisor values('65901', '96895');
	insert into advisor values('96203', '28400');
	insert into advisor values('1954', '4233');
	insert into advisor values('66484', '41930');
	insert into advisor values('15083', '73623');
	insert into advisor values('48901', '4034');
	insert into advisor values('15340', '16807');
	insert into advisor values('16515', '97302');
	insert into advisor values('54620', '58558');
	insert into advisor values('15430', '95709');
	insert into advisor values('27236', '79653');
	insert into advisor values('2201', '25946');
	insert into advisor values('69471', '63395');
	insert into advisor values('13880', '74420');
	insert into advisor values('827', '31955');
	insert into advisor values('42960', '73623');
	insert into advisor values('48471', '99052');
	insert into advisor values('13217', '16807');
	insert into advisor values('45570', '25946');
	insert into advisor values('94815', '41930');
	insert into advisor values('1922', '4233');
	insert into advisor values('51084', '63287');
	insert into advisor values('842', '48570');
	insert into advisor values('53152', '99052');
	insert into advisor values('11201', '52647');
	insert into advisor values('88577', '57180');
	insert into advisor values('22050', '79653');
	insert into advisor values('68010', '36897');
	insert into advisor values('10838', '96895');
	insert into advisor values('59848', '52647');
	insert into advisor values('7035', '36897');
	insert into advisor values('5463', '25946');
	insert into advisor values('74464', '43779');
	insert into advisor values('16969', '50885');
	insert into advisor values('62054', '25946');
	insert into advisor values('50719', '3335');
	insert into advisor values('41280', '81991');
	insert into advisor values('31341', '42782');
	insert into advisor values('23475', '97302');
	insert into advisor values('55354', '37687');
	insert into advisor values('50966', '25946');
	insert into advisor values('10269', '15347');
	insert into advisor values('92659', '19368');
	insert into advisor values('49792', '63395');
	insert into advisor values('27140', '25946');
	insert into advisor values('993', '90376');
	insert into advisor values('58326', '50885');
	insert into advisor values('70924', '63287');
	insert into advisor values('71944', '43779');
	insert into advisor values('95201', '28097');
	insert into advisor values('52876', '80759');
	insert into advisor values('58355', '58558');
	insert into advisor values('90181', '41930');
	insert into advisor values('53799', '3335');
	insert into advisor values('13511', '3335');
	insert into advisor values('69521', '35579');
	insert into advisor values('37946', '28097');
	insert into advisor values('15578', '37687');
	insert into advisor values('16311', '4233');
	insert into advisor values('56124', '52647');
	insert into advisor values('63560', '90376');
	insert into advisor values('75299', '43779');
	insert into advisor values('61356', '74420');
	insert into advisor values('70061', '36897');
	insert into advisor values('61232', '31955');
	insert into advisor values('16523', '57180');
	insert into advisor values('57238', '3199');
	insert into advisor values('63645', '37687');
	insert into advisor values('55857', '72553');
	insert into advisor values('90041', '50885');
	insert into advisor values('68263', '48507');
	insert into advisor values('48165', '59795');
	insert into advisor values('23373', '95030');
	insert into advisor values('5336', '42782');
	insert into advisor values('18286', '50885');
	insert into advisor values('4860', '73623');
	insert into advisor values('68516', '59795');
	insert into advisor values('94766', '36897');
	insert into advisor values('72669', '81991');
	insert into advisor values('41596', '3335');
	insert into advisor values('55286', '3199');
	insert into advisor values('10693', '72553');
	insert into advisor values('50467', '64871');
	insert into advisor values('21692', '97302');
	insert into advisor values('8517', '14365');
	insert into advisor values('28133', '3199');
	insert into advisor values('10033', '64871');
	insert into advisor values('60406', '41930');
	insert into advisor values('50703', '41930');
	insert into advisor values('98359', '48570');
	insert into advisor values('23992', '4034');
	insert into advisor values('31554', '14365');
	insert into advisor values('70807', '72553');
	insert into advisor values('4355', '14365');
	insert into advisor values('8457', '43779');
	insert into advisor values('10904', '48570');
	insert into advisor values('83836', '63287');
	insert into advisor values('72657', '58558');
	insert into advisor values('46035', '31955');
	insert into advisor values('36881', '59795');
	insert into advisor values('79487', '37687');
	insert into advisor values('48778', '80759');
	insert into advisor values('64039', '4034');
	insert into advisor values('42565', '79081');
	insert into advisor values('29665', '3199');
	insert into advisor values('83511', '74420');
	insert into advisor values('45494', '97302');
	insert into advisor values('12173', '95709');
	insert into advisor values('16993', '14365');
	insert into advisor values('62784', '74420');
	insert into advisor values('23344', '43779');
	insert into advisor values('92417', '78699');
	insert into advisor values('86529', '48570');
	insert into advisor values('84654', '22591');
	insert into advisor values('52134', '35579');
	insert into advisor values('90234', '57180');
	insert into advisor values('13921', '37687');
	insert into advisor values('76169', '50330');
	insert into advisor values('41832', '4233');
	insert into advisor values('68720', '41930');
	insert into advisor values('66753', '4034');
	insert into advisor values('13753', '81991');
	insert into advisor values('57190', '65931');
	insert into advisor values('27804', '79081');
	insert into advisor values('63449', '74420');
	insert into advisor values('27017', '95030');
	insert into advisor values('52291', '77346');
	insert into advisor values('80941', '15347');
	insert into advisor values('95953', '16807');
	insert into advisor values('72528', '28400');
	insert into advisor values('61854', '74420');
	insert into advisor values('91851', '37687');
	insert into advisor values('38973', '65931');
	insert into advisor values('83480', '79653');
	insert into advisor values('13504', '81991');
	insert into advisor values('19766', '28400');
	insert into advisor values('50365', '90376');
	insert into advisor values('43616', '79081');
	insert into advisor values('19917', '74426');
	insert into advisor values('29849', '43779');
	insert into advisor values('85063', '25946');
	insert into advisor values('70564', '35579');
	insert into advisor values('38121', '65931');
	insert into advisor values('14563', '6569');
	insert into advisor values('6895', '34175');
	insert into advisor values('3039', '4233');
	insert into advisor values('86969', '95709');
	insert into advisor values('11455', '63395');
	insert into advisor values('24809', '58558');
	insert into advisor values('50414', '52647');
	insert into advisor values('57026', '14365');
	insert into advisor values('69081', '73623');
	insert into advisor values('7498', '6569');
	insert into advisor values('34158', '90376');
	insert into advisor values('15144', '50330');
	insert into advisor values('88287', '22591');
	insert into advisor values('72006', '19368');
	insert into advisor values('49244', '72553');
	insert into advisor values('14639', '3199');
	insert into advisor values('76604', '63395');
	insert into advisor values('80113', '16807');
	insert into advisor values('18740', '63395');
	insert into advisor values('69628', '96895');
	insert into advisor values('13757', '42782');
	insert into advisor values('36513', '52647');
	insert into advisor values('97042', '74426');
	insert into advisor values('46260', '48570');
	insert into advisor values('29871', '3335');
	insert into advisor values('75082', '50885');
	insert into advisor values('65715', '52647');
	insert into advisor values('54875', '43779');
	insert into advisor values('99710', '52647');
	insert into advisor values('36384', '97302');
	insert into advisor values('51923', '96895');
	insert into advisor values('37653', '42782');
	insert into advisor values('61783', '48507');
	insert into advisor values('86552', '3335');
	insert into advisor values('11855', '72553');
	insert into advisor values('43016', '3199');
	insert into advisor values('11237', '72553');
	insert into advisor values('96710', '41930');
	insert into advisor values('27044', '73623');
	insert into advisor values('25046', '50885');
	insert into advisor values('62487', '37687');
	insert into advisor values('49759', '65931');
	insert into advisor values('65101', '48570');
	insert into advisor values('64550', '6569');
	insert into advisor values('25143', '95709');
	insert into advisor values('13495', '59795');
	insert into advisor values('67560', '78699');
	insert into advisor values('28316', '78699');
	insert into advisor values('47379', '74420');
	insert into advisor values('56003', '4233');
	insert into advisor values('32369', '64871');
	insert into advisor values('52187', '73623');
	insert into advisor values('91992', '97302');
	insert into advisor values('71543', '78699');
	insert into advisor values('1220', '50330');
	insert into advisor values('40937', '4233');
	insert into advisor values('14065', '77346');
	insert into advisor values('43495', '3335');
	insert into advisor values('26494', '25946');
	insert into advisor values('12362', '25946');
	insert into advisor values('41675', '36897');
	insert into advisor values('78314', '4034');
	insert into advisor values('51579', '34175');
	insert into advisor values('2178', '64871');
	insert into advisor values('86707', '6569');
	insert into advisor values('56849', '19368');
	insert into advisor values('6712', '96895');
	insert into advisor values('17207', '28400');
	insert into advisor values('81876', '97302');
	insert into advisor values('66259', '72553');
	insert into advisor values('75794', '48507');
	insert into advisor values('77003', '95709');
	insert into advisor values('31101', '15347');
	insert into advisor values('64196', '80759');
	insert into advisor values('14628', '59795');
	insert into advisor values('24197', '65931');
	insert into advisor values('3576', '78699');
	insert into advisor values('45720', '16807');
	insert into advisor values('15980', '43779');
	insert into advisor values('34569', '15347');
	insert into advisor values('73492', '37687');
	insert into advisor values('44836', '72553');
	insert into advisor values('27366', '77346');
	insert into advisor values('16250', '95709');
	insert into advisor values('10267', '59795');
	insert into advisor values('77244', '22591');
	insert into advisor values('7854', '4034');
	insert into advisor values('1726', '36897');
	insert into advisor values('8347', '37687');
	insert into advisor values('83573', '90376');
	insert into advisor values('6209', '79653');
	insert into advisor values('85849', '63395');
	insert into advisor values('76224', '35579');
	insert into advisor values('7043', '64871');
	insert into advisor values('70235', '34175');
	insert into advisor values('47824', '52647');
	insert into advisor values('58935', '57180');
	insert into advisor values('987', '90643');
	insert into advisor values('46074', '58558');
	insert into advisor values('23270', '65931');
	insert into advisor values('42956', '63287');
	insert into advisor values('78481', '58558');
	insert into advisor values('888', '50885');
	insert into advisor values('42625', '25946');
	insert into advisor values('43211', '79653');
	insert into advisor values('43226', '43779');
	insert into advisor values('53172', '90376');
	insert into advisor values('16133', '74420');
	insert into advisor values('75522', '59795');
	insert into advisor values('68330', '90376');
	insert into advisor values('53225', '58558');
	insert into advisor values('67542', '63287');
	insert into advisor values('8860', '72553');
	insert into advisor values('22198', '79081');
	insert into advisor values('56212', '14365');
	insert into advisor values('67514', '6569');
	insert into advisor values('58919', '52647');
	insert into advisor values('82707', '57180');
	insert into advisor values('86641', '65931');
	insert into advisor values('94324', '77346');
	insert into advisor values('75534', '50885');
	insert into advisor values('15283', '50330');
	insert into advisor values('47677', '31955');
	insert into advisor values('94569', '63287');
	insert into advisor values('90814', '72553');
	insert into advisor values('63310', '74426');
	insert into advisor values('48660', '95030');
	insert into advisor values('35293', '90376');
	insert into advisor values('28004', '3335');
	insert into advisor values('50038', '6569');
	insert into advisor values('25940', '96895');
	insert into advisor values('11126', '35579');
	insert into advisor values('92332', '80759');
	insert into advisor values('18752', '95709');
	insert into advisor values('61527', '22591');
	insert into advisor values('32119', '42782');
	insert into advisor values('163', '41930');
	insert into advisor values('32065', '42782');
	insert into advisor values('45436', '34175');
	insert into advisor values('58085', '73623');
	insert into advisor values('17076', '74420');
	insert into advisor values('17133', '95030');
	insert into advisor values('36791', '80759');
	insert into advisor values('25785', '73623');
	insert into advisor values('11055', '48507');
	insert into advisor values('96227', '63395');
	insert into advisor values('67024', '31955');
	insert into advisor values('69307', '79081');
	insert into advisor values('23439', '36897');
	insert into advisor values('66969', '50330');
	insert into advisor values('22268', '6569');
	insert into advisor values('41938', '96895');
	insert into advisor values('17057', '80759');
	insert into advisor values('92693', '99052');
	insert into advisor values('49503', '37687');
	insert into advisor values('77130', '78699');
	insert into advisor values('7861', '80759');
	insert into advisor values('51538', '77346');
	insert into advisor values('57787', '37687');
	insert into advisor values('75116', '31955');
	insert into advisor values('81984', '34175');
	insert into advisor values('68395', '52647');
	insert into advisor values('11057', '72553');
	insert into advisor values('20002', '28400');
	insert into advisor values('95027', '95030');
	insert into advisor values('7514', '64871');
	insert into advisor values('88358', '6569');
	insert into advisor values('34392', '79653');
	insert into advisor values('57538', '15347');
	insert into advisor values('9114', '15347');
	insert into advisor values('8378', '59795');
	insert into advisor values('51416', '19368');
	insert into advisor values('71389', '97302');
	insert into advisor values('16453', '34175');
	insert into advisor values('62226', '64871');
	insert into advisor values('26028', '42782');
	insert into advisor values('45817', '35579');
	insert into advisor values('48469', '95709');
	insert into advisor values('69230', '58558');
	insert into advisor values('99711', '42782');
	insert into advisor values('26695', '15347');
	insert into advisor values('2501', '50885');
	insert into advisor values('8819', '28097');
	insert into advisor values('507', '78699');
	insert into advisor values('80698', '31955');
	insert into advisor values('73328', '3335');
	insert into advisor values('23457', '57180');
	insert into advisor values('17996', '78699');
	insert into advisor values('75173', '72553');
	insert into advisor values('25552', '81991');
	insert into advisor values('63612', '48507');
	insert into advisor values('27898', '37687');
	insert into advisor values('33401', '14365');
	insert into advisor values('49280', '63395');
	insert into advisor values('66279', '19368');
	insert into advisor values('12326', '42782');
	insert into advisor values('32772', '59795');
	insert into advisor values('25725', '50330');
	insert into advisor values('89571', '37687');
	insert into advisor values('99780', '36897');
	insert into advisor values('91580', '4233');
	insert into advisor values('27043', '90376');
	insert into advisor values('96615', '35579');
	insert into advisor values('39892', '28097');
	insert into advisor values('1232', '79653');
	insert into advisor values('22467', '90643');
	insert into advisor values('88884', '52647');
	insert into advisor values('96911', '64871');
	insert into advisor values('46337', '48507');
	insert into advisor values('23110', '48507');
	insert into advisor values('60762', '15347');
	insert into advisor values('65676', '4233');
	insert into advisor values('47025', '58558');
	insert into advisor values('1812', '4034');
	insert into advisor values('66763', '63287');
	insert into advisor values('52741', '42782');
	insert into advisor values('78911', '73623');
	insert into advisor values('33206', '42782');
	insert into advisor values('15030', '77346');
	insert into advisor values('11377', '19368');
	insert into advisor values('17676', '74426');
	insert into advisor values('52019', '90643');
	insert into advisor values('64013', '57180');
	insert into advisor values('45770', '59795');
	insert into advisor values('63288', '99052');
	insert into advisor values('92949', '95030');
	insert into advisor values('83871', '90376');
	insert into advisor values('41671', '35579');
	insert into advisor values('645', '72553');
	insert into advisor values('61444', '81991');
	insert into advisor values('85534', '41930');
	insert into advisor values('35362', '16807');
	insert into advisor values('22417', '22591');
	insert into advisor values('5961', '97302');
	insert into advisor values('35257', '90643');
	insert into advisor values('65299', '81991');
	insert into advisor values('18367', '74426');
	insert into advisor values('68396', '4233');
	insert into advisor values('35905', '16807');
	insert into advisor values('45650', '37687');
	insert into advisor values('27662', '52647');
	insert into advisor values('25077', '79653');
	insert into advisor values('85575', '80759');
	insert into advisor values('760', '28400');
	insert into advisor values('67583', '65931');
	insert into advisor values('63886', '95030');
	insert into advisor values('34055', '14365');
	insert into advisor values('41973', '73623');
	insert into advisor values('30017', '15347');
	insert into advisor values('37581', '36897');
	insert into advisor values('62373', '19368');
	insert into advisor values('57160', '25946');
	insert into advisor values('2967', '73623');
	insert into advisor values('5144', '34175');
	insert into advisor values('5703', '79653');
	insert into advisor values('58170', '19368');
	insert into advisor values('53424', '63395');
	insert into advisor values('17397', '34175');
	insert into advisor values('77588', '35579');
	insert into advisor values('92442', '97302');
	insert into advisor values('42114', '28097');
	insert into advisor values('53699', '14365');
	insert into advisor values('22258', '4034');
	insert into advisor values('2133', '6569');
	insert into advisor values('73606', '16807');
	insert into advisor values('63040', '48507');
	insert into advisor values('74473', '41930');
	insert into advisor values('9659', '31955');
	insert into advisor values('21552', '22591');
	insert into advisor values('45002', '99052');
	insert into advisor values('57213', '42782');
	insert into advisor values('56058', '78699');
	insert into advisor values('84792', '96895');
	insert into advisor values('57185', '4034');
	insert into advisor values('75510', '4034');
	insert into advisor values('42560', '37687');
	insert into advisor values('75252', '63395');
	insert into advisor values('82402', '99052');
	insert into advisor values('17339', '57180');
	insert into advisor values('77148', '79081');
	insert into advisor values('11419', '97302');
	insert into advisor values('37869', '97302');
	insert into advisor values('28977', '74426');
	insert into advisor values('28989', '58558');
	insert into advisor values('92867', '95709');
	insert into advisor values('92703', '97302');
	insert into advisor values('17600', '73623');
	insert into advisor values('32464', '79653');
	insert into advisor values('71426', '48570');
	insert into advisor values('8343', '3335');
	insert into advisor values('41261', '35579');
	insert into advisor values('58469', '15347');
	insert into advisor values('36303', '58558');
	insert into advisor values('30164', '35579');
	insert into advisor values('29920', '35579');
	insert into advisor values('30858', '4233');
	insert into advisor values('88801', '50330');
	insert into advisor values('57780', '16807');
	insert into advisor values('21246', '72553');
	insert into advisor values('34957', '28097');
	insert into advisor values('61998', '3335');
	insert into advisor values('56598', '90376');
	insert into advisor values('463', '19368');
	insert into advisor values('81245', '19368');
	insert into advisor values('21100', '3335');
	insert into advisor values('56', '95030');
	insert into advisor values('64121', '95030');
	insert into advisor values('20489', '97302');
	insert into advisor values('10834', '79081');
	insert into advisor values('63289', '57180');
	insert into advisor values('9953', '95709');
	insert into advisor values('78782', '79653');
	insert into advisor values('5399', '79653');
	insert into advisor values('1367', '28097');
	insert into advisor values('30896', '50885');
	insert into advisor values('12236', '95030');
	insert into advisor values('89297', '22591');
	insert into advisor values('52656', '80759');
	insert into advisor values('18859', '63395');
	insert into advisor values('17377', '96895');
	insert into advisor values('50039', '64871');
	insert into advisor values('78756', '81991');
	insert into advisor values('3833', '14365');
	insert into advisor values('47627', '99052');
	insert into advisor values('65438', '35579');
	insert into advisor values('8912', '79653');
	insert into advisor values('22912', '19368');
	insert into advisor values('99289', '65931');
	insert into advisor values('63039', '52647');
	insert into advisor values('20180', '95030');
	insert into advisor values('35687', '77346');
	insert into advisor values('28409', '34175');
	insert into advisor values('56078', '52647');
	insert into advisor values('48589', '64871');
	insert into advisor values('7956', '50885');
	insert into advisor values('16347', '90376');
	insert into advisor values('75362', '58558');
	insert into advisor values('57242', '4034');
	insert into advisor values('71085', '19368');
	insert into advisor values('89132', '3199');
	insert into advisor values('79763', '42782');
	insert into advisor values('41818', '65931');
	insert into advisor values('667', '90376');
	insert into advisor values('82970', '36897');
	insert into advisor values('68150', '36897');
	insert into advisor values('63243', '28097');
	insert into advisor values('18338', '97302');
	insert into advisor values('51862', '28400');
	insert into advisor values('19203', '79653');
	insert into advisor values('78892', '48570');
	insert into advisor values('67657', '34175');
	insert into advisor values('71628', '58558');
	insert into advisor values('43854', '81991');
	insert into advisor values('123', '59795');
	insert into advisor values('5943', '52647');
	insert into advisor values('56139', '48570');
	insert into advisor values('45680', '79653');
	insert into advisor values('76759', '25946');
	insert into advisor values('26802', '77346');
	insert into advisor values('83747', '78699');
	insert into advisor values('35935', '48570');
	insert into advisor values('8957', '4233');
	insert into advisor values('40481', '16807');
	insert into advisor values('44352', '16807');
	insert into advisor values('73072', '41930');
	insert into advisor values('96206', '81991');
	insert into advisor values('8843', '72553');
	insert into advisor values('41299', '90643');
	insert into advisor values('13403', '14365');
	insert into advisor values('65703', '63287');
	insert into advisor values('49205', '36897');
	insert into advisor values('22345', '63287');
	insert into advisor values('39254', '90376');
	insert into advisor values('80742', '15347');
	insert into advisor values('94726', '80759');
	insert into advisor values('77361', '77346');
	insert into advisor values('52856', '97302');
	insert into advisor values('64138', '15347');
	insert into advisor values('89414', '52647');
	insert into advisor values('22618', '4034');
	insert into advisor values('98870', '43779');
	insert into advisor values('77234', '63395');
	insert into advisor values('56057', '42782');
	insert into advisor values('32881', '16807');
	insert into advisor values('92776', '99052');
	insert into advisor values('82301', '96895');
	insert into advisor values('29959', '57180');
	insert into advisor values('30182', '48507');
	insert into advisor values('96324', '79653');
	insert into advisor values('56232', '63287');
	insert into advisor values('53047', '34175');
	insert into advisor values('87015', '90376');
	insert into advisor values('55329', '48507');
	insert into advisor values('21394', '4034');
	insert into advisor values('61166', '37687');
	insert into advisor values('74530', '72553');
	insert into advisor values('99189', '90376');
	insert into advisor values('34170', '81991');
	insert into advisor values('19220', '16807');
	insert into advisor values('73542', '31955');
	insert into advisor values('97590', '28097');
	insert into advisor values('15613', '50885');
	insert into advisor values('78767', '3199');
	insert into advisor values('51553', '74426');
	insert into advisor values('9947', '79081');
	insert into advisor values('95260', '6569');
	insert into advisor values('87268', '59795');
	insert into advisor values('35', '65931');
	insert into advisor values('99451', '97302');
	insert into advisor values('65396', '50885');
	insert into advisor values('98140', '77346');
	insert into advisor values('62520', '73623');
	insert into advisor values('40044', '3199');
	insert into advisor values('78787', '31955');
	insert into advisor values('85308', '6569');
	insert into advisor values('85809', '43779');
	insert into advisor values('30021', '4233');
	insert into advisor values('54153', '57180');
	insert into advisor values('73387', '74426');
	insert into advisor values('83003', '28097');
	insert into advisor values('13211', '57180');
	insert into advisor values('20803', '58558');
	insert into advisor values('6990', '36897');
	insert into advisor values('2629', '4233');
	insert into advisor values('83398', '74426');
	insert into advisor values('6673', '79081');
	insert into advisor values('81294', '35579');
	insert into advisor values('81566', '63287');
	insert into advisor values('94620', '79653');
	insert into advisor values('57456', '16807');
	insert into advisor values('17424', '81991');
	insert into advisor values('34195', '14365');
	insert into advisor values('94836', '50885');
	insert into advisor values('16543', '79081');
	insert into advisor values('42843', '50330');
	insert into advisor values('82868', '90376');
	insert into advisor values('18499', '99052');
	insert into advisor values('50013', '25946');
	insert into advisor values('53077', '48507');
	insert into advisor values('87439', '19368');
	insert into advisor values('40738', '65931');
	insert into advisor values('13352', '99052');
	insert into advisor values('9605', '52647');
	insert into advisor values('53490', '42782');
	insert into advisor values('57925', '78699');
	insert into advisor values('57055', '42782');
	insert into advisor values('21009', '42782');
	insert into advisor values('8140', '31955');
	insert into advisor values('37284', '35579');
	insert into advisor values('97023', '52647');
	insert into advisor values('5920', '99052');
	insert into advisor values('91915', '28400');
	insert into advisor values('25780', '58558');
	insert into advisor values('26473', '28097');
	insert into advisor values('43032', '42782');
	insert into advisor values('30110', '95030');
	insert into advisor values('88302', '95709');
	insert into advisor values('83002', '74426');
	insert into advisor values('83136', '72553');
	insert into advisor values('61364', '16807');
	insert into advisor values('50598', '95709');
	insert into advisor values('83696', '97302');
	insert into advisor values('33791', '65931');
	insert into advisor values('61403', '65931');
	insert into advisor values('66356', '96895');
	insert into advisor values('12683', '63287');
	insert into advisor values('66106', '73623');
	insert into advisor values('77729', '28097');
	insert into advisor values('52750', '57180');
	insert into advisor values('25256', '95030');
	insert into advisor values('3640', '79653');
	insert into advisor values('22325', '37687');
	insert into advisor values('26730', '41930');
	insert into advisor values('70918', '19368');
	insert into advisor values('91616', '97302');
	insert into advisor values('69285', '41930');
	insert into advisor values('42688', '36897');
	insert into advisor values('24932', '3199');
	insert into advisor values('33817', '90643');
	insert into advisor values('53185', '25946');
	insert into advisor values('85445', '57180');
	insert into advisor values('58081', '42782');
	insert into advisor values('75560', '42782');
	insert into advisor values('80821', '95709');
	insert into advisor values('19536', '28097');
	insert into advisor values('27002', '28097');
	insert into advisor values('39925', '97302');
	insert into advisor values('90194', '3199');
	insert into advisor values('32056', '52647');
	insert into advisor values('67310', '63395');
	insert into advisor values('88389', '77346');
	insert into advisor values('78469', '48570');
	insert into advisor values('46450', '28400');
	insert into advisor values('86651', '41930');
	insert into advisor values('5824', '80759');
	insert into advisor values('11101', '14365');
	insert into advisor values('57431', '79081');
	insert into advisor values('96193', '99052');
	insert into advisor values('55531', '77346');
	insert into advisor values('17192', '77346');
	insert into advisor values('86075', '99052');
	insert into advisor values('81150', '50330');
	insert into advisor values('44206', '73623');
	insert into advisor values('67222', '63395');
	insert into advisor values('47126', '35579');
	insert into advisor values('67407', '28097');
	insert into advisor values('20814', '16807');
	insert into advisor values('25331', '35579');
	insert into advisor values('83838', '14365');
	insert into advisor values('66293', '64871');
	insert into advisor values('56499', '79653');
	insert into advisor values('32368', '48570');
	insert into advisor values('75273', '16807');
	insert into advisor values('67436', '52647');
	insert into advisor values('259', '16807');
	insert into advisor values('858', '81991');
	insert into advisor values('94990', '35579');
	insert into advisor values('89140', '97302');
	insert into advisor values('55940', '48507');
	insert into advisor values('72768', '79081');
	insert into advisor values('96772', '28097');
	insert into advisor values('25068', '99052');
	insert into advisor values('96988', '36897');
	insert into advisor values('44816', '80759');
	insert into advisor values('88417', '43779');
	insert into advisor values('11441', '35579');
	insert into advisor values('4435', '79081');
	insert into advisor values('70362', '64871');
	insert into advisor values('54460', '6569');
	insert into advisor values('7970', '79081');
	insert into advisor values('73807', '25946');
	insert into advisor values('19050', '35579');
	insert into advisor values('67146', '79081');
	insert into advisor values('23934', '99052');
	insert into advisor values('96246', '42782');
	insert into advisor values('21225', '74426');
	insert into advisor values('18554', '72553');
	insert into advisor values('38013', '63287');
	insert into advisor values('98019', '6569');
	insert into advisor values('40457', '95709');
	insert into advisor values('94801', '42782');
	insert into advisor values('65038', '74420');
	insert into advisor values('4383', '35579');
	insert into advisor values('36402', '57180');
	insert into advisor values('9514', '63287');
	insert into advisor values('11195', '31955');
	insert into advisor values('31442', '37687');
	insert into advisor values('51698', '6569');
	insert into advisor values('18809', '79081');
	insert into advisor values('85505', '36897');
	insert into advisor values('64642', '48570');
	insert into advisor values('54612', '3335');
	insert into advisor values('5843', '50330');
	insert into advisor values('90779', '95030');
	insert into advisor values('52371', '4233');
	insert into advisor values('51238', '4034');
	insert into advisor values('62124', '28400');
	insert into advisor values('84039', '95709');
	insert into advisor values('24201', '57180');
	insert into advisor values('31993', '77346');
	insert into advisor values('39520', '97302');
	insert into advisor values('59172', '50330');
	insert into advisor values('21774', '14365');
	insert into advisor values('30957', '14365');
	insert into advisor values('54610', '28400');
	insert into advisor values('72358', '73623');
	insert into advisor values('83204', '58558');
	insert into advisor values('76246', '14365');
	insert into advisor values('80047', '28097');
	insert into advisor values('38545', '63287');
	insert into advisor values('8986', '79653');
	insert into advisor values('89393', '3335');
	insert into advisor values('37103', '79081');
	insert into advisor values('76743', '64871');
	insert into advisor values('81396', '74426');
	insert into advisor values('46066', '79653');
	insert into advisor values('6729', '28097');
	insert into advisor values('90372', '25946');
	insert into advisor values('28352', '36897');
	insert into advisor values('9408', '6569');
	insert into advisor values('15517', '41930');
	insert into advisor values('61402', '63395');
	insert into advisor values('49813', '48507');
	insert into advisor values('72186', '95709');
	insert into advisor values('31250', '14365');
	insert into advisor values('51768', '80759');
	insert into advisor values('18636', '43779');
	insert into advisor values('88993', '41930');
	insert into advisor values('72177', '79653');
	insert into advisor values('99760', '81991');
	insert into advisor values('80227', '16807');
	insert into advisor values('76270', '4034');
	insert into advisor values('42019', '78699');
	insert into advisor values('15726', '72553');
	insert into advisor values('97694', '22591');
	insert into advisor values('16849', '3335');
	insert into advisor values('11262', '77346');
	insert into advisor values('64222', '37687');
	insert into advisor values('91799', '81991');
	insert into advisor values('10727', '6569');
	insert into advisor values('64169', '16807');
	insert into advisor values('81031', '50885');
	insert into advisor values('18941', '34175');
	insert into advisor values('46981', '77346');
	insert into prereq values('376', '130');
	insert into prereq values('760', '169');
	insert into prereq values('403', '345');
	insert into prereq values('353', '647');
	insert into prereq values('629', '139');
	insert into prereq values('608', '864');
	insert into prereq values('158', '408');
	insert into prereq values('496', '489');
	insert into prereq values('241', '486');
	insert into prereq values('958', '969');
	insert into prereq values('591', '403');
	insert into prereq values('656', '659');
	insert into prereq values('864', '634');
	insert into prereq values('559', '500');
	insert into prereq values('209', '780');
	insert into prereq values('603', '735');
	insert into prereq values('804', '947');
	insert into prereq values('545', '947');
	insert into prereq values('353', '694');
	insert into prereq values('692', '761');
	insert into prereq values('774', '258');
	insert into prereq values('747', '927');
	insert into prereq values('496', '416');
	insert into prereq values('544', '702');
	insert into prereq values('608', '421');
	insert into prereq values('313', '731');
	insert into prereq values('258', '137');
	insert into prereq values('486', '371');
	insert into prereq values('224', '227');
	insert into prereq values('972', '958');
	insert into prereq values('359', '694');
	insert into prereq values('998', '319');
	insert into prereq values('392', '875');
	insert into prereq values('443', '852');
	insert into prereq values('324', '408');
	insert into prereq values('805', '774');
	insert into prereq values('242', '304');
	insert into prereq values('795', '123');
	insert into prereq values('169', '603');
	insert into prereq values('774', '769');
	insert into prereq values('958', '735');
	insert into prereq values('692', '426');
	insert into prereq values('958', '139');
	insert into prereq values('663', '998');
	insert into prereq values('586', '468');
	insert into prereq values('254', '877');
	insert into prereq values('802', '666');
	insert into prereq values('820', '371');
	insert into prereq values('902', '130');
	insert into prereq values('362', '242');
	insert into prereq values('359', '818');
	insert into prereq values('664', '489');
	insert into prereq values('276', '403');
	insert into prereq values('582', '487');
	insert into prereq values('694', '254');
	insert into prereq values('841', '818');
	insert into prereq values('852', '133');
	insert into prereq values('843', '324');
	insert into prereq values('810', '966');
	insert into prereq values('628', '340');
	insert into prereq values('242', '594');
	insert into prereq values('292', '399');
	insert into prereq values('618', '352');
	insert into prereq values('664', '704');
	insert into prereq values('793', '791');
	insert into prereq values('692', '774');
	insert into prereq values('324', '857');
	insert into prereq values('612', '123');
	insert into prereq values('991', '598');
	insert into prereq values('544', '254');
	insert into prereq values('852', '267');
	insert into prereq values('792', '814');
	insert into prereq values('133', '852');
	insert into prereq values('496', '443');
	insert into prereq values('338', '133');
	insert into prereq values('399', '664');
	insert into prereq values('747', '272');
	insert into prereq values('696', '101');
	insert into prereq values('403', '352');
	insert into prereq values('545', '318');
	insert into prereq values('634', '864');
	insert into prereq values('947', '494');
	insert into prereq values('647', '792');
	insert into prereq values('631', '681');
	insert into prereq values('236', '984');
	insert into prereq values('362', '696');
	insert into prereq values('875', '458');
	insert into prereq values('457', '544');
	insert into prereq values('704', '416');
	insert into prereq values('656', '559');
	insert into prereq values('272', '275');
	insert into prereq values('338', '852');
	insert into prereq values('780', '345');
	insert into prereq values('458', '696');
	insert into prereq values('239', '628');
	insert into prereq values('411', '401');
	insert into prereq values('830', '748');
	insert into prereq values('558', '130');
	insert into prereq values('877', '599');
	insert into prereq values('349', '612');
